# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_gcmessages_common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import dota2.protobufs.steammessages_pb2 as steammessages__pb2
import dota2.protobufs.gcsdk_gcmessages_pb2 as gcsdk__gcmessages__pb2
import dota2.protobufs.dota_shared_enums_pb2 as dota__shared__enums__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_gcmessages_common.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x1c\x64ota_gcmessages_common.proto\x1a\x13steammessages.proto\x1a\x16gcsdk_gcmessages.proto\x1a\x17\x64ota_shared_enums.proto\"\x8f\x10\n\x18\x43SODOTAGameAccountClient\x12\x18\n\naccount_id\x18\x01 \x01(\rB\x04\x80\x97\"\x01\x12\x0c\n\x04wins\x18\x03 \x01(\r\x12\x0e\n\x06losses\x18\x04 \x01(\r\x12\n\n\x02xp\x18\x0c \x01(\r\x12\r\n\x05level\x18\r \x01(\r\x12\x15\n\rinitial_skill\x18\x0e \x01(\r\x12\x14\n\x0cleaver_count\x18\x0f \x01(\r\x12\x1e\n\x16secondary_leaver_count\x18: \x01(\r\x12\x1f\n\x17low_priority_until_date\x18\x12 \x01(\r\x12$\n\x1cprevent_text_chat_until_date\x18\x14 \x01(\r\x12 \n\x18prevent_voice_until_date\x18\x15 \x01(\r\x12+\n#prevent_public_text_chat_until_date\x18V \x01(\r\x12 \n\x18last_abandoned_game_date\x18\x16 \x01(\r\x12*\n\"last_secondary_abandoned_game_date\x18; \x01(\r\x12\x1c\n\x14leaver_penalty_count\x18\x17 \x01(\r\x12\x1d\n\x15\x63ompleted_game_streak\x18\x18 \x01(\r\x12\x10\n\x08teaching\x18\x1c \x01(\r\x12\x12\n\nleadership\x18\x1d \x01(\r\x12\x10\n\x08\x66riendly\x18\x1e \x01(\r\x12\x11\n\tforgiving\x18\x1f \x01(\r\x12#\n\x1b\x61\x63\x63ount_disabled_until_date\x18& \x01(\r\x12\x1e\n\x16\x61\x63\x63ount_disabled_count\x18\' \x01(\r\x12\x18\n\x10showcase_hero_id\x18( \x01(\r\x12!\n\x19match_disabled_until_date\x18) \x01(\r\x12\x1c\n\x14match_disabled_count\x18* \x01(\r\x12?\n\x14partner_account_type\x18, \x01(\x0e\x32\x13.PartnerAccountType:\x0cPARTNER_NONE\x12\x1d\n\x15partner_account_state\x18- \x01(\r\x12%\n\x1dshutdownlawterminatetimestamp\x18/ \x01(\r\x12$\n\x1clow_priority_games_remaining\x18\x30 \x01(\r\x12\x18\n\x10\x63ompetitive_rank\x18\x31 \x01(\r\x12#\n\x1b\x63\x61libration_games_remaining\x18\x33 \x01(\r\x12\x1d\n\x15solo_competitive_rank\x18\x34 \x01(\r\x12(\n solo_calibration_games_remaining\x18\x36 \x01(\r\x12$\n\x1cgeneral_seasonal_ranked_rank\x18K \x01(\r\x12;\n3general_seasonal_ranked_calibration_games_remaining\x18L \x01(\r\x12,\n$general_seasonal_ranked_games_played\x18P \x01(\r\x12)\n!general_seasonal_ranked_rank_peak\x18Q \x01(\r\x12)\n!general_seasonal_rank_transferred\x18S \x01(\x08\x12!\n\x19solo_seasonal_ranked_rank\x18M \x01(\r\x12\x38\n0solo_seasonal_ranked_calibration_games_remaining\x18N \x01(\r\x12)\n!solo_seasonal_ranked_games_played\x18O \x01(\r\x12&\n\x1esolo_seasonal_ranked_rank_peak\x18R \x01(\r\x12&\n\x1esolo_seasonal_rank_transferred\x18T \x01(\x08\x12\x19\n\x11recruitment_level\x18\x37 \x01(\r\x12\x1d\n\x15has_new_notifications\x18\x38 \x01(\x08\x12\x17\n\x0fis_league_admin\x18\x39 \x01(\x08\x12\x1b\n\x13\x63\x61sual_games_played\x18< \x01(\r\x12%\n\x1dsolo_competitive_games_played\x18= \x01(\r\x12&\n\x1eparty_competitive_games_played\x18> \x01(\r\x12\x1f\n\x17\x63\x61sual_1v1_games_played\x18\x41 \x01(\r\x12%\n\x1d\x63ompetitive_team_games_played\x18\x42 \x01(\r\x12\"\n\x1a\x63urr_all_hero_challenge_id\x18\x43 \x01(\r\x12\x18\n\x10play_time_points\x18\x44 \x01(\r\x12\x15\n\raccount_flags\x18\x45 \x01(\r\x12\x17\n\x0fplay_time_level\x18\x46 \x01(\r\x12+\n#player_behavior_seq_num_last_report\x18G \x01(\r\x12)\n!player_behavior_score_last_report\x18H \x01(\r\x12\'\n\x1fplayer_behavior_report_old_data\x18I \x01(\x08\x12\x1b\n\x13tourney_skill_level\x18J \x01(\r\x12)\n!tourney_recent_participation_date\x18U \x01(\r\x12\x15\n\rfavorite_team\x18W \x01(\r\"\xa8\x03\n\x14\x43MsgLobbyEventPoints\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12;\n\x0e\x61\x63\x63ount_points\x18\x02 \x03(\x0b\x32#.CMsgLobbyEventPoints.AccountPoints\x1a\xc0\x02\n\rAccountPoints\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x15\n\rnormal_points\x18\x02 \x01(\r\x12\x16\n\x0epremium_points\x18\x03 \x01(\r\x12\r\n\x05owned\x18\x04 \x01(\x08\x12\x15\n\rfavorite_team\x18\x05 \x01(\r\x12\x1b\n\x13\x66\x61vorite_team_level\x18\x06 \x01(\r\x12\x13\n\x0bpoints_held\x18\x07 \x01(\r\x12\x1b\n\x13premium_points_held\x18\x08 \x01(\r\x12 \n\x18\x66\x61vorite_team_foil_level\x18\t \x01(\r\x12\x1e\n\x16wager_tokens_remaining\x18\n \x01(\r\x12\x18\n\x10wager_tokens_max\x18\x0b \x01(\r\x12\x1b\n\x13\x61\x63tive_effects_mask\x18\x0c \x01(\x04\"\xb3\x01\n\x14\x43MsgBattleCupVictory\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x10\n\x08win_date\x18\x02 \x01(\r\x12\x13\n\x0bvalid_until\x18\x03 \x01(\r\x12\x13\n\x0bskill_level\x18\x04 \x01(\r\x12\x15\n\rtournament_id\x18\x05 \x01(\r\x12\x13\n\x0b\x64ivision_id\x18\x06 \x01(\r\x12\x0f\n\x07team_id\x18\x07 \x01(\r\x12\x0e\n\x06streak\x18\x08 \x01(\r\"G\n\x1d\x43MsgLobbyBattleCupVictoryList\x12&\n\x07winners\x18\x01 \x03(\x0b\x32\x15.CMsgBattleCupVictory\"0\n\x1d\x43MsgDOTABroadcastNotification\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xb9\x01\n\x14\x43ProtoItemHeroStatue\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12\x1b\n\x13status_effect_index\x18\x02 \x01(\r\x12\x15\n\rsequence_name\x18\x03 \x01(\t\x12\r\n\x05\x63ycle\x18\x04 \x01(\x02\x12\x10\n\x08wearable\x18\x05 \x03(\r\x12\x13\n\x0binscription\x18\x06 \x01(\t\x12\r\n\x05style\x18\x07 \x03(\r\x12\x17\n\x0ftournament_drop\x18\x08 \x01(\x08\"\xa2\x01\n\x16\x43ProtoItemTeamShowcase\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12\x1b\n\x13status_effect_index\x18\x02 \x01(\r\x12\x15\n\rsequence_name\x18\x03 \x01(\t\x12\r\n\x05\x63ycle\x18\x04 \x01(\x02\x12\x10\n\x08wearable\x18\x05 \x03(\r\x12\x13\n\x0binscription\x18\x06 \x01(\t\x12\r\n\x05style\x18\x07 \x03(\r\";\n\x1a\x43MatchPlayerAbilityUpgrade\x12\x0f\n\x07\x61\x62ility\x18\x01 \x01(\r\x12\x0c\n\x04time\x18\x02 \x01(\r\"A\n\x1d\x43MatchAdditionalUnitInventory\x12\x11\n\tunit_name\x18\x01 \x01(\t\x12\r\n\x05items\x18\x02 \x03(\r\"H\n\x19\x43MatchPlayerPermanentBuff\x12\x16\n\x0epermanent_buff\x18\x01 \x01(\r\x12\x13\n\x0bstack_count\x18\x02 \x01(\r\"G\n\x15\x43MatchHeroSelectEvent\x12\x0f\n\x07is_pick\x18\x01 \x01(\x08\x12\x0c\n\x04team\x18\x02 \x01(\r\x12\x0f\n\x07hero_id\x18\x03 \x01(\r\"\x8b\x01\n$CMsgDOTAProcessFantasyScheduledEvent\x12\r\n\x05\x65vent\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x03 \x01(\r\x12\x0e\n\x06season\x18\x04 \x01(\r\x12\x16\n\x0ereference_data\x18\x05 \x01(\r\";\n\x14\x43MsgDOTAHasItemQuery\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07item_id\x18\x02 \x01(\x04\"+\n\x17\x43MsgDOTAHasItemResponse\x12\x10\n\x08has_item\x18\x01 \x01(\x08\"C\n\x18\x43MsgDOTAHasItemDefsQuery\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x13\n\x0bitemdef_ids\x18\x02 \x03(\r\"0\n\x1b\x43MsgDOTAHasItemDefsResponse\x12\x11\n\thas_items\x18\x01 \x01(\x08\"O\n\x1b\x43MsgGCGetPlayerCardItemInfo\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x1c\n\x14player_card_item_ids\x18\x02 \x03(\x04\"\xd0\x01\n#CMsgGCGetPlayerCardItemInfoResponse\x12N\n\x11player_card_infos\x18\x01 \x03(\x0b\x32\x33.CMsgGCGetPlayerCardItemInfoResponse.PlayerCardInfo\x1aY\n\x0ePlayerCardInfo\x12\x1b\n\x13player_card_item_id\x18\x01 \x01(\x04\x12\x12\n\naccount_id\x18\x02 \x01(\r\x12\x16\n\x0epacked_bonuses\x18\x03 \x01(\x04\"F\n\x1f\x43MsgGCToGCFantasySetMatchLeague\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x11\n\tleague_id\x18\x02 \x01(\r\"a\n\x17\x43SODOTAMapLocationState\x12\x18\n\naccount_id\x18\x01 \x01(\rB\x04\x80\x97\"\x01\x12\x19\n\x0blocation_id\x18\x02 \x01(\x05\x42\x04\x80\x97\"\x01\x12\x11\n\tcompleted\x18\x03 \x01(\x08\"*\n\x13\x43MsgLeagueAdminList\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x01 \x03(\r\"\x80\x01\n\x1a\x43\x43ompendiumTimestampedData\x12\x11\n\tgame_time\x18\x01 \x01(\r\x12\x0b\n\x03gpm\x18\x02 \x01(\r\x12\x0b\n\x03xpm\x18\x03 \x01(\r\x12\r\n\x05kills\x18\x04 \x01(\r\x12\x0e\n\x06\x64\x65\x61ths\x18\x05 \x01(\r\x12\x16\n\x0eitem_purchases\x18\x06 \x03(\r\"R\n\x17\x43\x43ompendiumGameTimeline\x12)\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x1b.CCompendiumTimestampedData\x12\x0c\n\x04tags\x18\x02 \x03(\t\">\n\x13\x43\x43ompendiumGameList\x12\'\n\x05games\x18\x01 \x03(\x0b\x32\x18.CCompendiumGameTimeline\"L\n\x14\x43\x41\x64\x64itionalEquipSlot\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\r\x12\x0f\n\x07slot_id\x18\x02 \x01(\r\x12\x11\n\tdef_index\x18\x03 \x01(\r\"\xe2\x0b\n\x16\x43MsgDOTACombatLogEntry\x12;\n\x04type\x18\x01 \x01(\x0e\x32\x15.DOTA_COMBATLOG_TYPES:\x16\x44OTA_COMBATLOG_INVALID\x12\x13\n\x0btarget_name\x18\x02 \x01(\r\x12\x1a\n\x12target_source_name\x18\x03 \x01(\r\x12\x15\n\rattacker_name\x18\x04 \x01(\r\x12\x1a\n\x12\x64\x61mage_source_name\x18\x05 \x01(\r\x12\x16\n\x0einflictor_name\x18\x06 \x01(\r\x12\x1c\n\x14is_attacker_illusion\x18\x07 \x01(\x08\x12\x18\n\x10is_attacker_hero\x18\x08 \x01(\x08\x12\x1a\n\x12is_target_illusion\x18\t \x01(\x08\x12\x16\n\x0eis_target_hero\x18\n \x01(\x08\x12\x1a\n\x12is_visible_radiant\x18\x0b \x01(\x08\x12\x17\n\x0fis_visible_dire\x18\x0c \x01(\x08\x12\r\n\x05value\x18\r \x01(\r\x12\x0e\n\x06health\x18\x0e \x01(\x05\x12\x11\n\ttimestamp\x18\x0f \x01(\x02\x12\x15\n\rstun_duration\x18\x10 \x01(\x02\x12\x15\n\rslow_duration\x18\x11 \x01(\x02\x12\x1c\n\x14is_ability_toggle_on\x18\x12 \x01(\x08\x12\x1d\n\x15is_ability_toggle_off\x18\x13 \x01(\x08\x12\x15\n\rability_level\x18\x14 \x01(\r\x12\x12\n\nlocation_x\x18\x15 \x01(\x02\x12\x12\n\nlocation_y\x18\x16 \x01(\x02\x12\x13\n\x0bgold_reason\x18\x17 \x01(\r\x12\x15\n\rtimestamp_raw\x18\x18 \x01(\x02\x12\x19\n\x11modifier_duration\x18\x19 \x01(\x02\x12\x11\n\txp_reason\x18\x1a \x01(\r\x12\x11\n\tlast_hits\x18\x1b \x01(\r\x12\x15\n\rattacker_team\x18\x1c \x01(\r\x12\x13\n\x0btarget_team\x18\x1d \x01(\r\x12\x18\n\x10obs_wards_placed\x18\x1e \x01(\r\x12\x16\n\x0e\x61ssist_player0\x18\x1f \x01(\r\x12\x16\n\x0e\x61ssist_player1\x18  \x01(\r\x12\x16\n\x0e\x61ssist_player2\x18! \x01(\r\x12\x16\n\x0e\x61ssist_player3\x18\" \x01(\r\x12\x13\n\x0bstack_count\x18# \x01(\r\x12\x17\n\x0fhidden_modifier\x18$ \x01(\x08\x12\x1a\n\x12is_target_building\x18% \x01(\x08\x12\x19\n\x11neutral_camp_type\x18& \x01(\r\x12\x11\n\trune_type\x18\' \x01(\r\x12\x16\n\x0e\x61ssist_players\x18( \x03(\r\x12\x14\n\x0cis_heal_save\x18) \x01(\x08\x12\x1b\n\x13is_ultimate_ability\x18* \x01(\x08\x12\x1b\n\x13\x61ttacker_hero_level\x18+ \x01(\r\x12\x19\n\x11target_hero_level\x18, \x01(\r\x12\x0b\n\x03xpm\x18- \x01(\r\x12\x0b\n\x03gpm\x18. \x01(\r\x12\x16\n\x0e\x65vent_location\x18/ \x01(\r\x12\x16\n\x0etarget_is_self\x18\x30 \x01(\x08\x12\x13\n\x0b\x64\x61mage_type\x18\x31 \x01(\r\x12\x1d\n\x15invisibility_modifier\x18\x32 \x01(\x08\x12\x17\n\x0f\x64\x61mage_category\x18\x33 \x01(\r\x12\x10\n\x08networth\x18\x34 \x01(\r\x12\x15\n\rbuilding_type\x18\x35 \x01(\r\x12!\n\x19modifier_elapsed_duration\x18\x36 \x01(\x02\x12\x18\n\x10silence_modifier\x18\x37 \x01(\x08\x12\x1b\n\x13heal_from_lifesteal\x18\x38 \x01(\x08\x12\x17\n\x0fmodifier_purged\x18\x39 \x01(\x08\x12\x14\n\x0cspell_evaded\x18: \x01(\x08\x12\"\n\x1amotion_controller_modifier\x18; \x01(\x08\x12\x17\n\x0flong_range_kill\x18< \x01(\x08\"\xaf\x07\n\x13\x43MsgDOTAProfileCard\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x1c\n\x14\x62\x61\x63kground_def_index\x18\x02 \x01(\r\x12(\n\x05slots\x18\x03 \x03(\x0b\x32\x19.CMsgDOTAProfileCard.Slot\x12\x14\n\x0c\x62\x61\x64ge_points\x18\x04 \x01(\r\x12\x14\n\x0c\x65vent_points\x18\x05 \x01(\r\x12\x10\n\x08\x65vent_id\x18\x06 \x01(\r\x12\x38\n\x19recent_battle_cup_victory\x18\x07 \x01(\x0b\x32\x15.CMsgBattleCupVictory\x1a\xad\x04\n\x04Slot\x12\x0f\n\x07slot_id\x18\x01 \x01(\r\x12\x30\n\x06trophy\x18\x02 \x01(\x0b\x32 .CMsgDOTAProfileCard.Slot.Trophy\x12,\n\x04stat\x18\x03 \x01(\x0b\x32\x1e.CMsgDOTAProfileCard.Slot.Stat\x12,\n\x04item\x18\x04 \x01(\x0b\x32\x1e.CMsgDOTAProfileCard.Slot.Item\x12,\n\x04hero\x18\x05 \x01(\x0b\x32\x1e.CMsgDOTAProfileCard.Slot.Hero\x12\x34\n\x08\x65moticon\x18\x06 \x01(\x0b\x32\".CMsgDOTAProfileCard.Slot.Emoticon\x1a\x31\n\x06Trophy\x12\x11\n\ttrophy_id\x18\x01 \x01(\r\x12\x14\n\x0ctrophy_score\x18\x02 \x01(\r\x1a[\n\x04Stat\x12?\n\x07stat_id\x18\x01 \x01(\x0e\x32\x1c.CMsgDOTAProfileCard.EStatID:\x10k_eStat_SoloRank\x12\x12\n\nstat_score\x18\x02 \x01(\r\x1a\x30\n\x04Item\x12\x17\n\x0fserialized_item\x18\x01 \x01(\x0c\x12\x0f\n\x07item_id\x18\x02 \x01(\x04\x1a?\n\x04Hero\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12\x11\n\thero_wins\x18\x02 \x01(\r\x12\x13\n\x0bhero_losses\x18\x03 \x01(\r\x1a\x1f\n\x08\x45moticon\x12\x13\n\x0b\x65moticon_id\x18\x01 \x01(\r\"\x93\x01\n\x07\x45StatID\x12\x14\n\x10k_eStat_SoloRank\x10\x01\x12\x15\n\x11k_eStat_PartyRank\x10\x02\x12\x10\n\x0ck_eStat_Wins\x10\x03\x12\x14\n\x10k_eStat_Commends\x10\x04\x12\x17\n\x13k_eStat_GamesPlayed\x10\x05\x12\x1a\n\x16k_eStat_FirstMatchDate\x10\x06\"\x8e\x03\n\x16\x43SODOTAPlayerChallenge\x12\x18\n\naccount_id\x18\x01 \x01(\rB\x04\x80\x97\"\x01\x12\x16\n\x08\x65vent_id\x18\x02 \x01(\rB\x04\x80\x97\"\x01\x12\x15\n\x07slot_id\x18\x03 \x01(\rB\x04\x80\x97\"\x01\x12\x16\n\x0e\x63hallenge_type\x18\x04 \x01(\r\x12\x13\n\x0bint_param_0\x18\x05 \x01(\r\x12\x13\n\x0bint_param_1\x18\x06 \x01(\r\x12\x14\n\x0c\x63reated_time\x18\x07 \x01(\r\x12\x11\n\tcompleted\x18\x08 \x01(\r\x12\x13\n\x0bsequence_id\x18\t \x01(\r\x12\x16\n\x0e\x63hallenge_tier\x18\n \x01(\r\x12\r\n\x05\x66lags\x18\x0b \x01(\r\x12\x10\n\x08\x61ttempts\x18\x0c \x01(\r\x12\x16\n\x0e\x63omplete_limit\x18\r \x01(\r\x12\x12\n\nquest_rank\x18\x0e \x01(\r\"F\n\x06\x45\x46lags\x12\"\n\x1e\x65\x46lag_InstantRerollUncompleted\x10\x01\x12\x18\n\x14\x65\x46lag_QuestChallenge\x10\x02\"L\n#CMsgClientToGCRerollPlayerChallenge\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x13\n\x0bsequence_id\x18\x03 \x01(\r\"\xf0\x01\n#CMsgGCRerollPlayerChallengeResponse\x12M\n\x06result\x18\x01 \x01(\x0e\x32,.CMsgGCRerollPlayerChallengeResponse.EResult:\x0f\x65Result_Success\"z\n\x07\x45Result\x12\x13\n\x0f\x65Result_Success\x10\x00\x12\x13\n\x0f\x65Result_Dropped\x10\x01\x12\x14\n\x10\x65Result_NotFound\x10\x02\x12\x16\n\x12\x65Result_CantReroll\x10\x03\x12\x17\n\x13\x65Result_ServerError\x10\x04\"M\n\x18\x43MsgGCTopCustomGamesList\x12\x18\n\x10top_custom_games\x18\x01 \x03(\x04\x12\x17\n\x0fgame_of_the_day\x18\x02 \x01(\x04\"\xb4\x1a\n\x19\x43MsgDOTARealtimeGameStats\x12\x36\n\x05match\x18\x01 \x01(\x0b\x32\'.CMsgDOTARealtimeGameStats.MatchDetails\x12\x35\n\x05teams\x18\x02 \x03(\x0b\x32&.CMsgDOTARealtimeGameStats.TeamDetails\x12=\n\tbuildings\x18\x03 \x03(\x0b\x32*.CMsgDOTARealtimeGameStats.BuildingDetails\x12\x38\n\ngraph_data\x18\x04 \x01(\x0b\x32$.CMsgDOTARealtimeGameStats.GraphData\x12\x13\n\x0b\x64\x65lta_frame\x18\x05 \x01(\x08\x1a\xc6\x01\n\x0bTeamDetails\x12\x13\n\x0bteam_number\x18\x01 \x01(\r\x12\x0f\n\x07team_id\x18\x02 \x01(\r\x12\x11\n\tteam_name\x18\x03 \x01(\t\x12\x11\n\tteam_logo\x18\x04 \x01(\x06\x12\r\n\x05score\x18\x05 \x01(\r\x12\x39\n\x07players\x18\x06 \x03(\x0b\x32(.CMsgDOTARealtimeGameStats.PlayerDetails\x12\x11\n\tonly_team\x18\x07 \x01(\x08\x12\x0e\n\x06\x63heers\x18\x08 \x01(\r\x1aW\n\x0bItemDetails\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\x05\x12\x0c\n\x04sold\x18\x04 \x01(\x08\x12\x12\n\nstackcount\x18\x05 \x01(\r\x1a\x61\n\x0e\x41\x62ilityDetails\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\r\x12\x10\n\x08\x63ooldown\x18\x04 \x01(\x02\x12\x14\n\x0c\x63ooldown_max\x18\x05 \x01(\x02\x1a\x43\n\x0fHeroToHeroStats\x12\x10\n\x08victimid\x18\x01 \x01(\r\x12\r\n\x05kills\x18\x02 \x01(\r\x12\x0f\n\x07\x61ssists\x18\x03 \x01(\r\x1a\x19\n\x0b\x41\x62ilityList\x12\n\n\x02id\x18\x01 \x03(\r\x1a\xe5\t\n\rPlayerDetails\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x10\n\x08playerid\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04team\x18\x04 \x01(\r\x12\x0e\n\x06heroid\x18\x05 \x01(\r\x12\x14\n\x0chealthpoints\x18\x06 \x01(\r\x12\x17\n\x0fmaxhealthpoints\x18\x07 \x01(\r\x12\x17\n\x0fhealthregenrate\x18\x08 \x01(\x02\x12\x12\n\nmanapoints\x18\t \x01(\r\x12\x15\n\rmaxmanapoints\x18\n \x01(\r\x12\x15\n\rmanaregenrate\x18\x0b \x01(\x02\x12\x15\n\rbase_strength\x18\x0c \x01(\r\x12\x14\n\x0c\x62\x61se_agility\x18\r \x01(\r\x12\x19\n\x11\x62\x61se_intelligence\x18\x0e \x01(\r\x12\x12\n\nbase_armor\x18\x0f \x01(\x05\x12\x16\n\x0e\x62\x61se_movespeed\x18\x10 \x01(\r\x12\x13\n\x0b\x62\x61se_damage\x18\x11 \x01(\r\x12\x10\n\x08strength\x18\x12 \x01(\r\x12\x0f\n\x07\x61gility\x18\x13 \x01(\r\x12\x14\n\x0cintelligence\x18\x14 \x01(\r\x12\r\n\x05\x61rmor\x18\x15 \x01(\x05\x12\x11\n\tmovespeed\x18\x16 \x01(\r\x12\x0e\n\x06\x64\x61mage\x18\x17 \x01(\r\x12\x13\n\x0bhero_damage\x18\x18 \x01(\r\x12\x14\n\x0ctower_damage\x18\x19 \x01(\r\x12<\n\tabilities\x18\x1a \x03(\x0b\x32).CMsgDOTARealtimeGameStats.AbilityDetails\x12\r\n\x05level\x18\x1b \x01(\r\x12\x12\n\nkill_count\x18\x1c \x01(\r\x12\x13\n\x0b\x64\x65\x61th_count\x18\x1d \x01(\r\x12\x15\n\rassists_count\x18\x1e \x01(\r\x12\x14\n\x0c\x64\x65nies_count\x18\x1f \x01(\r\x12\x10\n\x08lh_count\x18  \x01(\r\x12\x14\n\x0chero_healing\x18! \x01(\r\x12\x14\n\x0cgold_per_min\x18\" \x01(\r\x12\x12\n\nxp_per_min\x18# \x01(\r\x12\x10\n\x08net_gold\x18$ \x01(\r\x12\x0c\n\x04gold\x18% \x01(\r\x12\t\n\x01x\x18& \x01(\x02\x12\t\n\x01y\x18\' \x01(\x02\x12\x14\n\x0crespawn_time\x18( \x01(\x05\x12\x19\n\x11ultimate_cooldown\x18) \x01(\r\x12\x13\n\x0bhas_buyback\x18* \x01(\x08\x12\x35\n\x05items\x18+ \x03(\x0b\x32&.CMsgDOTARealtimeGameStats.ItemDetails\x12:\n\nstashitems\x18, \x03(\x0b\x32&.CMsgDOTARealtimeGameStats.ItemDetails\x12@\n\x10itemshoppinglist\x18- \x03(\x0b\x32&.CMsgDOTARealtimeGameStats.ItemDetails\x12;\n\x0blevelpoints\x18. \x03(\x0b\x32&.CMsgDOTARealtimeGameStats.AbilityList\x12\x46\n\x12hero_to_hero_stats\x18/ \x03(\x0b\x32*.CMsgDOTARealtimeGameStats.HeroToHeroStats\x12\x14\n\x0chas_ultimate\x18\x30 \x01(\x08\x12\x19\n\x11has_ultimate_mana\x18\x31 \x01(\x08\x1a\x83\x01\n\x0f\x42uildingDetails\x12\x0c\n\x04team\x18\x02 \x01(\r\x12\x0f\n\x07heading\x18\x03 \x01(\x02\x12\x0c\n\x04lane\x18\x04 \x01(\r\x12\x0c\n\x04tier\x18\x05 \x01(\r\x12\x0c\n\x04type\x18\x06 \x01(\r\x12\t\n\x01x\x18\x07 \x01(\x02\x12\t\n\x01y\x18\x08 \x01(\x02\x12\x11\n\tdestroyed\x18\t \x01(\x08\x1aN\n\x0bKillDetails\x12\x11\n\tplayer_id\x18\x01 \x01(\r\x12\x12\n\ndeath_time\x18\x02 \x01(\x05\x12\x18\n\x10killer_player_id\x18\x03 \x01(\r\x1aV\n\x12\x42roadcasterDetails\x12\x11\n\tplayer_id\x18\x01 \x01(\r\x12\x15\n\rselected_hero\x18\x02 \x01(\r\x12\x16\n\x0eselected_graph\x18\x03 \x01(\r\x1a,\n\x0ePickBanDetails\x12\x0c\n\x04hero\x18\x01 \x01(\r\x12\x0c\n\x04team\x18\x02 \x01(\r\x1a\xfe\x03\n\x0cMatchDetails\x12\x17\n\x0fserver_steam_id\x18\x01 \x01(\x06\x12\x0f\n\x07matchid\x18\x02 \x01(\x04\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x13\n\x0btime_of_day\x18\x04 \x01(\x02\x12\x1d\n\x15is_nightstalker_night\x18\x05 \x01(\x08\x12\x11\n\tgame_time\x18\x06 \x01(\x05\x12\x16\n\x0eteamid_radiant\x18\x08 \x01(\r\x12\x13\n\x0bteamid_dire\x18\t \x01(\r\x12\x38\n\x05picks\x18\n \x03(\x0b\x32).CMsgDOTARealtimeGameStats.PickBanDetails\x12\x37\n\x04\x62\x61ns\x18\x0b \x03(\x0b\x32).CMsgDOTARealtimeGameStats.PickBanDetails\x12\x35\n\x05kills\x18\x0c \x03(\x0b\x32&.CMsgDOTARealtimeGameStats.KillDetails\x12\x43\n\x0c\x62roadcasters\x18\r \x03(\x0b\x32-.CMsgDOTARealtimeGameStats.BroadcasterDetails\x12\x11\n\tgame_mode\x18\x0e \x01(\r\x12\x11\n\tleague_id\x18\x0f \x01(\r\x12\x13\n\x0bsingle_team\x18\x10 \x01(\x08\x12\x13\n\x0b\x63heers_peak\x18\x11 \x01(\r\x1a\xef\x03\n\tGraphData\x12\x12\n\ngraph_gold\x18\x01 \x03(\x05\x12\x10\n\x08graph_xp\x18\x02 \x03(\x05\x12\x12\n\ngraph_kill\x18\x03 \x03(\x05\x12\x13\n\x0bgraph_tower\x18\x04 \x03(\x05\x12\x11\n\tgraph_rax\x18\x05 \x03(\x05\x12N\n\x0eteam_loc_stats\x18\x06 \x03(\x0b\x32\x36.CMsgDOTARealtimeGameStats.GraphData.TeamLocationStats\x1a\x1e\n\rLocationStats\x12\r\n\x05stats\x18\x01 \x03(\x05\x1aZ\n\x11TeamLocationStats\x12\x45\n\tloc_stats\x18\x01 \x03(\x0b\x32\x32.CMsgDOTARealtimeGameStats.GraphData.LocationStats\"[\n\x05\x65Stat\x12\x13\n\x0f\x43reepGoldEarned\x10\x00\x12\x12\n\x0eKillGoldEarned\x10\x01\x12\x1b\n\x17\x44\x65\x61thAndBuybackGoldLost\x10\x02\x12\x0c\n\x08XPEarned\x10\x03\"W\n\teLocation\x12\x0b\n\x07\x42otLane\x10\x00\x12\x0b\n\x07MidLane\x10\x01\x12\x0b\n\x07TopLane\x10\x02\x12\n\n\x06Jungle\x10\x03\x12\x0c\n\x08\x41ncients\x10\x04\x12\t\n\x05Other\x10\x05\"\xaf\x08\n\x1e\x43MsgDOTARealtimeGameStatsTerse\x12;\n\x05match\x18\x01 \x01(\x0b\x32,.CMsgDOTARealtimeGameStatsTerse.MatchDetails\x12:\n\x05teams\x18\x02 \x03(\x0b\x32+.CMsgDOTARealtimeGameStatsTerse.TeamDetails\x12\x42\n\tbuildings\x18\x03 \x03(\x0b\x32/.CMsgDOTARealtimeGameStatsTerse.BuildingDetails\x12=\n\ngraph_data\x18\x04 \x01(\x0b\x32).CMsgDOTARealtimeGameStatsTerse.GraphData\x12\x13\n\x0b\x64\x65lta_frame\x18\x05 \x01(\x08\x1a\xa8\x01\n\x0bTeamDetails\x12\x13\n\x0bteam_number\x18\x01 \x01(\r\x12\x0f\n\x07team_id\x18\x02 \x01(\r\x12\x11\n\tteam_name\x18\x03 \x01(\t\x12\x11\n\tteam_logo\x18\x04 \x01(\x06\x12\r\n\x05score\x18\x05 \x01(\r\x12>\n\x07players\x18\x06 \x03(\x0b\x32-.CMsgDOTARealtimeGameStatsTerse.PlayerDetails\x1a\xfb\x01\n\rPlayerDetails\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x10\n\x08playerid\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04team\x18\x04 \x01(\r\x12\x0e\n\x06heroid\x18\x05 \x01(\r\x12\r\n\x05level\x18\x06 \x01(\r\x12\x12\n\nkill_count\x18\x07 \x01(\r\x12\x13\n\x0b\x64\x65\x61th_count\x18\x08 \x01(\r\x12\x15\n\rassists_count\x18\t \x01(\r\x12\x14\n\x0c\x64\x65nies_count\x18\n \x01(\r\x12\x10\n\x08lh_count\x18\x0b \x01(\r\x12\x0c\n\x04gold\x18\x0c \x01(\r\x12\t\n\x01x\x18\r \x01(\x02\x12\t\n\x01y\x18\x0e \x01(\x02\x1a\x83\x01\n\x0f\x42uildingDetails\x12\x0c\n\x04team\x18\x01 \x01(\r\x12\x0f\n\x07heading\x18\x02 \x01(\x02\x12\x0c\n\x04type\x18\x03 \x01(\r\x12\x0c\n\x04lane\x18\x04 \x01(\r\x12\x0c\n\x04tier\x18\x05 \x01(\r\x12\t\n\x01x\x18\x06 \x01(\x02\x12\t\n\x01y\x18\x07 \x01(\x02\x12\x11\n\tdestroyed\x18\x08 \x01(\x08\x1a\xab\x01\n\x0cMatchDetails\x12\x17\n\x0fserver_steam_id\x18\x01 \x01(\x06\x12\x0f\n\x07matchid\x18\x02 \x01(\x04\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x11\n\tgame_time\x18\x04 \x01(\x05\x12%\n\x1dsteam_broadcaster_account_ids\x18\x06 \x03(\r\x12\x11\n\tgame_mode\x18\x07 \x01(\r\x12\x11\n\tleague_id\x18\x08 \x01(\r\x1a\x1f\n\tGraphData\x12\x12\n\ngraph_gold\x18\x01 \x03(\x05\"?\n CMsgGCToClientMatchGroupsVersion\x12\x1b\n\x13matchgroups_version\x18\x01 \x01(\r\"\xc1\x01\n\x1b\x43MsgDOTASDOHeroStatsHistory\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x11\n\tgame_mode\x18\x02 \x01(\r\x12\x12\n\nlobby_type\x18\x03 \x01(\r\x12\x12\n\nstart_time\x18\x04 \x01(\r\x12\x0b\n\x03won\x18\x05 \x01(\x08\x12\x0b\n\x03gpm\x18\x06 \x01(\r\x12\x0b\n\x03xpm\x18\x07 \x01(\r\x12\r\n\x05kills\x18\x08 \x01(\r\x12\x0e\n\x06\x64\x65\x61ths\x18\t \x01(\r\x12\x0f\n\x07\x61ssists\x18\n \x01(\r\"\xf7\x02\n\x15\x43MsgDOTASeasonRewards\x12.\n\x07rewards\x18\x01 \x03(\x0b\x32\x1d.CMsgDOTASeasonRewards.Reward\x1a\xe0\x01\n\x06Reward\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07itemdef\x18\x02 \x01(\r\x12\x12\n\nimportance\x18\x03 \x01(\r\x12\x12\n\nbase_level\x18\x04 \x01(\r\x12\x14\n\x0crepeat_level\x18\x05 \x01(\r\x12\x41\n\x0breward_type\x18\x06 \x01(\x0e\x32\".CMsgDOTASeasonRewards.ERewardType:\x08\x45\x63onItem\x12\r\n\x05image\x18\x07 \x01(\t\x12\x11\n\taction_id\x18\x08 \x01(\r\x12\x14\n\x0c\x65\x66\x66\x65\x63t_index\x18\t \x01(\r\"K\n\x0b\x45RewardType\x12\x0c\n\x08\x45\x63onItem\x10\x00\x12\x10\n\x0cMysteryWheel\x10\x01\x12\x11\n\rAbilityEffect\x10\x02\x12\t\n\x05Other\x10\x03\"\xae\x02\n\x1a\x43MsgDOTASeasonAchievements\x12=\n\x0c\x61\x63hievements\x18\x01 \x03(\x0b\x32\'.CMsgDOTASeasonAchievements.Achievement\x1a\xd0\x01\n\x0b\x41\x63hievement\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x11\n\taction_id\x18\x04 \x01(\r\x12\x12\n\nmax_grants\x18\x05 \x01(\r\x12\x15\n\rnormal_points\x18\x06 \x01(\r\x12\x1c\n\x14tracking_achievement\x18\x07 \x01(\r\x12\x18\n\x10\x61\x63hievement_goal\x18\x08 \x01(\r\x12\x19\n\x11\x61\x63hievement_level\x18\t \x01(\r\"\xc9\x10\n\x19\x43MsgDOTASeasonPredictions\x12:\n\x0bpredictions\x18\x01 \x03(\x0b\x32%.CMsgDOTASeasonPredictions.Prediction\x12H\n\x13in_game_predictions\x18\x02 \x03(\x0b\x32+.CMsgDOTASeasonPredictions.InGamePrediction\x12)\n!in_game_prediction_count_per_game\x18\x03 \x01(\r\x12\x30\n(in_game_prediction_voting_period_minutes\x18\x04 \x01(\r\x1aS\n\x06\x43hoice\x12\r\n\x05value\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rmin_raw_value\x18\x03 \x01(\r\x12\x15\n\rmax_raw_value\x18\x04 \x01(\r\x1a\x1c\n\x07\x41nswers\x12\x11\n\tanswer_id\x18\x01 \x01(\r\x1a-\n\x0eQueryKeyValues\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\xff\x03\n\nPrediction\x12\x41\n\x04type\x18\x01 \x01(\x0e\x32*.CMsgDOTASeasonPredictions.ePredictionType:\x07Generic\x12\x10\n\x08question\x18\x02 \x01(\t\x12\x32\n\x07\x63hoices\x18\x03 \x03(\x0b\x32!.CMsgDOTASeasonPredictions.Choice\x12\x14\n\x0cselection_id\x18\x04 \x01(\r\x12\x12\n\nstart_date\x18\x05 \x01(\r\x12\x11\n\tlock_date\x18\x06 \x01(\r\x12\x0e\n\x06reward\x18\x07 \x01(\r\x12\x46\n\x0b\x61nswer_type\x18\x08 \x01(\x0e\x32&.CMsgDOTASeasonPredictions.eAnswerType:\tSingleInt\x12\x11\n\tanswer_id\x18\t \x01(\r\x12\x33\n\x07\x61nswers\x18\n \x03(\x0b\x32\".CMsgDOTASeasonPredictions.Answers\x12\x12\n\nquery_name\x18\x0b \x01(\t\x12\x19\n\x11query_bind_params\x18\x0c \x03(\r\x12\x1c\n\x14lock_on_selection_id\x18\r \x01(\r\x12\x1f\n\x17lock_on_selection_value\x18\x0e \x01(\r\x12\x1d\n\x15lock_on_selection_set\x18\x0f \x01(\x08\x1a\xe8\x04\n\x10InGamePrediction\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x41\n\x04type\x18\x03 \x01(\x0e\x32*.CMsgDOTASeasonPredictions.ePredictionType:\x07Generic\x12L\n\x05group\x18\x04 \x01(\x0e\x32\x32.CMsgDOTASeasonPredictions.eRandomSelectionGroup_t:\tEarlyGame\x12\x10\n\x08question\x18\x05 \x01(\t\x12\x32\n\x07\x63hoices\x18\x06 \x03(\x0b\x32!.CMsgDOTASeasonPredictions.Choice\x12\x17\n\x0frequired_heroes\x18\x07 \x03(\t\x12\x12\n\nquery_name\x18\x08 \x01(\t\x12?\n\x0cquery_values\x18\t \x03(\x0b\x32).CMsgDOTASeasonPredictions.QueryKeyValues\x12Z\n\x16\x61nswer_resolution_type\x18\n \x01(\x0e\x32,.CMsgDOTASeasonPredictions.eResolutionType_t:\x0cInvalidQuery\x12\x17\n\x0fpoints_to_grant\x18\x0b \x01(\r\x12\x15\n\rreward_action\x18\x0c \x01(\r\x12\x1d\n\x15\x64\x65\x62ug_force_selection\x18\r \x01(\r\x12J\n\x0eraw_value_type\x18\x0e \x01(\x0e\x32*.CMsgDOTASeasonPredictions.eRawValueType_t:\x06Number\"V\n\x0f\x65PredictionType\x12\x0b\n\x07Generic\x10\x00\x12\x08\n\x04Hero\x10\x01\x12\x08\n\x04Team\x10\x02\x12\n\n\x06Player\x10\x03\x12\x0b\n\x07Special\x10\x04\x12\t\n\x05YesNo\x10\x05\"\x91\x01\n\x0b\x65\x41nswerType\x12\r\n\tSingleInt\x10\x00\x12\x0f\n\x0bSingleFloat\x10\x01\x12\x0f\n\x0bMultipleInt\x10\x02\x12\x11\n\rMultipleFloat\x10\x03\x12\x0e\n\nAnswerTeam\x10\x04\x12\x0e\n\nSingleTime\x10\x05\x12\x10\n\x0cMultipleTime\x10\x06\x12\x0c\n\x08NoAnswer\x10\x07\"\xd4\x01\n\x11\x65ResolutionType_t\x12\x10\n\x0cInvalidQuery\x10\x00\x12\x14\n\x10\x46irstToPassQuery\x10\x01\x12\x13\n\x0fLastToPassQuery\x10\x02\x12\x16\n\x12LastRemainingQuery\x10\x03\x12\x12\n\x0eMaxToPassQuery\x10\x04\x12\x12\n\x0eMinToPassQuery\x10\x05\x12\x0c\n\x08SumQuery\x10\x06\x12\x19\n\x15MaxTeamSumToPassQuery\x10\x07\x12\x19\n\x15MinTeamSumToPassQuery\x10\x08\"N\n\x17\x65RandomSelectionGroup_t\x12\r\n\tEarlyGame\x10\x00\x12\x0b\n\x07MidGame\x10\x01\x12\x0c\n\x08LateGame\x10\x02\x12\t\n\x05\x43ount\x10\x03\"\'\n\x0f\x65RawValueType_t\x12\n\n\x06Number\x10\x00\x12\x08\n\x04Time\x10\x01\"\xa8\x18\n\rCMsgDOTAMatch\x12\x10\n\x08\x64uration\x18\x03 \x01(\r\x12\x11\n\tstartTime\x18\x04 \x01(\x07\x12&\n\x07players\x18\x05 \x03(\x0b\x32\x15.CMsgDOTAMatch.Player\x12\x10\n\x08match_id\x18\x06 \x01(\x04\x12\x14\n\x0ctower_status\x18\x08 \x03(\r\x12\x17\n\x0f\x62\x61rracks_status\x18\t \x03(\r\x12\x0f\n\x07\x63luster\x18\n \x01(\r\x12\x18\n\x10\x66irst_blood_time\x18\x0c \x01(\r\x12\x13\n\x0breplay_salt\x18\r \x01(\x07\x12\x11\n\tserver_ip\x18\x0e \x01(\x07\x12\x13\n\x0bserver_port\x18\x0f \x01(\r\x12\x12\n\nlobby_type\x18\x10 \x01(\r\x12\x15\n\rhuman_players\x18\x11 \x01(\r\x12\x15\n\raverage_skill\x18\x12 \x01(\r\x12\x14\n\x0cgame_balance\x18\x13 \x01(\x02\x12\x17\n\x0fradiant_team_id\x18\x14 \x01(\r\x12\x14\n\x0c\x64ire_team_id\x18\x15 \x01(\r\x12\x10\n\x08leagueid\x18\x16 \x01(\r\x12\x19\n\x11radiant_team_name\x18\x17 \x01(\t\x12\x16\n\x0e\x64ire_team_name\x18\x18 \x01(\t\x12\x19\n\x11radiant_team_logo\x18\x19 \x01(\x04\x12\x16\n\x0e\x64ire_team_logo\x18\x1a \x01(\x04\x12\x1d\n\x15radiant_team_complete\x18\x1b \x01(\r\x12\x1a\n\x12\x64ire_team_complete\x18\x1c \x01(\r\x12\x16\n\x0epositive_votes\x18\x1d \x01(\r\x12\x16\n\x0enegative_votes\x18\x1e \x01(\r\x12\x35\n\tgame_mode\x18\x1f \x01(\x0e\x32\x0e.DOTA_GameMode:\x12\x44OTA_GAMEMODE_NONE\x12*\n\npicks_bans\x18  \x03(\x0b\x32\x16.CMatchHeroSelectEvent\x12\x15\n\rmatch_seq_num\x18! \x01(\x04\x12\x42\n\x0creplay_state\x18\" \x01(\x0e\x32\x1a.CMsgDOTAMatch.ReplayState:\x10REPLAY_AVAILABLE\x12\x18\n\x10radiant_guild_id\x18# \x01(\r\x12\x15\n\rdire_guild_id\x18$ \x01(\r\x12\x18\n\x10radiant_team_tag\x18% \x01(\t\x12\x15\n\rdire_team_tag\x18& \x01(\t\x12\x11\n\tseries_id\x18\' \x01(\r\x12\x13\n\x0bseries_type\x18( \x01(\r\x12?\n\x14\x62roadcaster_channels\x18+ \x03(\x0b\x32!.CMsgDOTAMatch.BroadcasterChannel\x12\x0e\n\x06\x65ngine\x18, \x01(\r\x12\x37\n\x10\x63ustom_game_data\x18- \x01(\x0b\x32\x1d.CMsgDOTAMatch.CustomGameData\x12\x13\n\x0bmatch_flags\x18. \x01(\r\x12\x1c\n\x14private_metadata_key\x18/ \x01(\x07\x12\x1a\n\x12radiant_team_score\x18\x30 \x01(\r\x12\x17\n\x0f\x64ire_team_score\x18\x31 \x01(\r\x12>\n\rmatch_outcome\x18\x32 \x01(\x0e\x32\x0e.EMatchOutcome:\x17k_EMatchOutcome_Unknown\x12\x15\n\rtournament_id\x18\x33 \x01(\r\x12\x18\n\x10tournament_round\x18\x34 \x01(\r\x12\x19\n\x11pre_game_duration\x18\x35 \x01(\r\x1a\x99\x0b\n\x06Player\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x13\n\x0bplayer_slot\x18\x02 \x01(\r\x12\x0f\n\x07hero_id\x18\x03 \x01(\r\x12\x0e\n\x06item_0\x18\x04 \x01(\r\x12\x0e\n\x06item_1\x18\x05 \x01(\r\x12\x0e\n\x06item_2\x18\x06 \x01(\r\x12\x0e\n\x06item_3\x18\x07 \x01(\r\x12\x0e\n\x06item_4\x18\x08 \x01(\r\x12\x0e\n\x06item_5\x18\t \x01(\r\x12\"\n\x1a\x65xpected_team_contribution\x18\n \x01(\x02\x12\x15\n\rscaled_metric\x18\x0b \x01(\x02\x12\x15\n\rprevious_rank\x18\x0c \x01(\r\x12\x13\n\x0brank_change\x18\r \x01(\x11\x12\x11\n\tsolo_rank\x18\x31 \x01(\x08\x12\x15\n\rseasonal_rank\x18\x35 \x01(\x08\x12\r\n\x05kills\x18\x0e \x01(\r\x12\x0e\n\x06\x64\x65\x61ths\x18\x0f \x01(\r\x12\x0f\n\x07\x61ssists\x18\x10 \x01(\r\x12\x15\n\rleaver_status\x18\x11 \x01(\r\x12\x0c\n\x04gold\x18\x12 \x01(\r\x12\x11\n\tlast_hits\x18\x13 \x01(\r\x12\x0e\n\x06\x64\x65nies\x18\x14 \x01(\r\x12\x14\n\x0cgold_per_min\x18\x15 \x01(\r\x12\x12\n\nXP_per_min\x18\x16 \x01(\r\x12\x12\n\ngold_spent\x18\x17 \x01(\r\x12\x13\n\x0bhero_damage\x18\x18 \x01(\r\x12\x14\n\x0ctower_damage\x18\x19 \x01(\r\x12\x14\n\x0chero_healing\x18\x1a \x01(\r\x12\r\n\x05level\x18\x1b \x01(\r\x12\x16\n\x0etime_last_seen\x18\x1c \x01(\r\x12\x13\n\x0bplayer_name\x18\x1d \x01(\t\x12\x1d\n\x15support_ability_value\x18\x1e \x01(\r\x12\x18\n\x10\x66\x65\x65\x64ing_detected\x18  \x01(\x08\x12\x13\n\x0bsearch_rank\x18\" \x01(\r\x12\x1f\n\x17search_rank_uncertainty\x18# \x01(\r\x12\x1f\n\x17rank_uncertainty_change\x18$ \x01(\x05\x12\x17\n\x0fhero_play_count\x18% \x01(\r\x12\x10\n\x08party_id\x18& \x01(\x06\x12\x1a\n\x12scaled_hero_damage\x18\x36 \x01(\r\x12\x1b\n\x13scaled_tower_damage\x18\x37 \x01(\r\x12\x1b\n\x13scaled_hero_healing\x18\x38 \x01(\r\x12\x14\n\x0cscaled_kills\x18\' \x01(\x02\x12\x15\n\rscaled_deaths\x18( \x01(\x02\x12\x16\n\x0escaled_assists\x18) \x01(\x02\x12\x19\n\x11\x63laimed_farm_gold\x18* \x01(\r\x12\x14\n\x0csupport_gold\x18+ \x01(\r\x12\x16\n\x0e\x63laimed_denies\x18, \x01(\r\x12\x16\n\x0e\x63laimed_misses\x18- \x01(\r\x12\x0e\n\x06misses\x18. \x01(\r\x12\x35\n\x10\x61\x62ility_upgrades\x18/ \x03(\x0b\x32\x1b.CMatchPlayerAbilityUpgrade\x12\x42\n\x1a\x61\x64\x64itional_units_inventory\x18\x30 \x03(\x0b\x32\x1e.CMatchAdditionalUnitInventory\x12\x33\n\x0fpermanent_buffs\x18\x39 \x03(\x0b\x32\x1a.CMatchPlayerPermanentBuff\x12>\n\x10\x63ustom_game_data\x18\x32 \x01(\x0b\x32$.CMsgDOTAMatch.Player.CustomGameData\x12\x1a\n\x12\x61\x63tive_battle_pass\x18\x33 \x01(\x08\x12\x11\n\tnet_worth\x18\x34 \x01(\r\x12\x16\n\x0e\x62ot_difficulty\x18: \x01(\r\x1a\x33\n\x0e\x43ustomGameData\x12\x11\n\tdota_team\x18\x01 \x01(\r\x12\x0e\n\x06winner\x18\x02 \x01(\x08\x1a\x33\n\x0f\x42roadcasterInfo\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a\x91\x01\n\x12\x42roadcasterChannel\x12\x14\n\x0c\x63ountry_code\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x39\n\x11\x62roadcaster_infos\x18\x03 \x03(\x0b\x32\x1e.CMsgDOTAMatch.BroadcasterInfo\x12\x15\n\rlanguage_code\x18\x04 \x01(\t\x1a:\n\x0e\x43ustomGameData\x12\x16\n\x0e\x63ustom_game_id\x18\x01 \x01(\x04\x12\x10\n\x08map_name\x18\x02 \x01(\t\"P\n\x0bReplayState\x12\x14\n\x10REPLAY_AVAILABLE\x10\x00\x12\x17\n\x13REPLAY_NOT_RECORDED\x10\x01\x12\x12\n\x0eREPLAY_EXPIRED\x10\x02\"\x86\x01\n\x0e\x43MsgPlayerCard\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x33\n\rstat_modifier\x18\x02 \x03(\x0b\x32\x1c.CMsgPlayerCard.StatModifier\x1a+\n\x0cStatModifier\x12\x0c\n\x04stat\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r\"\xa9\x03\n\x1a\x43MsgDOTAFantasyPlayerStats\x12\x19\n\x11player_account_id\x18\x01 \x01(\r\x12\x10\n\x08match_id\x18\x02 \x01(\x04\x12\x17\n\x0fmatch_completed\x18\x03 \x01(\x08\x12\x0f\n\x07team_id\x18\x04 \x01(\r\x12\x11\n\tleague_id\x18\x05 \x01(\r\x12\r\n\x05\x64\x65lay\x18\x06 \x01(\r\x12\x11\n\tseries_id\x18\x07 \x01(\r\x12\x13\n\x0bseries_type\x18\x08 \x01(\r\x12\r\n\x05kills\x18\n \x01(\r\x12\x0e\n\x06\x64\x65\x61ths\x18\x0b \x01(\r\x12\n\n\x02\x63s\x18\x0c \x01(\r\x12\x0b\n\x03gpm\x18\r \x01(\x02\x12\x13\n\x0btower_kills\x18\x0e \x01(\r\x12\x14\n\x0croshan_kills\x18\x0f \x01(\r\x12\x1f\n\x17teamfight_participation\x18\x10 \x01(\x02\x12\x14\n\x0cwards_placed\x18\x11 \x01(\r\x12\x15\n\rcamps_stacked\x18\x12 \x01(\r\x12\x15\n\rrunes_grabbed\x18\x13 \x01(\r\x12\x13\n\x0b\x66irst_blood\x18\x14 \x01(\r\x12\r\n\x05stuns\x18\x15 \x01(\x02\"O\n\x1f\x43MsgDOTAFantasyPlayerMatchStats\x12,\n\x07matches\x18\x01 \x03(\x0b\x32\x1b.CMsgDOTAFantasyPlayerStats\"\xe1\x05\n\x14\x43MsgDOTABotDebugInfo\x12\'\n\x04\x62ots\x18\x01 \x03(\x0b\x32\x19.CMsgDOTABotDebugInfo.Bot\x12\x1c\n\x14\x64\x65sire_push_lane_top\x18\x02 \x01(\x02\x12\x1c\n\x14\x64\x65sire_push_lane_mid\x18\x03 \x01(\x02\x12\x1c\n\x14\x64\x65sire_push_lane_bot\x18\x04 \x01(\x02\x12\x1e\n\x16\x64\x65sire_defend_lane_top\x18\x05 \x01(\x02\x12\x1e\n\x16\x64\x65sire_defend_lane_mid\x18\x06 \x01(\x02\x12\x1e\n\x16\x64\x65sire_defend_lane_bot\x18\x07 \x01(\x02\x12\x1c\n\x14\x64\x65sire_farm_lane_top\x18\x08 \x01(\x02\x12\x1c\n\x14\x64\x65sire_farm_lane_mid\x18\t \x01(\x02\x12\x1c\n\x14\x64\x65sire_farm_lane_bot\x18\n \x01(\x02\x12\x1a\n\x12\x64\x65sire_farm_roshan\x18\x0b \x01(\x02\x1a\xef\x02\n\x03\x42ot\x12\x17\n\x0fplayer_owner_id\x18\x01 \x01(\r\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\x12\x12\n\ndifficulty\x18\x03 \x01(\r\x12\x15\n\rpower_current\x18\x04 \x01(\r\x12\x11\n\tpower_max\x18\x05 \x01(\r\x12\x15\n\rmove_target_x\x18\x06 \x01(\r\x12\x15\n\rmove_target_y\x18\x07 \x01(\r\x12\x15\n\rmove_target_z\x18\x08 \x01(\r\x12\x16\n\x0e\x61\x63tive_mode_id\x18\t \x01(\r\x12-\n\x05modes\x18\n \x03(\x0b\x32\x1e.CMsgDOTABotDebugInfo.Bot.Mode\x1at\n\x04Mode\x12\x0f\n\x07mode_id\x18\x01 \x01(\r\x12\x0e\n\x06\x64\x65sire\x18\x02 \x01(\x02\x12\x15\n\rtarget_entity\x18\x03 \x01(\r\x12\x10\n\x08target_x\x18\x04 \x01(\r\x12\x10\n\x08target_y\x18\x05 \x01(\r\x12\x10\n\x08target_z\x18\x06 \x01(\r*U\n\x11\x45SpecialPingValue\x12\x1f\n\x1ak_ESpecialPingValue_NoData\x10\xfe\x7f\x12\x1f\n\x1ak_ESpecialPingValue_Failed\x10\xff\x7f*\x86\x05\n\x12\x45\x44OTAGCSessionNeed\x12 \n\x1ck_EDOTAGCSessionNeed_Unknown\x10\x00\x12,\n(k_EDOTAGCSessionNeed_UserNoSessionNeeded\x10\x64\x12)\n%k_EDOTAGCSessionNeed_UserInOnlineGame\x10\x65\x12(\n$k_EDOTAGCSessionNeed_UserInLocalGame\x10\x66\x12-\n)k_EDOTAGCSessionNeed_UserInUIWasConnected\x10g\x12/\n+k_EDOTAGCSessionNeed_UserInUINeverConnected\x10h\x12&\n\"k_EDOTAGCSessionNeed_UserTutorials\x10i\x12\x31\n-k_EDOTAGCSessionNeed_UserInUIWasConnectedIdle\x10j\x12\x33\n/k_EDOTAGCSessionNeed_UserInUINeverConnectedIdle\x10k\x12*\n%k_EDOTAGCSessionNeed_GameServerOnline\x10\xc8\x01\x12)\n$k_EDOTAGCSessionNeed_GameServerLocal\x10\xc9\x01\x12(\n#k_EDOTAGCSessionNeed_GameServerIdle\x10\xca\x01\x12)\n$k_EDOTAGCSessionNeed_GameServerRelay\x10\xcb\x01\x12/\n*k_EDOTAGCSessionNeed_GameServerLocalUpload\x10\xcc\x01*\xf6\x01\n\x15\x44OTA_TournamentEvents\x12\x12\n\x0eTE_FIRST_BLOOD\x10\x00\x12\x0f\n\x0bTE_GAME_END\x10\x01\x12\x11\n\rTE_MULTI_KILL\x10\x02\x12\x10\n\x0cTE_HERO_DENY\x10\x03\x12\x11\n\rTE_AEGIS_DENY\x10\x04\x12\x13\n\x0fTE_AEGIS_STOLEN\x10\x05\x12\x0e\n\nTE_GODLIKE\x10\x06\x12\x13\n\x0fTE_COURIER_KILL\x10\x07\x12\x0f\n\x0bTE_ECHOSLAM\x10\x08\x12\r\n\tTE_RAPIER\x10\t\x12\x13\n\x0fTE_EARLY_ROSHAN\x10\n\x12\x11\n\rTE_BLACK_HOLE\x10\x0b*\x87\n\n\x14\x44OTA_COMBATLOG_TYPES\x12#\n\x16\x44OTA_COMBATLOG_INVALID\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x19\n\x15\x44OTA_COMBATLOG_DAMAGE\x10\x00\x12\x17\n\x13\x44OTA_COMBATLOG_HEAL\x10\x01\x12\x1f\n\x1b\x44OTA_COMBATLOG_MODIFIER_ADD\x10\x02\x12\"\n\x1e\x44OTA_COMBATLOG_MODIFIER_REMOVE\x10\x03\x12\x18\n\x14\x44OTA_COMBATLOG_DEATH\x10\x04\x12\x1a\n\x16\x44OTA_COMBATLOG_ABILITY\x10\x05\x12\x17\n\x13\x44OTA_COMBATLOG_ITEM\x10\x06\x12\x1b\n\x17\x44OTA_COMBATLOG_LOCATION\x10\x07\x12\x17\n\x13\x44OTA_COMBATLOG_GOLD\x10\x08\x12\x1d\n\x19\x44OTA_COMBATLOG_GAME_STATE\x10\t\x12\x15\n\x11\x44OTA_COMBATLOG_XP\x10\n\x12\x1b\n\x17\x44OTA_COMBATLOG_PURCHASE\x10\x0b\x12\x1a\n\x16\x44OTA_COMBATLOG_BUYBACK\x10\x0c\x12\"\n\x1e\x44OTA_COMBATLOG_ABILITY_TRIGGER\x10\r\x12\x1e\n\x1a\x44OTA_COMBATLOG_PLAYERSTATS\x10\x0e\x12\x1c\n\x18\x44OTA_COMBATLOG_MULTIKILL\x10\x0f\x12\x1d\n\x19\x44OTA_COMBATLOG_KILLSTREAK\x10\x10\x12%\n!DOTA_COMBATLOG_TEAM_BUILDING_KILL\x10\x11\x12\x1e\n\x1a\x44OTA_COMBATLOG_FIRST_BLOOD\x10\x12\x12#\n\x1f\x44OTA_COMBATLOG_MODIFIER_REFRESH\x10\x13\x12%\n!DOTA_COMBATLOG_NEUTRAL_CAMP_STACK\x10\x14\x12\x1e\n\x1a\x44OTA_COMBATLOG_PICKUP_RUNE\x10\x15\x12%\n!DOTA_COMBATLOG_REVEALED_INVISIBLE\x10\x16\x12\x1d\n\x19\x44OTA_COMBATLOG_HERO_SAVED\x10\x17\x12 \n\x1c\x44OTA_COMBATLOG_MANA_RESTORED\x10\x18\x12\x1f\n\x1b\x44OTA_COMBATLOG_HERO_LEVELUP\x10\x19\x12#\n\x1f\x44OTA_COMBATLOG_BOTTLE_HEAL_ALLY\x10\x1a\x12 \n\x1c\x44OTA_COMBATLOG_ENDGAME_STATS\x10\x1b\x12$\n DOTA_COMBATLOG_INTERRUPT_CHANNEL\x10\x1c\x12\x1e\n\x1a\x44OTA_COMBATLOG_ALLIED_GOLD\x10\x1d\x12\x1e\n\x1a\x44OTA_COMBATLOG_AEGIS_TAKEN\x10\x1e\x12\x1e\n\x1a\x44OTA_COMBATLOG_MANA_DAMAGE\x10\x1f\x12,\n(DOTA_COMBATLOG_PHYSICAL_DAMAGE_PREVENTED\x10 \x12 \n\x1c\x44OTA_COMBATLOG_UNIT_SUMMONED\x10!\x12\x1f\n\x1b\x44OTA_COMBATLOG_ATTACK_EVADE\x10\"\x12\x1b\n\x17\x44OTA_COMBATLOG_TREE_CUT\x10#\x12\"\n\x1e\x44OTA_COMBATLOG_SUCCESSFUL_SCAN\x10$\x12!\n\x1d\x44OTA_COMBATLOG_END_KILLSTREAK\x10%B\x05H\x01\x90\x01\x00')
  ,
  dependencies=[steammessages__pb2.DESCRIPTOR,gcsdk__gcmessages__pb2.DESCRIPTOR,dota__shared__enums__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_ESPECIALPINGVALUE = _descriptor.EnumDescriptor(
  name='ESpecialPingValue',
  full_name='ESpecialPingValue',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ESpecialPingValue_NoData', index=0, number=16382,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESpecialPingValue_Failed', index=1, number=16383,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=20041,
  serialized_end=20126,
)
_sym_db.RegisterEnumDescriptor(_ESPECIALPINGVALUE)

ESpecialPingValue = enum_type_wrapper.EnumTypeWrapper(_ESPECIALPINGVALUE)
_EDOTAGCSESSIONNEED = _descriptor.EnumDescriptor(
  name='EDOTAGCSessionNeed',
  full_name='EDOTAGCSessionNeed',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGCSessionNeed_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGCSessionNeed_UserNoSessionNeeded', index=1, number=100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGCSessionNeed_UserInOnlineGame', index=2, number=101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGCSessionNeed_UserInLocalGame', index=3, number=102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGCSessionNeed_UserInUIWasConnected', index=4, number=103,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGCSessionNeed_UserInUINeverConnected', index=5, number=104,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGCSessionNeed_UserTutorials', index=6, number=105,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGCSessionNeed_UserInUIWasConnectedIdle', index=7, number=106,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGCSessionNeed_UserInUINeverConnectedIdle', index=8, number=107,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGCSessionNeed_GameServerOnline', index=9, number=200,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGCSessionNeed_GameServerLocal', index=10, number=201,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGCSessionNeed_GameServerIdle', index=11, number=202,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGCSessionNeed_GameServerRelay', index=12, number=203,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAGCSessionNeed_GameServerLocalUpload', index=13, number=204,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=20129,
  serialized_end=20775,
)
_sym_db.RegisterEnumDescriptor(_EDOTAGCSESSIONNEED)

EDOTAGCSessionNeed = enum_type_wrapper.EnumTypeWrapper(_EDOTAGCSESSIONNEED)
_DOTA_TOURNAMENTEVENTS = _descriptor.EnumDescriptor(
  name='DOTA_TournamentEvents',
  full_name='DOTA_TournamentEvents',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TE_FIRST_BLOOD', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TE_GAME_END', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TE_MULTI_KILL', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TE_HERO_DENY', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TE_AEGIS_DENY', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TE_AEGIS_STOLEN', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TE_GODLIKE', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TE_COURIER_KILL', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TE_ECHOSLAM', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TE_RAPIER', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TE_EARLY_ROSHAN', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TE_BLACK_HOLE', index=11, number=11,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=20778,
  serialized_end=21024,
)
_sym_db.RegisterEnumDescriptor(_DOTA_TOURNAMENTEVENTS)

DOTA_TournamentEvents = enum_type_wrapper.EnumTypeWrapper(_DOTA_TOURNAMENTEVENTS)
_DOTA_COMBATLOG_TYPES = _descriptor.EnumDescriptor(
  name='DOTA_COMBATLOG_TYPES',
  full_name='DOTA_COMBATLOG_TYPES',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_INVALID', index=0, number=-1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_DAMAGE', index=1, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_HEAL', index=2, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_MODIFIER_ADD', index=3, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_MODIFIER_REMOVE', index=4, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_DEATH', index=5, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_ABILITY', index=6, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_ITEM', index=7, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_LOCATION', index=8, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_GOLD', index=9, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_GAME_STATE', index=10, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_XP', index=11, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_PURCHASE', index=12, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_BUYBACK', index=13, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_ABILITY_TRIGGER', index=14, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_PLAYERSTATS', index=15, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_MULTIKILL', index=16, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_KILLSTREAK', index=17, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_TEAM_BUILDING_KILL', index=18, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_FIRST_BLOOD', index=19, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_MODIFIER_REFRESH', index=20, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_NEUTRAL_CAMP_STACK', index=21, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_PICKUP_RUNE', index=22, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_REVEALED_INVISIBLE', index=23, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_HERO_SAVED', index=24, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_MANA_RESTORED', index=25, number=24,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_HERO_LEVELUP', index=26, number=25,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_BOTTLE_HEAL_ALLY', index=27, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_ENDGAME_STATS', index=28, number=27,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_INTERRUPT_CHANNEL', index=29, number=28,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_ALLIED_GOLD', index=30, number=29,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_AEGIS_TAKEN', index=31, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_MANA_DAMAGE', index=32, number=31,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_PHYSICAL_DAMAGE_PREVENTED', index=33, number=32,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_UNIT_SUMMONED', index=34, number=33,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_ATTACK_EVADE', index=35, number=34,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_TREE_CUT', index=36, number=35,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_SUCCESSFUL_SCAN', index=37, number=36,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_END_KILLSTREAK', index=38, number=37,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=21027,
  serialized_end=22314,
)
_sym_db.RegisterEnumDescriptor(_DOTA_COMBATLOG_TYPES)

DOTA_COMBATLOG_TYPES = enum_type_wrapper.EnumTypeWrapper(_DOTA_COMBATLOG_TYPES)
k_ESpecialPingValue_NoData = 16382
k_ESpecialPingValue_Failed = 16383
k_EDOTAGCSessionNeed_Unknown = 0
k_EDOTAGCSessionNeed_UserNoSessionNeeded = 100
k_EDOTAGCSessionNeed_UserInOnlineGame = 101
k_EDOTAGCSessionNeed_UserInLocalGame = 102
k_EDOTAGCSessionNeed_UserInUIWasConnected = 103
k_EDOTAGCSessionNeed_UserInUINeverConnected = 104
k_EDOTAGCSessionNeed_UserTutorials = 105
k_EDOTAGCSessionNeed_UserInUIWasConnectedIdle = 106
k_EDOTAGCSessionNeed_UserInUINeverConnectedIdle = 107
k_EDOTAGCSessionNeed_GameServerOnline = 200
k_EDOTAGCSessionNeed_GameServerLocal = 201
k_EDOTAGCSessionNeed_GameServerIdle = 202
k_EDOTAGCSessionNeed_GameServerRelay = 203
k_EDOTAGCSessionNeed_GameServerLocalUpload = 204
TE_FIRST_BLOOD = 0
TE_GAME_END = 1
TE_MULTI_KILL = 2
TE_HERO_DENY = 3
TE_AEGIS_DENY = 4
TE_AEGIS_STOLEN = 5
TE_GODLIKE = 6
TE_COURIER_KILL = 7
TE_ECHOSLAM = 8
TE_RAPIER = 9
TE_EARLY_ROSHAN = 10
TE_BLACK_HOLE = 11
DOTA_COMBATLOG_INVALID = -1
DOTA_COMBATLOG_DAMAGE = 0
DOTA_COMBATLOG_HEAL = 1
DOTA_COMBATLOG_MODIFIER_ADD = 2
DOTA_COMBATLOG_MODIFIER_REMOVE = 3
DOTA_COMBATLOG_DEATH = 4
DOTA_COMBATLOG_ABILITY = 5
DOTA_COMBATLOG_ITEM = 6
DOTA_COMBATLOG_LOCATION = 7
DOTA_COMBATLOG_GOLD = 8
DOTA_COMBATLOG_GAME_STATE = 9
DOTA_COMBATLOG_XP = 10
DOTA_COMBATLOG_PURCHASE = 11
DOTA_COMBATLOG_BUYBACK = 12
DOTA_COMBATLOG_ABILITY_TRIGGER = 13
DOTA_COMBATLOG_PLAYERSTATS = 14
DOTA_COMBATLOG_MULTIKILL = 15
DOTA_COMBATLOG_KILLSTREAK = 16
DOTA_COMBATLOG_TEAM_BUILDING_KILL = 17
DOTA_COMBATLOG_FIRST_BLOOD = 18
DOTA_COMBATLOG_MODIFIER_REFRESH = 19
DOTA_COMBATLOG_NEUTRAL_CAMP_STACK = 20
DOTA_COMBATLOG_PICKUP_RUNE = 21
DOTA_COMBATLOG_REVEALED_INVISIBLE = 22
DOTA_COMBATLOG_HERO_SAVED = 23
DOTA_COMBATLOG_MANA_RESTORED = 24
DOTA_COMBATLOG_HERO_LEVELUP = 25
DOTA_COMBATLOG_BOTTLE_HEAL_ALLY = 26
DOTA_COMBATLOG_ENDGAME_STATS = 27
DOTA_COMBATLOG_INTERRUPT_CHANNEL = 28
DOTA_COMBATLOG_ALLIED_GOLD = 29
DOTA_COMBATLOG_AEGIS_TAKEN = 30
DOTA_COMBATLOG_MANA_DAMAGE = 31
DOTA_COMBATLOG_PHYSICAL_DAMAGE_PREVENTED = 32
DOTA_COMBATLOG_UNIT_SUMMONED = 33
DOTA_COMBATLOG_ATTACK_EVADE = 34
DOTA_COMBATLOG_TREE_CUT = 35
DOTA_COMBATLOG_SUCCESSFUL_SCAN = 36
DOTA_COMBATLOG_END_KILLSTREAK = 37


_CMSGDOTAPROFILECARD_ESTATID = _descriptor.EnumDescriptor(
  name='EStatID',
  full_name='CMsgDOTAProfileCard.EStatID',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_eStat_SoloRank', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eStat_PartyRank', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eStat_Wins', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eStat_Commends', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eStat_GamesPlayed', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_eStat_FirstMatchDate', index=5, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7065,
  serialized_end=7212,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAPROFILECARD_ESTATID)

_CSODOTAPLAYERCHALLENGE_EFLAGS = _descriptor.EnumDescriptor(
  name='EFlags',
  full_name='CSODOTAPlayerChallenge.EFlags',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='eFlag_InstantRerollUncompleted', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='eFlag_QuestChallenge', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7543,
  serialized_end=7613,
)
_sym_db.RegisterEnumDescriptor(_CSODOTAPLAYERCHALLENGE_EFLAGS)

_CMSGGCREROLLPLAYERCHALLENGERESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgGCRerollPlayerChallengeResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='eResult_Success', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='eResult_Dropped', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='eResult_NotFound', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='eResult_CantReroll', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='eResult_ServerError', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7812,
  serialized_end=7934,
)
_sym_db.RegisterEnumDescriptor(_CMSGGCREROLLPLAYERCHALLENGERESPONSE_ERESULT)

_CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_ESTAT = _descriptor.EnumDescriptor(
  name='eStat',
  full_name='CMsgDOTARealtimeGameStats.GraphData.eStat',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CreepGoldEarned', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KillGoldEarned', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DeathAndBuybackGoldLost', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='XPEarned', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11216,
  serialized_end=11307,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_ESTAT)

_CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_ELOCATION = _descriptor.EnumDescriptor(
  name='eLocation',
  full_name='CMsgDOTARealtimeGameStats.GraphData.eLocation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BotLane', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MidLane', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TopLane', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Jungle', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Ancients', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Other', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11309,
  serialized_end=11396,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_ELOCATION)

_CMSGDOTASEASONREWARDS_EREWARDTYPE = _descriptor.EnumDescriptor(
  name='ERewardType',
  full_name='CMsgDOTASeasonRewards.ERewardType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EconItem', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MysteryWheel', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AbilityEffect', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Other', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=13034,
  serialized_end=13109,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTASEASONREWARDS_EREWARDTYPE)

_CMSGDOTASEASONPREDICTIONS_EPREDICTIONTYPE = _descriptor.EnumDescriptor(
  name='ePredictionType',
  full_name='CMsgDOTASeasonPredictions.ePredictionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Generic', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Hero', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Team', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Player', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Special', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YesNo', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=14968,
  serialized_end=15054,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTASEASONPREDICTIONS_EPREDICTIONTYPE)

_CMSGDOTASEASONPREDICTIONS_EANSWERTYPE = _descriptor.EnumDescriptor(
  name='eAnswerType',
  full_name='CMsgDOTASeasonPredictions.eAnswerType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SingleInt', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SingleFloat', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MultipleInt', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MultipleFloat', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AnswerTeam', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SingleTime', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MultipleTime', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NoAnswer', index=7, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=15057,
  serialized_end=15202,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTASEASONPREDICTIONS_EANSWERTYPE)

_CMSGDOTASEASONPREDICTIONS_ERESOLUTIONTYPE_T = _descriptor.EnumDescriptor(
  name='eResolutionType_t',
  full_name='CMsgDOTASeasonPredictions.eResolutionType_t',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='InvalidQuery', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FirstToPassQuery', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LastToPassQuery', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LastRemainingQuery', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MaxToPassQuery', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MinToPassQuery', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SumQuery', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MaxTeamSumToPassQuery', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MinTeamSumToPassQuery', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=15205,
  serialized_end=15417,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTASEASONPREDICTIONS_ERESOLUTIONTYPE_T)

_CMSGDOTASEASONPREDICTIONS_ERANDOMSELECTIONGROUP_T = _descriptor.EnumDescriptor(
  name='eRandomSelectionGroup_t',
  full_name='CMsgDOTASeasonPredictions.eRandomSelectionGroup_t',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EarlyGame', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MidGame', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LateGame', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Count', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=15419,
  serialized_end=15497,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTASEASONPREDICTIONS_ERANDOMSELECTIONGROUP_T)

_CMSGDOTASEASONPREDICTIONS_ERAWVALUETYPE_T = _descriptor.EnumDescriptor(
  name='eRawValueType_t',
  full_name='CMsgDOTASeasonPredictions.eRawValueType_t',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Number', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Time', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=15499,
  serialized_end=15538,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTASEASONPREDICTIONS_ERAWVALUETYPE_T)

_CMSGDOTAMATCH_REPLAYSTATE = _descriptor.EnumDescriptor(
  name='ReplayState',
  full_name='CMsgDOTAMatch.ReplayState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REPLAY_AVAILABLE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REPLAY_NOT_RECORDED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REPLAY_EXPIRED', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=18573,
  serialized_end=18653,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAMATCH_REPLAYSTATE)


_CSODOTAGAMEACCOUNTCLIENT = _descriptor.Descriptor(
  name='CSODOTAGameAccountClient',
  full_name='CSODOTAGameAccountClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSODOTAGameAccountClient.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='wins', full_name='CSODOTAGameAccountClient.wins', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='losses', full_name='CSODOTAGameAccountClient.losses', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xp', full_name='CSODOTAGameAccountClient.xp', index=3,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='CSODOTAGameAccountClient.level', index=4,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initial_skill', full_name='CSODOTAGameAccountClient.initial_skill', index=5,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leaver_count', full_name='CSODOTAGameAccountClient.leaver_count', index=6,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='secondary_leaver_count', full_name='CSODOTAGameAccountClient.secondary_leaver_count', index=7,
      number=58, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='low_priority_until_date', full_name='CSODOTAGameAccountClient.low_priority_until_date', index=8,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prevent_text_chat_until_date', full_name='CSODOTAGameAccountClient.prevent_text_chat_until_date', index=9,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prevent_voice_until_date', full_name='CSODOTAGameAccountClient.prevent_voice_until_date', index=10,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prevent_public_text_chat_until_date', full_name='CSODOTAGameAccountClient.prevent_public_text_chat_until_date', index=11,
      number=86, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_abandoned_game_date', full_name='CSODOTAGameAccountClient.last_abandoned_game_date', index=12,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_secondary_abandoned_game_date', full_name='CSODOTAGameAccountClient.last_secondary_abandoned_game_date', index=13,
      number=59, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leaver_penalty_count', full_name='CSODOTAGameAccountClient.leaver_penalty_count', index=14,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='completed_game_streak', full_name='CSODOTAGameAccountClient.completed_game_streak', index=15,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teaching', full_name='CSODOTAGameAccountClient.teaching', index=16,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leadership', full_name='CSODOTAGameAccountClient.leadership', index=17,
      number=29, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='friendly', full_name='CSODOTAGameAccountClient.friendly', index=18,
      number=30, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='forgiving', full_name='CSODOTAGameAccountClient.forgiving', index=19,
      number=31, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_disabled_until_date', full_name='CSODOTAGameAccountClient.account_disabled_until_date', index=20,
      number=38, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_disabled_count', full_name='CSODOTAGameAccountClient.account_disabled_count', index=21,
      number=39, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='showcase_hero_id', full_name='CSODOTAGameAccountClient.showcase_hero_id', index=22,
      number=40, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_disabled_until_date', full_name='CSODOTAGameAccountClient.match_disabled_until_date', index=23,
      number=41, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_disabled_count', full_name='CSODOTAGameAccountClient.match_disabled_count', index=24,
      number=42, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='partner_account_type', full_name='CSODOTAGameAccountClient.partner_account_type', index=25,
      number=44, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='partner_account_state', full_name='CSODOTAGameAccountClient.partner_account_state', index=26,
      number=45, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='shutdownlawterminatetimestamp', full_name='CSODOTAGameAccountClient.shutdownlawterminatetimestamp', index=27,
      number=47, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='low_priority_games_remaining', full_name='CSODOTAGameAccountClient.low_priority_games_remaining', index=28,
      number=48, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='competitive_rank', full_name='CSODOTAGameAccountClient.competitive_rank', index=29,
      number=49, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calibration_games_remaining', full_name='CSODOTAGameAccountClient.calibration_games_remaining', index=30,
      number=51, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='solo_competitive_rank', full_name='CSODOTAGameAccountClient.solo_competitive_rank', index=31,
      number=52, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='solo_calibration_games_remaining', full_name='CSODOTAGameAccountClient.solo_calibration_games_remaining', index=32,
      number=54, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='general_seasonal_ranked_rank', full_name='CSODOTAGameAccountClient.general_seasonal_ranked_rank', index=33,
      number=75, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='general_seasonal_ranked_calibration_games_remaining', full_name='CSODOTAGameAccountClient.general_seasonal_ranked_calibration_games_remaining', index=34,
      number=76, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='general_seasonal_ranked_games_played', full_name='CSODOTAGameAccountClient.general_seasonal_ranked_games_played', index=35,
      number=80, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='general_seasonal_ranked_rank_peak', full_name='CSODOTAGameAccountClient.general_seasonal_ranked_rank_peak', index=36,
      number=81, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='general_seasonal_rank_transferred', full_name='CSODOTAGameAccountClient.general_seasonal_rank_transferred', index=37,
      number=83, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='solo_seasonal_ranked_rank', full_name='CSODOTAGameAccountClient.solo_seasonal_ranked_rank', index=38,
      number=77, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='solo_seasonal_ranked_calibration_games_remaining', full_name='CSODOTAGameAccountClient.solo_seasonal_ranked_calibration_games_remaining', index=39,
      number=78, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='solo_seasonal_ranked_games_played', full_name='CSODOTAGameAccountClient.solo_seasonal_ranked_games_played', index=40,
      number=79, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='solo_seasonal_ranked_rank_peak', full_name='CSODOTAGameAccountClient.solo_seasonal_ranked_rank_peak', index=41,
      number=82, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='solo_seasonal_rank_transferred', full_name='CSODOTAGameAccountClient.solo_seasonal_rank_transferred', index=42,
      number=84, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recruitment_level', full_name='CSODOTAGameAccountClient.recruitment_level', index=43,
      number=55, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='has_new_notifications', full_name='CSODOTAGameAccountClient.has_new_notifications', index=44,
      number=56, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_league_admin', full_name='CSODOTAGameAccountClient.is_league_admin', index=45,
      number=57, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='casual_games_played', full_name='CSODOTAGameAccountClient.casual_games_played', index=46,
      number=60, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='solo_competitive_games_played', full_name='CSODOTAGameAccountClient.solo_competitive_games_played', index=47,
      number=61, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='party_competitive_games_played', full_name='CSODOTAGameAccountClient.party_competitive_games_played', index=48,
      number=62, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='casual_1v1_games_played', full_name='CSODOTAGameAccountClient.casual_1v1_games_played', index=49,
      number=65, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='competitive_team_games_played', full_name='CSODOTAGameAccountClient.competitive_team_games_played', index=50,
      number=66, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='curr_all_hero_challenge_id', full_name='CSODOTAGameAccountClient.curr_all_hero_challenge_id', index=51,
      number=67, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='play_time_points', full_name='CSODOTAGameAccountClient.play_time_points', index=52,
      number=68, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_flags', full_name='CSODOTAGameAccountClient.account_flags', index=53,
      number=69, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='play_time_level', full_name='CSODOTAGameAccountClient.play_time_level', index=54,
      number=70, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_behavior_seq_num_last_report', full_name='CSODOTAGameAccountClient.player_behavior_seq_num_last_report', index=55,
      number=71, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_behavior_score_last_report', full_name='CSODOTAGameAccountClient.player_behavior_score_last_report', index=56,
      number=72, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_behavior_report_old_data', full_name='CSODOTAGameAccountClient.player_behavior_report_old_data', index=57,
      number=73, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tourney_skill_level', full_name='CSODOTAGameAccountClient.tourney_skill_level', index=58,
      number=74, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tourney_recent_participation_date', full_name='CSODOTAGameAccountClient.tourney_recent_participation_date', index=59,
      number=85, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='favorite_team', full_name='CSODOTAGameAccountClient.favorite_team', index=60,
      number=87, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=2166,
)


_CMSGLOBBYEVENTPOINTS_ACCOUNTPOINTS = _descriptor.Descriptor(
  name='AccountPoints',
  full_name='CMsgLobbyEventPoints.AccountPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgLobbyEventPoints.AccountPoints.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='normal_points', full_name='CMsgLobbyEventPoints.AccountPoints.normal_points', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='premium_points', full_name='CMsgLobbyEventPoints.AccountPoints.premium_points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owned', full_name='CMsgLobbyEventPoints.AccountPoints.owned', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='favorite_team', full_name='CMsgLobbyEventPoints.AccountPoints.favorite_team', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='favorite_team_level', full_name='CMsgLobbyEventPoints.AccountPoints.favorite_team_level', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='points_held', full_name='CMsgLobbyEventPoints.AccountPoints.points_held', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='premium_points_held', full_name='CMsgLobbyEventPoints.AccountPoints.premium_points_held', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='favorite_team_foil_level', full_name='CMsgLobbyEventPoints.AccountPoints.favorite_team_foil_level', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wager_tokens_remaining', full_name='CMsgLobbyEventPoints.AccountPoints.wager_tokens_remaining', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wager_tokens_max', full_name='CMsgLobbyEventPoints.AccountPoints.wager_tokens_max', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active_effects_mask', full_name='CMsgLobbyEventPoints.AccountPoints.active_effects_mask', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2273,
  serialized_end=2593,
)

_CMSGLOBBYEVENTPOINTS = _descriptor.Descriptor(
  name='CMsgLobbyEventPoints',
  full_name='CMsgLobbyEventPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgLobbyEventPoints.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_points', full_name='CMsgLobbyEventPoints.account_points', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGLOBBYEVENTPOINTS_ACCOUNTPOINTS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2169,
  serialized_end=2593,
)


_CMSGBATTLECUPVICTORY = _descriptor.Descriptor(
  name='CMsgBattleCupVictory',
  full_name='CMsgBattleCupVictory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgBattleCupVictory.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='win_date', full_name='CMsgBattleCupVictory.win_date', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='valid_until', full_name='CMsgBattleCupVictory.valid_until', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='skill_level', full_name='CMsgBattleCupVictory.skill_level', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_id', full_name='CMsgBattleCupVictory.tournament_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='division_id', full_name='CMsgBattleCupVictory.division_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgBattleCupVictory.team_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='streak', full_name='CMsgBattleCupVictory.streak', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2596,
  serialized_end=2775,
)


_CMSGLOBBYBATTLECUPVICTORYLIST = _descriptor.Descriptor(
  name='CMsgLobbyBattleCupVictoryList',
  full_name='CMsgLobbyBattleCupVictoryList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='winners', full_name='CMsgLobbyBattleCupVictoryList.winners', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2777,
  serialized_end=2848,
)


_CMSGDOTABROADCASTNOTIFICATION = _descriptor.Descriptor(
  name='CMsgDOTABroadcastNotification',
  full_name='CMsgDOTABroadcastNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='CMsgDOTABroadcastNotification.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2850,
  serialized_end=2898,
)


_CPROTOITEMHEROSTATUE = _descriptor.Descriptor(
  name='CProtoItemHeroStatue',
  full_name='CProtoItemHeroStatue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CProtoItemHeroStatue.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status_effect_index', full_name='CProtoItemHeroStatue.status_effect_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sequence_name', full_name='CProtoItemHeroStatue.sequence_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cycle', full_name='CProtoItemHeroStatue.cycle', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wearable', full_name='CProtoItemHeroStatue.wearable', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inscription', full_name='CProtoItemHeroStatue.inscription', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='style', full_name='CProtoItemHeroStatue.style', index=6,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_drop', full_name='CProtoItemHeroStatue.tournament_drop', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2901,
  serialized_end=3086,
)


_CPROTOITEMTEAMSHOWCASE = _descriptor.Descriptor(
  name='CProtoItemTeamShowcase',
  full_name='CProtoItemTeamShowcase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CProtoItemTeamShowcase.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status_effect_index', full_name='CProtoItemTeamShowcase.status_effect_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sequence_name', full_name='CProtoItemTeamShowcase.sequence_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cycle', full_name='CProtoItemTeamShowcase.cycle', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wearable', full_name='CProtoItemTeamShowcase.wearable', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inscription', full_name='CProtoItemTeamShowcase.inscription', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='style', full_name='CProtoItemTeamShowcase.style', index=6,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3089,
  serialized_end=3251,
)


_CMATCHPLAYERABILITYUPGRADE = _descriptor.Descriptor(
  name='CMatchPlayerAbilityUpgrade',
  full_name='CMatchPlayerAbilityUpgrade',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ability', full_name='CMatchPlayerAbilityUpgrade.ability', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='CMatchPlayerAbilityUpgrade.time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3253,
  serialized_end=3312,
)


_CMATCHADDITIONALUNITINVENTORY = _descriptor.Descriptor(
  name='CMatchAdditionalUnitInventory',
  full_name='CMatchAdditionalUnitInventory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit_name', full_name='CMatchAdditionalUnitInventory.unit_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='items', full_name='CMatchAdditionalUnitInventory.items', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3314,
  serialized_end=3379,
)


_CMATCHPLAYERPERMANENTBUFF = _descriptor.Descriptor(
  name='CMatchPlayerPermanentBuff',
  full_name='CMatchPlayerPermanentBuff',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='permanent_buff', full_name='CMatchPlayerPermanentBuff.permanent_buff', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stack_count', full_name='CMatchPlayerPermanentBuff.stack_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3381,
  serialized_end=3453,
)


_CMATCHHEROSELECTEVENT = _descriptor.Descriptor(
  name='CMatchHeroSelectEvent',
  full_name='CMatchHeroSelectEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_pick', full_name='CMatchHeroSelectEvent.is_pick', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team', full_name='CMatchHeroSelectEvent.team', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMatchHeroSelectEvent.hero_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3455,
  serialized_end=3526,
)


_CMSGDOTAPROCESSFANTASYSCHEDULEDEVENT = _descriptor.Descriptor(
  name='CMsgDOTAProcessFantasyScheduledEvent',
  full_name='CMsgDOTAProcessFantasyScheduledEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='CMsgDOTAProcessFantasyScheduledEvent.event', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgDOTAProcessFantasyScheduledEvent.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAProcessFantasyScheduledEvent.fantasy_league_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='season', full_name='CMsgDOTAProcessFantasyScheduledEvent.season', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reference_data', full_name='CMsgDOTAProcessFantasyScheduledEvent.reference_data', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3529,
  serialized_end=3668,
)


_CMSGDOTAHASITEMQUERY = _descriptor.Descriptor(
  name='CMsgDOTAHasItemQuery',
  full_name='CMsgDOTAHasItemQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAHasItemQuery.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgDOTAHasItemQuery.item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3670,
  serialized_end=3729,
)


_CMSGDOTAHASITEMRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAHasItemResponse',
  full_name='CMsgDOTAHasItemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='has_item', full_name='CMsgDOTAHasItemResponse.has_item', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3731,
  serialized_end=3774,
)


_CMSGDOTAHASITEMDEFSQUERY = _descriptor.Descriptor(
  name='CMsgDOTAHasItemDefsQuery',
  full_name='CMsgDOTAHasItemDefsQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAHasItemDefsQuery.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemdef_ids', full_name='CMsgDOTAHasItemDefsQuery.itemdef_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3776,
  serialized_end=3843,
)


_CMSGDOTAHASITEMDEFSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAHasItemDefsResponse',
  full_name='CMsgDOTAHasItemDefsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='has_items', full_name='CMsgDOTAHasItemDefsResponse.has_items', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3845,
  serialized_end=3893,
)


_CMSGGCGETPLAYERCARDITEMINFO = _descriptor.Descriptor(
  name='CMsgGCGetPlayerCardItemInfo',
  full_name='CMsgGCGetPlayerCardItemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCGetPlayerCardItemInfo.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_card_item_ids', full_name='CMsgGCGetPlayerCardItemInfo.player_card_item_ids', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3895,
  serialized_end=3974,
)


_CMSGGCGETPLAYERCARDITEMINFORESPONSE_PLAYERCARDINFO = _descriptor.Descriptor(
  name='PlayerCardInfo',
  full_name='CMsgGCGetPlayerCardItemInfoResponse.PlayerCardInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_card_item_id', full_name='CMsgGCGetPlayerCardItemInfoResponse.PlayerCardInfo.player_card_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCGetPlayerCardItemInfoResponse.PlayerCardInfo.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packed_bonuses', full_name='CMsgGCGetPlayerCardItemInfoResponse.PlayerCardInfo.packed_bonuses', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4096,
  serialized_end=4185,
)

_CMSGGCGETPLAYERCARDITEMINFORESPONSE = _descriptor.Descriptor(
  name='CMsgGCGetPlayerCardItemInfoResponse',
  full_name='CMsgGCGetPlayerCardItemInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_card_infos', full_name='CMsgGCGetPlayerCardItemInfoResponse.player_card_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCGETPLAYERCARDITEMINFORESPONSE_PLAYERCARDINFO, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3977,
  serialized_end=4185,
)


_CMSGGCTOGCFANTASYSETMATCHLEAGUE = _descriptor.Descriptor(
  name='CMsgGCToGCFantasySetMatchLeague',
  full_name='CMsgGCToGCFantasySetMatchLeague',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgGCToGCFantasySetMatchLeague.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgGCToGCFantasySetMatchLeague.league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4187,
  serialized_end=4257,
)


_CSODOTAMAPLOCATIONSTATE = _descriptor.Descriptor(
  name='CSODOTAMapLocationState',
  full_name='CSODOTAMapLocationState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSODOTAMapLocationState.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='location_id', full_name='CSODOTAMapLocationState.location_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='completed', full_name='CSODOTAMapLocationState.completed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4259,
  serialized_end=4356,
)


_CMSGLEAGUEADMINLIST = _descriptor.Descriptor(
  name='CMsgLeagueAdminList',
  full_name='CMsgLeagueAdminList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='CMsgLeagueAdminList.account_ids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4358,
  serialized_end=4400,
)


_CCOMPENDIUMTIMESTAMPEDDATA = _descriptor.Descriptor(
  name='CCompendiumTimestampedData',
  full_name='CCompendiumTimestampedData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_time', full_name='CCompendiumTimestampedData.game_time', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gpm', full_name='CCompendiumTimestampedData.gpm', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xpm', full_name='CCompendiumTimestampedData.xpm', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kills', full_name='CCompendiumTimestampedData.kills', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deaths', full_name='CCompendiumTimestampedData.deaths', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_purchases', full_name='CCompendiumTimestampedData.item_purchases', index=5,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4403,
  serialized_end=4531,
)


_CCOMPENDIUMGAMETIMELINE = _descriptor.Descriptor(
  name='CCompendiumGameTimeline',
  full_name='CCompendiumGameTimeline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='CCompendiumGameTimeline.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tags', full_name='CCompendiumGameTimeline.tags', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4533,
  serialized_end=4615,
)


_CCOMPENDIUMGAMELIST = _descriptor.Descriptor(
  name='CCompendiumGameList',
  full_name='CCompendiumGameList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='games', full_name='CCompendiumGameList.games', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4617,
  serialized_end=4679,
)


_CADDITIONALEQUIPSLOT = _descriptor.Descriptor(
  name='CAdditionalEquipSlot',
  full_name='CAdditionalEquipSlot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_id', full_name='CAdditionalEquipSlot.class_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot_id', full_name='CAdditionalEquipSlot.slot_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CAdditionalEquipSlot.def_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4681,
  serialized_end=4757,
)


_CMSGDOTACOMBATLOGENTRY = _descriptor.Descriptor(
  name='CMsgDOTACombatLogEntry',
  full_name='CMsgDOTACombatLogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CMsgDOTACombatLogEntry.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_name', full_name='CMsgDOTACombatLogEntry.target_name', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_source_name', full_name='CMsgDOTACombatLogEntry.target_source_name', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attacker_name', full_name='CMsgDOTACombatLogEntry.attacker_name', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='damage_source_name', full_name='CMsgDOTACombatLogEntry.damage_source_name', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inflictor_name', full_name='CMsgDOTACombatLogEntry.inflictor_name', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_attacker_illusion', full_name='CMsgDOTACombatLogEntry.is_attacker_illusion', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_attacker_hero', full_name='CMsgDOTACombatLogEntry.is_attacker_hero', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_target_illusion', full_name='CMsgDOTACombatLogEntry.is_target_illusion', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_target_hero', full_name='CMsgDOTACombatLogEntry.is_target_hero', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_visible_radiant', full_name='CMsgDOTACombatLogEntry.is_visible_radiant', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_visible_dire', full_name='CMsgDOTACombatLogEntry.is_visible_dire', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='CMsgDOTACombatLogEntry.value', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='health', full_name='CMsgDOTACombatLogEntry.health', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgDOTACombatLogEntry.timestamp', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stun_duration', full_name='CMsgDOTACombatLogEntry.stun_duration', index=15,
      number=16, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slow_duration', full_name='CMsgDOTACombatLogEntry.slow_duration', index=16,
      number=17, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_ability_toggle_on', full_name='CMsgDOTACombatLogEntry.is_ability_toggle_on', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_ability_toggle_off', full_name='CMsgDOTACombatLogEntry.is_ability_toggle_off', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ability_level', full_name='CMsgDOTACombatLogEntry.ability_level', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='location_x', full_name='CMsgDOTACombatLogEntry.location_x', index=20,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='location_y', full_name='CMsgDOTACombatLogEntry.location_y', index=21,
      number=22, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gold_reason', full_name='CMsgDOTACombatLogEntry.gold_reason', index=22,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp_raw', full_name='CMsgDOTACombatLogEntry.timestamp_raw', index=23,
      number=24, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='modifier_duration', full_name='CMsgDOTACombatLogEntry.modifier_duration', index=24,
      number=25, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xp_reason', full_name='CMsgDOTACombatLogEntry.xp_reason', index=25,
      number=26, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_hits', full_name='CMsgDOTACombatLogEntry.last_hits', index=26,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attacker_team', full_name='CMsgDOTACombatLogEntry.attacker_team', index=27,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_team', full_name='CMsgDOTACombatLogEntry.target_team', index=28,
      number=29, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='obs_wards_placed', full_name='CMsgDOTACombatLogEntry.obs_wards_placed', index=29,
      number=30, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assist_player0', full_name='CMsgDOTACombatLogEntry.assist_player0', index=30,
      number=31, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assist_player1', full_name='CMsgDOTACombatLogEntry.assist_player1', index=31,
      number=32, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assist_player2', full_name='CMsgDOTACombatLogEntry.assist_player2', index=32,
      number=33, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assist_player3', full_name='CMsgDOTACombatLogEntry.assist_player3', index=33,
      number=34, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stack_count', full_name='CMsgDOTACombatLogEntry.stack_count', index=34,
      number=35, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hidden_modifier', full_name='CMsgDOTACombatLogEntry.hidden_modifier', index=35,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_target_building', full_name='CMsgDOTACombatLogEntry.is_target_building', index=36,
      number=37, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='neutral_camp_type', full_name='CMsgDOTACombatLogEntry.neutral_camp_type', index=37,
      number=38, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rune_type', full_name='CMsgDOTACombatLogEntry.rune_type', index=38,
      number=39, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assist_players', full_name='CMsgDOTACombatLogEntry.assist_players', index=39,
      number=40, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_heal_save', full_name='CMsgDOTACombatLogEntry.is_heal_save', index=40,
      number=41, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_ultimate_ability', full_name='CMsgDOTACombatLogEntry.is_ultimate_ability', index=41,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attacker_hero_level', full_name='CMsgDOTACombatLogEntry.attacker_hero_level', index=42,
      number=43, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_hero_level', full_name='CMsgDOTACombatLogEntry.target_hero_level', index=43,
      number=44, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xpm', full_name='CMsgDOTACombatLogEntry.xpm', index=44,
      number=45, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gpm', full_name='CMsgDOTACombatLogEntry.gpm', index=45,
      number=46, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_location', full_name='CMsgDOTACombatLogEntry.event_location', index=46,
      number=47, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_is_self', full_name='CMsgDOTACombatLogEntry.target_is_self', index=47,
      number=48, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='damage_type', full_name='CMsgDOTACombatLogEntry.damage_type', index=48,
      number=49, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invisibility_modifier', full_name='CMsgDOTACombatLogEntry.invisibility_modifier', index=49,
      number=50, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='damage_category', full_name='CMsgDOTACombatLogEntry.damage_category', index=50,
      number=51, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='networth', full_name='CMsgDOTACombatLogEntry.networth', index=51,
      number=52, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='building_type', full_name='CMsgDOTACombatLogEntry.building_type', index=52,
      number=53, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='modifier_elapsed_duration', full_name='CMsgDOTACombatLogEntry.modifier_elapsed_duration', index=53,
      number=54, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='silence_modifier', full_name='CMsgDOTACombatLogEntry.silence_modifier', index=54,
      number=55, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='heal_from_lifesteal', full_name='CMsgDOTACombatLogEntry.heal_from_lifesteal', index=55,
      number=56, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='modifier_purged', full_name='CMsgDOTACombatLogEntry.modifier_purged', index=56,
      number=57, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spell_evaded', full_name='CMsgDOTACombatLogEntry.spell_evaded', index=57,
      number=58, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motion_controller_modifier', full_name='CMsgDOTACombatLogEntry.motion_controller_modifier', index=58,
      number=59, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='long_range_kill', full_name='CMsgDOTACombatLogEntry.long_range_kill', index=59,
      number=60, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4760,
  serialized_end=6266,
)


_CMSGDOTAPROFILECARD_SLOT_TROPHY = _descriptor.Descriptor(
  name='Trophy',
  full_name='CMsgDOTAProfileCard.Slot.Trophy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trophy_id', full_name='CMsgDOTAProfileCard.Slot.Trophy.trophy_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trophy_score', full_name='CMsgDOTAProfileCard.Slot.Trophy.trophy_score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6772,
  serialized_end=6821,
)

_CMSGDOTAPROFILECARD_SLOT_STAT = _descriptor.Descriptor(
  name='Stat',
  full_name='CMsgDOTAProfileCard.Slot.Stat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_id', full_name='CMsgDOTAProfileCard.Slot.Stat.stat_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stat_score', full_name='CMsgDOTAProfileCard.Slot.Stat.stat_score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6823,
  serialized_end=6914,
)

_CMSGDOTAPROFILECARD_SLOT_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='CMsgDOTAProfileCard.Slot.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='serialized_item', full_name='CMsgDOTAProfileCard.Slot.Item.serialized_item', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgDOTAProfileCard.Slot.Item.item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6916,
  serialized_end=6964,
)

_CMSGDOTAPROFILECARD_SLOT_HERO = _descriptor.Descriptor(
  name='Hero',
  full_name='CMsgDOTAProfileCard.Slot.Hero',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgDOTAProfileCard.Slot.Hero.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_wins', full_name='CMsgDOTAProfileCard.Slot.Hero.hero_wins', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_losses', full_name='CMsgDOTAProfileCard.Slot.Hero.hero_losses', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6966,
  serialized_end=7029,
)

_CMSGDOTAPROFILECARD_SLOT_EMOTICON = _descriptor.Descriptor(
  name='Emoticon',
  full_name='CMsgDOTAProfileCard.Slot.Emoticon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='emoticon_id', full_name='CMsgDOTAProfileCard.Slot.Emoticon.emoticon_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7031,
  serialized_end=7062,
)

_CMSGDOTAPROFILECARD_SLOT = _descriptor.Descriptor(
  name='Slot',
  full_name='CMsgDOTAProfileCard.Slot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slot_id', full_name='CMsgDOTAProfileCard.Slot.slot_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trophy', full_name='CMsgDOTAProfileCard.Slot.trophy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stat', full_name='CMsgDOTAProfileCard.Slot.stat', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item', full_name='CMsgDOTAProfileCard.Slot.item', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero', full_name='CMsgDOTAProfileCard.Slot.hero', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='emoticon', full_name='CMsgDOTAProfileCard.Slot.emoticon', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAPROFILECARD_SLOT_TROPHY, _CMSGDOTAPROFILECARD_SLOT_STAT, _CMSGDOTAPROFILECARD_SLOT_ITEM, _CMSGDOTAPROFILECARD_SLOT_HERO, _CMSGDOTAPROFILECARD_SLOT_EMOTICON, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6505,
  serialized_end=7062,
)

_CMSGDOTAPROFILECARD = _descriptor.Descriptor(
  name='CMsgDOTAProfileCard',
  full_name='CMsgDOTAProfileCard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAProfileCard.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='background_def_index', full_name='CMsgDOTAProfileCard.background_def_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slots', full_name='CMsgDOTAProfileCard.slots', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='badge_points', full_name='CMsgDOTAProfileCard.badge_points', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_points', full_name='CMsgDOTAProfileCard.event_points', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgDOTAProfileCard.event_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recent_battle_cup_victory', full_name='CMsgDOTAProfileCard.recent_battle_cup_victory', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAPROFILECARD_SLOT, ],
  enum_types=[
    _CMSGDOTAPROFILECARD_ESTATID,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6269,
  serialized_end=7212,
)


_CSODOTAPLAYERCHALLENGE = _descriptor.Descriptor(
  name='CSODOTAPlayerChallenge',
  full_name='CSODOTAPlayerChallenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSODOTAPlayerChallenge.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CSODOTAPlayerChallenge.event_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='slot_id', full_name='CSODOTAPlayerChallenge.slot_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='challenge_type', full_name='CSODOTAPlayerChallenge.challenge_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='int_param_0', full_name='CSODOTAPlayerChallenge.int_param_0', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='int_param_1', full_name='CSODOTAPlayerChallenge.int_param_1', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_time', full_name='CSODOTAPlayerChallenge.created_time', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='completed', full_name='CSODOTAPlayerChallenge.completed', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sequence_id', full_name='CSODOTAPlayerChallenge.sequence_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='challenge_tier', full_name='CSODOTAPlayerChallenge.challenge_tier', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CSODOTAPlayerChallenge.flags', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attempts', full_name='CSODOTAPlayerChallenge.attempts', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='complete_limit', full_name='CSODOTAPlayerChallenge.complete_limit', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quest_rank', full_name='CSODOTAPlayerChallenge.quest_rank', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CSODOTAPLAYERCHALLENGE_EFLAGS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7215,
  serialized_end=7613,
)


_CMSGCLIENTTOGCREROLLPLAYERCHALLENGE = _descriptor.Descriptor(
  name='CMsgClientToGCRerollPlayerChallenge',
  full_name='CMsgClientToGCRerollPlayerChallenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgClientToGCRerollPlayerChallenge.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sequence_id', full_name='CMsgClientToGCRerollPlayerChallenge.sequence_id', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7615,
  serialized_end=7691,
)


_CMSGGCREROLLPLAYERCHALLENGERESPONSE = _descriptor.Descriptor(
  name='CMsgGCRerollPlayerChallengeResponse',
  full_name='CMsgGCRerollPlayerChallengeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCRerollPlayerChallengeResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGGCREROLLPLAYERCHALLENGERESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7694,
  serialized_end=7934,
)


_CMSGGCTOPCUSTOMGAMESLIST = _descriptor.Descriptor(
  name='CMsgGCTopCustomGamesList',
  full_name='CMsgGCTopCustomGamesList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='top_custom_games', full_name='CMsgGCTopCustomGamesList.top_custom_games', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_of_the_day', full_name='CMsgGCTopCustomGamesList.game_of_the_day', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7936,
  serialized_end=8013,
)


_CMSGDOTAREALTIMEGAMESTATS_TEAMDETAILS = _descriptor.Descriptor(
  name='TeamDetails',
  full_name='CMsgDOTARealtimeGameStats.TeamDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_number', full_name='CMsgDOTARealtimeGameStats.TeamDetails.team_number', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTARealtimeGameStats.TeamDetails.team_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgDOTARealtimeGameStats.TeamDetails.team_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_logo', full_name='CMsgDOTARealtimeGameStats.TeamDetails.team_logo', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgDOTARealtimeGameStats.TeamDetails.score', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players', full_name='CMsgDOTARealtimeGameStats.TeamDetails.players', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='only_team', full_name='CMsgDOTARealtimeGameStats.TeamDetails.only_team', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cheers', full_name='CMsgDOTARealtimeGameStats.TeamDetails.cheers', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8299,
  serialized_end=8497,
)

_CMSGDOTAREALTIMEGAMESTATS_ITEMDETAILS = _descriptor.Descriptor(
  name='ItemDetails',
  full_name='CMsgDOTARealtimeGameStats.ItemDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgDOTARealtimeGameStats.ItemDetails.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTARealtimeGameStats.ItemDetails.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='CMsgDOTARealtimeGameStats.ItemDetails.time', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sold', full_name='CMsgDOTARealtimeGameStats.ItemDetails.sold', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stackcount', full_name='CMsgDOTARealtimeGameStats.ItemDetails.stackcount', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8499,
  serialized_end=8586,
)

_CMSGDOTAREALTIMEGAMESTATS_ABILITYDETAILS = _descriptor.Descriptor(
  name='AbilityDetails',
  full_name='CMsgDOTARealtimeGameStats.AbilityDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgDOTARealtimeGameStats.AbilityDetails.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTARealtimeGameStats.AbilityDetails.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='CMsgDOTARealtimeGameStats.AbilityDetails.level', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cooldown', full_name='CMsgDOTARealtimeGameStats.AbilityDetails.cooldown', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cooldown_max', full_name='CMsgDOTARealtimeGameStats.AbilityDetails.cooldown_max', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8588,
  serialized_end=8685,
)

_CMSGDOTAREALTIMEGAMESTATS_HEROTOHEROSTATS = _descriptor.Descriptor(
  name='HeroToHeroStats',
  full_name='CMsgDOTARealtimeGameStats.HeroToHeroStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='victimid', full_name='CMsgDOTARealtimeGameStats.HeroToHeroStats.victimid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kills', full_name='CMsgDOTARealtimeGameStats.HeroToHeroStats.kills', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assists', full_name='CMsgDOTARealtimeGameStats.HeroToHeroStats.assists', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8687,
  serialized_end=8754,
)

_CMSGDOTAREALTIMEGAMESTATS_ABILITYLIST = _descriptor.Descriptor(
  name='AbilityList',
  full_name='CMsgDOTARealtimeGameStats.AbilityList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgDOTARealtimeGameStats.AbilityList.id', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8756,
  serialized_end=8781,
)

_CMSGDOTAREALTIMEGAMESTATS_PLAYERDETAILS = _descriptor.Descriptor(
  name='PlayerDetails',
  full_name='CMsgDOTARealtimeGameStats.PlayerDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playerid', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.playerid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.team', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='heroid', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.heroid', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='healthpoints', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.healthpoints', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maxhealthpoints', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.maxhealthpoints', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='healthregenrate', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.healthregenrate', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='manapoints', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.manapoints', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maxmanapoints', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.maxmanapoints', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='manaregenrate', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.manaregenrate', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_strength', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.base_strength', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_agility', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.base_agility', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_intelligence', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.base_intelligence', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_armor', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.base_armor', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_movespeed', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.base_movespeed', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_damage', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.base_damage', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strength', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.strength', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='agility', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.agility', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='intelligence', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.intelligence', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='armor', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.armor', index=20,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='movespeed', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.movespeed', index=21,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='damage', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.damage', index=22,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_damage', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.hero_damage', index=23,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tower_damage', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.tower_damage', index=24,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='abilities', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.abilities', index=25,
      number=26, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.level', index=26,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kill_count', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.kill_count', index=27,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='death_count', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.death_count', index=28,
      number=29, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assists_count', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.assists_count', index=29,
      number=30, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='denies_count', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.denies_count', index=30,
      number=31, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lh_count', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.lh_count', index=31,
      number=32, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_healing', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.hero_healing', index=32,
      number=33, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gold_per_min', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.gold_per_min', index=33,
      number=34, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xp_per_min', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.xp_per_min', index=34,
      number=35, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='net_gold', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.net_gold', index=35,
      number=36, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gold', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.gold', index=36,
      number=37, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='x', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.x', index=37,
      number=38, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.y', index=38,
      number=39, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='respawn_time', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.respawn_time', index=39,
      number=40, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ultimate_cooldown', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.ultimate_cooldown', index=40,
      number=41, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='has_buyback', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.has_buyback', index=41,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='items', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.items', index=42,
      number=43, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stashitems', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.stashitems', index=43,
      number=44, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemshoppinglist', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.itemshoppinglist', index=44,
      number=45, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='levelpoints', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.levelpoints', index=45,
      number=46, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_to_hero_stats', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.hero_to_hero_stats', index=46,
      number=47, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='has_ultimate', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.has_ultimate', index=47,
      number=48, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='has_ultimate_mana', full_name='CMsgDOTARealtimeGameStats.PlayerDetails.has_ultimate_mana', index=48,
      number=49, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8784,
  serialized_end=10037,
)

_CMSGDOTAREALTIMEGAMESTATS_BUILDINGDETAILS = _descriptor.Descriptor(
  name='BuildingDetails',
  full_name='CMsgDOTARealtimeGameStats.BuildingDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team', full_name='CMsgDOTARealtimeGameStats.BuildingDetails.team', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='heading', full_name='CMsgDOTARealtimeGameStats.BuildingDetails.heading', index=1,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lane', full_name='CMsgDOTARealtimeGameStats.BuildingDetails.lane', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tier', full_name='CMsgDOTARealtimeGameStats.BuildingDetails.tier', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='CMsgDOTARealtimeGameStats.BuildingDetails.type', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='x', full_name='CMsgDOTARealtimeGameStats.BuildingDetails.x', index=5,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='CMsgDOTARealtimeGameStats.BuildingDetails.y', index=6,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='destroyed', full_name='CMsgDOTARealtimeGameStats.BuildingDetails.destroyed', index=7,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10040,
  serialized_end=10171,
)

_CMSGDOTAREALTIMEGAMESTATS_KILLDETAILS = _descriptor.Descriptor(
  name='KillDetails',
  full_name='CMsgDOTARealtimeGameStats.KillDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_id', full_name='CMsgDOTARealtimeGameStats.KillDetails.player_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='death_time', full_name='CMsgDOTARealtimeGameStats.KillDetails.death_time', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='killer_player_id', full_name='CMsgDOTARealtimeGameStats.KillDetails.killer_player_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10173,
  serialized_end=10251,
)

_CMSGDOTAREALTIMEGAMESTATS_BROADCASTERDETAILS = _descriptor.Descriptor(
  name='BroadcasterDetails',
  full_name='CMsgDOTARealtimeGameStats.BroadcasterDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_id', full_name='CMsgDOTARealtimeGameStats.BroadcasterDetails.player_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='selected_hero', full_name='CMsgDOTARealtimeGameStats.BroadcasterDetails.selected_hero', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='selected_graph', full_name='CMsgDOTARealtimeGameStats.BroadcasterDetails.selected_graph', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10253,
  serialized_end=10339,
)

_CMSGDOTAREALTIMEGAMESTATS_PICKBANDETAILS = _descriptor.Descriptor(
  name='PickBanDetails',
  full_name='CMsgDOTARealtimeGameStats.PickBanDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero', full_name='CMsgDOTARealtimeGameStats.PickBanDetails.hero', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team', full_name='CMsgDOTARealtimeGameStats.PickBanDetails.team', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10341,
  serialized_end=10385,
)

_CMSGDOTAREALTIMEGAMESTATS_MATCHDETAILS = _descriptor.Descriptor(
  name='MatchDetails',
  full_name='CMsgDOTARealtimeGameStats.MatchDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_steam_id', full_name='CMsgDOTARealtimeGameStats.MatchDetails.server_steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matchid', full_name='CMsgDOTARealtimeGameStats.MatchDetails.matchid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgDOTARealtimeGameStats.MatchDetails.timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_of_day', full_name='CMsgDOTARealtimeGameStats.MatchDetails.time_of_day', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_nightstalker_night', full_name='CMsgDOTARealtimeGameStats.MatchDetails.is_nightstalker_night', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_time', full_name='CMsgDOTARealtimeGameStats.MatchDetails.game_time', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teamid_radiant', full_name='CMsgDOTARealtimeGameStats.MatchDetails.teamid_radiant', index=6,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teamid_dire', full_name='CMsgDOTARealtimeGameStats.MatchDetails.teamid_dire', index=7,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='picks', full_name='CMsgDOTARealtimeGameStats.MatchDetails.picks', index=8,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bans', full_name='CMsgDOTARealtimeGameStats.MatchDetails.bans', index=9,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kills', full_name='CMsgDOTARealtimeGameStats.MatchDetails.kills', index=10,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='broadcasters', full_name='CMsgDOTARealtimeGameStats.MatchDetails.broadcasters', index=11,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CMsgDOTARealtimeGameStats.MatchDetails.game_mode', index=12,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgDOTARealtimeGameStats.MatchDetails.league_id', index=13,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='single_team', full_name='CMsgDOTARealtimeGameStats.MatchDetails.single_team', index=14,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cheers_peak', full_name='CMsgDOTARealtimeGameStats.MatchDetails.cheers_peak', index=15,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10388,
  serialized_end=10898,
)

_CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_LOCATIONSTATS = _descriptor.Descriptor(
  name='LocationStats',
  full_name='CMsgDOTARealtimeGameStats.GraphData.LocationStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats', full_name='CMsgDOTARealtimeGameStats.GraphData.LocationStats.stats', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11092,
  serialized_end=11122,
)

_CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_TEAMLOCATIONSTATS = _descriptor.Descriptor(
  name='TeamLocationStats',
  full_name='CMsgDOTARealtimeGameStats.GraphData.TeamLocationStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc_stats', full_name='CMsgDOTARealtimeGameStats.GraphData.TeamLocationStats.loc_stats', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11124,
  serialized_end=11214,
)

_CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA = _descriptor.Descriptor(
  name='GraphData',
  full_name='CMsgDOTARealtimeGameStats.GraphData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='graph_gold', full_name='CMsgDOTARealtimeGameStats.GraphData.graph_gold', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='graph_xp', full_name='CMsgDOTARealtimeGameStats.GraphData.graph_xp', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='graph_kill', full_name='CMsgDOTARealtimeGameStats.GraphData.graph_kill', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='graph_tower', full_name='CMsgDOTARealtimeGameStats.GraphData.graph_tower', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='graph_rax', full_name='CMsgDOTARealtimeGameStats.GraphData.graph_rax', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_loc_stats', full_name='CMsgDOTARealtimeGameStats.GraphData.team_loc_stats', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_LOCATIONSTATS, _CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_TEAMLOCATIONSTATS, ],
  enum_types=[
    _CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_ESTAT,
    _CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_ELOCATION,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10901,
  serialized_end=11396,
)

_CMSGDOTAREALTIMEGAMESTATS = _descriptor.Descriptor(
  name='CMsgDOTARealtimeGameStats',
  full_name='CMsgDOTARealtimeGameStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match', full_name='CMsgDOTARealtimeGameStats.match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teams', full_name='CMsgDOTARealtimeGameStats.teams', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='buildings', full_name='CMsgDOTARealtimeGameStats.buildings', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='graph_data', full_name='CMsgDOTARealtimeGameStats.graph_data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delta_frame', full_name='CMsgDOTARealtimeGameStats.delta_frame', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAREALTIMEGAMESTATS_TEAMDETAILS, _CMSGDOTAREALTIMEGAMESTATS_ITEMDETAILS, _CMSGDOTAREALTIMEGAMESTATS_ABILITYDETAILS, _CMSGDOTAREALTIMEGAMESTATS_HEROTOHEROSTATS, _CMSGDOTAREALTIMEGAMESTATS_ABILITYLIST, _CMSGDOTAREALTIMEGAMESTATS_PLAYERDETAILS, _CMSGDOTAREALTIMEGAMESTATS_BUILDINGDETAILS, _CMSGDOTAREALTIMEGAMESTATS_KILLDETAILS, _CMSGDOTAREALTIMEGAMESTATS_BROADCASTERDETAILS, _CMSGDOTAREALTIMEGAMESTATS_PICKBANDETAILS, _CMSGDOTAREALTIMEGAMESTATS_MATCHDETAILS, _CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8016,
  serialized_end=11396,
)


_CMSGDOTAREALTIMEGAMESTATSTERSE_TEAMDETAILS = _descriptor.Descriptor(
  name='TeamDetails',
  full_name='CMsgDOTARealtimeGameStatsTerse.TeamDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_number', full_name='CMsgDOTARealtimeGameStatsTerse.TeamDetails.team_number', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTARealtimeGameStatsTerse.TeamDetails.team_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgDOTARealtimeGameStatsTerse.TeamDetails.team_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_logo', full_name='CMsgDOTARealtimeGameStatsTerse.TeamDetails.team_logo', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgDOTARealtimeGameStatsTerse.TeamDetails.score', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players', full_name='CMsgDOTARealtimeGameStatsTerse.TeamDetails.players', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11707,
  serialized_end=11875,
)

_CMSGDOTAREALTIMEGAMESTATSTERSE_PLAYERDETAILS = _descriptor.Descriptor(
  name='PlayerDetails',
  full_name='CMsgDOTARealtimeGameStatsTerse.PlayerDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgDOTARealtimeGameStatsTerse.PlayerDetails.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playerid', full_name='CMsgDOTARealtimeGameStatsTerse.PlayerDetails.playerid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTARealtimeGameStatsTerse.PlayerDetails.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team', full_name='CMsgDOTARealtimeGameStatsTerse.PlayerDetails.team', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='heroid', full_name='CMsgDOTARealtimeGameStatsTerse.PlayerDetails.heroid', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='CMsgDOTARealtimeGameStatsTerse.PlayerDetails.level', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kill_count', full_name='CMsgDOTARealtimeGameStatsTerse.PlayerDetails.kill_count', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='death_count', full_name='CMsgDOTARealtimeGameStatsTerse.PlayerDetails.death_count', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assists_count', full_name='CMsgDOTARealtimeGameStatsTerse.PlayerDetails.assists_count', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='denies_count', full_name='CMsgDOTARealtimeGameStatsTerse.PlayerDetails.denies_count', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lh_count', full_name='CMsgDOTARealtimeGameStatsTerse.PlayerDetails.lh_count', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gold', full_name='CMsgDOTARealtimeGameStatsTerse.PlayerDetails.gold', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='x', full_name='CMsgDOTARealtimeGameStatsTerse.PlayerDetails.x', index=12,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='CMsgDOTARealtimeGameStatsTerse.PlayerDetails.y', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11878,
  serialized_end=12129,
)

_CMSGDOTAREALTIMEGAMESTATSTERSE_BUILDINGDETAILS = _descriptor.Descriptor(
  name='BuildingDetails',
  full_name='CMsgDOTARealtimeGameStatsTerse.BuildingDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team', full_name='CMsgDOTARealtimeGameStatsTerse.BuildingDetails.team', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='heading', full_name='CMsgDOTARealtimeGameStatsTerse.BuildingDetails.heading', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='CMsgDOTARealtimeGameStatsTerse.BuildingDetails.type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lane', full_name='CMsgDOTARealtimeGameStatsTerse.BuildingDetails.lane', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tier', full_name='CMsgDOTARealtimeGameStatsTerse.BuildingDetails.tier', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='x', full_name='CMsgDOTARealtimeGameStatsTerse.BuildingDetails.x', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='CMsgDOTARealtimeGameStatsTerse.BuildingDetails.y', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='destroyed', full_name='CMsgDOTARealtimeGameStatsTerse.BuildingDetails.destroyed', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12132,
  serialized_end=12263,
)

_CMSGDOTAREALTIMEGAMESTATSTERSE_MATCHDETAILS = _descriptor.Descriptor(
  name='MatchDetails',
  full_name='CMsgDOTARealtimeGameStatsTerse.MatchDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_steam_id', full_name='CMsgDOTARealtimeGameStatsTerse.MatchDetails.server_steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matchid', full_name='CMsgDOTARealtimeGameStatsTerse.MatchDetails.matchid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgDOTARealtimeGameStatsTerse.MatchDetails.timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_time', full_name='CMsgDOTARealtimeGameStatsTerse.MatchDetails.game_time', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steam_broadcaster_account_ids', full_name='CMsgDOTARealtimeGameStatsTerse.MatchDetails.steam_broadcaster_account_ids', index=4,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CMsgDOTARealtimeGameStatsTerse.MatchDetails.game_mode', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgDOTARealtimeGameStatsTerse.MatchDetails.league_id', index=6,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12266,
  serialized_end=12437,
)

_CMSGDOTAREALTIMEGAMESTATSTERSE_GRAPHDATA = _descriptor.Descriptor(
  name='GraphData',
  full_name='CMsgDOTARealtimeGameStatsTerse.GraphData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='graph_gold', full_name='CMsgDOTARealtimeGameStatsTerse.GraphData.graph_gold', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10901,
  serialized_end=10932,
)

_CMSGDOTAREALTIMEGAMESTATSTERSE = _descriptor.Descriptor(
  name='CMsgDOTARealtimeGameStatsTerse',
  full_name='CMsgDOTARealtimeGameStatsTerse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match', full_name='CMsgDOTARealtimeGameStatsTerse.match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teams', full_name='CMsgDOTARealtimeGameStatsTerse.teams', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='buildings', full_name='CMsgDOTARealtimeGameStatsTerse.buildings', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='graph_data', full_name='CMsgDOTARealtimeGameStatsTerse.graph_data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delta_frame', full_name='CMsgDOTARealtimeGameStatsTerse.delta_frame', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAREALTIMEGAMESTATSTERSE_TEAMDETAILS, _CMSGDOTAREALTIMEGAMESTATSTERSE_PLAYERDETAILS, _CMSGDOTAREALTIMEGAMESTATSTERSE_BUILDINGDETAILS, _CMSGDOTAREALTIMEGAMESTATSTERSE_MATCHDETAILS, _CMSGDOTAREALTIMEGAMESTATSTERSE_GRAPHDATA, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11399,
  serialized_end=12470,
)


_CMSGGCTOCLIENTMATCHGROUPSVERSION = _descriptor.Descriptor(
  name='CMsgGCToClientMatchGroupsVersion',
  full_name='CMsgGCToClientMatchGroupsVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matchgroups_version', full_name='CMsgGCToClientMatchGroupsVersion.matchgroups_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12472,
  serialized_end=12535,
)


_CMSGDOTASDOHEROSTATSHISTORY = _descriptor.Descriptor(
  name='CMsgDOTASDOHeroStatsHistory',
  full_name='CMsgDOTASDOHeroStatsHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgDOTASDOHeroStatsHistory.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CMsgDOTASDOHeroStatsHistory.game_mode', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='CMsgDOTASDOHeroStatsHistory.lobby_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='CMsgDOTASDOHeroStatsHistory.start_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='won', full_name='CMsgDOTASDOHeroStatsHistory.won', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gpm', full_name='CMsgDOTASDOHeroStatsHistory.gpm', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xpm', full_name='CMsgDOTASDOHeroStatsHistory.xpm', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kills', full_name='CMsgDOTASDOHeroStatsHistory.kills', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deaths', full_name='CMsgDOTASDOHeroStatsHistory.deaths', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assists', full_name='CMsgDOTASDOHeroStatsHistory.assists', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12538,
  serialized_end=12731,
)


_CMSGDOTASEASONREWARDS_REWARD = _descriptor.Descriptor(
  name='Reward',
  full_name='CMsgDOTASeasonRewards.Reward',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTASeasonRewards.Reward.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemdef', full_name='CMsgDOTASeasonRewards.Reward.itemdef', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='importance', full_name='CMsgDOTASeasonRewards.Reward.importance', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_level', full_name='CMsgDOTASeasonRewards.Reward.base_level', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='repeat_level', full_name='CMsgDOTASeasonRewards.Reward.repeat_level', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reward_type', full_name='CMsgDOTASeasonRewards.Reward.reward_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image', full_name='CMsgDOTASeasonRewards.Reward.image', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='action_id', full_name='CMsgDOTASeasonRewards.Reward.action_id', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='effect_index', full_name='CMsgDOTASeasonRewards.Reward.effect_index', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12808,
  serialized_end=13032,
)

_CMSGDOTASEASONREWARDS = _descriptor.Descriptor(
  name='CMsgDOTASeasonRewards',
  full_name='CMsgDOTASeasonRewards',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rewards', full_name='CMsgDOTASeasonRewards.rewards', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTASEASONREWARDS_REWARD, ],
  enum_types=[
    _CMSGDOTASEASONREWARDS_EREWARDTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12734,
  serialized_end=13109,
)


_CMSGDOTASEASONACHIEVEMENTS_ACHIEVEMENT = _descriptor.Descriptor(
  name='Achievement',
  full_name='CMsgDOTASeasonAchievements.Achievement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTASeasonAchievements.Achievement.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='CMsgDOTASeasonAchievements.Achievement.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image', full_name='CMsgDOTASeasonAchievements.Achievement.image', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='action_id', full_name='CMsgDOTASeasonAchievements.Achievement.action_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_grants', full_name='CMsgDOTASeasonAchievements.Achievement.max_grants', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='normal_points', full_name='CMsgDOTASeasonAchievements.Achievement.normal_points', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tracking_achievement', full_name='CMsgDOTASeasonAchievements.Achievement.tracking_achievement', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='achievement_goal', full_name='CMsgDOTASeasonAchievements.Achievement.achievement_goal', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='achievement_level', full_name='CMsgDOTASeasonAchievements.Achievement.achievement_level', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13206,
  serialized_end=13414,
)

_CMSGDOTASEASONACHIEVEMENTS = _descriptor.Descriptor(
  name='CMsgDOTASeasonAchievements',
  full_name='CMsgDOTASeasonAchievements',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='achievements', full_name='CMsgDOTASeasonAchievements.achievements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTASEASONACHIEVEMENTS_ACHIEVEMENT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13112,
  serialized_end=13414,
)


_CMSGDOTASEASONPREDICTIONS_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='CMsgDOTASeasonPredictions.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='CMsgDOTASeasonPredictions.Choice.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTASeasonPredictions.Choice.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_raw_value', full_name='CMsgDOTASeasonPredictions.Choice.min_raw_value', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_raw_value', full_name='CMsgDOTASeasonPredictions.Choice.max_raw_value', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13673,
  serialized_end=13756,
)

_CMSGDOTASEASONPREDICTIONS_ANSWERS = _descriptor.Descriptor(
  name='Answers',
  full_name='CMsgDOTASeasonPredictions.Answers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answer_id', full_name='CMsgDOTASeasonPredictions.Answers.answer_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13758,
  serialized_end=13786,
)

_CMSGDOTASEASONPREDICTIONS_QUERYKEYVALUES = _descriptor.Descriptor(
  name='QueryKeyValues',
  full_name='CMsgDOTASeasonPredictions.QueryKeyValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTASeasonPredictions.QueryKeyValues.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='CMsgDOTASeasonPredictions.QueryKeyValues.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13788,
  serialized_end=13833,
)

_CMSGDOTASEASONPREDICTIONS_PREDICTION = _descriptor.Descriptor(
  name='Prediction',
  full_name='CMsgDOTASeasonPredictions.Prediction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CMsgDOTASeasonPredictions.Prediction.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='question', full_name='CMsgDOTASeasonPredictions.Prediction.question', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='choices', full_name='CMsgDOTASeasonPredictions.Prediction.choices', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='selection_id', full_name='CMsgDOTASeasonPredictions.Prediction.selection_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='CMsgDOTASeasonPredictions.Prediction.start_date', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lock_date', full_name='CMsgDOTASeasonPredictions.Prediction.lock_date', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reward', full_name='CMsgDOTASeasonPredictions.Prediction.reward', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='answer_type', full_name='CMsgDOTASeasonPredictions.Prediction.answer_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='answer_id', full_name='CMsgDOTASeasonPredictions.Prediction.answer_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='answers', full_name='CMsgDOTASeasonPredictions.Prediction.answers', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='query_name', full_name='CMsgDOTASeasonPredictions.Prediction.query_name', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='query_bind_params', full_name='CMsgDOTASeasonPredictions.Prediction.query_bind_params', index=11,
      number=12, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lock_on_selection_id', full_name='CMsgDOTASeasonPredictions.Prediction.lock_on_selection_id', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lock_on_selection_value', full_name='CMsgDOTASeasonPredictions.Prediction.lock_on_selection_value', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lock_on_selection_set', full_name='CMsgDOTASeasonPredictions.Prediction.lock_on_selection_set', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13836,
  serialized_end=14347,
)

_CMSGDOTASEASONPREDICTIONS_INGAMEPREDICTION = _descriptor.Descriptor(
  name='InGamePrediction',
  full_name='CMsgDOTASeasonPredictions.InGamePrediction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgDOTASeasonPredictions.InGamePrediction.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTASeasonPredictions.InGamePrediction.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='CMsgDOTASeasonPredictions.InGamePrediction.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group', full_name='CMsgDOTASeasonPredictions.InGamePrediction.group', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='question', full_name='CMsgDOTASeasonPredictions.InGamePrediction.question', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='choices', full_name='CMsgDOTASeasonPredictions.InGamePrediction.choices', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='required_heroes', full_name='CMsgDOTASeasonPredictions.InGamePrediction.required_heroes', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='query_name', full_name='CMsgDOTASeasonPredictions.InGamePrediction.query_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='query_values', full_name='CMsgDOTASeasonPredictions.InGamePrediction.query_values', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='answer_resolution_type', full_name='CMsgDOTASeasonPredictions.InGamePrediction.answer_resolution_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='points_to_grant', full_name='CMsgDOTASeasonPredictions.InGamePrediction.points_to_grant', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reward_action', full_name='CMsgDOTASeasonPredictions.InGamePrediction.reward_action', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='debug_force_selection', full_name='CMsgDOTASeasonPredictions.InGamePrediction.debug_force_selection', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raw_value_type', full_name='CMsgDOTASeasonPredictions.InGamePrediction.raw_value_type', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14350,
  serialized_end=14966,
)

_CMSGDOTASEASONPREDICTIONS = _descriptor.Descriptor(
  name='CMsgDOTASeasonPredictions',
  full_name='CMsgDOTASeasonPredictions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='predictions', full_name='CMsgDOTASeasonPredictions.predictions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_game_predictions', full_name='CMsgDOTASeasonPredictions.in_game_predictions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_game_prediction_count_per_game', full_name='CMsgDOTASeasonPredictions.in_game_prediction_count_per_game', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_game_prediction_voting_period_minutes', full_name='CMsgDOTASeasonPredictions.in_game_prediction_voting_period_minutes', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTASEASONPREDICTIONS_CHOICE, _CMSGDOTASEASONPREDICTIONS_ANSWERS, _CMSGDOTASEASONPREDICTIONS_QUERYKEYVALUES, _CMSGDOTASEASONPREDICTIONS_PREDICTION, _CMSGDOTASEASONPREDICTIONS_INGAMEPREDICTION, ],
  enum_types=[
    _CMSGDOTASEASONPREDICTIONS_EPREDICTIONTYPE,
    _CMSGDOTASEASONPREDICTIONS_EANSWERTYPE,
    _CMSGDOTASEASONPREDICTIONS_ERESOLUTIONTYPE_T,
    _CMSGDOTASEASONPREDICTIONS_ERANDOMSELECTIONGROUP_T,
    _CMSGDOTASEASONPREDICTIONS_ERAWVALUETYPE_T,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13417,
  serialized_end=15538,
)


_CMSGDOTAMATCH_PLAYER_CUSTOMGAMEDATA = _descriptor.Descriptor(
  name='CustomGameData',
  full_name='CMsgDOTAMatch.Player.CustomGameData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dota_team', full_name='CMsgDOTAMatch.Player.CustomGameData.dota_team', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='winner', full_name='CMsgDOTAMatch.Player.CustomGameData.winner', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18259,
  serialized_end=18310,
)

_CMSGDOTAMATCH_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='CMsgDOTAMatch.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAMatch.Player.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_slot', full_name='CMsgDOTAMatch.Player.player_slot', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgDOTAMatch.Player.hero_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_0', full_name='CMsgDOTAMatch.Player.item_0', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_1', full_name='CMsgDOTAMatch.Player.item_1', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_2', full_name='CMsgDOTAMatch.Player.item_2', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_3', full_name='CMsgDOTAMatch.Player.item_3', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_4', full_name='CMsgDOTAMatch.Player.item_4', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_5', full_name='CMsgDOTAMatch.Player.item_5', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expected_team_contribution', full_name='CMsgDOTAMatch.Player.expected_team_contribution', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scaled_metric', full_name='CMsgDOTAMatch.Player.scaled_metric', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='previous_rank', full_name='CMsgDOTAMatch.Player.previous_rank', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rank_change', full_name='CMsgDOTAMatch.Player.rank_change', index=12,
      number=13, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='solo_rank', full_name='CMsgDOTAMatch.Player.solo_rank', index=13,
      number=49, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seasonal_rank', full_name='CMsgDOTAMatch.Player.seasonal_rank', index=14,
      number=53, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kills', full_name='CMsgDOTAMatch.Player.kills', index=15,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deaths', full_name='CMsgDOTAMatch.Player.deaths', index=16,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assists', full_name='CMsgDOTAMatch.Player.assists', index=17,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leaver_status', full_name='CMsgDOTAMatch.Player.leaver_status', index=18,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gold', full_name='CMsgDOTAMatch.Player.gold', index=19,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_hits', full_name='CMsgDOTAMatch.Player.last_hits', index=20,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='denies', full_name='CMsgDOTAMatch.Player.denies', index=21,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gold_per_min', full_name='CMsgDOTAMatch.Player.gold_per_min', index=22,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='XP_per_min', full_name='CMsgDOTAMatch.Player.XP_per_min', index=23,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gold_spent', full_name='CMsgDOTAMatch.Player.gold_spent', index=24,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_damage', full_name='CMsgDOTAMatch.Player.hero_damage', index=25,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tower_damage', full_name='CMsgDOTAMatch.Player.tower_damage', index=26,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_healing', full_name='CMsgDOTAMatch.Player.hero_healing', index=27,
      number=26, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='CMsgDOTAMatch.Player.level', index=28,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_last_seen', full_name='CMsgDOTAMatch.Player.time_last_seen', index=29,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_name', full_name='CMsgDOTAMatch.Player.player_name', index=30,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='support_ability_value', full_name='CMsgDOTAMatch.Player.support_ability_value', index=31,
      number=30, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='feeding_detected', full_name='CMsgDOTAMatch.Player.feeding_detected', index=32,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='search_rank', full_name='CMsgDOTAMatch.Player.search_rank', index=33,
      number=34, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='search_rank_uncertainty', full_name='CMsgDOTAMatch.Player.search_rank_uncertainty', index=34,
      number=35, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rank_uncertainty_change', full_name='CMsgDOTAMatch.Player.rank_uncertainty_change', index=35,
      number=36, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_play_count', full_name='CMsgDOTAMatch.Player.hero_play_count', index=36,
      number=37, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='party_id', full_name='CMsgDOTAMatch.Player.party_id', index=37,
      number=38, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scaled_hero_damage', full_name='CMsgDOTAMatch.Player.scaled_hero_damage', index=38,
      number=54, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scaled_tower_damage', full_name='CMsgDOTAMatch.Player.scaled_tower_damage', index=39,
      number=55, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scaled_hero_healing', full_name='CMsgDOTAMatch.Player.scaled_hero_healing', index=40,
      number=56, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scaled_kills', full_name='CMsgDOTAMatch.Player.scaled_kills', index=41,
      number=39, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scaled_deaths', full_name='CMsgDOTAMatch.Player.scaled_deaths', index=42,
      number=40, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scaled_assists', full_name='CMsgDOTAMatch.Player.scaled_assists', index=43,
      number=41, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='claimed_farm_gold', full_name='CMsgDOTAMatch.Player.claimed_farm_gold', index=44,
      number=42, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='support_gold', full_name='CMsgDOTAMatch.Player.support_gold', index=45,
      number=43, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='claimed_denies', full_name='CMsgDOTAMatch.Player.claimed_denies', index=46,
      number=44, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='claimed_misses', full_name='CMsgDOTAMatch.Player.claimed_misses', index=47,
      number=45, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='misses', full_name='CMsgDOTAMatch.Player.misses', index=48,
      number=46, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ability_upgrades', full_name='CMsgDOTAMatch.Player.ability_upgrades', index=49,
      number=47, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='additional_units_inventory', full_name='CMsgDOTAMatch.Player.additional_units_inventory', index=50,
      number=48, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permanent_buffs', full_name='CMsgDOTAMatch.Player.permanent_buffs', index=51,
      number=57, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_data', full_name='CMsgDOTAMatch.Player.custom_game_data', index=52,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active_battle_pass', full_name='CMsgDOTAMatch.Player.active_battle_pass', index=53,
      number=51, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='net_worth', full_name='CMsgDOTAMatch.Player.net_worth', index=54,
      number=52, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bot_difficulty', full_name='CMsgDOTAMatch.Player.bot_difficulty', index=55,
      number=58, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAMATCH_PLAYER_CUSTOMGAMEDATA, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16877,
  serialized_end=18310,
)

_CMSGDOTAMATCH_BROADCASTERINFO = _descriptor.Descriptor(
  name='BroadcasterInfo',
  full_name='CMsgDOTAMatch.BroadcasterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAMatch.BroadcasterInfo.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTAMatch.BroadcasterInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18312,
  serialized_end=18363,
)

_CMSGDOTAMATCH_BROADCASTERCHANNEL = _descriptor.Descriptor(
  name='BroadcasterChannel',
  full_name='CMsgDOTAMatch.BroadcasterChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CMsgDOTAMatch.BroadcasterChannel.country_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='CMsgDOTAMatch.BroadcasterChannel.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='broadcaster_infos', full_name='CMsgDOTAMatch.BroadcasterChannel.broadcaster_infos', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language_code', full_name='CMsgDOTAMatch.BroadcasterChannel.language_code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18366,
  serialized_end=18511,
)

_CMSGDOTAMATCH_CUSTOMGAMEDATA = _descriptor.Descriptor(
  name='CustomGameData',
  full_name='CMsgDOTAMatch.CustomGameData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CMsgDOTAMatch.CustomGameData.custom_game_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='map_name', full_name='CMsgDOTAMatch.CustomGameData.map_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18513,
  serialized_end=18571,
)

_CMSGDOTAMATCH = _descriptor.Descriptor(
  name='CMsgDOTAMatch',
  full_name='CMsgDOTAMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration', full_name='CMsgDOTAMatch.duration', index=0,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='CMsgDOTAMatch.startTime', index=1,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players', full_name='CMsgDOTAMatch.players', index=2,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgDOTAMatch.match_id', index=3,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tower_status', full_name='CMsgDOTAMatch.tower_status', index=4,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='barracks_status', full_name='CMsgDOTAMatch.barracks_status', index=5,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='CMsgDOTAMatch.cluster', index=6,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_blood_time', full_name='CMsgDOTAMatch.first_blood_time', index=7,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='replay_salt', full_name='CMsgDOTAMatch.replay_salt', index=8,
      number=13, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_ip', full_name='CMsgDOTAMatch.server_ip', index=9,
      number=14, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_port', full_name='CMsgDOTAMatch.server_port', index=10,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='CMsgDOTAMatch.lobby_type', index=11,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='human_players', full_name='CMsgDOTAMatch.human_players', index=12,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='average_skill', full_name='CMsgDOTAMatch.average_skill', index=13,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_balance', full_name='CMsgDOTAMatch.game_balance', index=14,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiant_team_id', full_name='CMsgDOTAMatch.radiant_team_id', index=15,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dire_team_id', full_name='CMsgDOTAMatch.dire_team_id', index=16,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leagueid', full_name='CMsgDOTAMatch.leagueid', index=17,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiant_team_name', full_name='CMsgDOTAMatch.radiant_team_name', index=18,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dire_team_name', full_name='CMsgDOTAMatch.dire_team_name', index=19,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiant_team_logo', full_name='CMsgDOTAMatch.radiant_team_logo', index=20,
      number=25, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dire_team_logo', full_name='CMsgDOTAMatch.dire_team_logo', index=21,
      number=26, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiant_team_complete', full_name='CMsgDOTAMatch.radiant_team_complete', index=22,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dire_team_complete', full_name='CMsgDOTAMatch.dire_team_complete', index=23,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='positive_votes', full_name='CMsgDOTAMatch.positive_votes', index=24,
      number=29, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='negative_votes', full_name='CMsgDOTAMatch.negative_votes', index=25,
      number=30, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CMsgDOTAMatch.game_mode', index=26,
      number=31, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='picks_bans', full_name='CMsgDOTAMatch.picks_bans', index=27,
      number=32, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_seq_num', full_name='CMsgDOTAMatch.match_seq_num', index=28,
      number=33, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='replay_state', full_name='CMsgDOTAMatch.replay_state', index=29,
      number=34, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiant_guild_id', full_name='CMsgDOTAMatch.radiant_guild_id', index=30,
      number=35, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dire_guild_id', full_name='CMsgDOTAMatch.dire_guild_id', index=31,
      number=36, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiant_team_tag', full_name='CMsgDOTAMatch.radiant_team_tag', index=32,
      number=37, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dire_team_tag', full_name='CMsgDOTAMatch.dire_team_tag', index=33,
      number=38, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_id', full_name='CMsgDOTAMatch.series_id', index=34,
      number=39, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_type', full_name='CMsgDOTAMatch.series_type', index=35,
      number=40, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='broadcaster_channels', full_name='CMsgDOTAMatch.broadcaster_channels', index=36,
      number=43, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='engine', full_name='CMsgDOTAMatch.engine', index=37,
      number=44, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_data', full_name='CMsgDOTAMatch.custom_game_data', index=38,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_flags', full_name='CMsgDOTAMatch.match_flags', index=39,
      number=46, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='private_metadata_key', full_name='CMsgDOTAMatch.private_metadata_key', index=40,
      number=47, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radiant_team_score', full_name='CMsgDOTAMatch.radiant_team_score', index=41,
      number=48, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dire_team_score', full_name='CMsgDOTAMatch.dire_team_score', index=42,
      number=49, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_outcome', full_name='CMsgDOTAMatch.match_outcome', index=43,
      number=50, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_id', full_name='CMsgDOTAMatch.tournament_id', index=44,
      number=51, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_round', full_name='CMsgDOTAMatch.tournament_round', index=45,
      number=52, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pre_game_duration', full_name='CMsgDOTAMatch.pre_game_duration', index=46,
      number=53, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAMATCH_PLAYER, _CMSGDOTAMATCH_BROADCASTERINFO, _CMSGDOTAMATCH_BROADCASTERCHANNEL, _CMSGDOTAMATCH_CUSTOMGAMEDATA, ],
  enum_types=[
    _CMSGDOTAMATCH_REPLAYSTATE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15541,
  serialized_end=18653,
)


_CMSGPLAYERCARD_STATMODIFIER = _descriptor.Descriptor(
  name='StatModifier',
  full_name='CMsgPlayerCard.StatModifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat', full_name='CMsgPlayerCard.StatModifier.stat', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='CMsgPlayerCard.StatModifier.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18747,
  serialized_end=18790,
)

_CMSGPLAYERCARD = _descriptor.Descriptor(
  name='CMsgPlayerCard',
  full_name='CMsgPlayerCard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgPlayerCard.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stat_modifier', full_name='CMsgPlayerCard.stat_modifier', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGPLAYERCARD_STATMODIFIER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18656,
  serialized_end=18790,
)


_CMSGDOTAFANTASYPLAYERSTATS = _descriptor.Descriptor(
  name='CMsgDOTAFantasyPlayerStats',
  full_name='CMsgDOTAFantasyPlayerStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_account_id', full_name='CMsgDOTAFantasyPlayerStats.player_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgDOTAFantasyPlayerStats.match_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_completed', full_name='CMsgDOTAFantasyPlayerStats.match_completed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTAFantasyPlayerStats.team_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgDOTAFantasyPlayerStats.league_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delay', full_name='CMsgDOTAFantasyPlayerStats.delay', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_id', full_name='CMsgDOTAFantasyPlayerStats.series_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_type', full_name='CMsgDOTAFantasyPlayerStats.series_type', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kills', full_name='CMsgDOTAFantasyPlayerStats.kills', index=8,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deaths', full_name='CMsgDOTAFantasyPlayerStats.deaths', index=9,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cs', full_name='CMsgDOTAFantasyPlayerStats.cs', index=10,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gpm', full_name='CMsgDOTAFantasyPlayerStats.gpm', index=11,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tower_kills', full_name='CMsgDOTAFantasyPlayerStats.tower_kills', index=12,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='roshan_kills', full_name='CMsgDOTAFantasyPlayerStats.roshan_kills', index=13,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teamfight_participation', full_name='CMsgDOTAFantasyPlayerStats.teamfight_participation', index=14,
      number=16, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wards_placed', full_name='CMsgDOTAFantasyPlayerStats.wards_placed', index=15,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='camps_stacked', full_name='CMsgDOTAFantasyPlayerStats.camps_stacked', index=16,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='runes_grabbed', full_name='CMsgDOTAFantasyPlayerStats.runes_grabbed', index=17,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_blood', full_name='CMsgDOTAFantasyPlayerStats.first_blood', index=18,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stuns', full_name='CMsgDOTAFantasyPlayerStats.stuns', index=19,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18793,
  serialized_end=19218,
)


_CMSGDOTAFANTASYPLAYERMATCHSTATS = _descriptor.Descriptor(
  name='CMsgDOTAFantasyPlayerMatchStats',
  full_name='CMsgDOTAFantasyPlayerMatchStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='CMsgDOTAFantasyPlayerMatchStats.matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19220,
  serialized_end=19299,
)


_CMSGDOTABOTDEBUGINFO_BOT_MODE = _descriptor.Descriptor(
  name='Mode',
  full_name='CMsgDOTABotDebugInfo.Bot.Mode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode_id', full_name='CMsgDOTABotDebugInfo.Bot.Mode.mode_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desire', full_name='CMsgDOTABotDebugInfo.Bot.Mode.desire', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_entity', full_name='CMsgDOTABotDebugInfo.Bot.Mode.target_entity', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_x', full_name='CMsgDOTABotDebugInfo.Bot.Mode.target_x', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_y', full_name='CMsgDOTABotDebugInfo.Bot.Mode.target_y', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_z', full_name='CMsgDOTABotDebugInfo.Bot.Mode.target_z', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19923,
  serialized_end=20039,
)

_CMSGDOTABOTDEBUGINFO_BOT = _descriptor.Descriptor(
  name='Bot',
  full_name='CMsgDOTABotDebugInfo.Bot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_owner_id', full_name='CMsgDOTABotDebugInfo.Bot.player_owner_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgDOTABotDebugInfo.Bot.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='difficulty', full_name='CMsgDOTABotDebugInfo.Bot.difficulty', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='power_current', full_name='CMsgDOTABotDebugInfo.Bot.power_current', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='power_max', full_name='CMsgDOTABotDebugInfo.Bot.power_max', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='move_target_x', full_name='CMsgDOTABotDebugInfo.Bot.move_target_x', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='move_target_y', full_name='CMsgDOTABotDebugInfo.Bot.move_target_y', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='move_target_z', full_name='CMsgDOTABotDebugInfo.Bot.move_target_z', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active_mode_id', full_name='CMsgDOTABotDebugInfo.Bot.active_mode_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='modes', full_name='CMsgDOTABotDebugInfo.Bot.modes', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTABOTDEBUGINFO_BOT_MODE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19672,
  serialized_end=20039,
)

_CMSGDOTABOTDEBUGINFO = _descriptor.Descriptor(
  name='CMsgDOTABotDebugInfo',
  full_name='CMsgDOTABotDebugInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bots', full_name='CMsgDOTABotDebugInfo.bots', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desire_push_lane_top', full_name='CMsgDOTABotDebugInfo.desire_push_lane_top', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desire_push_lane_mid', full_name='CMsgDOTABotDebugInfo.desire_push_lane_mid', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desire_push_lane_bot', full_name='CMsgDOTABotDebugInfo.desire_push_lane_bot', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desire_defend_lane_top', full_name='CMsgDOTABotDebugInfo.desire_defend_lane_top', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desire_defend_lane_mid', full_name='CMsgDOTABotDebugInfo.desire_defend_lane_mid', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desire_defend_lane_bot', full_name='CMsgDOTABotDebugInfo.desire_defend_lane_bot', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desire_farm_lane_top', full_name='CMsgDOTABotDebugInfo.desire_farm_lane_top', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desire_farm_lane_mid', full_name='CMsgDOTABotDebugInfo.desire_farm_lane_mid', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desire_farm_lane_bot', full_name='CMsgDOTABotDebugInfo.desire_farm_lane_bot', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desire_farm_roshan', full_name='CMsgDOTABotDebugInfo.desire_farm_roshan', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTABOTDEBUGINFO_BOT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19302,
  serialized_end=20039,
)

_CSODOTAGAMEACCOUNTCLIENT.fields_by_name['partner_account_type'].enum_type = gcsdk__gcmessages__pb2._PARTNERACCOUNTTYPE
_CMSGLOBBYEVENTPOINTS_ACCOUNTPOINTS.containing_type = _CMSGLOBBYEVENTPOINTS
_CMSGLOBBYEVENTPOINTS.fields_by_name['account_points'].message_type = _CMSGLOBBYEVENTPOINTS_ACCOUNTPOINTS
_CMSGLOBBYBATTLECUPVICTORYLIST.fields_by_name['winners'].message_type = _CMSGBATTLECUPVICTORY
_CMSGGCGETPLAYERCARDITEMINFORESPONSE_PLAYERCARDINFO.containing_type = _CMSGGCGETPLAYERCARDITEMINFORESPONSE
_CMSGGCGETPLAYERCARDITEMINFORESPONSE.fields_by_name['player_card_infos'].message_type = _CMSGGCGETPLAYERCARDITEMINFORESPONSE_PLAYERCARDINFO
_CCOMPENDIUMGAMETIMELINE.fields_by_name['data'].message_type = _CCOMPENDIUMTIMESTAMPEDDATA
_CCOMPENDIUMGAMELIST.fields_by_name['games'].message_type = _CCOMPENDIUMGAMETIMELINE
_CMSGDOTACOMBATLOGENTRY.fields_by_name['type'].enum_type = _DOTA_COMBATLOG_TYPES
_CMSGDOTAPROFILECARD_SLOT_TROPHY.containing_type = _CMSGDOTAPROFILECARD_SLOT
_CMSGDOTAPROFILECARD_SLOT_STAT.fields_by_name['stat_id'].enum_type = _CMSGDOTAPROFILECARD_ESTATID
_CMSGDOTAPROFILECARD_SLOT_STAT.containing_type = _CMSGDOTAPROFILECARD_SLOT
_CMSGDOTAPROFILECARD_SLOT_ITEM.containing_type = _CMSGDOTAPROFILECARD_SLOT
_CMSGDOTAPROFILECARD_SLOT_HERO.containing_type = _CMSGDOTAPROFILECARD_SLOT
_CMSGDOTAPROFILECARD_SLOT_EMOTICON.containing_type = _CMSGDOTAPROFILECARD_SLOT
_CMSGDOTAPROFILECARD_SLOT.fields_by_name['trophy'].message_type = _CMSGDOTAPROFILECARD_SLOT_TROPHY
_CMSGDOTAPROFILECARD_SLOT.fields_by_name['stat'].message_type = _CMSGDOTAPROFILECARD_SLOT_STAT
_CMSGDOTAPROFILECARD_SLOT.fields_by_name['item'].message_type = _CMSGDOTAPROFILECARD_SLOT_ITEM
_CMSGDOTAPROFILECARD_SLOT.fields_by_name['hero'].message_type = _CMSGDOTAPROFILECARD_SLOT_HERO
_CMSGDOTAPROFILECARD_SLOT.fields_by_name['emoticon'].message_type = _CMSGDOTAPROFILECARD_SLOT_EMOTICON
_CMSGDOTAPROFILECARD_SLOT.containing_type = _CMSGDOTAPROFILECARD
_CMSGDOTAPROFILECARD.fields_by_name['slots'].message_type = _CMSGDOTAPROFILECARD_SLOT
_CMSGDOTAPROFILECARD.fields_by_name['recent_battle_cup_victory'].message_type = _CMSGBATTLECUPVICTORY
_CMSGDOTAPROFILECARD_ESTATID.containing_type = _CMSGDOTAPROFILECARD
_CSODOTAPLAYERCHALLENGE_EFLAGS.containing_type = _CSODOTAPLAYERCHALLENGE
_CMSGGCREROLLPLAYERCHALLENGERESPONSE.fields_by_name['result'].enum_type = _CMSGGCREROLLPLAYERCHALLENGERESPONSE_ERESULT
_CMSGGCREROLLPLAYERCHALLENGERESPONSE_ERESULT.containing_type = _CMSGGCREROLLPLAYERCHALLENGERESPONSE
_CMSGDOTAREALTIMEGAMESTATS_TEAMDETAILS.fields_by_name['players'].message_type = _CMSGDOTAREALTIMEGAMESTATS_PLAYERDETAILS
_CMSGDOTAREALTIMEGAMESTATS_TEAMDETAILS.containing_type = _CMSGDOTAREALTIMEGAMESTATS
_CMSGDOTAREALTIMEGAMESTATS_ITEMDETAILS.containing_type = _CMSGDOTAREALTIMEGAMESTATS
_CMSGDOTAREALTIMEGAMESTATS_ABILITYDETAILS.containing_type = _CMSGDOTAREALTIMEGAMESTATS
_CMSGDOTAREALTIMEGAMESTATS_HEROTOHEROSTATS.containing_type = _CMSGDOTAREALTIMEGAMESTATS
_CMSGDOTAREALTIMEGAMESTATS_ABILITYLIST.containing_type = _CMSGDOTAREALTIMEGAMESTATS
_CMSGDOTAREALTIMEGAMESTATS_PLAYERDETAILS.fields_by_name['abilities'].message_type = _CMSGDOTAREALTIMEGAMESTATS_ABILITYDETAILS
_CMSGDOTAREALTIMEGAMESTATS_PLAYERDETAILS.fields_by_name['items'].message_type = _CMSGDOTAREALTIMEGAMESTATS_ITEMDETAILS
_CMSGDOTAREALTIMEGAMESTATS_PLAYERDETAILS.fields_by_name['stashitems'].message_type = _CMSGDOTAREALTIMEGAMESTATS_ITEMDETAILS
_CMSGDOTAREALTIMEGAMESTATS_PLAYERDETAILS.fields_by_name['itemshoppinglist'].message_type = _CMSGDOTAREALTIMEGAMESTATS_ITEMDETAILS
_CMSGDOTAREALTIMEGAMESTATS_PLAYERDETAILS.fields_by_name['levelpoints'].message_type = _CMSGDOTAREALTIMEGAMESTATS_ABILITYLIST
_CMSGDOTAREALTIMEGAMESTATS_PLAYERDETAILS.fields_by_name['hero_to_hero_stats'].message_type = _CMSGDOTAREALTIMEGAMESTATS_HEROTOHEROSTATS
_CMSGDOTAREALTIMEGAMESTATS_PLAYERDETAILS.containing_type = _CMSGDOTAREALTIMEGAMESTATS
_CMSGDOTAREALTIMEGAMESTATS_BUILDINGDETAILS.containing_type = _CMSGDOTAREALTIMEGAMESTATS
_CMSGDOTAREALTIMEGAMESTATS_KILLDETAILS.containing_type = _CMSGDOTAREALTIMEGAMESTATS
_CMSGDOTAREALTIMEGAMESTATS_BROADCASTERDETAILS.containing_type = _CMSGDOTAREALTIMEGAMESTATS
_CMSGDOTAREALTIMEGAMESTATS_PICKBANDETAILS.containing_type = _CMSGDOTAREALTIMEGAMESTATS
_CMSGDOTAREALTIMEGAMESTATS_MATCHDETAILS.fields_by_name['picks'].message_type = _CMSGDOTAREALTIMEGAMESTATS_PICKBANDETAILS
_CMSGDOTAREALTIMEGAMESTATS_MATCHDETAILS.fields_by_name['bans'].message_type = _CMSGDOTAREALTIMEGAMESTATS_PICKBANDETAILS
_CMSGDOTAREALTIMEGAMESTATS_MATCHDETAILS.fields_by_name['kills'].message_type = _CMSGDOTAREALTIMEGAMESTATS_KILLDETAILS
_CMSGDOTAREALTIMEGAMESTATS_MATCHDETAILS.fields_by_name['broadcasters'].message_type = _CMSGDOTAREALTIMEGAMESTATS_BROADCASTERDETAILS
_CMSGDOTAREALTIMEGAMESTATS_MATCHDETAILS.containing_type = _CMSGDOTAREALTIMEGAMESTATS
_CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_LOCATIONSTATS.containing_type = _CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA
_CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_TEAMLOCATIONSTATS.fields_by_name['loc_stats'].message_type = _CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_LOCATIONSTATS
_CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_TEAMLOCATIONSTATS.containing_type = _CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA
_CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA.fields_by_name['team_loc_stats'].message_type = _CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_TEAMLOCATIONSTATS
_CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA.containing_type = _CMSGDOTAREALTIMEGAMESTATS
_CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_ESTAT.containing_type = _CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA
_CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_ELOCATION.containing_type = _CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA
_CMSGDOTAREALTIMEGAMESTATS.fields_by_name['match'].message_type = _CMSGDOTAREALTIMEGAMESTATS_MATCHDETAILS
_CMSGDOTAREALTIMEGAMESTATS.fields_by_name['teams'].message_type = _CMSGDOTAREALTIMEGAMESTATS_TEAMDETAILS
_CMSGDOTAREALTIMEGAMESTATS.fields_by_name['buildings'].message_type = _CMSGDOTAREALTIMEGAMESTATS_BUILDINGDETAILS
_CMSGDOTAREALTIMEGAMESTATS.fields_by_name['graph_data'].message_type = _CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA
_CMSGDOTAREALTIMEGAMESTATSTERSE_TEAMDETAILS.fields_by_name['players'].message_type = _CMSGDOTAREALTIMEGAMESTATSTERSE_PLAYERDETAILS
_CMSGDOTAREALTIMEGAMESTATSTERSE_TEAMDETAILS.containing_type = _CMSGDOTAREALTIMEGAMESTATSTERSE
_CMSGDOTAREALTIMEGAMESTATSTERSE_PLAYERDETAILS.containing_type = _CMSGDOTAREALTIMEGAMESTATSTERSE
_CMSGDOTAREALTIMEGAMESTATSTERSE_BUILDINGDETAILS.containing_type = _CMSGDOTAREALTIMEGAMESTATSTERSE
_CMSGDOTAREALTIMEGAMESTATSTERSE_MATCHDETAILS.containing_type = _CMSGDOTAREALTIMEGAMESTATSTERSE
_CMSGDOTAREALTIMEGAMESTATSTERSE_GRAPHDATA.containing_type = _CMSGDOTAREALTIMEGAMESTATSTERSE
_CMSGDOTAREALTIMEGAMESTATSTERSE.fields_by_name['match'].message_type = _CMSGDOTAREALTIMEGAMESTATSTERSE_MATCHDETAILS
_CMSGDOTAREALTIMEGAMESTATSTERSE.fields_by_name['teams'].message_type = _CMSGDOTAREALTIMEGAMESTATSTERSE_TEAMDETAILS
_CMSGDOTAREALTIMEGAMESTATSTERSE.fields_by_name['buildings'].message_type = _CMSGDOTAREALTIMEGAMESTATSTERSE_BUILDINGDETAILS
_CMSGDOTAREALTIMEGAMESTATSTERSE.fields_by_name['graph_data'].message_type = _CMSGDOTAREALTIMEGAMESTATSTERSE_GRAPHDATA
_CMSGDOTASEASONREWARDS_REWARD.fields_by_name['reward_type'].enum_type = _CMSGDOTASEASONREWARDS_EREWARDTYPE
_CMSGDOTASEASONREWARDS_REWARD.containing_type = _CMSGDOTASEASONREWARDS
_CMSGDOTASEASONREWARDS.fields_by_name['rewards'].message_type = _CMSGDOTASEASONREWARDS_REWARD
_CMSGDOTASEASONREWARDS_EREWARDTYPE.containing_type = _CMSGDOTASEASONREWARDS
_CMSGDOTASEASONACHIEVEMENTS_ACHIEVEMENT.containing_type = _CMSGDOTASEASONACHIEVEMENTS
_CMSGDOTASEASONACHIEVEMENTS.fields_by_name['achievements'].message_type = _CMSGDOTASEASONACHIEVEMENTS_ACHIEVEMENT
_CMSGDOTASEASONPREDICTIONS_CHOICE.containing_type = _CMSGDOTASEASONPREDICTIONS
_CMSGDOTASEASONPREDICTIONS_ANSWERS.containing_type = _CMSGDOTASEASONPREDICTIONS
_CMSGDOTASEASONPREDICTIONS_QUERYKEYVALUES.containing_type = _CMSGDOTASEASONPREDICTIONS
_CMSGDOTASEASONPREDICTIONS_PREDICTION.fields_by_name['type'].enum_type = _CMSGDOTASEASONPREDICTIONS_EPREDICTIONTYPE
_CMSGDOTASEASONPREDICTIONS_PREDICTION.fields_by_name['choices'].message_type = _CMSGDOTASEASONPREDICTIONS_CHOICE
_CMSGDOTASEASONPREDICTIONS_PREDICTION.fields_by_name['answer_type'].enum_type = _CMSGDOTASEASONPREDICTIONS_EANSWERTYPE
_CMSGDOTASEASONPREDICTIONS_PREDICTION.fields_by_name['answers'].message_type = _CMSGDOTASEASONPREDICTIONS_ANSWERS
_CMSGDOTASEASONPREDICTIONS_PREDICTION.containing_type = _CMSGDOTASEASONPREDICTIONS
_CMSGDOTASEASONPREDICTIONS_INGAMEPREDICTION.fields_by_name['type'].enum_type = _CMSGDOTASEASONPREDICTIONS_EPREDICTIONTYPE
_CMSGDOTASEASONPREDICTIONS_INGAMEPREDICTION.fields_by_name['group'].enum_type = _CMSGDOTASEASONPREDICTIONS_ERANDOMSELECTIONGROUP_T
_CMSGDOTASEASONPREDICTIONS_INGAMEPREDICTION.fields_by_name['choices'].message_type = _CMSGDOTASEASONPREDICTIONS_CHOICE
_CMSGDOTASEASONPREDICTIONS_INGAMEPREDICTION.fields_by_name['query_values'].message_type = _CMSGDOTASEASONPREDICTIONS_QUERYKEYVALUES
_CMSGDOTASEASONPREDICTIONS_INGAMEPREDICTION.fields_by_name['answer_resolution_type'].enum_type = _CMSGDOTASEASONPREDICTIONS_ERESOLUTIONTYPE_T
_CMSGDOTASEASONPREDICTIONS_INGAMEPREDICTION.fields_by_name['raw_value_type'].enum_type = _CMSGDOTASEASONPREDICTIONS_ERAWVALUETYPE_T
_CMSGDOTASEASONPREDICTIONS_INGAMEPREDICTION.containing_type = _CMSGDOTASEASONPREDICTIONS
_CMSGDOTASEASONPREDICTIONS.fields_by_name['predictions'].message_type = _CMSGDOTASEASONPREDICTIONS_PREDICTION
_CMSGDOTASEASONPREDICTIONS.fields_by_name['in_game_predictions'].message_type = _CMSGDOTASEASONPREDICTIONS_INGAMEPREDICTION
_CMSGDOTASEASONPREDICTIONS_EPREDICTIONTYPE.containing_type = _CMSGDOTASEASONPREDICTIONS
_CMSGDOTASEASONPREDICTIONS_EANSWERTYPE.containing_type = _CMSGDOTASEASONPREDICTIONS
_CMSGDOTASEASONPREDICTIONS_ERESOLUTIONTYPE_T.containing_type = _CMSGDOTASEASONPREDICTIONS
_CMSGDOTASEASONPREDICTIONS_ERANDOMSELECTIONGROUP_T.containing_type = _CMSGDOTASEASONPREDICTIONS
_CMSGDOTASEASONPREDICTIONS_ERAWVALUETYPE_T.containing_type = _CMSGDOTASEASONPREDICTIONS
_CMSGDOTAMATCH_PLAYER_CUSTOMGAMEDATA.containing_type = _CMSGDOTAMATCH_PLAYER
_CMSGDOTAMATCH_PLAYER.fields_by_name['ability_upgrades'].message_type = _CMATCHPLAYERABILITYUPGRADE
_CMSGDOTAMATCH_PLAYER.fields_by_name['additional_units_inventory'].message_type = _CMATCHADDITIONALUNITINVENTORY
_CMSGDOTAMATCH_PLAYER.fields_by_name['permanent_buffs'].message_type = _CMATCHPLAYERPERMANENTBUFF
_CMSGDOTAMATCH_PLAYER.fields_by_name['custom_game_data'].message_type = _CMSGDOTAMATCH_PLAYER_CUSTOMGAMEDATA
_CMSGDOTAMATCH_PLAYER.containing_type = _CMSGDOTAMATCH
_CMSGDOTAMATCH_BROADCASTERINFO.containing_type = _CMSGDOTAMATCH
_CMSGDOTAMATCH_BROADCASTERCHANNEL.fields_by_name['broadcaster_infos'].message_type = _CMSGDOTAMATCH_BROADCASTERINFO
_CMSGDOTAMATCH_BROADCASTERCHANNEL.containing_type = _CMSGDOTAMATCH
_CMSGDOTAMATCH_CUSTOMGAMEDATA.containing_type = _CMSGDOTAMATCH
_CMSGDOTAMATCH.fields_by_name['players'].message_type = _CMSGDOTAMATCH_PLAYER
_CMSGDOTAMATCH.fields_by_name['game_mode'].enum_type = dota__shared__enums__pb2._DOTA_GAMEMODE
_CMSGDOTAMATCH.fields_by_name['picks_bans'].message_type = _CMATCHHEROSELECTEVENT
_CMSGDOTAMATCH.fields_by_name['replay_state'].enum_type = _CMSGDOTAMATCH_REPLAYSTATE
_CMSGDOTAMATCH.fields_by_name['broadcaster_channels'].message_type = _CMSGDOTAMATCH_BROADCASTERCHANNEL
_CMSGDOTAMATCH.fields_by_name['custom_game_data'].message_type = _CMSGDOTAMATCH_CUSTOMGAMEDATA
_CMSGDOTAMATCH.fields_by_name['match_outcome'].enum_type = dota__shared__enums__pb2._EMATCHOUTCOME
_CMSGDOTAMATCH_REPLAYSTATE.containing_type = _CMSGDOTAMATCH
_CMSGPLAYERCARD_STATMODIFIER.containing_type = _CMSGPLAYERCARD
_CMSGPLAYERCARD.fields_by_name['stat_modifier'].message_type = _CMSGPLAYERCARD_STATMODIFIER
_CMSGDOTAFANTASYPLAYERMATCHSTATS.fields_by_name['matches'].message_type = _CMSGDOTAFANTASYPLAYERSTATS
_CMSGDOTABOTDEBUGINFO_BOT_MODE.containing_type = _CMSGDOTABOTDEBUGINFO_BOT
_CMSGDOTABOTDEBUGINFO_BOT.fields_by_name['modes'].message_type = _CMSGDOTABOTDEBUGINFO_BOT_MODE
_CMSGDOTABOTDEBUGINFO_BOT.containing_type = _CMSGDOTABOTDEBUGINFO
_CMSGDOTABOTDEBUGINFO.fields_by_name['bots'].message_type = _CMSGDOTABOTDEBUGINFO_BOT
DESCRIPTOR.message_types_by_name['CSODOTAGameAccountClient'] = _CSODOTAGAMEACCOUNTCLIENT
DESCRIPTOR.message_types_by_name['CMsgLobbyEventPoints'] = _CMSGLOBBYEVENTPOINTS
DESCRIPTOR.message_types_by_name['CMsgBattleCupVictory'] = _CMSGBATTLECUPVICTORY
DESCRIPTOR.message_types_by_name['CMsgLobbyBattleCupVictoryList'] = _CMSGLOBBYBATTLECUPVICTORYLIST
DESCRIPTOR.message_types_by_name['CMsgDOTABroadcastNotification'] = _CMSGDOTABROADCASTNOTIFICATION
DESCRIPTOR.message_types_by_name['CProtoItemHeroStatue'] = _CPROTOITEMHEROSTATUE
DESCRIPTOR.message_types_by_name['CProtoItemTeamShowcase'] = _CPROTOITEMTEAMSHOWCASE
DESCRIPTOR.message_types_by_name['CMatchPlayerAbilityUpgrade'] = _CMATCHPLAYERABILITYUPGRADE
DESCRIPTOR.message_types_by_name['CMatchAdditionalUnitInventory'] = _CMATCHADDITIONALUNITINVENTORY
DESCRIPTOR.message_types_by_name['CMatchPlayerPermanentBuff'] = _CMATCHPLAYERPERMANENTBUFF
DESCRIPTOR.message_types_by_name['CMatchHeroSelectEvent'] = _CMATCHHEROSELECTEVENT
DESCRIPTOR.message_types_by_name['CMsgDOTAProcessFantasyScheduledEvent'] = _CMSGDOTAPROCESSFANTASYSCHEDULEDEVENT
DESCRIPTOR.message_types_by_name['CMsgDOTAHasItemQuery'] = _CMSGDOTAHASITEMQUERY
DESCRIPTOR.message_types_by_name['CMsgDOTAHasItemResponse'] = _CMSGDOTAHASITEMRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAHasItemDefsQuery'] = _CMSGDOTAHASITEMDEFSQUERY
DESCRIPTOR.message_types_by_name['CMsgDOTAHasItemDefsResponse'] = _CMSGDOTAHASITEMDEFSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCGetPlayerCardItemInfo'] = _CMSGGCGETPLAYERCARDITEMINFO
DESCRIPTOR.message_types_by_name['CMsgGCGetPlayerCardItemInfoResponse'] = _CMSGGCGETPLAYERCARDITEMINFORESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCFantasySetMatchLeague'] = _CMSGGCTOGCFANTASYSETMATCHLEAGUE
DESCRIPTOR.message_types_by_name['CSODOTAMapLocationState'] = _CSODOTAMAPLOCATIONSTATE
DESCRIPTOR.message_types_by_name['CMsgLeagueAdminList'] = _CMSGLEAGUEADMINLIST
DESCRIPTOR.message_types_by_name['CCompendiumTimestampedData'] = _CCOMPENDIUMTIMESTAMPEDDATA
DESCRIPTOR.message_types_by_name['CCompendiumGameTimeline'] = _CCOMPENDIUMGAMETIMELINE
DESCRIPTOR.message_types_by_name['CCompendiumGameList'] = _CCOMPENDIUMGAMELIST
DESCRIPTOR.message_types_by_name['CAdditionalEquipSlot'] = _CADDITIONALEQUIPSLOT
DESCRIPTOR.message_types_by_name['CMsgDOTACombatLogEntry'] = _CMSGDOTACOMBATLOGENTRY
DESCRIPTOR.message_types_by_name['CMsgDOTAProfileCard'] = _CMSGDOTAPROFILECARD
DESCRIPTOR.message_types_by_name['CSODOTAPlayerChallenge'] = _CSODOTAPLAYERCHALLENGE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRerollPlayerChallenge'] = _CMSGCLIENTTOGCREROLLPLAYERCHALLENGE
DESCRIPTOR.message_types_by_name['CMsgGCRerollPlayerChallengeResponse'] = _CMSGGCREROLLPLAYERCHALLENGERESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCTopCustomGamesList'] = _CMSGGCTOPCUSTOMGAMESLIST
DESCRIPTOR.message_types_by_name['CMsgDOTARealtimeGameStats'] = _CMSGDOTAREALTIMEGAMESTATS
DESCRIPTOR.message_types_by_name['CMsgDOTARealtimeGameStatsTerse'] = _CMSGDOTAREALTIMEGAMESTATSTERSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientMatchGroupsVersion'] = _CMSGGCTOCLIENTMATCHGROUPSVERSION
DESCRIPTOR.message_types_by_name['CMsgDOTASDOHeroStatsHistory'] = _CMSGDOTASDOHEROSTATSHISTORY
DESCRIPTOR.message_types_by_name['CMsgDOTASeasonRewards'] = _CMSGDOTASEASONREWARDS
DESCRIPTOR.message_types_by_name['CMsgDOTASeasonAchievements'] = _CMSGDOTASEASONACHIEVEMENTS
DESCRIPTOR.message_types_by_name['CMsgDOTASeasonPredictions'] = _CMSGDOTASEASONPREDICTIONS
DESCRIPTOR.message_types_by_name['CMsgDOTAMatch'] = _CMSGDOTAMATCH
DESCRIPTOR.message_types_by_name['CMsgPlayerCard'] = _CMSGPLAYERCARD
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyPlayerStats'] = _CMSGDOTAFANTASYPLAYERSTATS
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyPlayerMatchStats'] = _CMSGDOTAFANTASYPLAYERMATCHSTATS
DESCRIPTOR.message_types_by_name['CMsgDOTABotDebugInfo'] = _CMSGDOTABOTDEBUGINFO
DESCRIPTOR.enum_types_by_name['ESpecialPingValue'] = _ESPECIALPINGVALUE
DESCRIPTOR.enum_types_by_name['EDOTAGCSessionNeed'] = _EDOTAGCSESSIONNEED
DESCRIPTOR.enum_types_by_name['DOTA_TournamentEvents'] = _DOTA_TOURNAMENTEVENTS
DESCRIPTOR.enum_types_by_name['DOTA_COMBATLOG_TYPES'] = _DOTA_COMBATLOG_TYPES

CSODOTAGameAccountClient = _reflection.GeneratedProtocolMessageType('CSODOTAGameAccountClient', (_message.Message,), dict(
  DESCRIPTOR = _CSODOTAGAMEACCOUNTCLIENT,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CSODOTAGameAccountClient)
  ))
_sym_db.RegisterMessage(CSODOTAGameAccountClient)

CMsgLobbyEventPoints = _reflection.GeneratedProtocolMessageType('CMsgLobbyEventPoints', (_message.Message,), dict(

  AccountPoints = _reflection.GeneratedProtocolMessageType('AccountPoints', (_message.Message,), dict(
    DESCRIPTOR = _CMSGLOBBYEVENTPOINTS_ACCOUNTPOINTS,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgLobbyEventPoints.AccountPoints)
    ))
  ,
  DESCRIPTOR = _CMSGLOBBYEVENTPOINTS,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgLobbyEventPoints)
  ))
_sym_db.RegisterMessage(CMsgLobbyEventPoints)
_sym_db.RegisterMessage(CMsgLobbyEventPoints.AccountPoints)

CMsgBattleCupVictory = _reflection.GeneratedProtocolMessageType('CMsgBattleCupVictory', (_message.Message,), dict(
  DESCRIPTOR = _CMSGBATTLECUPVICTORY,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgBattleCupVictory)
  ))
_sym_db.RegisterMessage(CMsgBattleCupVictory)

CMsgLobbyBattleCupVictoryList = _reflection.GeneratedProtocolMessageType('CMsgLobbyBattleCupVictoryList', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLOBBYBATTLECUPVICTORYLIST,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgLobbyBattleCupVictoryList)
  ))
_sym_db.RegisterMessage(CMsgLobbyBattleCupVictoryList)

CMsgDOTABroadcastNotification = _reflection.GeneratedProtocolMessageType('CMsgDOTABroadcastNotification', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTABROADCASTNOTIFICATION,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTABroadcastNotification)
  ))
_sym_db.RegisterMessage(CMsgDOTABroadcastNotification)

CProtoItemHeroStatue = _reflection.GeneratedProtocolMessageType('CProtoItemHeroStatue', (_message.Message,), dict(
  DESCRIPTOR = _CPROTOITEMHEROSTATUE,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CProtoItemHeroStatue)
  ))
_sym_db.RegisterMessage(CProtoItemHeroStatue)

CProtoItemTeamShowcase = _reflection.GeneratedProtocolMessageType('CProtoItemTeamShowcase', (_message.Message,), dict(
  DESCRIPTOR = _CPROTOITEMTEAMSHOWCASE,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CProtoItemTeamShowcase)
  ))
_sym_db.RegisterMessage(CProtoItemTeamShowcase)

CMatchPlayerAbilityUpgrade = _reflection.GeneratedProtocolMessageType('CMatchPlayerAbilityUpgrade', (_message.Message,), dict(
  DESCRIPTOR = _CMATCHPLAYERABILITYUPGRADE,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMatchPlayerAbilityUpgrade)
  ))
_sym_db.RegisterMessage(CMatchPlayerAbilityUpgrade)

CMatchAdditionalUnitInventory = _reflection.GeneratedProtocolMessageType('CMatchAdditionalUnitInventory', (_message.Message,), dict(
  DESCRIPTOR = _CMATCHADDITIONALUNITINVENTORY,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMatchAdditionalUnitInventory)
  ))
_sym_db.RegisterMessage(CMatchAdditionalUnitInventory)

CMatchPlayerPermanentBuff = _reflection.GeneratedProtocolMessageType('CMatchPlayerPermanentBuff', (_message.Message,), dict(
  DESCRIPTOR = _CMATCHPLAYERPERMANENTBUFF,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMatchPlayerPermanentBuff)
  ))
_sym_db.RegisterMessage(CMatchPlayerPermanentBuff)

CMatchHeroSelectEvent = _reflection.GeneratedProtocolMessageType('CMatchHeroSelectEvent', (_message.Message,), dict(
  DESCRIPTOR = _CMATCHHEROSELECTEVENT,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMatchHeroSelectEvent)
  ))
_sym_db.RegisterMessage(CMatchHeroSelectEvent)

CMsgDOTAProcessFantasyScheduledEvent = _reflection.GeneratedProtocolMessageType('CMsgDOTAProcessFantasyScheduledEvent', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPROCESSFANTASYSCHEDULEDEVENT,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAProcessFantasyScheduledEvent)
  ))
_sym_db.RegisterMessage(CMsgDOTAProcessFantasyScheduledEvent)

CMsgDOTAHasItemQuery = _reflection.GeneratedProtocolMessageType('CMsgDOTAHasItemQuery', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAHASITEMQUERY,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAHasItemQuery)
  ))
_sym_db.RegisterMessage(CMsgDOTAHasItemQuery)

CMsgDOTAHasItemResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAHasItemResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAHASITEMRESPONSE,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAHasItemResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAHasItemResponse)

CMsgDOTAHasItemDefsQuery = _reflection.GeneratedProtocolMessageType('CMsgDOTAHasItemDefsQuery', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAHASITEMDEFSQUERY,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAHasItemDefsQuery)
  ))
_sym_db.RegisterMessage(CMsgDOTAHasItemDefsQuery)

CMsgDOTAHasItemDefsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAHasItemDefsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAHASITEMDEFSRESPONSE,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAHasItemDefsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAHasItemDefsResponse)

CMsgGCGetPlayerCardItemInfo = _reflection.GeneratedProtocolMessageType('CMsgGCGetPlayerCardItemInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCGETPLAYERCARDITEMINFO,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCGetPlayerCardItemInfo)
  ))
_sym_db.RegisterMessage(CMsgGCGetPlayerCardItemInfo)

CMsgGCGetPlayerCardItemInfoResponse = _reflection.GeneratedProtocolMessageType('CMsgGCGetPlayerCardItemInfoResponse', (_message.Message,), dict(

  PlayerCardInfo = _reflection.GeneratedProtocolMessageType('PlayerCardInfo', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCGETPLAYERCARDITEMINFORESPONSE_PLAYERCARDINFO,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCGetPlayerCardItemInfoResponse.PlayerCardInfo)
    ))
  ,
  DESCRIPTOR = _CMSGGCGETPLAYERCARDITEMINFORESPONSE,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCGetPlayerCardItemInfoResponse)
  ))
_sym_db.RegisterMessage(CMsgGCGetPlayerCardItemInfoResponse)
_sym_db.RegisterMessage(CMsgGCGetPlayerCardItemInfoResponse.PlayerCardInfo)

CMsgGCToGCFantasySetMatchLeague = _reflection.GeneratedProtocolMessageType('CMsgGCToGCFantasySetMatchLeague', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCFANTASYSETMATCHLEAGUE,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCFantasySetMatchLeague)
  ))
_sym_db.RegisterMessage(CMsgGCToGCFantasySetMatchLeague)

CSODOTAMapLocationState = _reflection.GeneratedProtocolMessageType('CSODOTAMapLocationState', (_message.Message,), dict(
  DESCRIPTOR = _CSODOTAMAPLOCATIONSTATE,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CSODOTAMapLocationState)
  ))
_sym_db.RegisterMessage(CSODOTAMapLocationState)

CMsgLeagueAdminList = _reflection.GeneratedProtocolMessageType('CMsgLeagueAdminList', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLEAGUEADMINLIST,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgLeagueAdminList)
  ))
_sym_db.RegisterMessage(CMsgLeagueAdminList)

CCompendiumTimestampedData = _reflection.GeneratedProtocolMessageType('CCompendiumTimestampedData', (_message.Message,), dict(
  DESCRIPTOR = _CCOMPENDIUMTIMESTAMPEDDATA,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CCompendiumTimestampedData)
  ))
_sym_db.RegisterMessage(CCompendiumTimestampedData)

CCompendiumGameTimeline = _reflection.GeneratedProtocolMessageType('CCompendiumGameTimeline', (_message.Message,), dict(
  DESCRIPTOR = _CCOMPENDIUMGAMETIMELINE,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CCompendiumGameTimeline)
  ))
_sym_db.RegisterMessage(CCompendiumGameTimeline)

CCompendiumGameList = _reflection.GeneratedProtocolMessageType('CCompendiumGameList', (_message.Message,), dict(
  DESCRIPTOR = _CCOMPENDIUMGAMELIST,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CCompendiumGameList)
  ))
_sym_db.RegisterMessage(CCompendiumGameList)

CAdditionalEquipSlot = _reflection.GeneratedProtocolMessageType('CAdditionalEquipSlot', (_message.Message,), dict(
  DESCRIPTOR = _CADDITIONALEQUIPSLOT,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CAdditionalEquipSlot)
  ))
_sym_db.RegisterMessage(CAdditionalEquipSlot)

CMsgDOTACombatLogEntry = _reflection.GeneratedProtocolMessageType('CMsgDOTACombatLogEntry', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACOMBATLOGENTRY,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTACombatLogEntry)
  ))
_sym_db.RegisterMessage(CMsgDOTACombatLogEntry)

CMsgDOTAProfileCard = _reflection.GeneratedProtocolMessageType('CMsgDOTAProfileCard', (_message.Message,), dict(

  Slot = _reflection.GeneratedProtocolMessageType('Slot', (_message.Message,), dict(

    Trophy = _reflection.GeneratedProtocolMessageType('Trophy', (_message.Message,), dict(
      DESCRIPTOR = _CMSGDOTAPROFILECARD_SLOT_TROPHY,
      __module__ = 'dota_gcmessages_common_pb2'
      # @@protoc_insertion_point(class_scope:CMsgDOTAProfileCard.Slot.Trophy)
      ))
    ,

    Stat = _reflection.GeneratedProtocolMessageType('Stat', (_message.Message,), dict(
      DESCRIPTOR = _CMSGDOTAPROFILECARD_SLOT_STAT,
      __module__ = 'dota_gcmessages_common_pb2'
      # @@protoc_insertion_point(class_scope:CMsgDOTAProfileCard.Slot.Stat)
      ))
    ,

    Item = _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), dict(
      DESCRIPTOR = _CMSGDOTAPROFILECARD_SLOT_ITEM,
      __module__ = 'dota_gcmessages_common_pb2'
      # @@protoc_insertion_point(class_scope:CMsgDOTAProfileCard.Slot.Item)
      ))
    ,

    Hero = _reflection.GeneratedProtocolMessageType('Hero', (_message.Message,), dict(
      DESCRIPTOR = _CMSGDOTAPROFILECARD_SLOT_HERO,
      __module__ = 'dota_gcmessages_common_pb2'
      # @@protoc_insertion_point(class_scope:CMsgDOTAProfileCard.Slot.Hero)
      ))
    ,

    Emoticon = _reflection.GeneratedProtocolMessageType('Emoticon', (_message.Message,), dict(
      DESCRIPTOR = _CMSGDOTAPROFILECARD_SLOT_EMOTICON,
      __module__ = 'dota_gcmessages_common_pb2'
      # @@protoc_insertion_point(class_scope:CMsgDOTAProfileCard.Slot.Emoticon)
      ))
    ,
    DESCRIPTOR = _CMSGDOTAPROFILECARD_SLOT,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAProfileCard.Slot)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAPROFILECARD,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAProfileCard)
  ))
_sym_db.RegisterMessage(CMsgDOTAProfileCard)
_sym_db.RegisterMessage(CMsgDOTAProfileCard.Slot)
_sym_db.RegisterMessage(CMsgDOTAProfileCard.Slot.Trophy)
_sym_db.RegisterMessage(CMsgDOTAProfileCard.Slot.Stat)
_sym_db.RegisterMessage(CMsgDOTAProfileCard.Slot.Item)
_sym_db.RegisterMessage(CMsgDOTAProfileCard.Slot.Hero)
_sym_db.RegisterMessage(CMsgDOTAProfileCard.Slot.Emoticon)

CSODOTAPlayerChallenge = _reflection.GeneratedProtocolMessageType('CSODOTAPlayerChallenge', (_message.Message,), dict(
  DESCRIPTOR = _CSODOTAPLAYERCHALLENGE,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CSODOTAPlayerChallenge)
  ))
_sym_db.RegisterMessage(CSODOTAPlayerChallenge)

CMsgClientToGCRerollPlayerChallenge = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRerollPlayerChallenge', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREROLLPLAYERCHALLENGE,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRerollPlayerChallenge)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRerollPlayerChallenge)

CMsgGCRerollPlayerChallengeResponse = _reflection.GeneratedProtocolMessageType('CMsgGCRerollPlayerChallengeResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCREROLLPLAYERCHALLENGERESPONSE,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCRerollPlayerChallengeResponse)
  ))
_sym_db.RegisterMessage(CMsgGCRerollPlayerChallengeResponse)

CMsgGCTopCustomGamesList = _reflection.GeneratedProtocolMessageType('CMsgGCTopCustomGamesList', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOPCUSTOMGAMESLIST,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCTopCustomGamesList)
  ))
_sym_db.RegisterMessage(CMsgGCTopCustomGamesList)

CMsgDOTARealtimeGameStats = _reflection.GeneratedProtocolMessageType('CMsgDOTARealtimeGameStats', (_message.Message,), dict(

  TeamDetails = _reflection.GeneratedProtocolMessageType('TeamDetails', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATS_TEAMDETAILS,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStats.TeamDetails)
    ))
  ,

  ItemDetails = _reflection.GeneratedProtocolMessageType('ItemDetails', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATS_ITEMDETAILS,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStats.ItemDetails)
    ))
  ,

  AbilityDetails = _reflection.GeneratedProtocolMessageType('AbilityDetails', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATS_ABILITYDETAILS,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStats.AbilityDetails)
    ))
  ,

  HeroToHeroStats = _reflection.GeneratedProtocolMessageType('HeroToHeroStats', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATS_HEROTOHEROSTATS,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStats.HeroToHeroStats)
    ))
  ,

  AbilityList = _reflection.GeneratedProtocolMessageType('AbilityList', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATS_ABILITYLIST,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStats.AbilityList)
    ))
  ,

  PlayerDetails = _reflection.GeneratedProtocolMessageType('PlayerDetails', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATS_PLAYERDETAILS,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStats.PlayerDetails)
    ))
  ,

  BuildingDetails = _reflection.GeneratedProtocolMessageType('BuildingDetails', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATS_BUILDINGDETAILS,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStats.BuildingDetails)
    ))
  ,

  KillDetails = _reflection.GeneratedProtocolMessageType('KillDetails', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATS_KILLDETAILS,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStats.KillDetails)
    ))
  ,

  BroadcasterDetails = _reflection.GeneratedProtocolMessageType('BroadcasterDetails', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATS_BROADCASTERDETAILS,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStats.BroadcasterDetails)
    ))
  ,

  PickBanDetails = _reflection.GeneratedProtocolMessageType('PickBanDetails', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATS_PICKBANDETAILS,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStats.PickBanDetails)
    ))
  ,

  MatchDetails = _reflection.GeneratedProtocolMessageType('MatchDetails', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATS_MATCHDETAILS,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStats.MatchDetails)
    ))
  ,

  GraphData = _reflection.GeneratedProtocolMessageType('GraphData', (_message.Message,), dict(

    LocationStats = _reflection.GeneratedProtocolMessageType('LocationStats', (_message.Message,), dict(
      DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_LOCATIONSTATS,
      __module__ = 'dota_gcmessages_common_pb2'
      # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStats.GraphData.LocationStats)
      ))
    ,

    TeamLocationStats = _reflection.GeneratedProtocolMessageType('TeamLocationStats', (_message.Message,), dict(
      DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA_TEAMLOCATIONSTATS,
      __module__ = 'dota_gcmessages_common_pb2'
      # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStats.GraphData.TeamLocationStats)
      ))
    ,
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATS_GRAPHDATA,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStats.GraphData)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATS,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStats)
  ))
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStats)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStats.TeamDetails)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStats.ItemDetails)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStats.AbilityDetails)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStats.HeroToHeroStats)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStats.AbilityList)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStats.PlayerDetails)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStats.BuildingDetails)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStats.KillDetails)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStats.BroadcasterDetails)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStats.PickBanDetails)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStats.MatchDetails)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStats.GraphData)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStats.GraphData.LocationStats)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStats.GraphData.TeamLocationStats)

CMsgDOTARealtimeGameStatsTerse = _reflection.GeneratedProtocolMessageType('CMsgDOTARealtimeGameStatsTerse', (_message.Message,), dict(

  TeamDetails = _reflection.GeneratedProtocolMessageType('TeamDetails', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATSTERSE_TEAMDETAILS,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStatsTerse.TeamDetails)
    ))
  ,

  PlayerDetails = _reflection.GeneratedProtocolMessageType('PlayerDetails', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATSTERSE_PLAYERDETAILS,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStatsTerse.PlayerDetails)
    ))
  ,

  BuildingDetails = _reflection.GeneratedProtocolMessageType('BuildingDetails', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATSTERSE_BUILDINGDETAILS,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStatsTerse.BuildingDetails)
    ))
  ,

  MatchDetails = _reflection.GeneratedProtocolMessageType('MatchDetails', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATSTERSE_MATCHDETAILS,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStatsTerse.MatchDetails)
    ))
  ,

  GraphData = _reflection.GeneratedProtocolMessageType('GraphData', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATSTERSE_GRAPHDATA,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStatsTerse.GraphData)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAREALTIMEGAMESTATSTERSE,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTARealtimeGameStatsTerse)
  ))
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStatsTerse)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStatsTerse.TeamDetails)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStatsTerse.PlayerDetails)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStatsTerse.BuildingDetails)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStatsTerse.MatchDetails)
_sym_db.RegisterMessage(CMsgDOTARealtimeGameStatsTerse.GraphData)

CMsgGCToClientMatchGroupsVersion = _reflection.GeneratedProtocolMessageType('CMsgGCToClientMatchGroupsVersion', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTMATCHGROUPSVERSION,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientMatchGroupsVersion)
  ))
_sym_db.RegisterMessage(CMsgGCToClientMatchGroupsVersion)

CMsgDOTASDOHeroStatsHistory = _reflection.GeneratedProtocolMessageType('CMsgDOTASDOHeroStatsHistory', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASDOHEROSTATSHISTORY,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTASDOHeroStatsHistory)
  ))
_sym_db.RegisterMessage(CMsgDOTASDOHeroStatsHistory)

CMsgDOTASeasonRewards = _reflection.GeneratedProtocolMessageType('CMsgDOTASeasonRewards', (_message.Message,), dict(

  Reward = _reflection.GeneratedProtocolMessageType('Reward', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTASEASONREWARDS_REWARD,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTASeasonRewards.Reward)
    ))
  ,
  DESCRIPTOR = _CMSGDOTASEASONREWARDS,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTASeasonRewards)
  ))
_sym_db.RegisterMessage(CMsgDOTASeasonRewards)
_sym_db.RegisterMessage(CMsgDOTASeasonRewards.Reward)

CMsgDOTASeasonAchievements = _reflection.GeneratedProtocolMessageType('CMsgDOTASeasonAchievements', (_message.Message,), dict(

  Achievement = _reflection.GeneratedProtocolMessageType('Achievement', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTASEASONACHIEVEMENTS_ACHIEVEMENT,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTASeasonAchievements.Achievement)
    ))
  ,
  DESCRIPTOR = _CMSGDOTASEASONACHIEVEMENTS,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTASeasonAchievements)
  ))
_sym_db.RegisterMessage(CMsgDOTASeasonAchievements)
_sym_db.RegisterMessage(CMsgDOTASeasonAchievements.Achievement)

CMsgDOTASeasonPredictions = _reflection.GeneratedProtocolMessageType('CMsgDOTASeasonPredictions', (_message.Message,), dict(

  Choice = _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTASEASONPREDICTIONS_CHOICE,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTASeasonPredictions.Choice)
    ))
  ,

  Answers = _reflection.GeneratedProtocolMessageType('Answers', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTASEASONPREDICTIONS_ANSWERS,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTASeasonPredictions.Answers)
    ))
  ,

  QueryKeyValues = _reflection.GeneratedProtocolMessageType('QueryKeyValues', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTASEASONPREDICTIONS_QUERYKEYVALUES,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTASeasonPredictions.QueryKeyValues)
    ))
  ,

  Prediction = _reflection.GeneratedProtocolMessageType('Prediction', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTASEASONPREDICTIONS_PREDICTION,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTASeasonPredictions.Prediction)
    ))
  ,

  InGamePrediction = _reflection.GeneratedProtocolMessageType('InGamePrediction', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTASEASONPREDICTIONS_INGAMEPREDICTION,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTASeasonPredictions.InGamePrediction)
    ))
  ,
  DESCRIPTOR = _CMSGDOTASEASONPREDICTIONS,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTASeasonPredictions)
  ))
_sym_db.RegisterMessage(CMsgDOTASeasonPredictions)
_sym_db.RegisterMessage(CMsgDOTASeasonPredictions.Choice)
_sym_db.RegisterMessage(CMsgDOTASeasonPredictions.Answers)
_sym_db.RegisterMessage(CMsgDOTASeasonPredictions.QueryKeyValues)
_sym_db.RegisterMessage(CMsgDOTASeasonPredictions.Prediction)
_sym_db.RegisterMessage(CMsgDOTASeasonPredictions.InGamePrediction)

CMsgDOTAMatch = _reflection.GeneratedProtocolMessageType('CMsgDOTAMatch', (_message.Message,), dict(

  Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), dict(

    CustomGameData = _reflection.GeneratedProtocolMessageType('CustomGameData', (_message.Message,), dict(
      DESCRIPTOR = _CMSGDOTAMATCH_PLAYER_CUSTOMGAMEDATA,
      __module__ = 'dota_gcmessages_common_pb2'
      # @@protoc_insertion_point(class_scope:CMsgDOTAMatch.Player.CustomGameData)
      ))
    ,
    DESCRIPTOR = _CMSGDOTAMATCH_PLAYER,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAMatch.Player)
    ))
  ,

  BroadcasterInfo = _reflection.GeneratedProtocolMessageType('BroadcasterInfo', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAMATCH_BROADCASTERINFO,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAMatch.BroadcasterInfo)
    ))
  ,

  BroadcasterChannel = _reflection.GeneratedProtocolMessageType('BroadcasterChannel', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAMATCH_BROADCASTERCHANNEL,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAMatch.BroadcasterChannel)
    ))
  ,

  CustomGameData = _reflection.GeneratedProtocolMessageType('CustomGameData', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAMATCH_CUSTOMGAMEDATA,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAMatch.CustomGameData)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAMATCH,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAMatch)
  ))
_sym_db.RegisterMessage(CMsgDOTAMatch)
_sym_db.RegisterMessage(CMsgDOTAMatch.Player)
_sym_db.RegisterMessage(CMsgDOTAMatch.Player.CustomGameData)
_sym_db.RegisterMessage(CMsgDOTAMatch.BroadcasterInfo)
_sym_db.RegisterMessage(CMsgDOTAMatch.BroadcasterChannel)
_sym_db.RegisterMessage(CMsgDOTAMatch.CustomGameData)

CMsgPlayerCard = _reflection.GeneratedProtocolMessageType('CMsgPlayerCard', (_message.Message,), dict(

  StatModifier = _reflection.GeneratedProtocolMessageType('StatModifier', (_message.Message,), dict(
    DESCRIPTOR = _CMSGPLAYERCARD_STATMODIFIER,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgPlayerCard.StatModifier)
    ))
  ,
  DESCRIPTOR = _CMSGPLAYERCARD,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPlayerCard)
  ))
_sym_db.RegisterMessage(CMsgPlayerCard)
_sym_db.RegisterMessage(CMsgPlayerCard.StatModifier)

CMsgDOTAFantasyPlayerStats = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyPlayerStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYPLAYERSTATS,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyPlayerStats)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyPlayerStats)

CMsgDOTAFantasyPlayerMatchStats = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyPlayerMatchStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYPLAYERMATCHSTATS,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyPlayerMatchStats)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyPlayerMatchStats)

CMsgDOTABotDebugInfo = _reflection.GeneratedProtocolMessageType('CMsgDOTABotDebugInfo', (_message.Message,), dict(

  Bot = _reflection.GeneratedProtocolMessageType('Bot', (_message.Message,), dict(

    Mode = _reflection.GeneratedProtocolMessageType('Mode', (_message.Message,), dict(
      DESCRIPTOR = _CMSGDOTABOTDEBUGINFO_BOT_MODE,
      __module__ = 'dota_gcmessages_common_pb2'
      # @@protoc_insertion_point(class_scope:CMsgDOTABotDebugInfo.Bot.Mode)
      ))
    ,
    DESCRIPTOR = _CMSGDOTABOTDEBUGINFO_BOT,
    __module__ = 'dota_gcmessages_common_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTABotDebugInfo.Bot)
    ))
  ,
  DESCRIPTOR = _CMSGDOTABOTDEBUGINFO,
  __module__ = 'dota_gcmessages_common_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTABotDebugInfo)
  ))
_sym_db.RegisterMessage(CMsgDOTABotDebugInfo)
_sym_db.RegisterMessage(CMsgDOTABotDebugInfo.Bot)
_sym_db.RegisterMessage(CMsgDOTABotDebugInfo.Bot.Mode)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
_CSODOTAGAMEACCOUNTCLIENT.fields_by_name['account_id'].has_options = True
_CSODOTAGAMEACCOUNTCLIENT.fields_by_name['account_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
_CSODOTAMAPLOCATIONSTATE.fields_by_name['account_id'].has_options = True
_CSODOTAMAPLOCATIONSTATE.fields_by_name['account_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
_CSODOTAMAPLOCATIONSTATE.fields_by_name['location_id'].has_options = True
_CSODOTAMAPLOCATIONSTATE.fields_by_name['location_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
_CSODOTAPLAYERCHALLENGE.fields_by_name['account_id'].has_options = True
_CSODOTAPLAYERCHALLENGE.fields_by_name['account_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
_CSODOTAPLAYERCHALLENGE.fields_by_name['event_id'].has_options = True
_CSODOTAPLAYERCHALLENGE.fields_by_name['event_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
_CSODOTAPLAYERCHALLENGE.fields_by_name['slot_id'].has_options = True
_CSODOTAPLAYERCHALLENGE.fields_by_name['slot_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
# @@protoc_insertion_point(module_scope)
