# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_gcmessages_client.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import dota2.protobufs.steammessages_pb2 as steammessages__pb2
import dota2.protobufs.dota_shared_enums_pb2 as dota__shared__enums__pb2
import dota2.protobufs.dota_gcmessages_common_pb2 as dota__gcmessages__common__pb2
import dota2.protobufs.gcsdk_gcmessages_pb2 as gcsdk__gcmessages__pb2
import dota2.protobufs.dota_gcmessages_common_match_management_pb2 as dota__gcmessages__common__match__management__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_gcmessages_client.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x1c\x64ota_gcmessages_client.proto\x1a\x13steammessages.proto\x1a\x17\x64ota_shared_enums.proto\x1a\x1c\x64ota_gcmessages_common.proto\x1a\x16gcsdk_gcmessages.proto\x1a-dota_gcmessages_common_match_management.proto\"\'\n\x13\x43MsgClientSuspended\x12\x10\n\x08time_end\x18\x01 \x01(\r\" \n\x1e\x43MsgRequestInternationalTicket\"\x1a\n\x18\x43MsgBalancedShuffleLobby\"9\n CMsgInitialQuestionnaireResponse\x12\x15\n\rinitial_skill\x18\x01 \x01(\r\"/\n\x1a\x43MsgDOTAPlayerMatchHistory\x12\x11\n\tmatch_ids\x18\x01 \x03(\x04\"o\n\x1a\x43MsgDOTAMatchHistoryFilter\x12\x11\n\tmatch_ids\x18\x01 \x03(\x04\x12%\n\x1dnewest_match_id_at_last_query\x18\x02 \x01(\x04\x12\x17\n\x0ftime_last_query\x18\x03 \x01(\r\"\xa1\x03\n\x16\x43MsgDOTARequestMatches\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\x12\x11\n\tgame_mode\x18\x03 \x01(\r\x12\x10\n\x08\x64\x61te_min\x18\x06 \x01(\x07\x12\x10\n\x08\x64\x61te_max\x18\x07 \x01(\x07\x12\x19\n\x11matches_requested\x18\n \x01(\r\x12\x19\n\x11start_at_match_id\x18\x0b \x01(\x04\x12\x13\n\x0bmin_players\x18\x0c \x01(\x07\x12\x12\n\nrequest_id\x18\r \x01(\r\x12\x1d\n\x15tournament_games_only\x18\x0e \x01(\x08\x12\x12\n\naccount_id\x18\x0f \x01(\r\x12\x11\n\tleague_id\x18\x10 \x01(\r\x12\x36\n\x05skill\x18\x11 \x01(\x0e\x32\".CMsgDOTARequestMatches.SkillLevel:\x03\x41ny\x12\x0f\n\x07team_id\x18\x12 \x01(\r\x12\x16\n\x0e\x63ustom_game_id\x18\x14 \x01(\x04\"9\n\nSkillLevel\x12\x07\n\x03\x41ny\x10\x00\x12\n\n\x06Normal\x10\x01\x12\x08\n\x04High\x10\x02\x12\x0c\n\x08VeryHigh\x10\x03\"\x92\x02\n\x1e\x43MsgDOTARequestMatchesResponse\x12\x1f\n\x07matches\x18\x01 \x03(\x0b\x32\x0e.CMsgDOTAMatch\x12\x36\n\x06series\x18\x02 \x03(\x0b\x32&.CMsgDOTARequestMatchesResponse.Series\x12\x12\n\nrequest_id\x18\x03 \x01(\r\x12\x15\n\rtotal_results\x18\x04 \x01(\r\x12\x19\n\x11results_remaining\x18\x05 \x01(\r\x1aQ\n\x06Series\x12\x1f\n\x07matches\x18\x01 \x03(\x0b\x32\x0e.CMsgDOTAMatch\x12\x11\n\tseries_id\x18\x02 \x01(\r\x12\x13\n\x0bseries_type\x18\x03 \x01(\r\"\x89\x0e\n\rCMsgDOTAPopup\x12(\n\x02id\x18\x01 \x01(\x0e\x32\x16.CMsgDOTAPopup.PopupID:\x04NONE\x12\x13\n\x0b\x63ustom_text\x18\x02 \x01(\t\x12\x10\n\x08int_data\x18\x03 \x01(\x11\x12\x12\n\npopup_data\x18\x04 \x01(\x0c\x12\x18\n\x10loc_token_header\x18\x05 \x01(\t\x12\x15\n\rloc_token_msg\x18\x06 \x01(\t\x12\x11\n\tvar_names\x18\x07 \x03(\t\x12\x12\n\nvar_values\x18\x08 \x03(\t\x12\x12\n\ndebug_text\x18\t \x01(\t\"\xa6\x0c\n\x07PopupID\x12\x11\n\x04NONE\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x15\n\x11KICKED_FROM_LOBBY\x10\x00\x12\x15\n\x11KICKED_FROM_PARTY\x10\x01\x12\x14\n\x10KICKED_FROM_TEAM\x10\x02\x12\x16\n\x12TEAM_WAS_DISBANDED\x10\x03\x12 \n\x1cTEAM_MATCHMAKE_ALREADY_MATCH\x10\x04\x12\"\n\x1eTEAM_MATCHMAKE_ALREADY_FINDING\x10\x05\x12\x17\n\x13TEAM_MATCHMAKE_FULL\x10\x06\x12\x1b\n\x17TEAM_MATCHMAKE_FAIL_ADD\x10\x07\x12#\n\x1fTEAM_MATCHMAKE_FAIL_ADD_CURRENT\x10\x08\x12%\n!TEAM_MATCHMAKE_FAILED_TEAM_MEMBER\x10\t\x12\x1f\n\x1bTEAM_MATCHMAKE_ALREADY_GAME\x10\n\x12!\n\x1dTEAM_MATCHMAKE_FAIL_GET_PARTY\x10\x0b\x12\x18\n\x14MATCHMAKING_DISABLED\x10\x0c\x12\x11\n\rINVITE_DENIED\x10\r\x12\x0e\n\nPARTY_FULL\x10\x0e\x12\x0e\n\nMADE_ADMIN\x10\x0f\x12\x14\n\x10NEED_TO_PURCHASE\x10\x10\x12\x12\n\x0eSIGNON_MESSAGE\x10\x11\x12\x10\n\x0cGUILD_KICKED\x10\x12\x12\x1e\n\x1aMATCHMAKING_REGION_OFFLINE\x10\x13\x12\x1d\n\x19TOURNAMENT_GAME_NOT_FOUND\x10\x15\x12 \n\x1cTOURNAMENT_GAME_HAS_LOBBY_ID\x10\x16\x12 \n\x1cTOURNAMENT_GAME_HAS_MATCH_ID\x10\x17\x12\'\n#TOURNAMENT_GAME_HAS_NO_RADIANT_TEAM\x10\x18\x12$\n TOURNAMENT_GAME_HAS_NO_DIRE_TEAM\x10\x19\x12%\n!TOURNAMENT_GAME_SQL_UPDATE_FAILED\x10\x1a\x12\x14\n\x10NOT_LEAGUE_ADMIN\x10\x1b\x12\x13\n\x0fIN_ANOTHER_GAME\x10\x1d\x12 \n\x1cPARTY_MEMBER_IN_ANOTHER_GAME\x10\x1e\x12 \n\x1cPARTY_MEMBER_IN_LOW_PRIORITY\x10\x1f\x12\x16\n\x12\x43LIENT_OUT_OF_DATE\x10 \x12\x15\n\x11SAVE_GAME_CORRUPT\x10&\x12\x17\n\x13INSUFFICIENT_INGOTS\x10\'\x12\x39\n5COMPETITIVE_MM_NOT_ENOUGH_SKILL_DATA_PLAY_MORE_CASUAL\x10*\x12\x1d\n\x19PARTY_LEADER_JOINED_LOBBY\x10,\x12\x1d\n\x19WEEKEND_TOURNEY_UNMATCHED\x10\x30\x12\x15\n\x11POST_MATCH_SURVEY\x10\x31\x12\x12\n\x0eTROPHY_AWARDED\x10\x32\x12\x13\n\x0fTROPHY_LEVEL_UP\x10\x33\x12\x1f\n\x1b\x41LL_HERO_CHALLENGE_PROGRESS\x10\x34\x12\x16\n\x12NEED_INITIAL_SKILL\x10\x35\x12\x1f\n\x1bNEED_INITIAL_SKILL_IN_PARTY\x10\x36\x12\x1a\n\x16TARGET_ENGINE_MISMATCH\x10\x37\x12\x14\n\x10VAC_NOT_VERIFIED\x10\x38\x12$\n KICKED_FROM_QUEUE_EVENT_STARTING\x10\x39\x12\"\n\x1eKICKED_FROM_QUEUE_EVENT_ENDING\x10:\x12\x0e\n\nLOBBY_FULL\x10>\x12\x17\n\x13\x45VENT_POINTS_EARNED\x10?\x12!\n\x1d\x43USTOM_GAME_INCORRECT_VERSION\x10@\x12\x15\n\x11LIMITED_USER_CHAT\x10\x42\x12\x1f\n\x1b\x45VENT_PREMIUM_POINTS_EARNED\x10\x43\x12\x15\n\x11LOBBY_MVP_AWARDED\x10\x44\x12\x18\n\x14LOW_BADGE_LEVEL_CHAT\x10G\x12\x10\n\x0cGENERIC_INFO\x10\x45\x12\x11\n\rGENERIC_ERROR\x10\x46\"!\n\x1f\x43MsgDOTAReportsRemainingRequest\"\xba\x01\n CMsgDOTAReportsRemainingResponse\x12&\n\x1enum_positive_reports_remaining\x18\x01 \x01(\r\x12&\n\x1enum_negative_reports_remaining\x18\x02 \x01(\r\x12\"\n\x1anum_positive_reports_total\x18\x03 \x01(\r\x12\"\n\x1anum_negative_reports_total\x18\x04 \x01(\r\"p\n\x1a\x43MsgDOTASubmitPlayerReport\x12\x19\n\x11target_account_id\x18\x01 \x01(\r\x12\x14\n\x0creport_flags\x18\x02 \x01(\r\x12\x10\n\x08lobby_id\x18\x04 \x01(\x04\x12\x0f\n\x07\x63omment\x18\x05 \x01(\t\"|\n\"CMsgDOTASubmitPlayerReportResponse\x12\x19\n\x11target_account_id\x18\x01 \x01(\r\x12\x14\n\x0creport_flags\x18\x02 \x01(\r\x12\x0e\n\x06result\x18\x03 \x01(\r\x12\x15\n\rdebug_message\x18\x04 \x01(\t\"8\n\x1b\x43MsgDOTAReportCountsRequest\x12\x19\n\x11target_account_id\x18\x01 \x01(\r\"\x9c\x01\n\x1c\x43MsgDOTAReportCountsResponse\x12\x19\n\x11target_account_id\x18\x01 \x01(\r\x12\x18\n\x10leadership_count\x18\x02 \x01(\r\x12\x16\n\x0eteaching_count\x18\x03 \x01(\r\x12\x16\n\x0e\x66riendly_count\x18\x04 \x01(\r\x12\x17\n\x0f\x66orgiving_count\x18\x05 \x01(\r\"7\n\x1a\x43MsgDOTASubmitLobbyMVPVote\x12\x19\n\x11target_account_id\x18\x01 \x01(\r\"P\n\"CMsgDOTASubmitLobbyMVPVoteResponse\x12\x19\n\x11target_account_id\x18\x01 \x01(\r\x12\x0f\n\x07\x65result\x18\x02 \x01(\r\"l\n\x1f\x43MsgDOTALobbyMVPNotifyRecipient\x12\x18\n\x10voter_account_id\x18\x01 \x01(\r\x12\x1c\n\x14recipient_account_id\x18\x02 \x01(\r\x12\x11\n\tnum_votes\x18\x03 \x01(\r\"1\n\x17\x43MsgDOTALobbyMVPAwarded\x12\x16\n\x0emvp_account_id\x18\x01 \x01(\r\"W\n\"CMsgDOTAKickedFromMatchmakingQueue\x12\x31\n\nmatch_type\x18\x01 \x01(\x0e\x32\n.MatchType:\x11MATCH_TYPE_CASUAL\"1\n\x18\x43MsgDOTARequestSaveGames\x12\x15\n\rserver_region\x18\x01 \x01(\r\"X\n CMsgDOTARequestSaveGamesResponse\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\"\n\nsave_games\x18\x02 \x03(\x0b\x32\x0e.CDOTASaveGame\"-\n\x19\x43MsgGCMatchDetailsRequest\x12\x10\n\x08match_id\x18\x01 \x01(\x04\"\x80\x01\n\x1a\x43MsgGCMatchDetailsResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x1d\n\x05match\x18\x02 \x01(\x0b\x32\x0e.CMsgDOTAMatch\x12\x33\n\x04vote\x18\x03 \x01(\x0e\x32\x0e.DOTAMatchVote:\x15\x44OTAMatchVote_INVALID\"6\n!CMsgServerToGCMatchDetailsRequest\x12\x11\n\tmatch_ids\x18\x01 \x03(\x04\"E\n\"CMsgGCToServerMatchDetailsResponse\x12\x1f\n\x07matches\x18\x01 \x03(\x0b\x32\x0e.CMsgDOTAMatch\"q\n\x16\x43MsgDOTAProfileRequest\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x14\n\x0crequest_name\x18\x02 \x01(\x08\x12-\n\x06\x65ngine\x18\x03 \x01(\x0e\x32\x0e.ESourceEngine:\rk_ESE_Source1\"\xc2\x06\n\x17\x43MsgDOTAProfileResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x36\n\x13game_account_client\x18\x02 \x01(\x0b\x32\x19.CSODOTAGameAccountClient\x12&\n\x0elatest_matches\x18\x03 \x03(\x0b\x32\x0e.CMsgDOTAMatch\x12\x33\n\x06heroes\x18\x04 \x03(\x0b\x32#.CMsgDOTAProfileResponse.PlayedHero\x12\x13\n\x0bplayer_name\x18\x05 \x01(\t\x12\x11\n\tteam_name\x18\x06 \x01(\t\x12\x10\n\x08team_tag\x18\x07 \x01(\t\x12\x11\n\tteam_logo\x18\x08 \x01(\x04\x12<\n\rshowcase_hero\x18\t \x01(\x0b\x32%.CMsgDOTAProfileResponse.ShowcaseHero\x12:\n\rleague_passes\x18\n \x03(\x0b\x32#.CMsgDOTAProfileResponse.LeaguePass\x12;\n\revent_tickets\x18\x0b \x03(\x0b\x32$.CMsgDOTAProfileResponse.EventTicket\x12\x0f\n\x07team_id\x18\x0c \x01(\r\x12\x14\n\x0chas_passport\x18\r \x01(\x08\x12=\n\x0e\x66\x65\x61tured_items\x18\x0e \x03(\x0b\x32%.CMsgDOTAProfileResponse.FeaturedItem\x12\x17\n\x0f\x61\x62\x61ndon_percent\x18\x0f \x01(\r\x1a+\n\nPlayedHero\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12\x0c\n\x04wins\x18\x02 \x01(\r\x1a\x34\n\x0cShowcaseHero\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12\x13\n\x0bobject_data\x18\x02 \x03(\x0c\x1a\x31\n\nLeaguePass\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12\x10\n\x08item_def\x18\x02 \x01(\r\x1a\x1f\n\x0b\x45ventTicket\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x1aH\n\x0c\x46\x65\x61turedItem\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x13\n\x0bobject_data\x18\x02 \x01(\x0c\x12\x12\n\nslot_index\x18\x03 \x01(\r\"\x87\x02\n\x16\x43MsgDOTAProfileTickets\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x12\n\naccount_id\x18\x02 \x01(\r\x12\x39\n\rleague_passes\x18\x03 \x03(\x0b\x32\".CMsgDOTAProfileTickets.LeaguePass\x12:\n\revent_tickets\x18\x04 \x03(\x0b\x32#.CMsgDOTAProfileTickets.EventTicket\x1a\x31\n\nLeaguePass\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12\x10\n\x08item_def\x18\x02 \x01(\r\x1a\x1f\n\x0b\x45ventTicket\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\"5\n\x1f\x43MsgClientToGCGetProfileTickets\x12\x12\n\naccount_id\x18\x01 \x01(\r\"/\n\x19\x43MsgGCSteamProfileRequest\x12\x12\n\naccount_id\x18\x01 \x01(\r\"3\n!CMsgGCSteamProfileRequestResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"%\n#CMsgDOTAClearNotifySuccessfulReport\"\xa7\x07\n\x0f\x43MsgDOTAWelcome\x12\x17\n\x0fstore_item_hash\x18\x05 \x01(\r\x12\x1f\n\x17timeplayedconsecutively\x18\x06 \x01(\r\x12%\n\x1d\x61llow_3rd_party_match_history\x18\x07 \x01(\x08\x12?\n\x14partner_account_type\x18\x08 \x01(\x0e\x32\x13.PartnerAccountType:\x0cPARTNER_NONE\x12 \n\x18\x62\x61nned_word_list_word_id\x18\t \x01(\r\x12\x1d\n\x15partner_account_state\x18\x0b \x01(\r\x12\x18\n\x10last_time_played\x18\x0c \x01(\r\x12\x17\n\x0flast_ip_address\x18\r \x01(\r\x12#\n\x1bshutdownlawterminateminutes\x18\x0f \x01(\r\x12 \n\x18\x62\x61nned_word_list_version\x18\x10 \x01(\r\x12\x17\n\x0fprofile_private\x18\x11 \x01(\x08\x12\x10\n\x08\x63urrency\x18\x12 \x01(\r\x12\x0f\n\x07\x62\x61ng_no\x18\x13 \x01(\r\x12$\n\x1cshould_request_player_origin\x18\x14 \x01(\x08\x12\x1a\n\x12\x63ompendium_unlocks\x18\x15 \x01(\x04\x12\x1f\n\x17gc_socache_file_version\x18\x16 \x01(\r\x12\x41\n\x14localization_digests\x18\x17 \x03(\x0b\x32#.CMsgDOTAWelcome.LocalizationDigest\x12%\n\x1dis_perfect_world_test_account\x18\x18 \x01(\x08\x12\x1e\n\ractive_events\x18\x19 \x03(\x0e\x32\x07.EEvent\x12\x32\n\x0e\x65xtra_messages\x18\x1a \x03(\x0b\x32\x1a.CMsgDOTAWelcome.CExtraMsg\x12\x1e\n\x16minimum_recent_item_id\x18\x1b \x01(\x04\x1a\x8e\x01\n\x12LocalizationDigest\x12\x0f\n\x07\x63ontext\x18\x01 \x01(\t\x12\x33\n\x1a\x65nglish_language_file_sha1\x18\x02 \x01(\x0b\x32\x0f.CMsgSHA1Digest\x12\x32\n\x19\x63lient_language_file_sha1\x18\x03 \x01(\x0b\x32\x0f.CMsgSHA1Digest\x1a)\n\tCExtraMsg\x12\n\n\x02id\x18\x01 \x01(\r\x12\x10\n\x08\x63ontents\x18\x02 \x01(\x0c\"K\n\x18\x43SODOTAGameHeroFavorites\x12\x18\n\naccount_id\x18\x01 \x01(\rB\x04\x80\x97\"\x01\x12\x15\n\x07hero_id\x18\x02 \x01(\rB\x04\x80\x97\"\x01\"+\n\x18\x43MsgDOTAHeroFavoritesAdd\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\".\n\x1b\x43MsgDOTAHeroFavoritesRemove\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\"/\n\x13\x43MsgSetShowcaseHero\x12\x18\n\x10showcase_hero_id\x18\x01 \x01(\r\"0\n\x14\x43MsgSetFeaturedItems\x12\x18\n\x10\x66\x65\x61tured_item_id\x18\x01 \x03(\x04\"Z\n\x15\x43MsgDOTAFeaturedItems\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x18\n\x10\x66\x65\x61tured_item_id\x18\x02 \x03(\x04\x12\x13\n\x0bobject_data\x18\x03 \x03(\x0c\"\x17\n\x15\x43MsgRequestLeagueInfo\"\xd0\x01\n\x12\x43\x44ynamicLeagueData\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12\x17\n\x0flast_match_time\x18\x02 \x01(\x07\x12\x16\n\x0eprize_pool_usd\x18\x03 \x01(\r\x12\x18\n\x10has_live_matches\x18\x04 \x01(\x08\x12\x1c\n\x14is_compendium_public\x18\x05 \x01(\x08\x12\x1a\n\x12\x63ompendium_version\x18\x06 \x01(\r\x12\"\n\x1a\x63ompendium_content_version\x18\x07 \x01(\r\"\xd2\x03\n\x11\x43StaticLeagueData\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0b\x62\x61nner_name\x18\x04 \x01(\t\x12\x14\n\x0citemdef_name\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x16\n\x0eitem_def_index\x18\x07 \x01(\r\x12\x1f\n\x17hud_skin_item_def_index\x18\x08 \x01(\r\x12\x1b\n\x13loading_screen_name\x18\t \x01(\t\x12\x17\n\x0f\x62\x61se_prize_pool\x18\n \x01(\r\x12\x10\n\x08is_major\x18\x0b \x01(\x08\x12\x12\n\nsort_order\x18\x0c \x01(\r\x12\x0c\n\x04tier\x18\r \x01(\r\x12\x16\n\x0e\x61mateur_region\x18\x0e \x01(\r\x12\x11\n\torganizer\x18\x0f \x01(\t\x12\x12\n\nstart_date\x18\x10 \x01(\r\x12\x10\n\x08\x65nd_date\x18\x11 \x01(\r\x12\x10\n\x08location\x18\x12 \x01(\t\x12\x17\n\x0finventory_image\x18\x13 \x01(\t\x12\x14\n\x0csquare_image\x18\x14 \x01(\t\x12\x1a\n\x12\x62\x61ttle_pass_rollup\x18\x15 \x01(\x08\"s\n\x0b\x43LeagueData\x12)\n\x0c\x64ynamic_data\x18\x01 \x01(\x0b\x32\x13.CDynamicLeagueData\x12\'\n\x0bstatic_data\x18\x02 \x01(\x0b\x32\x12.CStaticLeagueData\x12\x10\n\x08is_owned\x18\x03 \x01(\x08\">\n\x16\x43MsgResponseLeagueInfo\x12$\n\x07leagues\x18\x01 \x03(\x0b\x32\x13.CDynamicLeagueData\"\x85\x01\n\x12\x43MsgDOTAMatchVotes\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12-\n\x05votes\x18\x02 \x03(\x0b\x32\x1e.CMsgDOTAMatchVotes.PlayerVote\x1a.\n\nPlayerVote\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0c\n\x04vote\x18\x02 \x01(\r\"Z\n\x11\x43MsgCastMatchVote\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x33\n\x04vote\x18\x02 \x01(\x0e\x32\x0e.DOTAMatchVote:\x15\x44OTAMatchVote_INVALID\">\n\x15\x43MsgRetrieveMatchVote\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x13\n\x0bincremental\x18\x02 \x01(\r\"\x90\x01\n\x15\x43MsgMatchVoteResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\x12\x33\n\x04vote\x18\x02 \x01(\x0e\x32\x0e.DOTAMatchVote:\x15\x44OTAMatchVote_INVALID\x12\x16\n\x0epositive_votes\x18\x03 \x01(\r\x12\x16\n\x0enegative_votes\x18\x04 \x01(\r\"\xe5\x02\n\x12\x43MsgDOTAHallOfFame\x12\x0c\n\x04week\x18\x01 \x01(\r\x12<\n\x10\x66\x65\x61tured_players\x18\x02 \x03(\x0b\x32\".CMsgDOTAHallOfFame.FeaturedPlayer\x12;\n\x0f\x66\x65\x61tured_farmer\x18\x03 \x01(\x0b\x32\".CMsgDOTAHallOfFame.FeaturedFarmer\x1ag\n\x0e\x46\x65\x61turedPlayer\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\x12\x1d\n\x15\x61verage_scaled_metric\x18\x03 \x01(\x02\x12\x11\n\tnum_games\x18\x04 \x01(\r\x1a]\n\x0e\x46\x65\x61turedFarmer\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\x12\x14\n\x0cgold_per_min\x18\x03 \x01(\r\x12\x10\n\x08match_id\x18\x04 \x01(\x04\")\n\x19\x43MsgDOTAHallOfFameRequest\x12\x0c\n\x04week\x18\x01 \x01(\r\"[\n\x1a\x43MsgDOTAHallOfFameResponse\x12)\n\x0chall_of_fame\x18\x01 \x01(\x0b\x32\x13.CMsgDOTAHallOfFame\x12\x12\n\x07\x65result\x18\x02 \x01(\r:\x01\x32\"6\n!CMsgDOTAHalloweenHighScoreRequest\x12\x11\n\x05round\x18\x01 \x01(\x05:\x02-1\"r\n\"CMsgDOTAHalloweenHighScoreResponse\x12\r\n\x05score\x18\x01 \x01(\r\x12\x1d\n\x05match\x18\x02 \x01(\x0b\x32\x0e.CMsgDOTAMatch\x12\x0f\n\x07\x65result\x18\x03 \x01(\r\x12\r\n\x05round\x18\x04 \x01(\x05\"6\n\x1e\x43MsgDOTAStorePromoPagesRequest\x12\x14\n\x0cversion_seen\x18\x01 \x01(\r\"\x97\x01\n\x1f\x43MsgDOTAStorePromoPagesResponse\x12\x39\n\x05pages\x18\x01 \x03(\x0b\x32*.CMsgDOTAStorePromoPagesResponse.PromoPage\x1a\x39\n\tPromoPage\x12\x10\n\x08promo_id\x18\x01 \x01(\r\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\"N\n\x1f\x43MsgLeagueScheduleBlockTeamInfo\x12\x0f\n\x07team_id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04logo\x18\x04 \x01(\x04\"\x91\x01\n\x17\x43MsgLeagueScheduleBlock\x12\x10\n\x08\x62lock_id\x18\x01 \x01(\r\x12\x12\n\nstart_time\x18\x02 \x01(\r\x12\x0e\n\x06\x66inals\x18\x04 \x01(\x08\x12\x0f\n\x07\x63omment\x18\x05 \x01(\t\x12/\n\x05teams\x18\x06 \x03(\x0b\x32 .CMsgLeagueScheduleBlockTeamInfo\"O\n\x0e\x43MsgDOTALeague\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12*\n\x08schedule\x18\x02 \x03(\x0b\x32\x18.CMsgLeagueScheduleBlock\"2\n\x1d\x43MsgDOTALeagueScheduleRequest\x12\x11\n\tleague_id\x18\x01 \x01(\r\"U\n\x1e\x43MsgDOTALeagueScheduleResponse\x12\x1f\n\x06league\x18\x01 \x01(\x0b\x32\x0f.CMsgDOTALeague\x12\x12\n\x07\x65result\x18\x02 \x01(\r:\x01\x32\"q\n\x1a\x43MsgDOTALeagueScheduleEdit\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12*\n\x08schedule\x18\x02 \x01(\x0b\x32\x18.CMsgLeagueScheduleBlock\x12\x14\n\x0c\x64\x65lete_block\x18\x03 \x01(\x08\"Y\n\"CMsgDOTALeagueScheduleEditResponse\x12\x1f\n\x06league\x18\x01 \x01(\x0b\x32\x0f.CMsgDOTALeague\x12\x12\n\x07\x65result\x18\x02 \x01(\r:\x01\x32\"J\n\x1d\x43MsgDOTALeaguesInMonthRequest\x12\r\n\x05month\x18\x01 \x01(\r\x12\x0c\n\x04year\x18\x02 \x01(\r\x12\x0c\n\x04tier\x18\x03 \x01(\r\"s\n\x1e\x43MsgDOTALeaguesInMonthResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\x12\r\n\x05month\x18\x02 \x01(\r\x12\x0c\n\x04year\x18\x03 \x01(\r\x12 \n\x07leagues\x18\x04 \x03(\x0b\x32\x0f.CMsgDOTALeague\"\xab\x01\n\x1d\x43MsgMatchmakingMatchGroupInfo\x12\x19\n\x11players_searching\x18\x01 \x01(\r\x12\'\n\x1f\x61uto_region_select_ping_penalty\x18\x02 \x01(\x11\x12\x46\n\x06status\x18\x03 \x01(\x0e\x32\x18.EMatchGroupServerStatus:\x1ck_EMatchGroupServerStatus_OK\"!\n\x1f\x43MsgDOTAMatchmakingStatsRequest\"\xa8\x01\n CMsgDOTAMatchmakingStatsResponse\x12\x1b\n\x13matchgroups_version\x18\x01 \x01(\r\x12\x31\n)legacy_searching_players_by_group_source2\x18\x07 \x03(\r\x12\x34\n\x0cmatch_groups\x18\x08 \x03(\x0b\x32\x1e.CMsgMatchmakingMatchGroupInfo\"R\n\x1e\x43MsgDOTAUpdateMatchmakingStats\x12\x30\n\x05stats\x18\x01 \x01(\x0b\x32!.CMsgDOTAMatchmakingStatsResponse\"V\n\"CMsgDOTAUpdateMatchManagementStats\x12\x30\n\x05stats\x18\x01 \x01(\x0b\x32!.CMsgDOTAMatchmakingStatsResponse\"F\n\x1d\x43MsgDOTASetMatchHistoryAccess\x12%\n\x1d\x61llow_3rd_party_match_history\x18\x01 \x01(\x08\";\n%CMsgDOTASetMatchHistoryAccessResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\"L\n CMsgDOTANotifyAccountFlagsChange\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x15\n\raccount_flags\x18\x02 \x01(\r\"4\n\x19\x43MsgDOTASetProfilePrivacy\x12\x17\n\x0fprofile_private\x18\x01 \x01(\x08\"4\n!CMsgDOTASetProfilePrivacyResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\r\"<\n\x15\x43MsgUpgradeLeagueItem\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x11\n\tleague_id\x18\x02 \x01(\r\"\x1f\n\x1d\x43MsgUpgradeLeagueItemResponse\"t\n\x1b\x43MsgGCWatchDownloadedReplay\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x43\n\nwatch_type\x18\x02 \x01(\x0e\x32\x15.DOTA_WatchReplayType:\x18\x44OTA_WATCH_REPLAY_NORMAL\"A\n\x17\x43MsgSetMapLocationState\x12\x13\n\x0blocation_id\x18\x01 \x01(\x05\x12\x11\n\tcompleted\x18\x02 \x01(\x08\"5\n\x1f\x43MsgSetMapLocationStateResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\"\x17\n\x15\x43MsgResetMapLocations\"3\n\x1d\x43MsgResetMapLocationsResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\"5\n\x1d\x43MsgRefreshPartnerAccountLink\x12\x14\n\x0cpartner_type\x18\x01 \x01(\x05\"\x1f\n\x1d\x43MsgClientsRejoinChatChannels\".\n\x1a\x43MsgDOTASendFriendRecruits\x12\x10\n\x08recruits\x18\x01 \x03(\r\"4\n\x1d\x43MsgDOTAFriendRecruitsRequest\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x01 \x03(\r\"\x82\x03\n\x1e\x43MsgDOTAFriendRecruitsResponse\x12@\n\x06result\x18\x01 \x01(\x0e\x32\'.CMsgDOTAFriendRecruitsResponse.EResult:\x07SUCCESS\x12\x45\n\x08recruits\x18\x02 \x03(\x0b\x32\x33.CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus\x12G\n\nrecruiters\x18\x03 \x03(\x0b\x32\x33.CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus\x1a_\n\x13\x46riendRecruitStatus\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0e\n\x06status\x18\x02 \x01(\r\x12\x15\n\rlevels_earned\x18\x03 \x01(\r\x12\r\n\x05\x62onus\x18\x04 \x01(\x08\"-\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\"P\n(CMsgDOTAFriendRecruitInviteAcceptDecline\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08\x12\x12\n\naccount_id\x18\x02 \x01(\r\"/\n\x1a\x43MsgRequestLeaguePrizePool\x12\x11\n\tleague_id\x18\x01 \x01(\r\"K\n\"CMsgRequestLeaguePrizePoolResponse\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12\x12\n\nprize_pool\x18\x02 \x01(\r\"\x18\n\x16\x43MsgGCGetHeroStandings\"\xff\x02\n\x1e\x43MsgGCGetHeroStandingsResponse\x12\x37\n\tstandings\x18\x01 \x03(\x0b\x32$.CMsgGCGetHeroStandingsResponse.Hero\x1a\xa3\x02\n\x04Hero\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12\x0c\n\x04wins\x18\x02 \x01(\r\x12\x0e\n\x06losses\x18\x03 \x01(\r\x12\x12\n\nwin_streak\x18\x04 \x01(\r\x12\x17\n\x0f\x62\x65st_win_streak\x18\x05 \x01(\r\x12\x11\n\tavg_kills\x18\x06 \x01(\x02\x12\x12\n\navg_deaths\x18\x07 \x01(\x02\x12\x13\n\x0b\x61vg_assists\x18\x08 \x01(\x02\x12\x0f\n\x07\x61vg_gpm\x18\t \x01(\x02\x12\x0f\n\x07\x61vg_xpm\x18\n \x01(\x02\x12\x12\n\nbest_kills\x18\x0b \x01(\r\x12\x14\n\x0c\x62\x65st_assists\x18\x0c \x01(\r\x12\x10\n\x08\x62\x65st_gpm\x18\r \x01(\r\x12\x10\n\x08\x62\x65st_xpm\x18\x0e \x01(\r\x12\x13\n\x0bperformance\x18\x0f \x01(\x02\"%\n#CMsgGCItemEditorReservationsRequest\">\n\x1b\x43MsgGCItemEditorReservation\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\"Z\n$CMsgGCItemEditorReservationsResponse\x12\x32\n\x0creservations\x18\x01 \x03(\x0b\x32\x1c.CMsgGCItemEditorReservation\"E\n\x1e\x43MsgGCItemEditorReserveItemDef\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\x10\n\x08username\x18\x02 \x01(\t\"]\n&CMsgGCItemEditorReserveItemDefResponse\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0e\n\x06result\x18\x03 \x01(\r\"I\n\"CMsgGCItemEditorReleaseReservation\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\x10\n\x08username\x18\x02 \x01(\t\"Q\n*CMsgGCItemEditorReleaseReservationResponse\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\x10\n\x08released\x18\x02 \x01(\x08\"6\n!CMsgGCItemEditorRequestLeagueInfo\x12\x11\n\tleague_id\x18\x01 \x01(\r\"\xba\x01\n\"CMsgGCItemEditorLeagueInfoResponse\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12\x13\n\x0bleague_name\x18\x02 \x01(\t\x12\x13\n\x0bleague_desc\x18\x03 \x01(\t\x12\x12\n\nleague_url\x18\x04 \x01(\t\x12\x13\n\x0brevenue_url\x18\x05 \x01(\t\x12\x0c\n\x04tier\x18\x06 \x01(\r\x12\x10\n\x08location\x18\x07 \x01(\r\x12\x0e\n\x06result\x18\x08 \x01(\r\"J\n\x1c\x43MsgDOTARewardTutorialPrizes\x12\x13\n\x0blocation_id\x18\x01 \x01(\r\x12\x15\n\rtracking_only\x18\x02 \x01(\x08\"L\n%CMsgDOTALastHitChallengeHighScorePost\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12\x12\n\nhigh_score\x18\x02 \x01(\r\";\n(CMsgDOTALastHitChallengeHighScoreRequest\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\"K\n)CMsgDOTALastHitChallengeHighScoreResponse\x12\r\n\x05score\x18\x01 \x01(\r\x12\x0f\n\x07\x65result\x18\x02 \x01(\r\"\x14\n\x12\x43MsgFlipLobbyTeams\"!\n\x1f\x43MsgPresentedClientTerminateDlg\"}\n%CMsgGCLobbyUpdateBroadcastChannelInfo\x12\x12\n\nchannel_id\x18\x01 \x01(\r\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x15\n\rlanguage_code\x18\x04 \x01(\t\"S\n\x18\x43MsgDOTARedeemEventPrize\x12\x10\n\x08prize_id\x18\x01 \x01(\r\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\r\x12\x13\n\x08quantity\x18\x03 \x01(\r:\x01\x31\"\x8b\x02\n CMsgDOTARedeemEventPrizeResponse\x12\x45\n\x06result\x18\x01 \x01(\x0e\x32,.CMsgDOTARedeemEventPrizeResponse.ResultCode:\x07Success\x12\x18\n\x10remaining_points\x18\x02 \x01(\r\x12 \n\x18remaining_premium_points\x18\x03 \x01(\r\x12\x10\n\x08\x65vent_id\x18\x04 \x01(\r\"R\n\nResultCode\x12\x0b\n\x07Success\x10\x00\x12\x0f\n\x0bServerError\x10\x01\x12\x16\n\x12InsufficientPoints\x10\x02\x12\x0e\n\nPointsHeld\x10\x03\">\n\x16\x43MsgDOTAGetEventPoints\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x12\n\naccount_id\x18\x02 \x01(\r\"\xe3\x02\n\x1e\x43MsgDOTAGetEventPointsResponse\x12\x14\n\x0ctotal_points\x18\x01 \x01(\r\x12\x1c\n\x14total_premium_points\x18\x02 \x01(\r\x12\x10\n\x08\x65vent_id\x18\x03 \x01(\r\x12\x0e\n\x06points\x18\x04 \x01(\r\x12\x16\n\x0epremium_points\x18\x05 \x01(\r\x12\x41\n\x11\x63ompleted_actions\x18\x06 \x03(\x0b\x32&.CMsgDOTAGetEventPointsResponse.Action\x12\x12\n\naccount_id\x18\x07 \x01(\r\x12\r\n\x05owned\x18\x08 \x01(\x08\x12\x14\n\x0c\x61udit_action\x18\t \x01(\r\x12\x1e\n\x16wager_tokens_remaining\x18\n \x01(\r\x1a\x37\n\x06\x41\x63tion\x12\x11\n\taction_id\x18\x01 \x01(\r\x12\x1a\n\x0ftimes_completed\x18\x02 \x01(\r:\x01\x31\"9\n\x1c\x43MsgDOTALiveLeagueGameUpdate\x12\x19\n\x11live_league_games\x18\x01 \x01(\r\"[\n\x1b\x43MsgDOTACompendiumSelection\x12\x17\n\x0fselection_index\x18\x01 \x01(\r\x12\x11\n\tselection\x18\x02 \x01(\r\x12\x10\n\x08leagueid\x18\x03 \x01(\r\"q\n#CMsgDOTACompendiumSelectionResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\x12\x36\n\x10\x65xtra_selections\x18\x02 \x03(\x0b\x32\x1c.CMsgDOTACompendiumSelection\"J\n\x16\x43MsgDOTACompendiumData\x12\x30\n\nselections\x18\x01 \x03(\x0b\x32\x1c.CMsgDOTACompendiumSelection\"E\n\x1d\x43MsgDOTACompendiumDataRequest\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x10\n\x08leagueid\x18\x02 \x01(\r\"\x8b\x01\n\x1e\x43MsgDOTACompendiumDataResponse\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x10\n\x08leagueid\x18\x02 \x01(\r\x12\x11\n\x06result\x18\x03 \x01(\r:\x01\x32\x12\x30\n\x0f\x63ompendium_data\x18\x04 \x01(\x0b\x32\x17.CMsgDOTACompendiumData\"\xce\x01\n\x1d\x43MsgDOTAGetPlayerMatchHistory\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x19\n\x11start_at_match_id\x18\x02 \x01(\x04\x12\x19\n\x11matches_requested\x18\x03 \x01(\r\x12\x0f\n\x07hero_id\x18\x04 \x01(\r\x12\x12\n\nrequest_id\x18\x05 \x01(\r\x12 \n\x18include_practice_matches\x18\x07 \x01(\x08\x12\x1c\n\x14include_custom_games\x18\x08 \x01(\x08\"\xb0\x04\n%CMsgDOTAGetPlayerMatchHistoryResponse\x12=\n\x07matches\x18\x01 \x03(\x0b\x32,.CMsgDOTAGetPlayerMatchHistoryResponse.Match\x12\x12\n\nrequest_id\x18\x02 \x01(\r\x1a\xb3\x03\n\x05Match\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x12\n\nstart_time\x18\x02 \x01(\r\x12\x0f\n\x07hero_id\x18\x03 \x01(\r\x12\x0e\n\x06winner\x18\x04 \x01(\x08\x12\x11\n\tgame_mode\x18\x05 \x01(\r\x12\x13\n\x0brank_change\x18\x06 \x01(\x05\x12\x15\n\rprevious_rank\x18\x07 \x01(\r\x12\x12\n\nlobby_type\x18\x08 \x01(\r\x12\x11\n\tsolo_rank\x18\t \x01(\x08\x12\x0f\n\x07\x61\x62\x61ndon\x18\n \x01(\x08\x12\x10\n\x08\x64uration\x18\x0b \x01(\r\x12\x0e\n\x06\x65ngine\x18\x0c \x01(\r\x12\x1a\n\x12\x61\x63tive_battle_pass\x18\r \x01(\x08\x12\x15\n\rseasonal_rank\x18\x0e \x01(\x08\x12\x12\n\ntourney_id\x18\x0f \x01(\r\x12\x15\n\rtourney_round\x18\x10 \x01(\r\x12\x14\n\x0ctourney_tier\x18\x11 \x01(\r\x12\x18\n\x10tourney_division\x18\x12 \x01(\r\x12\x0f\n\x07team_id\x18\x13 \x01(\r\x12\x11\n\tteam_name\x18\x14 \x01(\t\x12\x18\n\x10ugc_team_ui_logo\x18\x15 \x01(\x04\"!\n\x1f\x43MsgDOTAStartDailyHeroChallenge\"\x1c\n\x1a\x43MsgGCNotificationsRequest\"\xeb\x02\n\x1b\x43MsgGCNotificationsResponse\x12=\n\x06result\x18\x01 \x01(\x0e\x32$.CMsgGCNotificationsResponse.EResult:\x07SUCCESS\x12@\n\rnotifications\x18\x02 \x03(\x0b\x32).CMsgGCNotificationsResponse.Notification\x1a\x9b\x01\n\x0cNotification\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x13\n\x0breference_a\x18\x04 \x01(\r\x12\x13\n\x0breference_b\x18\x05 \x01(\r\x12\x13\n\x0breference_c\x18\x06 \x01(\r\x12\x0f\n\x07message\x18\x07 \x01(\t\x12\x0e\n\x06unread\x18\x08 \x01(\x08\"-\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\"$\n\"CMsgGCNotificationsMarkReadRequest\"B\n&CMsgClientToGCMarkNotificationListRead\x12\x18\n\x10notification_ids\x18\x01 \x03(\x04\"\x9d\x01\n\x16\x43MsgGCLeagueAdminState\x12\x0f\n\x07leagues\x18\x01 \x03(\r\x12\x37\n\x04keys\x18\x02 \x03(\x0b\x32).CMsgGCLeagueAdminState.PrivateLeagueKeys\x1a\x39\n\x11PrivateLeagueKeys\x12\x10\n\x08leagueid\x18\x01 \x01(\r\x12\x12\n\nprivatekey\x18\x02 \x01(\r\"\x89\x01\n\x17\x43MsgGCPlayerInfoRequest\x12\x39\n\x0cplayer_infos\x18\x01 \x03(\x0b\x32#.CMsgGCPlayerInfoRequest.PlayerInfo\x1a\x33\n\nPlayerInfo\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\"t\n\x16\x43MsgGCPlayerInfoSubmit\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\x14\n\x0c\x66\x61ntasy_role\x18\x03 \x01(\r\x12\x0f\n\x07team_id\x18\x04 \x01(\r\x12\x0f\n\x07sponsor\x18\x05 \x01(\t\"\xa8\x01\n\x1e\x43MsgGCPlayerInfoSubmitResponse\x12@\n\x06result\x18\x01 \x01(\x0e\x32\'.CMsgGCPlayerInfoSubmitResponse.EResult:\x07SUCCESS\"D\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x15\n\x11\x45RROR_INFO_LOCKED\x10\x02\"\xa6\x01\n\x1d\x43MsgClientProvideSurveyResult\x12:\n\tresponses\x18\x01 \x03(\x0b\x32\'.CMsgClientProvideSurveyResult.Response\x12\x12\n\nsurvey_key\x18\x02 \x01(\x04\x1a\x35\n\x08Response\x12\x13\n\x0bquestion_id\x18\x01 \x01(\r\x12\x14\n\x0csurvey_value\x18\x02 \x01(\r\"K\n\x19\x43MsgDOTAEmoticonAccessSDO\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x1a\n\x12unlocked_emoticons\x18\x02 \x01(\x0c\"#\n!CMsgClientToGCEmoticonDataRequest\"Q\n\x1a\x43MsgGCToClientEmoticonData\x12\x33\n\x0f\x65moticon_access\x18\x01 \x01(\x0b\x32\x1a.CMsgDOTAEmoticonAccessSDO\"C\n\x1f\x43MsgClientToGCTrackDialogResult\x12\x11\n\tdialog_id\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r\"H\n CMsgGCToClientTournamentItemDrop\x12\x10\n\x08item_def\x18\x01 \x01(\r\x12\x12\n\nevent_type\x18\x02 \x01(\r\"J\n!CMsgClientToGCSetAdditionalEquips\x12%\n\x06\x65quips\x18\x01 \x03(\x0b\x32\x15.CAdditionalEquipSlot\"+\n)CMsgClientToGCSetAdditionalEquipsResponse\"#\n!CMsgClientToGCGetAdditionalEquips\"R\n)CMsgClientToGCGetAdditionalEquipsResponse\x12%\n\x06\x65quips\x18\x01 \x03(\x0b\x32\x15.CAdditionalEquipSlot\"\x1f\n\x1d\x43MsgClientToGCGetAllHeroOrder\"9\n%CMsgClientToGCGetAllHeroOrderResponse\x12\x10\n\x08hero_ids\x18\x01 \x03(\r\"6\n CMsgClientToGCGetAllHeroProgress\x12\x12\n\naccount_id\x18\x01 \x01(\r\"\x99\x04\n(CMsgClientToGCGetAllHeroProgressResponse\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x14\n\x0c\x63urr_hero_id\x18\x02 \x01(\r\x12\x16\n\x0elaps_completed\x18\x03 \x01(\r\x12\x17\n\x0f\x63urr_hero_games\x18\x04 \x01(\r\x12\x1d\n\x15\x63urr_lap_time_started\x18\x05 \x01(\r\x12\x16\n\x0e\x63urr_lap_games\x18\x06 \x01(\r\x12\x16\n\x0e\x62\x65st_lap_games\x18\x07 \x01(\r\x12\x15\n\rbest_lap_time\x18\x08 \x01(\r\x12\x1c\n\x14lap_heroes_completed\x18\t \x01(\r\x12\x1c\n\x14lap_heroes_remaining\x18\n \x01(\r\x12\x14\n\x0cnext_hero_id\x18\x0b \x01(\r\x12\x14\n\x0cprev_hero_id\x18\x0c \x01(\r\x12\x17\n\x0fprev_hero_games\x18\r \x01(\r\x12\x16\n\x0eprev_avg_tries\x18\x0e \x01(\x02\x12\x16\n\x0e\x63urr_avg_tries\x18\x0f \x01(\x02\x12\x16\n\x0enext_avg_tries\x18\x10 \x01(\x02\x12\x1a\n\x12\x66ull_lap_avg_tries\x18\x11 \x01(\x02\x12\x1a\n\x12\x63urr_lap_avg_tries\x18\x12 \x01(\x02\x12\x14\n\x0cprofile_name\x18\x13 \x01(\t\x12\x15\n\rstart_hero_id\x18\x14 \x01(\r\"1\n\x1b\x43MsgClientToGCGetTrophyList\x12\x12\n\naccount_id\x18\x01 \x01(\r\"\xd7\x01\n#CMsgClientToGCGetTrophyListResponse\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12=\n\x08trophies\x18\x02 \x03(\x0b\x32+.CMsgClientToGCGetTrophyListResponse.Trophy\x12\x14\n\x0cprofile_name\x18\x03 \x01(\t\x1aG\n\x06Trophy\x12\x11\n\ttrophy_id\x18\x01 \x01(\r\x12\x14\n\x0ctrophy_score\x18\x02 \x01(\r\x12\x14\n\x0clast_updated\x18\x03 \x01(\r\"v\n\x1b\x43MsgGCToClientTrophyAwarded\x12\x11\n\ttrophy_id\x18\x01 \x01(\r\x12\x14\n\x0ctrophy_score\x18\x02 \x01(\r\x12\x18\n\x10trophy_old_score\x18\x03 \x01(\r\x12\x14\n\x0clast_updated\x18\x04 \x01(\r\"2\n\x1c\x43MsgClientToGCGetProfileCard\x12\x12\n\naccount_id\x18\x01 \x01(\r\"\xd8\x01\n!CMsgClientToGCSetProfileCardSlots\x12:\n\x05slots\x18\x01 \x03(\x0b\x32+.CMsgClientToGCSetProfileCardSlots.CardSlot\x1aw\n\x08\x43\x61rdSlot\x12\x0f\n\x07slot_id\x18\x01 \x01(\r\x12\x46\n\tslot_type\x18\x02 \x01(\x0e\x32\x15.EProfileCardSlotType:\x1ck_EProfileCardSlotType_Empty\x12\x12\n\nslot_value\x18\x03 \x01(\x04\"#\n!CMsgClientToGCGetProfileCardStats\"\xd4\x01\n\x1e\x43MsgClientToGCCreateHeroStatue\x12\x13\n\x0bsource_item\x18\x01 \x01(\x04\x12\x0f\n\x07hero_id\x18\x03 \x01(\r\x12\x15\n\rsequence_name\x18\x04 \x01(\t\x12\r\n\x05\x63ycle\x18\x05 \x01(\x02\x12\x11\n\twearables\x18\x06 \x03(\r\x12\x13\n\x0binscription\x18\x07 \x01(\t\x12\x0e\n\x06styles\x18\x08 \x03(\r\x12\x15\n\rreforger_item\x18\t \x01(\x04\x12\x17\n\x0ftournament_drop\x18\n \x01(\x08\">\n$CMsgGCToClientHeroStatueCreateResult\x12\x16\n\x0eresulting_item\x18\x01 \x01(\x04\"\x94\x01\n#CMsgClientToGCRecordCompendiumStats\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12\x17\n\x0fview_duration_s\x18\x02 \x01(\r\x12\x15\n\rvideos_viewed\x18\x03 \x01(\r\x12\x12\n\npage_turns\x18\x04 \x01(\r\x12\x16\n\x0elinks_followed\x18\x05 \x01(\r\"B\n CMsgGCToClientEventStatusChanged\x12\x1e\n\ractive_events\x18\x01 \x03(\x0e\x32\x07.EEvent\"6\n CMsgClientToGCPlayerStatsRequest\x12\x12\n\naccount_id\x18\x01 \x01(\r\"\xcf\x03\n!CMsgGCToClientPlayerStatsResponse\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x14\n\x0cplayer_stats\x18\x02 \x03(\x02\x12\x13\n\x0bmatch_count\x18\x03 \x01(\r\x12\x10\n\x08mean_gpm\x18\x04 \x01(\x02\x12\x11\n\tmean_xppm\x18\x05 \x01(\x02\x12\x15\n\rmean_lasthits\x18\x06 \x01(\x02\x12\x10\n\x08rampages\x18\x07 \x01(\r\x12\x14\n\x0ctriple_kills\x18\x08 \x01(\r\x12\x1b\n\x13\x66irst_blood_claimed\x18\t \x01(\r\x12\x19\n\x11\x66irst_blood_given\x18\n \x01(\r\x12\x17\n\x0f\x63ouriers_killed\x18\x0b \x01(\r\x12\x18\n\x10\x61\x65gises_snatched\x18\x0c \x01(\r\x12\x15\n\rcheeses_eaten\x18\r \x01(\r\x12\x16\n\x0e\x63reeps_stacked\x18\x0e \x01(\r\x12\x13\n\x0b\x66ight_score\x18\x0f \x01(\x02\x12\x12\n\nfarm_score\x18\x10 \x01(\x02\x12\x15\n\rsupport_score\x18\x11 \x01(\x02\x12\x12\n\npush_score\x18\x12 \x01(\x02\x12\x19\n\x11versatility_score\x18\x13 \x01(\x02\"D\n*CMsgClientToGCCustomGamePlayerCountRequest\x12\x16\n\x0e\x63ustom_game_id\x18\x01 \x01(\x04\"t\n+CMsgGCToClientCustomGamePlayerCountResponse\x12\x16\n\x0e\x63ustom_game_id\x18\x01 \x01(\x04\x12\x14\n\x0cplayer_count\x18\x02 \x01(\x04\x12\x17\n\x0fspectator_count\x18\x03 \x01(\x04\"/\n-CMsgClientToGCCustomGamesFriendsPlayedRequest\"\xca\x01\n.CMsgGCToClientCustomGamesFriendsPlayedResponse\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12I\n\x05games\x18\x02 \x03(\x0b\x32:.CMsgGCToClientCustomGamesFriendsPlayedResponse.CustomGame\x1a\x39\n\nCustomGame\x12\x16\n\x0e\x63ustom_game_id\x18\x01 \x01(\x04\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x02 \x03(\r\"O\n*CMsgClientToGCSocialFeedPostCommentRequest\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\">\n+CMsgGCToClientSocialFeedPostCommentResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"h\n*CMsgClientToGCSocialFeedPostMessageRequest\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x10\n\x08match_id\x18\x02 \x01(\x04\x12\x17\n\x0fmatch_timestamp\x18\x03 \x01(\r\">\n+CMsgGCToClientSocialFeedPostMessageResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"F\n,CMsgClientToGCFriendsPlayedCustomGameRequest\x12\x16\n\x0e\x63ustom_game_id\x18\x01 \x01(\x04\"\\\n-CMsgGCToClientFriendsPlayedCustomGameResponse\x12\x16\n\x0e\x63ustom_game_id\x18\x01 \x01(\x04\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x02 \x03(\r\"%\n#CMsgClientToGCFeaturedHeroesRequest\"\x91\x04\n$CMsgGCToClientFeaturedHeroesResponse\x12\x42\n\ncategories\x18\x01 \x03(\x0b\x32..CMsgGCToClientFeaturedHeroesResponse.Category\x1a\xad\x01\n\tDataField\x12I\n\tdata_type\x18\x01 \x01(\x0e\x32\x16.EFeaturedHeroDataType:\x1ek_EFeaturedHeroDataType_HeroID\x12\x14\n\x0cuint32_value\x18\x02 \x01(\r\x12\x14\n\x0cuint64_value\x18\x03 \x01(\x04\x12\x14\n\x0cstring_value\x18\x04 \x01(\t\x12\x13\n\x0b\x66loat_value\x18\x05 \x01(\x02\x1aT\n\x0c\x46\x65\x61turedHero\x12\x44\n\x0b\x64\x61ta_fields\x18\x01 \x03(\x0b\x32/.CMsgGCToClientFeaturedHeroesResponse.DataField\x1a\x9e\x01\n\x08\x43\x61tegory\x12\x17\n\x0f\x63\x61tegory_weight\x18\x01 \x01(\x05\x12,\n\x0btext_fields\x18\x02 \x03(\x0e\x32\x17.EFeaturedHeroTextField\x12K\n\x0f\x66\x65\x61tured_heroes\x18\x03 \x03(\x0b\x32\x32.CMsgGCToClientFeaturedHeroesResponse.FeaturedHero\"P\n+CMsgClientToGCSocialMatchPostCommentRequest\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"?\n,CMsgGCToClientSocialMatchPostCommentResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"Y\n\'CMsgClientToGCSocialMatchDetailsRequest\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x1c\n\x14pagination_timestamp\x18\x02 \x01(\r\"\xd9\x01\n(CMsgGCToClientSocialMatchDetailsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x43\n\x08\x63omments\x18\x02 \x03(\x0b\x32\x31.CMsgGCToClientSocialMatchDetailsResponse.Comment\x1aW\n\x07\x43omment\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x14\n\x0cpersona_name\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x0f\n\x07\x63omment\x18\x04 \x01(\t\"\xc7\x04\n\x19\x43MsgDOTAPartyRichPresence\x12\x10\n\x08party_id\x18\x01 \x01(\x06\x12,\n\x0bparty_state\x18\x02 \x01(\x0e\x32\x13.CSODOTAParty.State:\x02UI\x12\x0c\n\x04open\x18\x03 \x01(\x08\x12\x14\n\x0clow_priority\x18\x05 \x01(\x08\x12\x0f\n\x07team_id\x18\x07 \x01(\r\x12\x11\n\tteam_name\x18\x08 \x01(\t\x12\x18\n\x10ugc_team_ui_logo\x18\t \x01(\x04\x12\x32\n\x07members\x18\x04 \x03(\x0b\x32!.CMsgDOTAPartyRichPresence.Member\x12\x42\n\x0fweekend_tourney\x18\x06 \x01(\x0b\x32).CMsgDOTAPartyRichPresence.WeekendTourney\x1a)\n\x06Member\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\r\n\x05\x63oach\x18\x02 \x01(\x08\x1a\xe4\x01\n\x0eWeekendTourney\x12\x10\n\x08\x64ivision\x18\x01 \x01(\r\x12\x13\n\x0bskill_level\x18\x02 \x01(\r\x12\r\n\x05round\x18\x03 \x01(\r\x12\x15\n\rtournament_id\x18\x04 \x01(\r\x12\x15\n\rstate_seq_num\x18\x05 \x01(\r\x12Y\n\x05\x65vent\x18\x06 \x01(\x0e\x32!.EWeekendTourneyRichPresenceEvent:\'k_EWeekendTourneyRichPresenceEvent_None\x12\x13\n\x0b\x65vent_round\x18\x07 \x01(\r\"\x8e\x02\n\x19\x43MsgDOTALobbyRichPresence\x12\x10\n\x08lobby_id\x18\x01 \x01(\x06\x12,\n\x0blobby_state\x18\x02 \x01(\x0e\x32\x13.CSODOTALobby.State:\x02UI\x12\x10\n\x08password\x18\x03 \x01(\x08\x12\x35\n\tgame_mode\x18\x04 \x01(\x0e\x32\x0e.DOTA_GameMode:\x12\x44OTA_GAMEMODE_NONE\x12\x14\n\x0cmember_count\x18\x05 \x01(\r\x12\x18\n\x10max_member_count\x18\x06 \x01(\r\x12\x16\n\x0e\x63ustom_game_id\x18\x07 \x01(\x06\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x12\n\nlobby_type\x18\t \x01(\r\"\x83\x01\n,CMsgDOTACustomGameListenServerStartedLoading\x12\x10\n\x08lobby_id\x18\x01 \x01(\x06\x12\x16\n\x0e\x63ustom_game_id\x18\x02 \x01(\x04\x12\x15\n\rlobby_members\x18\x03 \x03(\r\x12\x12\n\nstart_time\x18\x04 \x01(\r\"\xa9\x01\n\'CMsgDOTACustomGameClientFinishedLoading\x12\x10\n\x08lobby_id\x18\x01 \x01(\x06\x12\x18\n\x10loading_duration\x18\x02 \x01(\r\x12\x13\n\x0bresult_code\x18\x03 \x01(\x11\x12\x15\n\rresult_string\x18\x04 \x01(\t\x12\x15\n\rsignon_states\x18\x05 \x01(\r\x12\x0f\n\x07\x63omment\x18\x06 \x01(\t\"2\n\x1d\x43MsgClientToGCGetLeagueSeries\x12\x11\n\tleague_id\x18\x01 \x01(\r\"\xb2\x03\n%CMsgClientToGCGetLeagueSeriesResponse\x12=\n\x06series\x18\x01 \x03(\x0b\x32-.CMsgClientToGCGetLeagueSeriesResponse.Series\x1a\xc9\x02\n\x06Series\x12\x11\n\tseries_id\x18\x01 \x01(\r\x12\x11\n\tnum_games\x18\x02 \x01(\r\x12\x41\n\x05teams\x18\x03 \x03(\x0b\x32\x32.CMsgClientToGCGetLeagueSeriesResponse.Series.Team\x12\x13\n\x0bseries_name\x18\x04 \x01(\t\x12\x12\n\nphase_name\x18\x05 \x01(\t\x12\x12\n\nstart_time\x18\x06 \x01(\r\x12\x17\n\x0f\x61\x66ter_series_id\x18\x07 \x01(\r\x12\x1b\n\x13num_completed_games\x18\x08 \x01(\r\x1a\x63\n\x04Team\x12\x0f\n\x07team_id\x18\x01 \x01(\r\x12\x11\n\tteam_name\x18\x02 \x01(\t\x12\x10\n\x08team_tag\x18\x03 \x01(\t\x12\x12\n\nteam_score\x18\x04 \x01(\r\x12\x11\n\tteam_wins\x18\x05 \x01(\r\"F\n\x1e\x43MsgClientToGCApplyGemCombiner\x12\x11\n\titem_id_1\x18\x01 \x01(\x04\x12\x11\n\titem_id_2\x18\x02 \x01(\x04\"\x1f\n\x1d\x43MsgClientToGCH264Unsupported\"\"\n CMsgClientToGCRequestH264Support\"3\n\x1e\x43MsgClientToGCGetQuestProgress\x12\x11\n\tquest_ids\x18\x01 \x03(\r\"\xef\x02\n&CMsgClientToGCGetQuestProgressResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12=\n\x06quests\x18\x02 \x03(\x0b\x32-.CMsgClientToGCGetQuestProgressResponse.Quest\x1a\x88\x01\n\tChallenge\x12\x14\n\x0c\x63hallenge_id\x18\x01 \x01(\r\x12\x16\n\x0etime_completed\x18\x02 \x01(\r\x12\x10\n\x08\x61ttempts\x18\x03 \x01(\r\x12\x0f\n\x07hero_id\x18\x04 \x01(\r\x12\x16\n\x0e\x63hallenge_type\x18\x05 \x01(\r\x12\x12\n\nquest_rank\x18\x06 \x01(\r\x1aj\n\x05Quest\x12\x10\n\x08quest_id\x18\x01 \x01(\r\x12O\n\x14\x63ompleted_challenges\x18\x02 \x03(\x0b\x32\x31.CMsgClientToGCGetQuestProgressResponse.Challenge\"0\n\x1c\x43MsgGCToClientMatchSignedOut\x12\x10\n\x08match_id\x18\x01 \x01(\x04\",\n\x19\x43MsgGCGetHeroStatsHistory\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\"c\n!CMsgGCGetHeroStatsHistoryResponse\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12-\n\x07records\x18\x02 \x03(\x0b\x32\x1c.CMsgDOTASDOHeroStatsHistory\"#\n!CMsgPlayerConductScorecardRequest\"\xb3\x02\n\x1a\x43MsgPlayerConductScorecard\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x10\n\x08match_id\x18\x02 \x01(\x04\x12\x0f\n\x07seq_num\x18\x03 \x01(\r\x12\x0f\n\x07reasons\x18\x04 \x01(\r\x12\x19\n\x11matches_in_report\x18\x05 \x01(\r\x12\x15\n\rmatches_clean\x18\x06 \x01(\r\x12\x18\n\x10matches_reported\x18\x07 \x01(\r\x12\x19\n\x11matches_abandoned\x18\x08 \x01(\r\x12\x15\n\rreports_count\x18\t \x01(\r\x12\x17\n\x0freports_parties\x18\n \x01(\r\x12\x15\n\rcommend_count\x18\x0b \x01(\r\x12\x11\n\tend_score\x18\r \x01(\r\x12\x0c\n\x04\x64\x61te\x18\x0e \x01(\r\"1\n\x1d\x43MsgClientToGCWageringRequest\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\"\xd4\x01\n\x1e\x43MsgGCToClientWageringResponse\x12\x17\n\x0f\x63oins_remaining\x18\x01 \x01(\r\x12\x18\n\x10total_points_won\x18\x02 \x01(\r\x12\x1c\n\x14total_points_wagered\x18\x03 \x01(\r\x12\x1b\n\x13total_points_tipped\x18\x04 \x01(\r\x12\x14\n\x0csuccess_rate\x18\x05 \x01(\r\x12\x1b\n\x13total_games_wagered\x18\x06 \x01(\r\x12\x11\n\tcoins_max\x18\x07 \x01(\r\"h\n\x1c\x43MsgGCToClientWageringUpdate\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x36\n\rwagering_info\x18\x02 \x01(\x0b\x32\x1f.CMsgGCToClientWageringResponse\"}\n\x1f\x43MsgGCToClientArcanaVotesUpdate\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12H\n\x0c\x61rcana_votes\x18\x02 \x01(\x0b\x32\x32.CMsgClientToGCRequestArcanaVotesRemainingResponse\"@\n\x19\x43MsgClientToGCMysteryItem\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x11\n\taction_id\x18\x02 \x01(\r\"\x95\x03\n!CMsgGCToClientMysteryItemResponse\x12\x42\n\x06result\x18\x01 \x01(\x0e\x32).CMsgGCToClientMysteryItemResponse.Result:\x07SUCCESS\x12\x13\n\x0breward_type\x18\x02 \x01(\r\x12\x0f\n\x07itemdef\x18\x03 \x01(\r\"\x85\x02\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x14\n\x10\x46\x41ILURE_SDO_LOAD\x10\x01\x12\x16\n\x12\x46\x41ILURE_NO_ACTIONS\x10\x02\x12\x17\n\x13\x46\x41ILURE_NO_LOOTLIST\x10\x03\x12\x1a\n\x16\x46\x41ILURE_EMPTY_LOOTLIST\x10\x04\x12\x1d\n\x19\x46\x41ILURE_NO_ITEM_GENERATED\x10\x05\x12\x16\n\x12\x46\x41ILURE_SQL_COMMIT\x10\x06\x12\x1b\n\x17\x46\x41ILURE_EVENT_NOT_OWNED\x10\x07\x12\x1a\n\x16\x46\x41ILURE_INVALID_ACTION\x10\x08\x12\x1b\n\x17\x46\x41ILURE_ALREADY_GRANTED\x10\t\"9\n\x1b\x43MsgClientToGCGetEventGoals\x12\x1a\n\tevent_ids\x18\x01 \x03(\x0e\x32\x07.EEvent\"\x97\x01\n\x0e\x43MsgEventGoals\x12.\n\x0b\x65vent_goals\x18\x01 \x03(\x0b\x32\x19.CMsgEventGoals.EventGoal\x1aU\n\tEventGoal\x12(\n\x08\x65vent_id\x18\x01 \x01(\x0e\x32\x07.EEvent:\rEVENT_ID_NONE\x12\x0f\n\x07goal_id\x18\x02 \x01(\r\x12\r\n\x05value\x18\x03 \x01(\x04\"0\n\x1b\x43MsgGCToGCLeaguePredictions\x12\x11\n\tleague_id\x18\x01 \x01(\r\"\x9c\x02\n\x16\x43MsgPredictionRankings\x12\x37\n\x0bpredictions\x18\x01 \x03(\x0b\x32\".CMsgPredictionRankings.Prediction\x1a\x63\n\x0ePredictionLine\x12\x11\n\tanswer_id\x18\x01 \x01(\r\x12\x13\n\x0b\x61nswer_name\x18\x02 \x01(\t\x12\x13\n\x0b\x61nswer_logo\x18\x03 \x01(\x04\x12\x14\n\x0c\x61nswer_value\x18\x04 \x01(\x02\x1a\x64\n\nPrediction\x12\x14\n\x0cselection_id\x18\x01 \x01(\r\x12@\n\x10prediction_lines\x18\x02 \x03(\x0b\x32&.CMsgPredictionRankings.PredictionLine\"\xec\x01\n\x15\x43MsgPredictionResults\x12.\n\x07results\x18\x01 \x03(\x0b\x32\x1d.CMsgPredictionResults.Result\x1a\x41\n\x0fResultBreakdown\x12\x18\n\x10\x61nswer_selection\x18\x02 \x01(\r\x12\x14\n\x0c\x61nswer_value\x18\x03 \x01(\x02\x1a`\n\x06Result\x12\x14\n\x0cselection_id\x18\x01 \x01(\r\x12@\n\x10result_breakdown\x18\x02 \x03(\x0b\x32&.CMsgPredictionResults.ResultBreakdown\"4\n CMsgClientToGCSuspiciousActivity\x12\x10\n\x08\x61pp_data\x18\x01 \x01(\x04\"6\n\"CMsgClientToGCHasPlayerVotedForMVP\x12\x10\n\x08match_id\x18\x01 \x01(\x04\"<\n*CMsgClientToGCHasPlayerVotedForMVPResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\"@\n\x18\x43MsgClientToGCVoteForMVP\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x12\n\naccount_id\x18\x03 \x01(\r\"2\n CMsgClientToGCVoteForMVPResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\"w\n\x14\x43MsgMVPVotesForMatch\x12-\n\x07players\x18\x01 \x03(\x0b\x32\x1c.CMsgMVPVotesForMatch.Player\x1a\x30\n\x06Player\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x12\n\nvote_count\x18\x02 \x01(\r\"G\n\x13\x43MsgLeaguePrizePool\x12\x12\n\nprize_pool\x18\x01 \x01(\r\x12\x1c\n\x14increment_per_second\x18\x02 \x01(\x02\"$\n\"CMsgClientToGCTeammateStatsRequest\"\x9f\x02\n#CMsgClientToGCTeammateStatsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12I\n\x0eteammate_stats\x18\x02 \x03(\x0b\x32\x31.CMsgClientToGCTeammateStatsResponse.TeammateStat\x1a\x9b\x01\n\x0cTeammateStat\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\r\n\x05games\x18\x02 \x01(\r\x12\x0c\n\x04wins\x18\x03 \x01(\r\x12\"\n\x1amost_recent_game_timestamp\x18\x04 \x01(\r\x12!\n\x19most_recent_game_match_id\x18\x05 \x01(\x04\x12\x13\n\x0bperformance\x18\x64 \x01(\x02\"\x9a\x01\n\x1b\x43MsgClientToGCVoteForArcana\x12\x37\n\x07matches\x18\x01 \x03(\x0b\x32&.CMsgClientToGCVoteForArcana.MatchVote\x1a\x42\n\tMatchVote\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\x12\x12\n\nvote_count\x18\x03 \x01(\r\"\xbd\x01\n#CMsgClientToGCVoteForArcanaResponse\x12\x46\n\x06result\x18\x01 \x01(\x0e\x32+.CMsgClientToGCVoteForArcanaResponse.Result:\tSUCCEEDED\"N\n\x06Result\x12\r\n\tSUCCEEDED\x10\x00\x12 \n\x1cVOTING_NOT_ENABLED_FOR_ROUND\x10\x01\x12\x13\n\x0fUNKNOWN_FAILURE\x10\x02\"\x8f\x04\n\x0f\x43MsgArcanaVotes\x12\'\n\x07matches\x18\x01 \x03(\x0b\x32\x16.CMsgArcanaVotes.Match\x12\x1c\n\x14round_time_remaining\x18\x02 \x01(\r\x12\x14\n\x0cround_number\x18\x03 \x01(\r\x12\x14\n\x0cvoting_state\x18\x04 \x01(\r\x12$\n\x1cis_current_round_calibrating\x18\x05 \x01(\x08\x12\x1f\n\x17\x63losest_active_match_id\x18\x06 \x01(\r\x1a\x84\x02\n\x05Match\x12\x10\n\x08match_id\x18\x01 \x01(\r\x12\x11\n\thero_id_0\x18\x02 \x01(\r\x12\x11\n\thero_id_1\x18\x03 \x01(\r\x12\x16\n\x0ehero_seeding_0\x18\x04 \x01(\r\x12\x16\n\x0ehero_seeding_1\x18\x05 \x01(\r\x12\x14\n\x0cvote_count_0\x18\x06 \x01(\r\x12\x14\n\x0cvote_count_1\x18\x07 \x01(\r\x12\x14\n\x0cvoting_state\x18\x08 \x01(\r\x12\x14\n\x0cround_number\x18\t \x01(\r\x12\x17\n\x0fis_votes_hidden\x18\n \x01(\x08\x12\"\n\x1a\x63\x61libration_time_remaining\x18\x0b \x01(\r\";\n\x0bVotingState\x12\x0c\n\x08\x46INISHED\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\r\n\tIN_FUTURE\x10\x02\"+\n)CMsgClientToGCRequestArcanaVotesRemaining\"\x99\x02\n1CMsgClientToGCRequestArcanaVotesRemainingResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12\x17\n\x0fvotes_remaining\x18\x02 \x01(\r\x12\x13\n\x0bvotes_total\x18\x03 \x01(\r\x12\x62\n\x1cmatches_previously_voted_for\x18\x04 \x03(\x0b\x32<.CMsgClientToGCRequestArcanaVotesRemainingResponse.MatchVote\x1a\x42\n\tMatchVote\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x0f\n\x07hero_id\x18\x02 \x01(\r\x12\x12\n\nvote_count\x18\x03 \x01(\r\"6\n\"CMsgClientToGCRequestEventPointLog\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\"\x95\x10\n*CMsgClientToGCRequestEventPointLogResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12W\n\x0ctransactions\x18\x02 \x03(\x0b\x32\x41.CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction\x12\x10\n\x08\x65vent_id\x18\x03 \x01(\r\x1aK\n\x13QuestChallengeEvent\x12\x10\n\x08quest_id\x18\x01 \x01(\r\x12\x14\n\x0c\x63hallenge_id\x18\x02 \x01(\r\x12\x0c\n\x04rank\x18\x03 \x01(\r\x1a!\n\rWagerWonEvent\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x1a\x45\n\rTipGivenEvent\x12\x1c\n\x14recipient_account_id\x18\x01 \x01(\r\x12\x16\n\x0erecipient_name\x18\x02 \x01(\t\x1a@\n\x10TipReceivedEvent\x12\x18\n\x10giver_account_id\x18\x01 \x01(\r\x12\x12\n\ngiver_name\x18\x02 \x01(\t\x1a\x32\n\x11RecycledItemEvent\x12\x1d\n\x15recipe_item_def_index\x18\x01 \x01(\r\x1a%\n\x10\x41\x63hievementEvent\x12\x11\n\taction_id\x18\x01 \x01(\r\x1a\x37\n\x18MysteryItemReceivedEvent\x12\x1b\n\x13\x63ommunity_goal_item\x18\x01 \x01(\x08\x1a/\n\x16\x43orrectPredictionEvent\x12\x15\n\rprediction_id\x18\x01 \x01(\r\x1a\x30\n\x1cInGamePredictionCorrectEvent\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x1a-\n\x19WeekendTourneyPayoutEvent\x12\x10\n\x08team_gid\x18\x01 \x01(\x04\x1a(\n\x12\x46\x61ntasyRewardEvent\x12\x12\n\npercentile\x18\x01 \x01(\r\x1a-\n\x12\x42racketRewardEvent\x12\x17\n\x0f\x63orrect_answers\x18\x01 \x01(\r\x1a\xf3\t\n\x15\x45ventPointTransaction\x12\x0c\n\x04time\x18\x01 \x01(\r\x12\x14\n\x0c\x65vent_points\x18\x02 \x01(\x05\x12\"\n\x1a\x63ompendium_activated_event\x18\x03 \x01(\x08\x12\x1d\n\x15point_item_used_event\x18\x04 \x01(\x08\x12R\n\x0fwager_won_event\x18\x05 \x01(\x0b\x32\x39.CMsgClientToGCRequestEventPointLogResponse.WagerWonEvent\x12i\n\x1bmystery_item_received_event\x18\x06 \x01(\x0b\x32\x44.CMsgClientToGCRequestEventPointLogResponse.MysteryItemReceivedEvent\x12^\n\x15quest_challenge_event\x18\x07 \x01(\x0b\x32?.CMsgClientToGCRequestEventPointLogResponse.QuestChallengeEvent\x12R\n\x0ftip_given_event\x18\x08 \x01(\x0b\x32\x39.CMsgClientToGCRequestEventPointLogResponse.TipGivenEvent\x12X\n\x12tip_received_event\x18\t \x01(\x0b\x32<.CMsgClientToGCRequestEventPointLogResponse.TipReceivedEvent\x12Z\n\x13recycled_item_event\x18\n \x01(\x0b\x32=.CMsgClientToGCRequestEventPointLogResponse.RecycledItemEvent\x12W\n\x11\x61\x63hievement_event\x18\x0b \x01(\x0b\x32<.CMsgClientToGCRequestEventPointLogResponse.AchievementEvent\x12j\n\x18in_game_prediction_event\x18\x0c \x01(\x0b\x32H.CMsgClientToGCRequestEventPointLogResponse.InGamePredictionCorrectEvent\x12\\\n\x10prediction_event\x18\r \x01(\x0b\x32\x42.CMsgClientToGCRequestEventPointLogResponse.CorrectPredictionEvent\x12k\n\x1cweekend_tourney_payout_event\x18\x0e \x01(\x0b\x32\x45.CMsgClientToGCRequestEventPointLogResponse.WeekendTourneyPayoutEvent\x12\\\n\x14\x66\x61ntasy_reward_event\x18\x0f \x01(\x0b\x32>.CMsgClientToGCRequestEventPointLogResponse.FantasyRewardEvent\x12\\\n\x14\x62racket_reward_event\x18\x10 \x01(\x0b\x32>.CMsgClientToGCRequestEventPointLogResponse.BracketRewardEvent\"Q\n\x1d\x43MsgClientToGCPublishUserStat\x12\x18\n\x10user_stats_event\x18\x01 \x01(\r\x12\x16\n\x0ereference_data\x18\x02 \x01(\x04\"1\n CMsgClientToGCAddTI6TreeProgress\x12\r\n\x05trees\x18\x01 \x01(\r\"Y\n\x1a\x43MsgClientToGCRedeemReward\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x11\n\taction_id\x18\x02 \x01(\r\x12\x16\n\x0e\x62\x61se_action_id\x18\x03 \x01(\r\"\xd8\x02\n\"CMsgGCToClientRedeemRewardResponse\x12\x43\n\x06result\x18\x01 \x01(\x0e\x32*.CMsgGCToClientRedeemRewardResponse.Result:\x07SUCCESS\"\xec\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x14\n\x10\x46\x41ILURE_SDO_LOCK\x10\x01\x12\x14\n\x10\x46\x41ILURE_SDO_LOAD\x10\x02\x12\x1b\n\x17\x46\x41ILURE_EVENT_NOT_OWNED\x10\x03\x12\x1c\n\x18\x46\x41ILURE_EVENT_NOT_ACTIVE\x10\x04\x12\x1a\n\x16\x46\x41ILURE_INVALID_ACTION\x10\x05\x12 \n\x1c\x46\x41ILURE_REQUIREMENTS_NOT_MET\x10\x06\x12\x1b\n\x17\x46\x41ILURE_ALREADY_GRANTED\x10\x07\x12\x13\n\x0f\x46\x41ILURE_TIMEOUT\x10\x08\"S\n\'CMsgClientToGCRequestLinaPlaysRemaining\x12(\n\x08\x65vent_id\x18\x01 \x01(\x0e\x32\x07.EEvent:\rEVENT_ID_NONE\"_\n/CMsgClientToGCRequestLinaPlaysRemainingResponse\x12\x17\n\x0fplays_remaining\x18\x01 \x01(\r\x12\x13\n\x0bplays_total\x18\x02 \x01(\r\"d\n#CMsgClientToGCRequestLinaGameResult\x12(\n\x08\x65vent_id\x18\x01 \x01(\x0e\x32\x07.EEvent:\rEVENT_ID_NONE\x12\x13\n\x0bslot_chosen\x18\x02 \x01(\r\"=\n+CMsgClientToGCRequestLinaGameResultResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"\x8e\x02\n\"CMsgGCToClientQuestProgressUpdated\x12\x10\n\x08quest_id\x18\x01 \x01(\r\x12K\n\x14\x63ompleted_challenges\x18\x02 \x03(\x0b\x32-.CMsgGCToClientQuestProgressUpdated.Challenge\x1a\x88\x01\n\tChallenge\x12\x14\n\x0c\x63hallenge_id\x18\x01 \x01(\r\x12\x16\n\x0etime_completed\x18\x02 \x01(\r\x12\x10\n\x08\x61ttempts\x18\x03 \x01(\r\x12\x0f\n\x07hero_id\x18\x04 \x01(\r\x12\x16\n\x0e\x63hallenge_type\x18\x05 \x01(\r\x12\x12\n\nquest_rank\x18\x06 \x01(\r\"?\n\x12\x43MsgDOTARedeemItem\x12\x13\n\x0b\x63urrency_id\x18\x01 \x01(\x04\x12\x14\n\x0cpurchase_def\x18\x02 \x01(\r\"\x92\x01\n\x1a\x43MsgDOTARedeemItemResponse\x12\x46\n\x08response\x18\x01 \x01(\x0e\x32\'.CMsgDOTARedeemItemResponse.EResultCode:\x0bk_Succeeded\",\n\x0b\x45ResultCode\x12\x0f\n\x0bk_Succeeded\x10\x00\x12\x0c\n\x08k_Failed\x10\x01\"6\n!CMsgPerfectWorldUserLookupRequest\x12\x11\n\tuser_name\x18\x01 \x01(\t\"\xc8\x02\n\"CMsgPerfectWorldUserLookupResponse\x12[\n\x0bresult_code\x18\x01 \x01(\x0e\x32/.CMsgPerfectWorldUserLookupResponse.EResultCode:\x15SUCCESS_ACCOUNT_FOUND\x12\x12\n\naccount_id\x18\x02 \x01(\r\"\xb0\x01\n\x0b\x45ResultCode\x12\x19\n\x15SUCCESS_ACCOUNT_FOUND\x10\x00\x12\x11\n\rERROR_UNKNOWN\x10\x01\x12 \n\x1c\x45RROR_USER_NAME_WRONG_FORMAT\x10\x02\x12(\n$ERROR_NO_PERFECT_WORLD_ACCOUNT_FOUND\x10\x03\x12\'\n#ERROR_NO_LINKED_STEAM_ACCOUNT_FOUND\x10\x04\"W\n\x16\x43MsgNexonPartnerUpdate\x12\x13\n\x0bmessagetype\x18\x01 \x01(\r\x12\x15\n\rtimeremaining\x18\x02 \x01(\r\x12\x11\n\tterminate\x18\x03 \x01(\x08\"#\n\x10\x43MsgMakeOffering\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\"\x16\n\x14\x43MsgRequestOfferings\"\xac\x01\n\x1c\x43MsgRequestOfferingsResponse\x12\x41\n\tofferings\x18\x01 \x03(\x0b\x32..CMsgRequestOfferingsResponse.NewYearsOffering\x12\x11\n\tcompleted\x18\x02 \x01(\x08\x1a\x36\n\x10NewYearsOffering\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\x0f\n\x07item_id\x18\x02 \x01(\x04\"Q\n\x19\x43MsgDOTAPCBangTimedReward\x12\x0f\n\x07persona\x18\x01 \x01(\t\x12\x0f\n\x07itemdef\x18\x02 \x01(\r\x12\x12\n\npcbangname\x18\x03 \x01(\t\"\xed\x01\n)CMsgDOTACompendiumInGamePredictionResults\x12L\n\x07results\x18\x01 \x03(\x0b\x32;.CMsgDOTACompendiumInGamePredictionResults.PredictionResult\x12\x11\n\tleague_id\x18\x02 \x01(\r\x12\x1a\n\x12predictions_closed\x18\x03 \x01(\x08\x1a\x43\n\x10PredictionResult\x12\x15\n\rprediction_id\x18\x01 \x01(\r\x12\x18\n\x10prediction_value\x18\x02 \x01(\r\"\xd2\x01\n.CMsgClientToGCSelectCompendiumInGamePrediction\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12O\n\x0bpredictions\x18\x02 \x03(\x0b\x32:.CMsgClientToGCSelectCompendiumInGamePrediction.Prediction\x1a=\n\nPrediction\x12\x15\n\rprediction_id\x18\x01 \x01(\r\x12\x18\n\x10prediction_value\x18\x02 \x01(\r\"\xea\x01\n6CMsgClientToGCSelectCompendiumInGamePredictionResponse\x12X\n\x06result\x18\x01 \x01(\x0e\x32?.CMsgClientToGCSelectCompendiumInGamePredictionResponse.EResult:\x07SUCCESS\"V\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x11\n\rINVALID_MATCH\x10\x01\x12\x1a\n\x16PREDICTIONS_ARE_CLOSED\x10\x02\x12\x0f\n\x0bOTHER_ERROR\x10\x03\"D\n CMsgClientToGCOpenPlayerCardPack\x12 \n\x18player_card_pack_item_id\x18\x01 \x01(\x04\"\x9a\x02\n(CMsgClientToGCOpenPlayerCardPackResponse\x12I\n\x06result\x18\x01 \x01(\x0e\x32\x30.CMsgClientToGCOpenPlayerCardPackResponse.Result:\x07SUCCESS\x12\x1c\n\x14player_card_item_ids\x18\x02 \x03(\x04\"\x84\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0e\x45RROR_INTERNAL\x10\x02\x12\x1d\n\x19\x45RROR_FAILED_TO_FIND_PACK\x10\x03\x12\x1c\n\x18\x45RROR_ITEM_NOT_CARD_PACK\x10\x04\x12\x1c\n\x18\x45RROR_FAILED_CARD_CREATE\x10\x05\">\n\x1f\x43MsgClientToGCRecyclePlayerCard\x12\x1b\n\x13player_card_item_id\x18\x01 \x01(\x04\"\xb4\x02\n\'CMsgClientToGCRecyclePlayerCardResponse\x12H\n\x06result\x18\x01 \x01(\x0e\x32/.CMsgClientToGCRecyclePlayerCardResponse.Result:\x07SUCCESS\x12\x13\n\x0b\x64ust_amount\x18\x02 \x01(\r\"\xa9\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0e\x45RROR_INTERNAL\x10\x02\x12$\n ERROR_FAILED_TO_FIND_PLAYER_CARD\x10\x03\x12\x1e\n\x1a\x45RROR_ITEM_NOT_PLAYER_CARD\x10\x04\x12!\n\x1d\x45RROR_FAILED_DUST_CARD_CREATE\x10\x05\x12\x15\n\x11\x45RROR_CARD_LOCKED\x10\x06\"?\n\"CMsgClientToGCCreatePlayerCardPack\x12\x19\n\x11\x63\x61rd_dust_item_id\x18\x01 \x01(\x04\"\x83\x02\n*CMsgClientToGCCreatePlayerCardPackResponse\x12K\n\x06result\x18\x01 \x01(\x0e\x32\x32.CMsgClientToGCCreatePlayerCardPackResponse.Result:\x07SUCCESS\"\x87\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0e\x45RROR_INTERNAL\x10\x02\x12\x1b\n\x17\x45RROR_INSUFFICIENT_DUST\x10\x03\x12\x1c\n\x18\x45RROR_ITEM_NOT_DUST_ITEM\x10\x04\x12!\n\x1d\x45RROR_FAILED_CARD_PACK_CREATE\x10\x05\"\x83\n\n0CMsgGCToClientBattlePassRollup_International2016\x12\x19\n\x11\x62\x61ttle_pass_level\x18\x01 \x01(\r\x12P\n\nquestlines\x18\x02 \x03(\x0b\x32<.CMsgGCToClientBattlePassRollup_International2016.Questlines\x12L\n\x08wagering\x18\x03 \x01(\x0b\x32:.CMsgGCToClientBattlePassRollup_International2016.Wagering\x12T\n\x0c\x61\x63hievements\x18\x04 \x01(\x0b\x32>.CMsgGCToClientBattlePassRollup_International2016.Achievements\x12O\n\nbattle_cup\x18\x05 \x01(\x0b\x32;.CMsgGCToClientBattlePassRollup_International2016.BattleCup\x12R\n\x0bpredictions\x18\x06 \x01(\x0b\x32=.CMsgGCToClientBattlePassRollup_International2016.Predictions\x12J\n\x07\x62racket\x18\x07 \x01(\x0b\x32\x39.CMsgGCToClientBattlePassRollup_International2016.Bracket\x12R\n\x0cplayer_cards\x18\x08 \x03(\x0b\x32<.CMsgGCToClientBattlePassRollup_International2016.PlayerCard\x12]\n\x11\x66\x61ntasy_challenge\x18\t \x01(\x0b\x32\x42.CMsgGCToClientBattlePassRollup_International2016.FantasyChallenge\x1a^\n\nQuestlines\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07onestar\x18\x02 \x01(\r\x12\x0f\n\x07twostar\x18\x03 \x01(\r\x12\x11\n\tthreestar\x18\x04 \x01(\r\x12\r\n\x05total\x18\x05 \x01(\r\x1as\n\x08Wagering\x12\x15\n\rtotal_wagered\x18\x01 \x01(\r\x12\x11\n\ttotal_won\x18\x02 \x01(\r\x12\x13\n\x0b\x61verage_won\x18\x03 \x01(\r\x12\x14\n\x0csuccess_rate\x18\x04 \x01(\r\x12\x12\n\ntotal_tips\x18\x05 \x01(\r\x1a@\n\x0c\x41\x63hievements\x12\x11\n\tcompleted\x18\x01 \x01(\r\x12\r\n\x05total\x18\x02 \x01(\r\x12\x0e\n\x06points\x18\x03 \x01(\r\x1a(\n\tBattleCup\x12\x0c\n\x04wins\x18\x01 \x01(\r\x12\r\n\x05score\x18\x02 \x01(\r\x1a=\n\x0bPredictions\x12\x0f\n\x07\x63orrect\x18\x01 \x01(\r\x12\r\n\x05total\x18\x02 \x01(\r\x12\x0e\n\x06points\x18\x03 \x01(\r\x1a*\n\x07\x42racket\x12\x0f\n\x07\x63orrect\x18\x01 \x01(\r\x12\x0e\n\x06points\x18\x02 \x01(\r\x1a\x31\n\nPlayerCard\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07quality\x18\x02 \x01(\r\x1a;\n\x10\x46\x61ntasyChallenge\x12\x13\n\x0btotal_score\x18\x01 \x01(\x02\x12\x12\n\npercentile\x18\x02 \x01(\x02\"M\n%CMsgGCToClientBattlePassRollupRequest\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x12\n\naccount_id\x18\x02 \x01(\r\"n\n&CMsgGCToClientBattlePassRollupResponse\x12\x44\n\tevent_ti6\x18\x01 \x01(\x0b\x32\x31.CMsgGCToClientBattlePassRollup_International2016\"?\n)CMsgGCToClientBattlePassRollupListRequest\x12\x12\n\naccount_id\x18\x01 \x01(\r\">\n*CMsgGCToClientBattlePassRollupListResponse\x12\x10\n\x08\x65vent_id\x18\x01 \x03(\r\"<\n(CMsgClientToGCTransferSeasonalMMRRequest\x12\x10\n\x08is_party\x18\x01 \x01(\x08\"<\n)CMsgClientToGCTransferSeasonalMMRResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x9b\x01\n\x13\x43MsgDOTAEventInvite\x12(\n\x05teams\x18\x01 \x03(\x0b\x32\x19.CMsgDOTAEventInvite.Team\x1aZ\n\x04Team\x12\x0f\n\x07team_id\x18\x01 \x01(\r\x12\x19\n\x11\x61nnouncement_date\x18\x02 \x01(\r\x12\x11\n\tteam_name\x18\x03 \x01(\t\x12\x13\n\x0binvite_type\x18\x04 \x01(\r\"*\n\x17\x43MsgDOTASetFavoriteTeam\x12\x0f\n\x07team_id\x18\x01 \x01(\r*V\n\x14\x44OTA_WatchReplayType\x12\x1c\n\x18\x44OTA_WATCH_REPLAY_NORMAL\x10\x00\x12 \n\x1c\x44OTA_WATCH_REPLAY_HIGHLIGHTS\x10\x01*\xd1\x01\n\x1c\x45ItemEditorReservationResult\x12%\n!k_EItemEditorReservationResult_OK\x10\x01\x12\x30\n,k_EItemEditorReservationResult_AlreadyExists\x10\x02\x12+\n\'k_EItemEditorReservationResult_Reserved\x10\x03\x12+\n\'k_EItemEditorReservationResult_TimedOut\x10\x04*\x92\x04\n\x16\x45\x46\x65\x61turedHeroTextField\x12$\n k_EFeaturedHeroTextField_NewHero\x10\x00\x12$\n k_EFeaturedHeroTextField_NewItem\x10\x01\x12/\n+k_EFeaturedHeroTextField_ItemSetDescription\x10\x02\x12,\n(k_EFeaturedHeroTextField_ItemDescription\x10\x03\x12!\n\x1dk_EFeaturedHeroTextField_Hype\x10\x04\x12(\n$k_EFeaturedHeroTextField_HeroWinLoss\x10\x05\x12\x31\n-k_EFeaturedHeroTextField_FrequentlyPlayedHero\x10\x06\x12)\n%k_EFeaturedHeroTextField_FeaturedItem\x10\x07\x12(\n$k_EFeaturedHeroTextField_PopularItem\x10\x08\x12%\n!k_EFeaturedHeroTextField_SaleItem\x10\t\x12)\n%k_EFeaturedHeroTextField_SaleDiscount\x10\n\x12&\n\"k_EFeaturedHeroTextField_Container\x10\x0b*\x87\x03\n\x15\x45\x46\x65\x61turedHeroDataType\x12\"\n\x1ek_EFeaturedHeroDataType_HeroID\x10\x00\x12#\n\x1fk_EFeaturedHeroDataType_ItemDef\x10\x01\x12&\n\"k_EFeaturedHeroDataType_HypeString\x10\x02\x12*\n&k_EFeaturedHeroDataType_StartTimestamp\x10\x03\x12+\n\'k_EFeaturedHeroDataType_ExpireTimestamp\x10\x04\x12$\n k_EFeaturedHeroDataType_HeroWins\x10\x05\x12&\n\"k_EFeaturedHeroDataType_HeroLosses\x10\x06\x12(\n$k_EFeaturedHeroDataType_SaleDiscount\x10\x07\x12,\n(k_EFeaturedHeroDataType_ContainerItemDef\x10\x08*\xe8\x01\n EWeekendTourneyRichPresenceEvent\x12+\n\'k_EWeekendTourneyRichPresenceEvent_None\x10\x00\x12\x33\n/k_EWeekendTourneyRichPresenceEvent_StartedMatch\x10\x01\x12/\n+k_EWeekendTourneyRichPresenceEvent_WonMatch\x10\x02\x12\x31\n-k_EWeekendTourneyRichPresenceEvent_Eliminated\x10\x03\x42\x05H\x01\x90\x01\x00')
  ,
  dependencies=[steammessages__pb2.DESCRIPTOR,dota__shared__enums__pb2.DESCRIPTOR,dota__gcmessages__common__pb2.DESCRIPTOR,gcsdk__gcmessages__pb2.DESCRIPTOR,dota__gcmessages__common__match__management__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_DOTA_WATCHREPLAYTYPE = _descriptor.EnumDescriptor(
  name='DOTA_WatchReplayType',
  full_name='DOTA_WatchReplayType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_WATCH_REPLAY_NORMAL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_WATCH_REPLAY_HIGHLIGHTS', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=36897,
  serialized_end=36983,
)
_sym_db.RegisterEnumDescriptor(_DOTA_WATCHREPLAYTYPE)

DOTA_WatchReplayType = enum_type_wrapper.EnumTypeWrapper(_DOTA_WATCHREPLAYTYPE)
_EITEMEDITORRESERVATIONRESULT = _descriptor.EnumDescriptor(
  name='EItemEditorReservationResult',
  full_name='EItemEditorReservationResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EItemEditorReservationResult_OK', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EItemEditorReservationResult_AlreadyExists', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EItemEditorReservationResult_Reserved', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EItemEditorReservationResult_TimedOut', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=36986,
  serialized_end=37195,
)
_sym_db.RegisterEnumDescriptor(_EITEMEDITORRESERVATIONRESULT)

EItemEditorReservationResult = enum_type_wrapper.EnumTypeWrapper(_EITEMEDITORRESERVATIONRESULT)
_EFEATUREDHEROTEXTFIELD = _descriptor.EnumDescriptor(
  name='EFeaturedHeroTextField',
  full_name='EFeaturedHeroTextField',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_NewHero', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_NewItem', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_ItemSetDescription', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_ItemDescription', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_Hype', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_HeroWinLoss', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_FrequentlyPlayedHero', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_FeaturedItem', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_PopularItem', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_SaleItem', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_SaleDiscount', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroTextField_Container', index=11, number=11,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=37198,
  serialized_end=37728,
)
_sym_db.RegisterEnumDescriptor(_EFEATUREDHEROTEXTFIELD)

EFeaturedHeroTextField = enum_type_wrapper.EnumTypeWrapper(_EFEATUREDHEROTEXTFIELD)
_EFEATUREDHERODATATYPE = _descriptor.EnumDescriptor(
  name='EFeaturedHeroDataType',
  full_name='EFeaturedHeroDataType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_HeroID', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_ItemDef', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_HypeString', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_StartTimestamp', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_ExpireTimestamp', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_HeroWins', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_HeroLosses', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_SaleDiscount', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EFeaturedHeroDataType_ContainerItemDef', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=37731,
  serialized_end=38122,
)
_sym_db.RegisterEnumDescriptor(_EFEATUREDHERODATATYPE)

EFeaturedHeroDataType = enum_type_wrapper.EnumTypeWrapper(_EFEATUREDHERODATATYPE)
_EWEEKENDTOURNEYRICHPRESENCEEVENT = _descriptor.EnumDescriptor(
  name='EWeekendTourneyRichPresenceEvent',
  full_name='EWeekendTourneyRichPresenceEvent',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EWeekendTourneyRichPresenceEvent_None', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EWeekendTourneyRichPresenceEvent_StartedMatch', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EWeekendTourneyRichPresenceEvent_WonMatch', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EWeekendTourneyRichPresenceEvent_Eliminated', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=38125,
  serialized_end=38357,
)
_sym_db.RegisterEnumDescriptor(_EWEEKENDTOURNEYRICHPRESENCEEVENT)

EWeekendTourneyRichPresenceEvent = enum_type_wrapper.EnumTypeWrapper(_EWEEKENDTOURNEYRICHPRESENCEEVENT)
DOTA_WATCH_REPLAY_NORMAL = 0
DOTA_WATCH_REPLAY_HIGHLIGHTS = 1
k_EItemEditorReservationResult_OK = 1
k_EItemEditorReservationResult_AlreadyExists = 2
k_EItemEditorReservationResult_Reserved = 3
k_EItemEditorReservationResult_TimedOut = 4
k_EFeaturedHeroTextField_NewHero = 0
k_EFeaturedHeroTextField_NewItem = 1
k_EFeaturedHeroTextField_ItemSetDescription = 2
k_EFeaturedHeroTextField_ItemDescription = 3
k_EFeaturedHeroTextField_Hype = 4
k_EFeaturedHeroTextField_HeroWinLoss = 5
k_EFeaturedHeroTextField_FrequentlyPlayedHero = 6
k_EFeaturedHeroTextField_FeaturedItem = 7
k_EFeaturedHeroTextField_PopularItem = 8
k_EFeaturedHeroTextField_SaleItem = 9
k_EFeaturedHeroTextField_SaleDiscount = 10
k_EFeaturedHeroTextField_Container = 11
k_EFeaturedHeroDataType_HeroID = 0
k_EFeaturedHeroDataType_ItemDef = 1
k_EFeaturedHeroDataType_HypeString = 2
k_EFeaturedHeroDataType_StartTimestamp = 3
k_EFeaturedHeroDataType_ExpireTimestamp = 4
k_EFeaturedHeroDataType_HeroWins = 5
k_EFeaturedHeroDataType_HeroLosses = 6
k_EFeaturedHeroDataType_SaleDiscount = 7
k_EFeaturedHeroDataType_ContainerItemDef = 8
k_EWeekendTourneyRichPresenceEvent_None = 0
k_EWeekendTourneyRichPresenceEvent_StartedMatch = 1
k_EWeekendTourneyRichPresenceEvent_WonMatch = 2
k_EWeekendTourneyRichPresenceEvent_Eliminated = 3


_CMSGDOTAREQUESTMATCHES_SKILLLEVEL = _descriptor.EnumDescriptor(
  name='SkillLevel',
  full_name='CMsgDOTARequestMatches.SkillLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Any', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Normal', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='High', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VeryHigh', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=864,
  serialized_end=921,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAREQUESTMATCHES_SKILLLEVEL)

_CMSGDOTAPOPUP_POPUPID = _descriptor.EnumDescriptor(
  name='PopupID',
  full_name='CMsgDOTAPopup.PopupID',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=-1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KICKED_FROM_LOBBY', index=1, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KICKED_FROM_PARTY', index=2, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KICKED_FROM_TEAM', index=3, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_WAS_DISBANDED', index=4, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_MATCHMAKE_ALREADY_MATCH', index=5, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_MATCHMAKE_ALREADY_FINDING', index=6, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_MATCHMAKE_FULL', index=7, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_MATCHMAKE_FAIL_ADD', index=8, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_MATCHMAKE_FAIL_ADD_CURRENT', index=9, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_MATCHMAKE_FAILED_TEAM_MEMBER', index=10, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_MATCHMAKE_ALREADY_GAME', index=11, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEAM_MATCHMAKE_FAIL_GET_PARTY', index=12, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCHMAKING_DISABLED', index=13, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVITE_DENIED', index=14, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARTY_FULL', index=15, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MADE_ADMIN', index=16, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEED_TO_PURCHASE', index=17, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIGNON_MESSAGE', index=18, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GUILD_KICKED', index=19, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCHMAKING_REGION_OFFLINE', index=20, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOURNAMENT_GAME_NOT_FOUND', index=21, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOURNAMENT_GAME_HAS_LOBBY_ID', index=22, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOURNAMENT_GAME_HAS_MATCH_ID', index=23, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOURNAMENT_GAME_HAS_NO_RADIANT_TEAM', index=24, number=24,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOURNAMENT_GAME_HAS_NO_DIRE_TEAM', index=25, number=25,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOURNAMENT_GAME_SQL_UPDATE_FAILED', index=26, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_LEAGUE_ADMIN', index=27, number=27,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IN_ANOTHER_GAME', index=28, number=29,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARTY_MEMBER_IN_ANOTHER_GAME', index=29, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARTY_MEMBER_IN_LOW_PRIORITY', index=30, number=31,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_OUT_OF_DATE', index=31, number=32,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAVE_GAME_CORRUPT', index=32, number=38,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INSUFFICIENT_INGOTS', index=33, number=39,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPETITIVE_MM_NOT_ENOUGH_SKILL_DATA_PLAY_MORE_CASUAL', index=34, number=42,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARTY_LEADER_JOINED_LOBBY', index=35, number=44,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKEND_TOURNEY_UNMATCHED', index=36, number=48,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POST_MATCH_SURVEY', index=37, number=49,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TROPHY_AWARDED', index=38, number=50,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TROPHY_LEVEL_UP', index=39, number=51,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL_HERO_CHALLENGE_PROGRESS', index=40, number=52,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEED_INITIAL_SKILL', index=41, number=53,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEED_INITIAL_SKILL_IN_PARTY', index=42, number=54,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TARGET_ENGINE_MISMATCH', index=43, number=55,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VAC_NOT_VERIFIED', index=44, number=56,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KICKED_FROM_QUEUE_EVENT_STARTING', index=45, number=57,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KICKED_FROM_QUEUE_EVENT_ENDING', index=46, number=58,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOBBY_FULL', index=47, number=62,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_POINTS_EARNED', index=48, number=63,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOM_GAME_INCORRECT_VERSION', index=49, number=64,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIMITED_USER_CHAT', index=50, number=66,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_PREMIUM_POINTS_EARNED', index=51, number=67,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOBBY_MVP_AWARDED', index=52, number=68,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOW_BADGE_LEVEL_CHAT', index=53, number=71,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GENERIC_INFO', index=54, number=69,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GENERIC_ERROR', index=55, number=70,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1428,
  serialized_end=3002,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAPOPUP_POPUPID)

_CMSGDOTAFRIENDRECRUITSRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFriendRecruitsResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=12099,
  serialized_end=12144,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFRIENDRECRUITSRESPONSE_ERESULT)

_CMSGDOTAREDEEMEVENTPRIZERESPONSE_RESULTCODE = _descriptor.EnumDescriptor(
  name='ResultCode',
  full_name='CMsgDOTARedeemEventPrizeResponse.ResultCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Success', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ServerError', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InsufficientPoints', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PointsHeld', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=14277,
  serialized_end=14359,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAREDEEMEVENTPRIZERESPONSE_RESULTCODE)

_CMSGGCNOTIFICATIONSRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgGCNotificationsResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=12099,
  serialized_end=12144,
)
_sym_db.RegisterEnumDescriptor(_CMSGGCNOTIFICATIONSRESPONSE_ERESULT)

_CMSGGCPLAYERINFOSUBMITRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgGCPlayerInfoSubmitResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INFO_LOCKED', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=17167,
  serialized_end=17235,
)
_sym_db.RegisterEnumDescriptor(_CMSGGCPLAYERINFOSUBMITRESPONSE_ERESULT)

_CMSGGCTOCLIENTMYSTERYITEMRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='CMsgGCToClientMysteryItemResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_SDO_LOAD', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_NO_ACTIONS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_NO_LOOTLIST', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_EMPTY_LOOTLIST', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_NO_ITEM_GENERATED', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_SQL_COMMIT', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_EVENT_NOT_OWNED', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_INVALID_ACTION', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_ALREADY_GRANTED', index=9, number=9,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=25817,
  serialized_end=26078,
)
_sym_db.RegisterEnumDescriptor(_CMSGGCTOCLIENTMYSTERYITEMRESPONSE_RESULT)

_CMSGCLIENTTOGCVOTEFORARCANARESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='CMsgClientToGCVoteForArcanaResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCEEDED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VOTING_NOT_ENABLED_FOR_ROUND', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_FAILURE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=27950,
  serialized_end=28028,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCVOTEFORARCANARESPONSE_RESULT)

_CMSGARCANAVOTES_VOTINGSTATE = _descriptor.EnumDescriptor(
  name='VotingState',
  full_name='CMsgArcanaVotes.VotingState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FINISHED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IN_PROGRESS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IN_FUTURE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=28499,
  serialized_end=28558,
)
_sym_db.RegisterEnumDescriptor(_CMSGARCANAVOTES_VOTINGSTATE)

_CMSGGCTOCLIENTREDEEMREWARDRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='CMsgGCToClientRedeemRewardResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_SDO_LOCK', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_SDO_LOAD', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_EVENT_NOT_OWNED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_EVENT_NOT_ACTIVE', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_INVALID_ACTION', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_REQUIREMENTS_NOT_MET', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_ALREADY_GRANTED', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_TIMEOUT', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=31351,
  serialized_end=31587,
)
_sym_db.RegisterEnumDescriptor(_CMSGGCTOCLIENTREDEEMREWARDRESPONSE_RESULT)

_CMSGDOTAREDEEMITEMRESPONSE_ERESULTCODE = _descriptor.EnumDescriptor(
  name='EResultCode',
  full_name='CMsgDOTARedeemItemResponse.EResultCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_Succeeded', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_Failed', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=32377,
  serialized_end=32421,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAREDEEMITEMRESPONSE_ERESULTCODE)

_CMSGPERFECTWORLDUSERLOOKUPRESPONSE_ERESULTCODE = _descriptor.EnumDescriptor(
  name='EResultCode',
  full_name='CMsgPerfectWorldUserLookupResponse.EResultCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS_ACCOUNT_FOUND', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_USER_NAME_WRONG_FORMAT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERFECT_WORLD_ACCOUNT_FOUND', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_LINKED_STEAM_ACCOUNT_FOUND', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=32632,
  serialized_end=32808,
)
_sym_db.RegisterEnumDescriptor(_CMSGPERFECTWORLDUSERLOOKUPRESPONSE_ERESULTCODE)

_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgClientToGCSelectCompendiumInGamePredictionResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_MATCH', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREDICTIONS_ARE_CLOSED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTHER_ERROR', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=33820,
  serialized_end=33906,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE_ERESULT)

_CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='CMsgClientToGCOpenPlayerCardPackResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INTERNAL', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FAILED_TO_FIND_PACK', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ITEM_NOT_CARD_PACK', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FAILED_CARD_CREATE', index=4, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=34129,
  serialized_end=34261,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE_RESULT)

_CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='CMsgClientToGCRecyclePlayerCardResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INTERNAL', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FAILED_TO_FIND_PLAYER_CARD', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ITEM_NOT_PLAYER_CARD', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FAILED_DUST_CARD_CREATE', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_CARD_LOCKED', index=5, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=34467,
  serialized_end=34636,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE_RESULT)

_CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='CMsgClientToGCCreatePlayerCardPackResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INTERNAL', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INSUFFICIENT_DUST', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ITEM_NOT_DUST_ITEM', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FAILED_CARD_PACK_CREATE', index=4, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=34828,
  serialized_end=34963,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE_RESULT)


_CMSGCLIENTSUSPENDED = _descriptor.Descriptor(
  name='CMsgClientSuspended',
  full_name='CMsgClientSuspended',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_end', full_name='CMsgClientSuspended.time_end', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=218,
)


_CMSGREQUESTINTERNATIONALTICKET = _descriptor.Descriptor(
  name='CMsgRequestInternationalTicket',
  full_name='CMsgRequestInternationalTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=252,
)


_CMSGBALANCEDSHUFFLELOBBY = _descriptor.Descriptor(
  name='CMsgBalancedShuffleLobby',
  full_name='CMsgBalancedShuffleLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=280,
)


_CMSGINITIALQUESTIONNAIRERESPONSE = _descriptor.Descriptor(
  name='CMsgInitialQuestionnaireResponse',
  full_name='CMsgInitialQuestionnaireResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='initial_skill', full_name='CMsgInitialQuestionnaireResponse.initial_skill', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=339,
)


_CMSGDOTAPLAYERMATCHHISTORY = _descriptor.Descriptor(
  name='CMsgDOTAPlayerMatchHistory',
  full_name='CMsgDOTAPlayerMatchHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_ids', full_name='CMsgDOTAPlayerMatchHistory.match_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=341,
  serialized_end=388,
)


_CMSGDOTAMATCHHISTORYFILTER = _descriptor.Descriptor(
  name='CMsgDOTAMatchHistoryFilter',
  full_name='CMsgDOTAMatchHistoryFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_ids', full_name='CMsgDOTAMatchHistoryFilter.match_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='newest_match_id_at_last_query', full_name='CMsgDOTAMatchHistoryFilter.newest_match_id_at_last_query', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_last_query', full_name='CMsgDOTAMatchHistoryFilter.time_last_query', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=390,
  serialized_end=501,
)


_CMSGDOTAREQUESTMATCHES = _descriptor.Descriptor(
  name='CMsgDOTARequestMatches',
  full_name='CMsgDOTARequestMatches',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgDOTARequestMatches.hero_id', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CMsgDOTARequestMatches.game_mode', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='date_min', full_name='CMsgDOTARequestMatches.date_min', index=2,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='date_max', full_name='CMsgDOTARequestMatches.date_max', index=3,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matches_requested', full_name='CMsgDOTARequestMatches.matches_requested', index=4,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_at_match_id', full_name='CMsgDOTARequestMatches.start_at_match_id', index=5,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_players', full_name='CMsgDOTARequestMatches.min_players', index=6,
      number=12, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='CMsgDOTARequestMatches.request_id', index=7,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_games_only', full_name='CMsgDOTARequestMatches.tournament_games_only', index=8,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTARequestMatches.account_id', index=9,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgDOTARequestMatches.league_id', index=10,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='skill', full_name='CMsgDOTARequestMatches.skill', index=11,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTARequestMatches.team_id', index=12,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CMsgDOTARequestMatches.custom_game_id', index=13,
      number=20, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAREQUESTMATCHES_SKILLLEVEL,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=921,
)


_CMSGDOTAREQUESTMATCHESRESPONSE_SERIES = _descriptor.Descriptor(
  name='Series',
  full_name='CMsgDOTARequestMatchesResponse.Series',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='CMsgDOTARequestMatchesResponse.Series.matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_id', full_name='CMsgDOTARequestMatchesResponse.Series.series_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_type', full_name='CMsgDOTARequestMatchesResponse.Series.series_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1117,
  serialized_end=1198,
)

_CMSGDOTAREQUESTMATCHESRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTARequestMatchesResponse',
  full_name='CMsgDOTARequestMatchesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='CMsgDOTARequestMatchesResponse.matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series', full_name='CMsgDOTARequestMatchesResponse.series', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='CMsgDOTARequestMatchesResponse.request_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_results', full_name='CMsgDOTARequestMatchesResponse.total_results', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='results_remaining', full_name='CMsgDOTARequestMatchesResponse.results_remaining', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAREQUESTMATCHESRESPONSE_SERIES, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=1198,
)


_CMSGDOTAPOPUP = _descriptor.Descriptor(
  name='CMsgDOTAPopup',
  full_name='CMsgDOTAPopup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgDOTAPopup.id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_text', full_name='CMsgDOTAPopup.custom_text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='int_data', full_name='CMsgDOTAPopup.int_data', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='popup_data', full_name='CMsgDOTAPopup.popup_data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='loc_token_header', full_name='CMsgDOTAPopup.loc_token_header', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='loc_token_msg', full_name='CMsgDOTAPopup.loc_token_msg', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='var_names', full_name='CMsgDOTAPopup.var_names', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='var_values', full_name='CMsgDOTAPopup.var_values', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='debug_text', full_name='CMsgDOTAPopup.debug_text', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAPOPUP_POPUPID,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1201,
  serialized_end=3002,
)


_CMSGDOTAREPORTSREMAININGREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAReportsRemainingRequest',
  full_name='CMsgDOTAReportsRemainingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3004,
  serialized_end=3037,
)


_CMSGDOTAREPORTSREMAININGRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAReportsRemainingResponse',
  full_name='CMsgDOTAReportsRemainingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_positive_reports_remaining', full_name='CMsgDOTAReportsRemainingResponse.num_positive_reports_remaining', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_negative_reports_remaining', full_name='CMsgDOTAReportsRemainingResponse.num_negative_reports_remaining', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_positive_reports_total', full_name='CMsgDOTAReportsRemainingResponse.num_positive_reports_total', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_negative_reports_total', full_name='CMsgDOTAReportsRemainingResponse.num_negative_reports_total', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3040,
  serialized_end=3226,
)


_CMSGDOTASUBMITPLAYERREPORT = _descriptor.Descriptor(
  name='CMsgDOTASubmitPlayerReport',
  full_name='CMsgDOTASubmitPlayerReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_account_id', full_name='CMsgDOTASubmitPlayerReport.target_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='report_flags', full_name='CMsgDOTASubmitPlayerReport.report_flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CMsgDOTASubmitPlayerReport.lobby_id', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comment', full_name='CMsgDOTASubmitPlayerReport.comment', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3228,
  serialized_end=3340,
)


_CMSGDOTASUBMITPLAYERREPORTRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTASubmitPlayerReportResponse',
  full_name='CMsgDOTASubmitPlayerReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_account_id', full_name='CMsgDOTASubmitPlayerReportResponse.target_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='report_flags', full_name='CMsgDOTASubmitPlayerReportResponse.report_flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTASubmitPlayerReportResponse.result', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='debug_message', full_name='CMsgDOTASubmitPlayerReportResponse.debug_message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3342,
  serialized_end=3466,
)


_CMSGDOTAREPORTCOUNTSREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAReportCountsRequest',
  full_name='CMsgDOTAReportCountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_account_id', full_name='CMsgDOTAReportCountsRequest.target_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3468,
  serialized_end=3524,
)


_CMSGDOTAREPORTCOUNTSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAReportCountsResponse',
  full_name='CMsgDOTAReportCountsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_account_id', full_name='CMsgDOTAReportCountsResponse.target_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leadership_count', full_name='CMsgDOTAReportCountsResponse.leadership_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teaching_count', full_name='CMsgDOTAReportCountsResponse.teaching_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='friendly_count', full_name='CMsgDOTAReportCountsResponse.friendly_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='forgiving_count', full_name='CMsgDOTAReportCountsResponse.forgiving_count', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3527,
  serialized_end=3683,
)


_CMSGDOTASUBMITLOBBYMVPVOTE = _descriptor.Descriptor(
  name='CMsgDOTASubmitLobbyMVPVote',
  full_name='CMsgDOTASubmitLobbyMVPVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_account_id', full_name='CMsgDOTASubmitLobbyMVPVote.target_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3685,
  serialized_end=3740,
)


_CMSGDOTASUBMITLOBBYMVPVOTERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTASubmitLobbyMVPVoteResponse',
  full_name='CMsgDOTASubmitLobbyMVPVoteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_account_id', full_name='CMsgDOTASubmitLobbyMVPVoteResponse.target_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgDOTASubmitLobbyMVPVoteResponse.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3742,
  serialized_end=3822,
)


_CMSGDOTALOBBYMVPNOTIFYRECIPIENT = _descriptor.Descriptor(
  name='CMsgDOTALobbyMVPNotifyRecipient',
  full_name='CMsgDOTALobbyMVPNotifyRecipient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voter_account_id', full_name='CMsgDOTALobbyMVPNotifyRecipient.voter_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recipient_account_id', full_name='CMsgDOTALobbyMVPNotifyRecipient.recipient_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_votes', full_name='CMsgDOTALobbyMVPNotifyRecipient.num_votes', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3824,
  serialized_end=3932,
)


_CMSGDOTALOBBYMVPAWARDED = _descriptor.Descriptor(
  name='CMsgDOTALobbyMVPAwarded',
  full_name='CMsgDOTALobbyMVPAwarded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mvp_account_id', full_name='CMsgDOTALobbyMVPAwarded.mvp_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3934,
  serialized_end=3983,
)


_CMSGDOTAKICKEDFROMMATCHMAKINGQUEUE = _descriptor.Descriptor(
  name='CMsgDOTAKickedFromMatchmakingQueue',
  full_name='CMsgDOTAKickedFromMatchmakingQueue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_type', full_name='CMsgDOTAKickedFromMatchmakingQueue.match_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3985,
  serialized_end=4072,
)


_CMSGDOTAREQUESTSAVEGAMES = _descriptor.Descriptor(
  name='CMsgDOTARequestSaveGames',
  full_name='CMsgDOTARequestSaveGames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_region', full_name='CMsgDOTARequestSaveGames.server_region', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4074,
  serialized_end=4123,
)


_CMSGDOTAREQUESTSAVEGAMESRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTARequestSaveGamesResponse',
  full_name='CMsgDOTARequestSaveGamesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgDOTARequestSaveGamesResponse.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='save_games', full_name='CMsgDOTARequestSaveGamesResponse.save_games', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4125,
  serialized_end=4213,
)


_CMSGGCMATCHDETAILSREQUEST = _descriptor.Descriptor(
  name='CMsgGCMatchDetailsRequest',
  full_name='CMsgGCMatchDetailsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgGCMatchDetailsRequest.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4215,
  serialized_end=4260,
)


_CMSGGCMATCHDETAILSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCMatchDetailsResponse',
  full_name='CMsgGCMatchDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCMatchDetailsResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match', full_name='CMsgGCMatchDetailsResponse.match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vote', full_name='CMsgGCMatchDetailsResponse.vote', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4263,
  serialized_end=4391,
)


_CMSGSERVERTOGCMATCHDETAILSREQUEST = _descriptor.Descriptor(
  name='CMsgServerToGCMatchDetailsRequest',
  full_name='CMsgServerToGCMatchDetailsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_ids', full_name='CMsgServerToGCMatchDetailsRequest.match_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4393,
  serialized_end=4447,
)


_CMSGGCTOSERVERMATCHDETAILSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToServerMatchDetailsResponse',
  full_name='CMsgGCToServerMatchDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='CMsgGCToServerMatchDetailsResponse.matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4449,
  serialized_end=4518,
)


_CMSGDOTAPROFILEREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAProfileRequest',
  full_name='CMsgDOTAProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAProfileRequest.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='request_name', full_name='CMsgDOTAProfileRequest.request_name', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='engine', full_name='CMsgDOTAProfileRequest.engine', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4520,
  serialized_end=4633,
)


_CMSGDOTAPROFILERESPONSE_PLAYEDHERO = _descriptor.Descriptor(
  name='PlayedHero',
  full_name='CMsgDOTAProfileResponse.PlayedHero',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgDOTAProfileResponse.PlayedHero.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wins', full_name='CMsgDOTAProfileResponse.PlayedHero.wins', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5215,
  serialized_end=5258,
)

_CMSGDOTAPROFILERESPONSE_SHOWCASEHERO = _descriptor.Descriptor(
  name='ShowcaseHero',
  full_name='CMsgDOTAProfileResponse.ShowcaseHero',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgDOTAProfileResponse.ShowcaseHero.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='object_data', full_name='CMsgDOTAProfileResponse.ShowcaseHero.object_data', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5260,
  serialized_end=5312,
)

_CMSGDOTAPROFILERESPONSE_LEAGUEPASS = _descriptor.Descriptor(
  name='LeaguePass',
  full_name='CMsgDOTAProfileResponse.LeaguePass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgDOTAProfileResponse.LeaguePass.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_def', full_name='CMsgDOTAProfileResponse.LeaguePass.item_def', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5314,
  serialized_end=5363,
)

_CMSGDOTAPROFILERESPONSE_EVENTTICKET = _descriptor.Descriptor(
  name='EventTicket',
  full_name='CMsgDOTAProfileResponse.EventTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgDOTAProfileResponse.EventTicket.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5365,
  serialized_end=5396,
)

_CMSGDOTAPROFILERESPONSE_FEATUREDITEM = _descriptor.Descriptor(
  name='FeaturedItem',
  full_name='CMsgDOTAProfileResponse.FeaturedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgDOTAProfileResponse.FeaturedItem.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='object_data', full_name='CMsgDOTAProfileResponse.FeaturedItem.object_data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot_index', full_name='CMsgDOTAProfileResponse.FeaturedItem.slot_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5398,
  serialized_end=5470,
)

_CMSGDOTAPROFILERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAProfileResponse',
  full_name='CMsgDOTAProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAProfileResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_account_client', full_name='CMsgDOTAProfileResponse.game_account_client', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='latest_matches', full_name='CMsgDOTAProfileResponse.latest_matches', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='heroes', full_name='CMsgDOTAProfileResponse.heroes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_name', full_name='CMsgDOTAProfileResponse.player_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgDOTAProfileResponse.team_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_tag', full_name='CMsgDOTAProfileResponse.team_tag', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_logo', full_name='CMsgDOTAProfileResponse.team_logo', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='showcase_hero', full_name='CMsgDOTAProfileResponse.showcase_hero', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_passes', full_name='CMsgDOTAProfileResponse.league_passes', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_tickets', full_name='CMsgDOTAProfileResponse.event_tickets', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTAProfileResponse.team_id', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='has_passport', full_name='CMsgDOTAProfileResponse.has_passport', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='featured_items', full_name='CMsgDOTAProfileResponse.featured_items', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='abandon_percent', full_name='CMsgDOTAProfileResponse.abandon_percent', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAPROFILERESPONSE_PLAYEDHERO, _CMSGDOTAPROFILERESPONSE_SHOWCASEHERO, _CMSGDOTAPROFILERESPONSE_LEAGUEPASS, _CMSGDOTAPROFILERESPONSE_EVENTTICKET, _CMSGDOTAPROFILERESPONSE_FEATUREDITEM, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4636,
  serialized_end=5470,
)


_CMSGDOTAPROFILETICKETS_LEAGUEPASS = _descriptor.Descriptor(
  name='LeaguePass',
  full_name='CMsgDOTAProfileTickets.LeaguePass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgDOTAProfileTickets.LeaguePass.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_def', full_name='CMsgDOTAProfileTickets.LeaguePass.item_def', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5314,
  serialized_end=5363,
)

_CMSGDOTAPROFILETICKETS_EVENTTICKET = _descriptor.Descriptor(
  name='EventTicket',
  full_name='CMsgDOTAProfileTickets.EventTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgDOTAProfileTickets.EventTicket.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5365,
  serialized_end=5396,
)

_CMSGDOTAPROFILETICKETS = _descriptor.Descriptor(
  name='CMsgDOTAProfileTickets',
  full_name='CMsgDOTAProfileTickets',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAProfileTickets.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAProfileTickets.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_passes', full_name='CMsgDOTAProfileTickets.league_passes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_tickets', full_name='CMsgDOTAProfileTickets.event_tickets', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAPROFILETICKETS_LEAGUEPASS, _CMSGDOTAPROFILETICKETS_EVENTTICKET, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5473,
  serialized_end=5736,
)


_CMSGCLIENTTOGCGETPROFILETICKETS = _descriptor.Descriptor(
  name='CMsgClientToGCGetProfileTickets',
  full_name='CMsgClientToGCGetProfileTickets',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgClientToGCGetProfileTickets.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5738,
  serialized_end=5791,
)


_CMSGGCSTEAMPROFILEREQUEST = _descriptor.Descriptor(
  name='CMsgGCSteamProfileRequest',
  full_name='CMsgGCSteamProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCSteamProfileRequest.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5793,
  serialized_end=5840,
)


_CMSGGCSTEAMPROFILEREQUESTRESPONSE = _descriptor.Descriptor(
  name='CMsgGCSteamProfileRequestResponse',
  full_name='CMsgGCSteamProfileRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCSteamProfileRequestResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5842,
  serialized_end=5893,
)


_CMSGDOTACLEARNOTIFYSUCCESSFULREPORT = _descriptor.Descriptor(
  name='CMsgDOTAClearNotifySuccessfulReport',
  full_name='CMsgDOTAClearNotifySuccessfulReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5895,
  serialized_end=5932,
)


_CMSGDOTAWELCOME_LOCALIZATIONDIGEST = _descriptor.Descriptor(
  name='LocalizationDigest',
  full_name='CMsgDOTAWelcome.LocalizationDigest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='context', full_name='CMsgDOTAWelcome.LocalizationDigest.context', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='english_language_file_sha1', full_name='CMsgDOTAWelcome.LocalizationDigest.english_language_file_sha1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_language_file_sha1', full_name='CMsgDOTAWelcome.LocalizationDigest.client_language_file_sha1', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6685,
  serialized_end=6827,
)

_CMSGDOTAWELCOME_CEXTRAMSG = _descriptor.Descriptor(
  name='CExtraMsg',
  full_name='CMsgDOTAWelcome.CExtraMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgDOTAWelcome.CExtraMsg.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contents', full_name='CMsgDOTAWelcome.CExtraMsg.contents', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6829,
  serialized_end=6870,
)

_CMSGDOTAWELCOME = _descriptor.Descriptor(
  name='CMsgDOTAWelcome',
  full_name='CMsgDOTAWelcome',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='store_item_hash', full_name='CMsgDOTAWelcome.store_item_hash', index=0,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timeplayedconsecutively', full_name='CMsgDOTAWelcome.timeplayedconsecutively', index=1,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='allow_3rd_party_match_history', full_name='CMsgDOTAWelcome.allow_3rd_party_match_history', index=2,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='partner_account_type', full_name='CMsgDOTAWelcome.partner_account_type', index=3,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='banned_word_list_word_id', full_name='CMsgDOTAWelcome.banned_word_list_word_id', index=4,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='partner_account_state', full_name='CMsgDOTAWelcome.partner_account_state', index=5,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_time_played', full_name='CMsgDOTAWelcome.last_time_played', index=6,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_ip_address', full_name='CMsgDOTAWelcome.last_ip_address', index=7,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='shutdownlawterminateminutes', full_name='CMsgDOTAWelcome.shutdownlawterminateminutes', index=8,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='banned_word_list_version', full_name='CMsgDOTAWelcome.banned_word_list_version', index=9,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='profile_private', full_name='CMsgDOTAWelcome.profile_private', index=10,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currency', full_name='CMsgDOTAWelcome.currency', index=11,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bang_no', full_name='CMsgDOTAWelcome.bang_no', index=12,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='should_request_player_origin', full_name='CMsgDOTAWelcome.should_request_player_origin', index=13,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='compendium_unlocks', full_name='CMsgDOTAWelcome.compendium_unlocks', index=14,
      number=21, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gc_socache_file_version', full_name='CMsgDOTAWelcome.gc_socache_file_version', index=15,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='localization_digests', full_name='CMsgDOTAWelcome.localization_digests', index=16,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_perfect_world_test_account', full_name='CMsgDOTAWelcome.is_perfect_world_test_account', index=17,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active_events', full_name='CMsgDOTAWelcome.active_events', index=18,
      number=25, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='extra_messages', full_name='CMsgDOTAWelcome.extra_messages', index=19,
      number=26, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='minimum_recent_item_id', full_name='CMsgDOTAWelcome.minimum_recent_item_id', index=20,
      number=27, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAWELCOME_LOCALIZATIONDIGEST, _CMSGDOTAWELCOME_CEXTRAMSG, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5935,
  serialized_end=6870,
)


_CSODOTAGAMEHEROFAVORITES = _descriptor.Descriptor(
  name='CSODOTAGameHeroFavorites',
  full_name='CSODOTAGameHeroFavorites',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSODOTAGameHeroFavorites.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CSODOTAGameHeroFavorites.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6872,
  serialized_end=6947,
)


_CMSGDOTAHEROFAVORITESADD = _descriptor.Descriptor(
  name='CMsgDOTAHeroFavoritesAdd',
  full_name='CMsgDOTAHeroFavoritesAdd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgDOTAHeroFavoritesAdd.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6949,
  serialized_end=6992,
)


_CMSGDOTAHEROFAVORITESREMOVE = _descriptor.Descriptor(
  name='CMsgDOTAHeroFavoritesRemove',
  full_name='CMsgDOTAHeroFavoritesRemove',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgDOTAHeroFavoritesRemove.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6994,
  serialized_end=7040,
)


_CMSGSETSHOWCASEHERO = _descriptor.Descriptor(
  name='CMsgSetShowcaseHero',
  full_name='CMsgSetShowcaseHero',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='showcase_hero_id', full_name='CMsgSetShowcaseHero.showcase_hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7042,
  serialized_end=7089,
)


_CMSGSETFEATUREDITEMS = _descriptor.Descriptor(
  name='CMsgSetFeaturedItems',
  full_name='CMsgSetFeaturedItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='featured_item_id', full_name='CMsgSetFeaturedItems.featured_item_id', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7091,
  serialized_end=7139,
)


_CMSGDOTAFEATUREDITEMS = _descriptor.Descriptor(
  name='CMsgDOTAFeaturedItems',
  full_name='CMsgDOTAFeaturedItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAFeaturedItems.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='featured_item_id', full_name='CMsgDOTAFeaturedItems.featured_item_id', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='object_data', full_name='CMsgDOTAFeaturedItems.object_data', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7141,
  serialized_end=7231,
)


_CMSGREQUESTLEAGUEINFO = _descriptor.Descriptor(
  name='CMsgRequestLeagueInfo',
  full_name='CMsgRequestLeagueInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7233,
  serialized_end=7256,
)


_CDYNAMICLEAGUEDATA = _descriptor.Descriptor(
  name='CDynamicLeagueData',
  full_name='CDynamicLeagueData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CDynamicLeagueData.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_match_time', full_name='CDynamicLeagueData.last_match_time', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prize_pool_usd', full_name='CDynamicLeagueData.prize_pool_usd', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='has_live_matches', full_name='CDynamicLeagueData.has_live_matches', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_compendium_public', full_name='CDynamicLeagueData.is_compendium_public', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='compendium_version', full_name='CDynamicLeagueData.compendium_version', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='compendium_content_version', full_name='CDynamicLeagueData.compendium_content_version', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7259,
  serialized_end=7467,
)


_CSTATICLEAGUEDATA = _descriptor.Descriptor(
  name='CStaticLeagueData',
  full_name='CStaticLeagueData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CStaticLeagueData.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CStaticLeagueData.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='CStaticLeagueData.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='banner_name', full_name='CStaticLeagueData.banner_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemdef_name', full_name='CStaticLeagueData.itemdef_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='url', full_name='CStaticLeagueData.url', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_def_index', full_name='CStaticLeagueData.item_def_index', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hud_skin_item_def_index', full_name='CStaticLeagueData.hud_skin_item_def_index', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='loading_screen_name', full_name='CStaticLeagueData.loading_screen_name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_prize_pool', full_name='CStaticLeagueData.base_prize_pool', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_major', full_name='CStaticLeagueData.is_major', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sort_order', full_name='CStaticLeagueData.sort_order', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tier', full_name='CStaticLeagueData.tier', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amateur_region', full_name='CStaticLeagueData.amateur_region', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='organizer', full_name='CStaticLeagueData.organizer', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='CStaticLeagueData.start_date', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='CStaticLeagueData.end_date', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='location', full_name='CStaticLeagueData.location', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inventory_image', full_name='CStaticLeagueData.inventory_image', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='square_image', full_name='CStaticLeagueData.square_image', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='battle_pass_rollup', full_name='CStaticLeagueData.battle_pass_rollup', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7470,
  serialized_end=7936,
)


_CLEAGUEDATA = _descriptor.Descriptor(
  name='CLeagueData',
  full_name='CLeagueData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dynamic_data', full_name='CLeagueData.dynamic_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='static_data', full_name='CLeagueData.static_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_owned', full_name='CLeagueData.is_owned', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7938,
  serialized_end=8053,
)


_CMSGRESPONSELEAGUEINFO = _descriptor.Descriptor(
  name='CMsgResponseLeagueInfo',
  full_name='CMsgResponseLeagueInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='leagues', full_name='CMsgResponseLeagueInfo.leagues', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8055,
  serialized_end=8117,
)


_CMSGDOTAMATCHVOTES_PLAYERVOTE = _descriptor.Descriptor(
  name='PlayerVote',
  full_name='CMsgDOTAMatchVotes.PlayerVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAMatchVotes.PlayerVote.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vote', full_name='CMsgDOTAMatchVotes.PlayerVote.vote', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8207,
  serialized_end=8253,
)

_CMSGDOTAMATCHVOTES = _descriptor.Descriptor(
  name='CMsgDOTAMatchVotes',
  full_name='CMsgDOTAMatchVotes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgDOTAMatchVotes.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='votes', full_name='CMsgDOTAMatchVotes.votes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAMATCHVOTES_PLAYERVOTE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8120,
  serialized_end=8253,
)


_CMSGCASTMATCHVOTE = _descriptor.Descriptor(
  name='CMsgCastMatchVote',
  full_name='CMsgCastMatchVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgCastMatchVote.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vote', full_name='CMsgCastMatchVote.vote', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8255,
  serialized_end=8345,
)


_CMSGRETRIEVEMATCHVOTE = _descriptor.Descriptor(
  name='CMsgRetrieveMatchVote',
  full_name='CMsgRetrieveMatchVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgRetrieveMatchVote.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='incremental', full_name='CMsgRetrieveMatchVote.incremental', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8347,
  serialized_end=8409,
)


_CMSGMATCHVOTERESPONSE = _descriptor.Descriptor(
  name='CMsgMatchVoteResponse',
  full_name='CMsgMatchVoteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgMatchVoteResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vote', full_name='CMsgMatchVoteResponse.vote', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='positive_votes', full_name='CMsgMatchVoteResponse.positive_votes', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='negative_votes', full_name='CMsgMatchVoteResponse.negative_votes', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8412,
  serialized_end=8556,
)


_CMSGDOTAHALLOFFAME_FEATUREDPLAYER = _descriptor.Descriptor(
  name='FeaturedPlayer',
  full_name='CMsgDOTAHallOfFame.FeaturedPlayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAHallOfFame.FeaturedPlayer.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgDOTAHallOfFame.FeaturedPlayer.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='average_scaled_metric', full_name='CMsgDOTAHallOfFame.FeaturedPlayer.average_scaled_metric', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_games', full_name='CMsgDOTAHallOfFame.FeaturedPlayer.num_games', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8718,
  serialized_end=8821,
)

_CMSGDOTAHALLOFFAME_FEATUREDFARMER = _descriptor.Descriptor(
  name='FeaturedFarmer',
  full_name='CMsgDOTAHallOfFame.FeaturedFarmer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAHallOfFame.FeaturedFarmer.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgDOTAHallOfFame.FeaturedFarmer.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gold_per_min', full_name='CMsgDOTAHallOfFame.FeaturedFarmer.gold_per_min', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgDOTAHallOfFame.FeaturedFarmer.match_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8823,
  serialized_end=8916,
)

_CMSGDOTAHALLOFFAME = _descriptor.Descriptor(
  name='CMsgDOTAHallOfFame',
  full_name='CMsgDOTAHallOfFame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='week', full_name='CMsgDOTAHallOfFame.week', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='featured_players', full_name='CMsgDOTAHallOfFame.featured_players', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='featured_farmer', full_name='CMsgDOTAHallOfFame.featured_farmer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAHALLOFFAME_FEATUREDPLAYER, _CMSGDOTAHALLOFFAME_FEATUREDFARMER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8559,
  serialized_end=8916,
)


_CMSGDOTAHALLOFFAMEREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAHallOfFameRequest',
  full_name='CMsgDOTAHallOfFameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='week', full_name='CMsgDOTAHallOfFameRequest.week', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8918,
  serialized_end=8959,
)


_CMSGDOTAHALLOFFAMERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAHallOfFameResponse',
  full_name='CMsgDOTAHallOfFameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hall_of_fame', full_name='CMsgDOTAHallOfFameResponse.hall_of_fame', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgDOTAHallOfFameResponse.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8961,
  serialized_end=9052,
)


_CMSGDOTAHALLOWEENHIGHSCOREREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAHalloweenHighScoreRequest',
  full_name='CMsgDOTAHalloweenHighScoreRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='round', full_name='CMsgDOTAHalloweenHighScoreRequest.round', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9054,
  serialized_end=9108,
)


_CMSGDOTAHALLOWEENHIGHSCORERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAHalloweenHighScoreResponse',
  full_name='CMsgDOTAHalloweenHighScoreResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgDOTAHalloweenHighScoreResponse.score', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match', full_name='CMsgDOTAHalloweenHighScoreResponse.match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgDOTAHalloweenHighScoreResponse.eresult', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='round', full_name='CMsgDOTAHalloweenHighScoreResponse.round', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9110,
  serialized_end=9224,
)


_CMSGDOTASTOREPROMOPAGESREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAStorePromoPagesRequest',
  full_name='CMsgDOTAStorePromoPagesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_seen', full_name='CMsgDOTAStorePromoPagesRequest.version_seen', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9226,
  serialized_end=9280,
)


_CMSGDOTASTOREPROMOPAGESRESPONSE_PROMOPAGE = _descriptor.Descriptor(
  name='PromoPage',
  full_name='CMsgDOTAStorePromoPagesResponse.PromoPage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='promo_id', full_name='CMsgDOTAStorePromoPagesResponse.PromoPage.promo_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='title', full_name='CMsgDOTAStorePromoPagesResponse.PromoPage.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='url', full_name='CMsgDOTAStorePromoPagesResponse.PromoPage.url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9377,
  serialized_end=9434,
)

_CMSGDOTASTOREPROMOPAGESRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAStorePromoPagesResponse',
  full_name='CMsgDOTAStorePromoPagesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pages', full_name='CMsgDOTAStorePromoPagesResponse.pages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTASTOREPROMOPAGESRESPONSE_PROMOPAGE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9283,
  serialized_end=9434,
)


_CMSGLEAGUESCHEDULEBLOCKTEAMINFO = _descriptor.Descriptor(
  name='CMsgLeagueScheduleBlockTeamInfo',
  full_name='CMsgLeagueScheduleBlockTeamInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgLeagueScheduleBlockTeamInfo.team_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgLeagueScheduleBlockTeamInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logo', full_name='CMsgLeagueScheduleBlockTeamInfo.logo', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9436,
  serialized_end=9514,
)


_CMSGLEAGUESCHEDULEBLOCK = _descriptor.Descriptor(
  name='CMsgLeagueScheduleBlock',
  full_name='CMsgLeagueScheduleBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_id', full_name='CMsgLeagueScheduleBlock.block_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='CMsgLeagueScheduleBlock.start_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='finals', full_name='CMsgLeagueScheduleBlock.finals', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comment', full_name='CMsgLeagueScheduleBlock.comment', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teams', full_name='CMsgLeagueScheduleBlock.teams', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9517,
  serialized_end=9662,
)


_CMSGDOTALEAGUE = _descriptor.Descriptor(
  name='CMsgDOTALeague',
  full_name='CMsgDOTALeague',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgDOTALeague.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='schedule', full_name='CMsgDOTALeague.schedule', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9664,
  serialized_end=9743,
)


_CMSGDOTALEAGUESCHEDULEREQUEST = _descriptor.Descriptor(
  name='CMsgDOTALeagueScheduleRequest',
  full_name='CMsgDOTALeagueScheduleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgDOTALeagueScheduleRequest.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9745,
  serialized_end=9795,
)


_CMSGDOTALEAGUESCHEDULERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTALeagueScheduleResponse',
  full_name='CMsgDOTALeagueScheduleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league', full_name='CMsgDOTALeagueScheduleResponse.league', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgDOTALeagueScheduleResponse.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9797,
  serialized_end=9882,
)


_CMSGDOTALEAGUESCHEDULEEDIT = _descriptor.Descriptor(
  name='CMsgDOTALeagueScheduleEdit',
  full_name='CMsgDOTALeagueScheduleEdit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgDOTALeagueScheduleEdit.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='schedule', full_name='CMsgDOTALeagueScheduleEdit.schedule', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delete_block', full_name='CMsgDOTALeagueScheduleEdit.delete_block', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9884,
  serialized_end=9997,
)


_CMSGDOTALEAGUESCHEDULEEDITRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTALeagueScheduleEditResponse',
  full_name='CMsgDOTALeagueScheduleEditResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league', full_name='CMsgDOTALeagueScheduleEditResponse.league', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgDOTALeagueScheduleEditResponse.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9999,
  serialized_end=10088,
)


_CMSGDOTALEAGUESINMONTHREQUEST = _descriptor.Descriptor(
  name='CMsgDOTALeaguesInMonthRequest',
  full_name='CMsgDOTALeaguesInMonthRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='month', full_name='CMsgDOTALeaguesInMonthRequest.month', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='year', full_name='CMsgDOTALeaguesInMonthRequest.year', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tier', full_name='CMsgDOTALeaguesInMonthRequest.tier', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10090,
  serialized_end=10164,
)


_CMSGDOTALEAGUESINMONTHRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTALeaguesInMonthResponse',
  full_name='CMsgDOTALeaguesInMonthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgDOTALeaguesInMonthResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='month', full_name='CMsgDOTALeaguesInMonthResponse.month', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='year', full_name='CMsgDOTALeaguesInMonthResponse.year', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leagues', full_name='CMsgDOTALeaguesInMonthResponse.leagues', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10166,
  serialized_end=10281,
)


_CMSGMATCHMAKINGMATCHGROUPINFO = _descriptor.Descriptor(
  name='CMsgMatchmakingMatchGroupInfo',
  full_name='CMsgMatchmakingMatchGroupInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='players_searching', full_name='CMsgMatchmakingMatchGroupInfo.players_searching', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='auto_region_select_ping_penalty', full_name='CMsgMatchmakingMatchGroupInfo.auto_region_select_ping_penalty', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='CMsgMatchmakingMatchGroupInfo.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10284,
  serialized_end=10455,
)


_CMSGDOTAMATCHMAKINGSTATSREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAMatchmakingStatsRequest',
  full_name='CMsgDOTAMatchmakingStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10457,
  serialized_end=10490,
)


_CMSGDOTAMATCHMAKINGSTATSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAMatchmakingStatsResponse',
  full_name='CMsgDOTAMatchmakingStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matchgroups_version', full_name='CMsgDOTAMatchmakingStatsResponse.matchgroups_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='legacy_searching_players_by_group_source2', full_name='CMsgDOTAMatchmakingStatsResponse.legacy_searching_players_by_group_source2', index=1,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_groups', full_name='CMsgDOTAMatchmakingStatsResponse.match_groups', index=2,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10493,
  serialized_end=10661,
)


_CMSGDOTAUPDATEMATCHMAKINGSTATS = _descriptor.Descriptor(
  name='CMsgDOTAUpdateMatchmakingStats',
  full_name='CMsgDOTAUpdateMatchmakingStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats', full_name='CMsgDOTAUpdateMatchmakingStats.stats', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10663,
  serialized_end=10745,
)


_CMSGDOTAUPDATEMATCHMANAGEMENTSTATS = _descriptor.Descriptor(
  name='CMsgDOTAUpdateMatchManagementStats',
  full_name='CMsgDOTAUpdateMatchManagementStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats', full_name='CMsgDOTAUpdateMatchManagementStats.stats', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10747,
  serialized_end=10833,
)


_CMSGDOTASETMATCHHISTORYACCESS = _descriptor.Descriptor(
  name='CMsgDOTASetMatchHistoryAccess',
  full_name='CMsgDOTASetMatchHistoryAccess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='allow_3rd_party_match_history', full_name='CMsgDOTASetMatchHistoryAccess.allow_3rd_party_match_history', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10835,
  serialized_end=10905,
)


_CMSGDOTASETMATCHHISTORYACCESSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTASetMatchHistoryAccessResponse',
  full_name='CMsgDOTASetMatchHistoryAccessResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgDOTASetMatchHistoryAccessResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10907,
  serialized_end=10966,
)


_CMSGDOTANOTIFYACCOUNTFLAGSCHANGE = _descriptor.Descriptor(
  name='CMsgDOTANotifyAccountFlagsChange',
  full_name='CMsgDOTANotifyAccountFlagsChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgDOTANotifyAccountFlagsChange.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_flags', full_name='CMsgDOTANotifyAccountFlagsChange.account_flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10968,
  serialized_end=11044,
)


_CMSGDOTASETPROFILEPRIVACY = _descriptor.Descriptor(
  name='CMsgDOTASetProfilePrivacy',
  full_name='CMsgDOTASetProfilePrivacy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile_private', full_name='CMsgDOTASetProfilePrivacy.profile_private', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11046,
  serialized_end=11098,
)


_CMSGDOTASETPROFILEPRIVACYRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTASetProfilePrivacyResponse',
  full_name='CMsgDOTASetProfilePrivacyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgDOTASetProfilePrivacyResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11100,
  serialized_end=11152,
)


_CMSGUPGRADELEAGUEITEM = _descriptor.Descriptor(
  name='CMsgUpgradeLeagueItem',
  full_name='CMsgUpgradeLeagueItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgUpgradeLeagueItem.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgUpgradeLeagueItem.league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11154,
  serialized_end=11214,
)


_CMSGUPGRADELEAGUEITEMRESPONSE = _descriptor.Descriptor(
  name='CMsgUpgradeLeagueItemResponse',
  full_name='CMsgUpgradeLeagueItemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11216,
  serialized_end=11247,
)


_CMSGGCWATCHDOWNLOADEDREPLAY = _descriptor.Descriptor(
  name='CMsgGCWatchDownloadedReplay',
  full_name='CMsgGCWatchDownloadedReplay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgGCWatchDownloadedReplay.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='watch_type', full_name='CMsgGCWatchDownloadedReplay.watch_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11249,
  serialized_end=11365,
)


_CMSGSETMAPLOCATIONSTATE = _descriptor.Descriptor(
  name='CMsgSetMapLocationState',
  full_name='CMsgSetMapLocationState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='location_id', full_name='CMsgSetMapLocationState.location_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='completed', full_name='CMsgSetMapLocationState.completed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11367,
  serialized_end=11432,
)


_CMSGSETMAPLOCATIONSTATERESPONSE = _descriptor.Descriptor(
  name='CMsgSetMapLocationStateResponse',
  full_name='CMsgSetMapLocationStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgSetMapLocationStateResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11434,
  serialized_end=11487,
)


_CMSGRESETMAPLOCATIONS = _descriptor.Descriptor(
  name='CMsgResetMapLocations',
  full_name='CMsgResetMapLocations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11489,
  serialized_end=11512,
)


_CMSGRESETMAPLOCATIONSRESPONSE = _descriptor.Descriptor(
  name='CMsgResetMapLocationsResponse',
  full_name='CMsgResetMapLocationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgResetMapLocationsResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11514,
  serialized_end=11565,
)


_CMSGREFRESHPARTNERACCOUNTLINK = _descriptor.Descriptor(
  name='CMsgRefreshPartnerAccountLink',
  full_name='CMsgRefreshPartnerAccountLink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partner_type', full_name='CMsgRefreshPartnerAccountLink.partner_type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11567,
  serialized_end=11620,
)


_CMSGCLIENTSREJOINCHATCHANNELS = _descriptor.Descriptor(
  name='CMsgClientsRejoinChatChannels',
  full_name='CMsgClientsRejoinChatChannels',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11622,
  serialized_end=11653,
)


_CMSGDOTASENDFRIENDRECRUITS = _descriptor.Descriptor(
  name='CMsgDOTASendFriendRecruits',
  full_name='CMsgDOTASendFriendRecruits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recruits', full_name='CMsgDOTASendFriendRecruits.recruits', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11655,
  serialized_end=11701,
)


_CMSGDOTAFRIENDRECRUITSREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFriendRecruitsRequest',
  full_name='CMsgDOTAFriendRecruitsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='CMsgDOTAFriendRecruitsRequest.account_ids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11703,
  serialized_end=11755,
)


_CMSGDOTAFRIENDRECRUITSRESPONSE_FRIENDRECRUITSTATUS = _descriptor.Descriptor(
  name='FriendRecruitStatus',
  full_name='CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus.status', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='levels_earned', full_name='CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus.levels_earned', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bonus', full_name='CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus.bonus', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12002,
  serialized_end=12097,
)

_CMSGDOTAFRIENDRECRUITSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFriendRecruitsResponse',
  full_name='CMsgDOTAFriendRecruitsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFriendRecruitsResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recruits', full_name='CMsgDOTAFriendRecruitsResponse.recruits', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recruiters', full_name='CMsgDOTAFriendRecruitsResponse.recruiters', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAFRIENDRECRUITSRESPONSE_FRIENDRECRUITSTATUS, ],
  enum_types=[
    _CMSGDOTAFRIENDRECRUITSRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11758,
  serialized_end=12144,
)


_CMSGDOTAFRIENDRECRUITINVITEACCEPTDECLINE = _descriptor.Descriptor(
  name='CMsgDOTAFriendRecruitInviteAcceptDecline',
  full_name='CMsgDOTAFriendRecruitInviteAcceptDecline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accepted', full_name='CMsgDOTAFriendRecruitInviteAcceptDecline.accepted', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAFriendRecruitInviteAcceptDecline.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12146,
  serialized_end=12226,
)


_CMSGREQUESTLEAGUEPRIZEPOOL = _descriptor.Descriptor(
  name='CMsgRequestLeaguePrizePool',
  full_name='CMsgRequestLeaguePrizePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgRequestLeaguePrizePool.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12228,
  serialized_end=12275,
)


_CMSGREQUESTLEAGUEPRIZEPOOLRESPONSE = _descriptor.Descriptor(
  name='CMsgRequestLeaguePrizePoolResponse',
  full_name='CMsgRequestLeaguePrizePoolResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgRequestLeaguePrizePoolResponse.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prize_pool', full_name='CMsgRequestLeaguePrizePoolResponse.prize_pool', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12277,
  serialized_end=12352,
)


_CMSGGCGETHEROSTANDINGS = _descriptor.Descriptor(
  name='CMsgGCGetHeroStandings',
  full_name='CMsgGCGetHeroStandings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12354,
  serialized_end=12378,
)


_CMSGGCGETHEROSTANDINGSRESPONSE_HERO = _descriptor.Descriptor(
  name='Hero',
  full_name='CMsgGCGetHeroStandingsResponse.Hero',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgGCGetHeroStandingsResponse.Hero.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wins', full_name='CMsgGCGetHeroStandingsResponse.Hero.wins', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='losses', full_name='CMsgGCGetHeroStandingsResponse.Hero.losses', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='win_streak', full_name='CMsgGCGetHeroStandingsResponse.Hero.win_streak', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='best_win_streak', full_name='CMsgGCGetHeroStandingsResponse.Hero.best_win_streak', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avg_kills', full_name='CMsgGCGetHeroStandingsResponse.Hero.avg_kills', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avg_deaths', full_name='CMsgGCGetHeroStandingsResponse.Hero.avg_deaths', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avg_assists', full_name='CMsgGCGetHeroStandingsResponse.Hero.avg_assists', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avg_gpm', full_name='CMsgGCGetHeroStandingsResponse.Hero.avg_gpm', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avg_xpm', full_name='CMsgGCGetHeroStandingsResponse.Hero.avg_xpm', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='best_kills', full_name='CMsgGCGetHeroStandingsResponse.Hero.best_kills', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='best_assists', full_name='CMsgGCGetHeroStandingsResponse.Hero.best_assists', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='best_gpm', full_name='CMsgGCGetHeroStandingsResponse.Hero.best_gpm', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='best_xpm', full_name='CMsgGCGetHeroStandingsResponse.Hero.best_xpm', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='performance', full_name='CMsgGCGetHeroStandingsResponse.Hero.performance', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12473,
  serialized_end=12764,
)

_CMSGGCGETHEROSTANDINGSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCGetHeroStandingsResponse',
  full_name='CMsgGCGetHeroStandingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='standings', full_name='CMsgGCGetHeroStandingsResponse.standings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCGETHEROSTANDINGSRESPONSE_HERO, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12381,
  serialized_end=12764,
)


_CMSGGCITEMEDITORRESERVATIONSREQUEST = _descriptor.Descriptor(
  name='CMsgGCItemEditorReservationsRequest',
  full_name='CMsgGCItemEditorReservationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12766,
  serialized_end=12803,
)


_CMSGGCITEMEDITORRESERVATION = _descriptor.Descriptor(
  name='CMsgGCItemEditorReservation',
  full_name='CMsgGCItemEditorReservation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CMsgGCItemEditorReservation.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgGCItemEditorReservation.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12805,
  serialized_end=12867,
)


_CMSGGCITEMEDITORRESERVATIONSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCItemEditorReservationsResponse',
  full_name='CMsgGCItemEditorReservationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reservations', full_name='CMsgGCItemEditorReservationsResponse.reservations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12869,
  serialized_end=12959,
)


_CMSGGCITEMEDITORRESERVEITEMDEF = _descriptor.Descriptor(
  name='CMsgGCItemEditorReserveItemDef',
  full_name='CMsgGCItemEditorReserveItemDef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CMsgGCItemEditorReserveItemDef.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='CMsgGCItemEditorReserveItemDef.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12961,
  serialized_end=13030,
)


_CMSGGCITEMEDITORRESERVEITEMDEFRESPONSE = _descriptor.Descriptor(
  name='CMsgGCItemEditorReserveItemDefResponse',
  full_name='CMsgGCItemEditorReserveItemDefResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CMsgGCItemEditorReserveItemDefResponse.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='CMsgGCItemEditorReserveItemDefResponse.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCItemEditorReserveItemDefResponse.result', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13032,
  serialized_end=13125,
)


_CMSGGCITEMEDITORRELEASERESERVATION = _descriptor.Descriptor(
  name='CMsgGCItemEditorReleaseReservation',
  full_name='CMsgGCItemEditorReleaseReservation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CMsgGCItemEditorReleaseReservation.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='CMsgGCItemEditorReleaseReservation.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13127,
  serialized_end=13200,
)


_CMSGGCITEMEDITORRELEASERESERVATIONRESPONSE = _descriptor.Descriptor(
  name='CMsgGCItemEditorReleaseReservationResponse',
  full_name='CMsgGCItemEditorReleaseReservationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CMsgGCItemEditorReleaseReservationResponse.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='released', full_name='CMsgGCItemEditorReleaseReservationResponse.released', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13202,
  serialized_end=13283,
)


_CMSGGCITEMEDITORREQUESTLEAGUEINFO = _descriptor.Descriptor(
  name='CMsgGCItemEditorRequestLeagueInfo',
  full_name='CMsgGCItemEditorRequestLeagueInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgGCItemEditorRequestLeagueInfo.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13285,
  serialized_end=13339,
)


_CMSGGCITEMEDITORLEAGUEINFORESPONSE = _descriptor.Descriptor(
  name='CMsgGCItemEditorLeagueInfoResponse',
  full_name='CMsgGCItemEditorLeagueInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgGCItemEditorLeagueInfoResponse.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_name', full_name='CMsgGCItemEditorLeagueInfoResponse.league_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_desc', full_name='CMsgGCItemEditorLeagueInfoResponse.league_desc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_url', full_name='CMsgGCItemEditorLeagueInfoResponse.league_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='revenue_url', full_name='CMsgGCItemEditorLeagueInfoResponse.revenue_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tier', full_name='CMsgGCItemEditorLeagueInfoResponse.tier', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='location', full_name='CMsgGCItemEditorLeagueInfoResponse.location', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCItemEditorLeagueInfoResponse.result', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13342,
  serialized_end=13528,
)


_CMSGDOTAREWARDTUTORIALPRIZES = _descriptor.Descriptor(
  name='CMsgDOTARewardTutorialPrizes',
  full_name='CMsgDOTARewardTutorialPrizes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='location_id', full_name='CMsgDOTARewardTutorialPrizes.location_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tracking_only', full_name='CMsgDOTARewardTutorialPrizes.tracking_only', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13530,
  serialized_end=13604,
)


_CMSGDOTALASTHITCHALLENGEHIGHSCOREPOST = _descriptor.Descriptor(
  name='CMsgDOTALastHitChallengeHighScorePost',
  full_name='CMsgDOTALastHitChallengeHighScorePost',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgDOTALastHitChallengeHighScorePost.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='high_score', full_name='CMsgDOTALastHitChallengeHighScorePost.high_score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13606,
  serialized_end=13682,
)


_CMSGDOTALASTHITCHALLENGEHIGHSCOREREQUEST = _descriptor.Descriptor(
  name='CMsgDOTALastHitChallengeHighScoreRequest',
  full_name='CMsgDOTALastHitChallengeHighScoreRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgDOTALastHitChallengeHighScoreRequest.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13684,
  serialized_end=13743,
)


_CMSGDOTALASTHITCHALLENGEHIGHSCORERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTALastHitChallengeHighScoreResponse',
  full_name='CMsgDOTALastHitChallengeHighScoreResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgDOTALastHitChallengeHighScoreResponse.score', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgDOTALastHitChallengeHighScoreResponse.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13745,
  serialized_end=13820,
)


_CMSGFLIPLOBBYTEAMS = _descriptor.Descriptor(
  name='CMsgFlipLobbyTeams',
  full_name='CMsgFlipLobbyTeams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13822,
  serialized_end=13842,
)


_CMSGPRESENTEDCLIENTTERMINATEDLG = _descriptor.Descriptor(
  name='CMsgPresentedClientTerminateDlg',
  full_name='CMsgPresentedClientTerminateDlg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13844,
  serialized_end=13877,
)


_CMSGGCLOBBYUPDATEBROADCASTCHANNELINFO = _descriptor.Descriptor(
  name='CMsgGCLobbyUpdateBroadcastChannelInfo',
  full_name='CMsgGCLobbyUpdateBroadcastChannelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='CMsgGCLobbyUpdateBroadcastChannelInfo.channel_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CMsgGCLobbyUpdateBroadcastChannelInfo.country_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='CMsgGCLobbyUpdateBroadcastChannelInfo.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language_code', full_name='CMsgGCLobbyUpdateBroadcastChannelInfo.language_code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13879,
  serialized_end=14004,
)


_CMSGDOTAREDEEMEVENTPRIZE = _descriptor.Descriptor(
  name='CMsgDOTARedeemEventPrize',
  full_name='CMsgDOTARedeemEventPrize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prize_id', full_name='CMsgDOTARedeemEventPrize.prize_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgDOTARedeemEventPrize.event_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='CMsgDOTARedeemEventPrize.quantity', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14006,
  serialized_end=14089,
)


_CMSGDOTAREDEEMEVENTPRIZERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTARedeemEventPrizeResponse',
  full_name='CMsgDOTARedeemEventPrizeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTARedeemEventPrizeResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remaining_points', full_name='CMsgDOTARedeemEventPrizeResponse.remaining_points', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remaining_premium_points', full_name='CMsgDOTARedeemEventPrizeResponse.remaining_premium_points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgDOTARedeemEventPrizeResponse.event_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAREDEEMEVENTPRIZERESPONSE_RESULTCODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14092,
  serialized_end=14359,
)


_CMSGDOTAGETEVENTPOINTS = _descriptor.Descriptor(
  name='CMsgDOTAGetEventPoints',
  full_name='CMsgDOTAGetEventPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgDOTAGetEventPoints.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAGetEventPoints.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14361,
  serialized_end=14423,
)


_CMSGDOTAGETEVENTPOINTSRESPONSE_ACTION = _descriptor.Descriptor(
  name='Action',
  full_name='CMsgDOTAGetEventPointsResponse.Action',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='action_id', full_name='CMsgDOTAGetEventPointsResponse.Action.action_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='times_completed', full_name='CMsgDOTAGetEventPointsResponse.Action.times_completed', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14726,
  serialized_end=14781,
)

_CMSGDOTAGETEVENTPOINTSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGetEventPointsResponse',
  full_name='CMsgDOTAGetEventPointsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_points', full_name='CMsgDOTAGetEventPointsResponse.total_points', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_premium_points', full_name='CMsgDOTAGetEventPointsResponse.total_premium_points', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgDOTAGetEventPointsResponse.event_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='points', full_name='CMsgDOTAGetEventPointsResponse.points', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='premium_points', full_name='CMsgDOTAGetEventPointsResponse.premium_points', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='completed_actions', full_name='CMsgDOTAGetEventPointsResponse.completed_actions', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAGetEventPointsResponse.account_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owned', full_name='CMsgDOTAGetEventPointsResponse.owned', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audit_action', full_name='CMsgDOTAGetEventPointsResponse.audit_action', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wager_tokens_remaining', full_name='CMsgDOTAGetEventPointsResponse.wager_tokens_remaining', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAGETEVENTPOINTSRESPONSE_ACTION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14426,
  serialized_end=14781,
)


_CMSGDOTALIVELEAGUEGAMEUPDATE = _descriptor.Descriptor(
  name='CMsgDOTALiveLeagueGameUpdate',
  full_name='CMsgDOTALiveLeagueGameUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='live_league_games', full_name='CMsgDOTALiveLeagueGameUpdate.live_league_games', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14783,
  serialized_end=14840,
)


_CMSGDOTACOMPENDIUMSELECTION = _descriptor.Descriptor(
  name='CMsgDOTACompendiumSelection',
  full_name='CMsgDOTACompendiumSelection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selection_index', full_name='CMsgDOTACompendiumSelection.selection_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='selection', full_name='CMsgDOTACompendiumSelection.selection', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leagueid', full_name='CMsgDOTACompendiumSelection.leagueid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14842,
  serialized_end=14933,
)


_CMSGDOTACOMPENDIUMSELECTIONRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTACompendiumSelectionResponse',
  full_name='CMsgDOTACompendiumSelectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgDOTACompendiumSelectionResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='extra_selections', full_name='CMsgDOTACompendiumSelectionResponse.extra_selections', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14935,
  serialized_end=15048,
)


_CMSGDOTACOMPENDIUMDATA = _descriptor.Descriptor(
  name='CMsgDOTACompendiumData',
  full_name='CMsgDOTACompendiumData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selections', full_name='CMsgDOTACompendiumData.selections', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15050,
  serialized_end=15124,
)


_CMSGDOTACOMPENDIUMDATAREQUEST = _descriptor.Descriptor(
  name='CMsgDOTACompendiumDataRequest',
  full_name='CMsgDOTACompendiumDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTACompendiumDataRequest.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leagueid', full_name='CMsgDOTACompendiumDataRequest.leagueid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15126,
  serialized_end=15195,
)


_CMSGDOTACOMPENDIUMDATARESPONSE = _descriptor.Descriptor(
  name='CMsgDOTACompendiumDataResponse',
  full_name='CMsgDOTACompendiumDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTACompendiumDataResponse.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leagueid', full_name='CMsgDOTACompendiumDataResponse.leagueid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTACompendiumDataResponse.result', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='compendium_data', full_name='CMsgDOTACompendiumDataResponse.compendium_data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15198,
  serialized_end=15337,
)


_CMSGDOTAGETPLAYERMATCHHISTORY = _descriptor.Descriptor(
  name='CMsgDOTAGetPlayerMatchHistory',
  full_name='CMsgDOTAGetPlayerMatchHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAGetPlayerMatchHistory.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_at_match_id', full_name='CMsgDOTAGetPlayerMatchHistory.start_at_match_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matches_requested', full_name='CMsgDOTAGetPlayerMatchHistory.matches_requested', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgDOTAGetPlayerMatchHistory.hero_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='CMsgDOTAGetPlayerMatchHistory.request_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='include_practice_matches', full_name='CMsgDOTAGetPlayerMatchHistory.include_practice_matches', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='include_custom_games', full_name='CMsgDOTAGetPlayerMatchHistory.include_custom_games', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15340,
  serialized_end=15546,
)


_CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE_MATCH = _descriptor.Descriptor(
  name='Match',
  full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.start_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.hero_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='winner', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.winner', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.game_mode', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rank_change', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.rank_change', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='previous_rank', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.previous_rank', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.lobby_type', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='solo_rank', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.solo_rank', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='abandon', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.abandon', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.duration', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='engine', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.engine', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active_battle_pass', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.active_battle_pass', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seasonal_rank', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.seasonal_rank', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tourney_id', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.tourney_id', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tourney_round', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.tourney_round', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tourney_tier', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.tourney_tier', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tourney_division', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.tourney_division', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.team_id', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.team_name', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ugc_team_ui_logo', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.Match.ugc_team_ui_logo', index=20,
      number=21, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15674,
  serialized_end=16109,
)

_CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGetPlayerMatchHistoryResponse',
  full_name='CMsgDOTAGetPlayerMatchHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='CMsgDOTAGetPlayerMatchHistoryResponse.request_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE_MATCH, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15549,
  serialized_end=16109,
)


_CMSGDOTASTARTDAILYHEROCHALLENGE = _descriptor.Descriptor(
  name='CMsgDOTAStartDailyHeroChallenge',
  full_name='CMsgDOTAStartDailyHeroChallenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16111,
  serialized_end=16144,
)


_CMSGGCNOTIFICATIONSREQUEST = _descriptor.Descriptor(
  name='CMsgGCNotificationsRequest',
  full_name='CMsgGCNotificationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16146,
  serialized_end=16174,
)


_CMSGGCNOTIFICATIONSRESPONSE_NOTIFICATION = _descriptor.Descriptor(
  name='Notification',
  full_name='CMsgGCNotificationsResponse.Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgGCNotificationsResponse.Notification.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='CMsgGCNotificationsResponse.Notification.type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgGCNotificationsResponse.Notification.timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reference_a', full_name='CMsgGCNotificationsResponse.Notification.reference_a', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reference_b', full_name='CMsgGCNotificationsResponse.Notification.reference_b', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reference_c', full_name='CMsgGCNotificationsResponse.Notification.reference_c', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='CMsgGCNotificationsResponse.Notification.message', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unread', full_name='CMsgGCNotificationsResponse.Notification.unread', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16338,
  serialized_end=16493,
)

_CMSGGCNOTIFICATIONSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCNotificationsResponse',
  full_name='CMsgGCNotificationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCNotificationsResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='notifications', full_name='CMsgGCNotificationsResponse.notifications', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCNOTIFICATIONSRESPONSE_NOTIFICATION, ],
  enum_types=[
    _CMSGGCNOTIFICATIONSRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16177,
  serialized_end=16540,
)


_CMSGGCNOTIFICATIONSMARKREADREQUEST = _descriptor.Descriptor(
  name='CMsgGCNotificationsMarkReadRequest',
  full_name='CMsgGCNotificationsMarkReadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16542,
  serialized_end=16578,
)


_CMSGCLIENTTOGCMARKNOTIFICATIONLISTREAD = _descriptor.Descriptor(
  name='CMsgClientToGCMarkNotificationListRead',
  full_name='CMsgClientToGCMarkNotificationListRead',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='notification_ids', full_name='CMsgClientToGCMarkNotificationListRead.notification_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16580,
  serialized_end=16646,
)


_CMSGGCLEAGUEADMINSTATE_PRIVATELEAGUEKEYS = _descriptor.Descriptor(
  name='PrivateLeagueKeys',
  full_name='CMsgGCLeagueAdminState.PrivateLeagueKeys',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='leagueid', full_name='CMsgGCLeagueAdminState.PrivateLeagueKeys.leagueid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='privatekey', full_name='CMsgGCLeagueAdminState.PrivateLeagueKeys.privatekey', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16749,
  serialized_end=16806,
)

_CMSGGCLEAGUEADMINSTATE = _descriptor.Descriptor(
  name='CMsgGCLeagueAdminState',
  full_name='CMsgGCLeagueAdminState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='leagues', full_name='CMsgGCLeagueAdminState.leagues', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='keys', full_name='CMsgGCLeagueAdminState.keys', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCLEAGUEADMINSTATE_PRIVATELEAGUEKEYS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16649,
  serialized_end=16806,
)


_CMSGGCPLAYERINFOREQUEST_PLAYERINFO = _descriptor.Descriptor(
  name='PlayerInfo',
  full_name='CMsgGCPlayerInfoRequest.PlayerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCPlayerInfoRequest.PlayerInfo.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgGCPlayerInfoRequest.PlayerInfo.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16895,
  serialized_end=16946,
)

_CMSGGCPLAYERINFOREQUEST = _descriptor.Descriptor(
  name='CMsgGCPlayerInfoRequest',
  full_name='CMsgGCPlayerInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_infos', full_name='CMsgGCPlayerInfoRequest.player_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCPLAYERINFOREQUEST_PLAYERINFO, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16809,
  serialized_end=16946,
)


_CMSGGCPLAYERINFOSUBMIT = _descriptor.Descriptor(
  name='CMsgGCPlayerInfoSubmit',
  full_name='CMsgGCPlayerInfoSubmit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgGCPlayerInfoSubmit.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CMsgGCPlayerInfoSubmit.country_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_role', full_name='CMsgGCPlayerInfoSubmit.fantasy_role', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgGCPlayerInfoSubmit.team_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sponsor', full_name='CMsgGCPlayerInfoSubmit.sponsor', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16948,
  serialized_end=17064,
)


_CMSGGCPLAYERINFOSUBMITRESPONSE = _descriptor.Descriptor(
  name='CMsgGCPlayerInfoSubmitResponse',
  full_name='CMsgGCPlayerInfoSubmitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCPlayerInfoSubmitResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGGCPLAYERINFOSUBMITRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17067,
  serialized_end=17235,
)


_CMSGCLIENTPROVIDESURVEYRESULT_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='CMsgClientProvideSurveyResult.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='question_id', full_name='CMsgClientProvideSurveyResult.Response.question_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='survey_value', full_name='CMsgClientProvideSurveyResult.Response.survey_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17351,
  serialized_end=17404,
)

_CMSGCLIENTPROVIDESURVEYRESULT = _descriptor.Descriptor(
  name='CMsgClientProvideSurveyResult',
  full_name='CMsgClientProvideSurveyResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='responses', full_name='CMsgClientProvideSurveyResult.responses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='survey_key', full_name='CMsgClientProvideSurveyResult.survey_key', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTPROVIDESURVEYRESULT_RESPONSE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17238,
  serialized_end=17404,
)


_CMSGDOTAEMOTICONACCESSSDO = _descriptor.Descriptor(
  name='CMsgDOTAEmoticonAccessSDO',
  full_name='CMsgDOTAEmoticonAccessSDO',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAEmoticonAccessSDO.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unlocked_emoticons', full_name='CMsgDOTAEmoticonAccessSDO.unlocked_emoticons', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17406,
  serialized_end=17481,
)


_CMSGCLIENTTOGCEMOTICONDATAREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCEmoticonDataRequest',
  full_name='CMsgClientToGCEmoticonDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17483,
  serialized_end=17518,
)


_CMSGGCTOCLIENTEMOTICONDATA = _descriptor.Descriptor(
  name='CMsgGCToClientEmoticonData',
  full_name='CMsgGCToClientEmoticonData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='emoticon_access', full_name='CMsgGCToClientEmoticonData.emoticon_access', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17520,
  serialized_end=17601,
)


_CMSGCLIENTTOGCTRACKDIALOGRESULT = _descriptor.Descriptor(
  name='CMsgClientToGCTrackDialogResult',
  full_name='CMsgClientToGCTrackDialogResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dialog_id', full_name='CMsgClientToGCTrackDialogResult.dialog_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='CMsgClientToGCTrackDialogResult.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17603,
  serialized_end=17670,
)


_CMSGGCTOCLIENTTOURNAMENTITEMDROP = _descriptor.Descriptor(
  name='CMsgGCToClientTournamentItemDrop',
  full_name='CMsgGCToClientTournamentItemDrop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def', full_name='CMsgGCToClientTournamentItemDrop.item_def', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='CMsgGCToClientTournamentItemDrop.event_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17672,
  serialized_end=17744,
)


_CMSGCLIENTTOGCSETADDITIONALEQUIPS = _descriptor.Descriptor(
  name='CMsgClientToGCSetAdditionalEquips',
  full_name='CMsgClientToGCSetAdditionalEquips',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='equips', full_name='CMsgClientToGCSetAdditionalEquips.equips', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17746,
  serialized_end=17820,
)


_CMSGCLIENTTOGCSETADDITIONALEQUIPSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCSetAdditionalEquipsResponse',
  full_name='CMsgClientToGCSetAdditionalEquipsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17822,
  serialized_end=17865,
)


_CMSGCLIENTTOGCGETADDITIONALEQUIPS = _descriptor.Descriptor(
  name='CMsgClientToGCGetAdditionalEquips',
  full_name='CMsgClientToGCGetAdditionalEquips',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17867,
  serialized_end=17902,
)


_CMSGCLIENTTOGCGETADDITIONALEQUIPSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGetAdditionalEquipsResponse',
  full_name='CMsgClientToGCGetAdditionalEquipsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='equips', full_name='CMsgClientToGCGetAdditionalEquipsResponse.equips', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17904,
  serialized_end=17986,
)


_CMSGCLIENTTOGCGETALLHEROORDER = _descriptor.Descriptor(
  name='CMsgClientToGCGetAllHeroOrder',
  full_name='CMsgClientToGCGetAllHeroOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17988,
  serialized_end=18019,
)


_CMSGCLIENTTOGCGETALLHEROORDERRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGetAllHeroOrderResponse',
  full_name='CMsgClientToGCGetAllHeroOrderResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_ids', full_name='CMsgClientToGCGetAllHeroOrderResponse.hero_ids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18021,
  serialized_end=18078,
)


_CMSGCLIENTTOGCGETALLHEROPROGRESS = _descriptor.Descriptor(
  name='CMsgClientToGCGetAllHeroProgress',
  full_name='CMsgClientToGCGetAllHeroProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgClientToGCGetAllHeroProgress.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18080,
  serialized_end=18134,
)


_CMSGCLIENTTOGCGETALLHEROPROGRESSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGetAllHeroProgressResponse',
  full_name='CMsgClientToGCGetAllHeroProgressResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgClientToGCGetAllHeroProgressResponse.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='curr_hero_id', full_name='CMsgClientToGCGetAllHeroProgressResponse.curr_hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='laps_completed', full_name='CMsgClientToGCGetAllHeroProgressResponse.laps_completed', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='curr_hero_games', full_name='CMsgClientToGCGetAllHeroProgressResponse.curr_hero_games', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='curr_lap_time_started', full_name='CMsgClientToGCGetAllHeroProgressResponse.curr_lap_time_started', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='curr_lap_games', full_name='CMsgClientToGCGetAllHeroProgressResponse.curr_lap_games', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='best_lap_games', full_name='CMsgClientToGCGetAllHeroProgressResponse.best_lap_games', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='best_lap_time', full_name='CMsgClientToGCGetAllHeroProgressResponse.best_lap_time', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lap_heroes_completed', full_name='CMsgClientToGCGetAllHeroProgressResponse.lap_heroes_completed', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lap_heroes_remaining', full_name='CMsgClientToGCGetAllHeroProgressResponse.lap_heroes_remaining', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='next_hero_id', full_name='CMsgClientToGCGetAllHeroProgressResponse.next_hero_id', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prev_hero_id', full_name='CMsgClientToGCGetAllHeroProgressResponse.prev_hero_id', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prev_hero_games', full_name='CMsgClientToGCGetAllHeroProgressResponse.prev_hero_games', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prev_avg_tries', full_name='CMsgClientToGCGetAllHeroProgressResponse.prev_avg_tries', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='curr_avg_tries', full_name='CMsgClientToGCGetAllHeroProgressResponse.curr_avg_tries', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='next_avg_tries', full_name='CMsgClientToGCGetAllHeroProgressResponse.next_avg_tries', index=15,
      number=16, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='full_lap_avg_tries', full_name='CMsgClientToGCGetAllHeroProgressResponse.full_lap_avg_tries', index=16,
      number=17, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='curr_lap_avg_tries', full_name='CMsgClientToGCGetAllHeroProgressResponse.curr_lap_avg_tries', index=17,
      number=18, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='profile_name', full_name='CMsgClientToGCGetAllHeroProgressResponse.profile_name', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_hero_id', full_name='CMsgClientToGCGetAllHeroProgressResponse.start_hero_id', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18137,
  serialized_end=18674,
)


_CMSGCLIENTTOGCGETTROPHYLIST = _descriptor.Descriptor(
  name='CMsgClientToGCGetTrophyList',
  full_name='CMsgClientToGCGetTrophyList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgClientToGCGetTrophyList.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18676,
  serialized_end=18725,
)


_CMSGCLIENTTOGCGETTROPHYLISTRESPONSE_TROPHY = _descriptor.Descriptor(
  name='Trophy',
  full_name='CMsgClientToGCGetTrophyListResponse.Trophy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trophy_id', full_name='CMsgClientToGCGetTrophyListResponse.Trophy.trophy_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trophy_score', full_name='CMsgClientToGCGetTrophyListResponse.Trophy.trophy_score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='CMsgClientToGCGetTrophyListResponse.Trophy.last_updated', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18872,
  serialized_end=18943,
)

_CMSGCLIENTTOGCGETTROPHYLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGetTrophyListResponse',
  full_name='CMsgClientToGCGetTrophyListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgClientToGCGetTrophyListResponse.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trophies', full_name='CMsgClientToGCGetTrophyListResponse.trophies', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='profile_name', full_name='CMsgClientToGCGetTrophyListResponse.profile_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCGETTROPHYLISTRESPONSE_TROPHY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18728,
  serialized_end=18943,
)


_CMSGGCTOCLIENTTROPHYAWARDED = _descriptor.Descriptor(
  name='CMsgGCToClientTrophyAwarded',
  full_name='CMsgGCToClientTrophyAwarded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trophy_id', full_name='CMsgGCToClientTrophyAwarded.trophy_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trophy_score', full_name='CMsgGCToClientTrophyAwarded.trophy_score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trophy_old_score', full_name='CMsgGCToClientTrophyAwarded.trophy_old_score', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='CMsgGCToClientTrophyAwarded.last_updated', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18945,
  serialized_end=19063,
)


_CMSGCLIENTTOGCGETPROFILECARD = _descriptor.Descriptor(
  name='CMsgClientToGCGetProfileCard',
  full_name='CMsgClientToGCGetProfileCard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgClientToGCGetProfileCard.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19065,
  serialized_end=19115,
)


_CMSGCLIENTTOGCSETPROFILECARDSLOTS_CARDSLOT = _descriptor.Descriptor(
  name='CardSlot',
  full_name='CMsgClientToGCSetProfileCardSlots.CardSlot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slot_id', full_name='CMsgClientToGCSetProfileCardSlots.CardSlot.slot_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot_type', full_name='CMsgClientToGCSetProfileCardSlots.CardSlot.slot_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot_value', full_name='CMsgClientToGCSetProfileCardSlots.CardSlot.slot_value', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19215,
  serialized_end=19334,
)

_CMSGCLIENTTOGCSETPROFILECARDSLOTS = _descriptor.Descriptor(
  name='CMsgClientToGCSetProfileCardSlots',
  full_name='CMsgClientToGCSetProfileCardSlots',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slots', full_name='CMsgClientToGCSetProfileCardSlots.slots', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCSETPROFILECARDSLOTS_CARDSLOT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19118,
  serialized_end=19334,
)


_CMSGCLIENTTOGCGETPROFILECARDSTATS = _descriptor.Descriptor(
  name='CMsgClientToGCGetProfileCardStats',
  full_name='CMsgClientToGCGetProfileCardStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19336,
  serialized_end=19371,
)


_CMSGCLIENTTOGCCREATEHEROSTATUE = _descriptor.Descriptor(
  name='CMsgClientToGCCreateHeroStatue',
  full_name='CMsgClientToGCCreateHeroStatue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_item', full_name='CMsgClientToGCCreateHeroStatue.source_item', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgClientToGCCreateHeroStatue.hero_id', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sequence_name', full_name='CMsgClientToGCCreateHeroStatue.sequence_name', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cycle', full_name='CMsgClientToGCCreateHeroStatue.cycle', index=3,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wearables', full_name='CMsgClientToGCCreateHeroStatue.wearables', index=4,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inscription', full_name='CMsgClientToGCCreateHeroStatue.inscription', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='styles', full_name='CMsgClientToGCCreateHeroStatue.styles', index=6,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reforger_item', full_name='CMsgClientToGCCreateHeroStatue.reforger_item', index=7,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_drop', full_name='CMsgClientToGCCreateHeroStatue.tournament_drop', index=8,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19374,
  serialized_end=19586,
)


_CMSGGCTOCLIENTHEROSTATUECREATERESULT = _descriptor.Descriptor(
  name='CMsgGCToClientHeroStatueCreateResult',
  full_name='CMsgGCToClientHeroStatueCreateResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resulting_item', full_name='CMsgGCToClientHeroStatueCreateResult.resulting_item', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19588,
  serialized_end=19650,
)


_CMSGCLIENTTOGCRECORDCOMPENDIUMSTATS = _descriptor.Descriptor(
  name='CMsgClientToGCRecordCompendiumStats',
  full_name='CMsgClientToGCRecordCompendiumStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgClientToGCRecordCompendiumStats.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='view_duration_s', full_name='CMsgClientToGCRecordCompendiumStats.view_duration_s', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='videos_viewed', full_name='CMsgClientToGCRecordCompendiumStats.videos_viewed', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='page_turns', full_name='CMsgClientToGCRecordCompendiumStats.page_turns', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='links_followed', full_name='CMsgClientToGCRecordCompendiumStats.links_followed', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19653,
  serialized_end=19801,
)


_CMSGGCTOCLIENTEVENTSTATUSCHANGED = _descriptor.Descriptor(
  name='CMsgGCToClientEventStatusChanged',
  full_name='CMsgGCToClientEventStatusChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='active_events', full_name='CMsgGCToClientEventStatusChanged.active_events', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19803,
  serialized_end=19869,
)


_CMSGCLIENTTOGCPLAYERSTATSREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCPlayerStatsRequest',
  full_name='CMsgClientToGCPlayerStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgClientToGCPlayerStatsRequest.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19871,
  serialized_end=19925,
)


_CMSGGCTOCLIENTPLAYERSTATSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientPlayerStatsResponse',
  full_name='CMsgGCToClientPlayerStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCToClientPlayerStatsResponse.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_stats', full_name='CMsgGCToClientPlayerStatsResponse.player_stats', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_count', full_name='CMsgGCToClientPlayerStatsResponse.match_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mean_gpm', full_name='CMsgGCToClientPlayerStatsResponse.mean_gpm', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mean_xppm', full_name='CMsgGCToClientPlayerStatsResponse.mean_xppm', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mean_lasthits', full_name='CMsgGCToClientPlayerStatsResponse.mean_lasthits', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rampages', full_name='CMsgGCToClientPlayerStatsResponse.rampages', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='triple_kills', full_name='CMsgGCToClientPlayerStatsResponse.triple_kills', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_blood_claimed', full_name='CMsgGCToClientPlayerStatsResponse.first_blood_claimed', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_blood_given', full_name='CMsgGCToClientPlayerStatsResponse.first_blood_given', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='couriers_killed', full_name='CMsgGCToClientPlayerStatsResponse.couriers_killed', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='aegises_snatched', full_name='CMsgGCToClientPlayerStatsResponse.aegises_snatched', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cheeses_eaten', full_name='CMsgGCToClientPlayerStatsResponse.cheeses_eaten', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='creeps_stacked', full_name='CMsgGCToClientPlayerStatsResponse.creeps_stacked', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fight_score', full_name='CMsgGCToClientPlayerStatsResponse.fight_score', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='farm_score', full_name='CMsgGCToClientPlayerStatsResponse.farm_score', index=15,
      number=16, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='support_score', full_name='CMsgGCToClientPlayerStatsResponse.support_score', index=16,
      number=17, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='push_score', full_name='CMsgGCToClientPlayerStatsResponse.push_score', index=17,
      number=18, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='versatility_score', full_name='CMsgGCToClientPlayerStatsResponse.versatility_score', index=18,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19928,
  serialized_end=20391,
)


_CMSGCLIENTTOGCCUSTOMGAMEPLAYERCOUNTREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCCustomGamePlayerCountRequest',
  full_name='CMsgClientToGCCustomGamePlayerCountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CMsgClientToGCCustomGamePlayerCountRequest.custom_game_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20393,
  serialized_end=20461,
)


_CMSGGCTOCLIENTCUSTOMGAMEPLAYERCOUNTRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientCustomGamePlayerCountResponse',
  full_name='CMsgGCToClientCustomGamePlayerCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CMsgGCToClientCustomGamePlayerCountResponse.custom_game_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_count', full_name='CMsgGCToClientCustomGamePlayerCountResponse.player_count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spectator_count', full_name='CMsgGCToClientCustomGamePlayerCountResponse.spectator_count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20463,
  serialized_end=20579,
)


_CMSGCLIENTTOGCCUSTOMGAMESFRIENDSPLAYEDREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCCustomGamesFriendsPlayedRequest',
  full_name='CMsgClientToGCCustomGamesFriendsPlayedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20581,
  serialized_end=20628,
)


_CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE_CUSTOMGAME = _descriptor.Descriptor(
  name='CustomGame',
  full_name='CMsgGCToClientCustomGamesFriendsPlayedResponse.CustomGame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CMsgGCToClientCustomGamesFriendsPlayedResponse.CustomGame.custom_game_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='CMsgGCToClientCustomGamesFriendsPlayedResponse.CustomGame.account_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20776,
  serialized_end=20833,
)

_CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientCustomGamesFriendsPlayedResponse',
  full_name='CMsgGCToClientCustomGamesFriendsPlayedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCToClientCustomGamesFriendsPlayedResponse.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='games', full_name='CMsgGCToClientCustomGamesFriendsPlayedResponse.games', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE_CUSTOMGAME, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20631,
  serialized_end=20833,
)


_CMSGCLIENTTOGCSOCIALFEEDPOSTCOMMENTREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCSocialFeedPostCommentRequest',
  full_name='CMsgClientToGCSocialFeedPostCommentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgClientToGCSocialFeedPostCommentRequest.event_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comment', full_name='CMsgClientToGCSocialFeedPostCommentRequest.comment', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20835,
  serialized_end=20914,
)


_CMSGGCTOCLIENTSOCIALFEEDPOSTCOMMENTRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientSocialFeedPostCommentResponse',
  full_name='CMsgGCToClientSocialFeedPostCommentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CMsgGCToClientSocialFeedPostCommentResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20916,
  serialized_end=20978,
)


_CMSGCLIENTTOGCSOCIALFEEDPOSTMESSAGEREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCSocialFeedPostMessageRequest',
  full_name='CMsgClientToGCSocialFeedPostMessageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='CMsgClientToGCSocialFeedPostMessageRequest.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgClientToGCSocialFeedPostMessageRequest.match_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_timestamp', full_name='CMsgClientToGCSocialFeedPostMessageRequest.match_timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20980,
  serialized_end=21084,
)


_CMSGGCTOCLIENTSOCIALFEEDPOSTMESSAGERESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientSocialFeedPostMessageResponse',
  full_name='CMsgGCToClientSocialFeedPostMessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CMsgGCToClientSocialFeedPostMessageResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21086,
  serialized_end=21148,
)


_CMSGCLIENTTOGCFRIENDSPLAYEDCUSTOMGAMEREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCFriendsPlayedCustomGameRequest',
  full_name='CMsgClientToGCFriendsPlayedCustomGameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CMsgClientToGCFriendsPlayedCustomGameRequest.custom_game_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21150,
  serialized_end=21220,
)


_CMSGGCTOCLIENTFRIENDSPLAYEDCUSTOMGAMERESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientFriendsPlayedCustomGameResponse',
  full_name='CMsgGCToClientFriendsPlayedCustomGameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CMsgGCToClientFriendsPlayedCustomGameResponse.custom_game_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='CMsgGCToClientFriendsPlayedCustomGameResponse.account_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21222,
  serialized_end=21314,
)


_CMSGCLIENTTOGCFEATUREDHEROESREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCFeaturedHeroesRequest',
  full_name='CMsgClientToGCFeaturedHeroesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21316,
  serialized_end=21353,
)


_CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_DATAFIELD = _descriptor.Descriptor(
  name='DataField',
  full_name='CMsgGCToClientFeaturedHeroesResponse.DataField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_type', full_name='CMsgGCToClientFeaturedHeroesResponse.DataField.data_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uint32_value', full_name='CMsgGCToClientFeaturedHeroesResponse.DataField.uint32_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uint64_value', full_name='CMsgGCToClientFeaturedHeroesResponse.DataField.uint64_value', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='CMsgGCToClientFeaturedHeroesResponse.DataField.string_value', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='float_value', full_name='CMsgGCToClientFeaturedHeroesResponse.DataField.float_value', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21465,
  serialized_end=21638,
)

_CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_FEATUREDHERO = _descriptor.Descriptor(
  name='FeaturedHero',
  full_name='CMsgGCToClientFeaturedHeroesResponse.FeaturedHero',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_fields', full_name='CMsgGCToClientFeaturedHeroesResponse.FeaturedHero.data_fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21640,
  serialized_end=21724,
)

_CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_CATEGORY = _descriptor.Descriptor(
  name='Category',
  full_name='CMsgGCToClientFeaturedHeroesResponse.Category',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='category_weight', full_name='CMsgGCToClientFeaturedHeroesResponse.Category.category_weight', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text_fields', full_name='CMsgGCToClientFeaturedHeroesResponse.Category.text_fields', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='featured_heroes', full_name='CMsgGCToClientFeaturedHeroesResponse.Category.featured_heroes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21727,
  serialized_end=21885,
)

_CMSGGCTOCLIENTFEATUREDHEROESRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientFeaturedHeroesResponse',
  full_name='CMsgGCToClientFeaturedHeroesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='categories', full_name='CMsgGCToClientFeaturedHeroesResponse.categories', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_DATAFIELD, _CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_FEATUREDHERO, _CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_CATEGORY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21356,
  serialized_end=21885,
)


_CMSGCLIENTTOGCSOCIALMATCHPOSTCOMMENTREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCSocialMatchPostCommentRequest',
  full_name='CMsgClientToGCSocialMatchPostCommentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgClientToGCSocialMatchPostCommentRequest.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comment', full_name='CMsgClientToGCSocialMatchPostCommentRequest.comment', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21887,
  serialized_end=21967,
)


_CMSGGCTOCLIENTSOCIALMATCHPOSTCOMMENTRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientSocialMatchPostCommentResponse',
  full_name='CMsgGCToClientSocialMatchPostCommentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CMsgGCToClientSocialMatchPostCommentResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21969,
  serialized_end=22032,
)


_CMSGCLIENTTOGCSOCIALMATCHDETAILSREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCSocialMatchDetailsRequest',
  full_name='CMsgClientToGCSocialMatchDetailsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgClientToGCSocialMatchDetailsRequest.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pagination_timestamp', full_name='CMsgClientToGCSocialMatchDetailsRequest.pagination_timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22034,
  serialized_end=22123,
)


_CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE_COMMENT = _descriptor.Descriptor(
  name='Comment',
  full_name='CMsgGCToClientSocialMatchDetailsResponse.Comment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCToClientSocialMatchDetailsResponse.Comment.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CMsgGCToClientSocialMatchDetailsResponse.Comment.persona_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgGCToClientSocialMatchDetailsResponse.Comment.timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comment', full_name='CMsgGCToClientSocialMatchDetailsResponse.Comment.comment', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22256,
  serialized_end=22343,
)

_CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientSocialMatchDetailsResponse',
  full_name='CMsgGCToClientSocialMatchDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CMsgGCToClientSocialMatchDetailsResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comments', full_name='CMsgGCToClientSocialMatchDetailsResponse.comments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE_COMMENT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22126,
  serialized_end=22343,
)


_CMSGDOTAPARTYRICHPRESENCE_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='CMsgDOTAPartyRichPresence.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgDOTAPartyRichPresence.Member.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='coach', full_name='CMsgDOTAPartyRichPresence.Member.coach', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22657,
  serialized_end=22698,
)

_CMSGDOTAPARTYRICHPRESENCE_WEEKENDTOURNEY = _descriptor.Descriptor(
  name='WeekendTourney',
  full_name='CMsgDOTAPartyRichPresence.WeekendTourney',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='division', full_name='CMsgDOTAPartyRichPresence.WeekendTourney.division', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='skill_level', full_name='CMsgDOTAPartyRichPresence.WeekendTourney.skill_level', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='round', full_name='CMsgDOTAPartyRichPresence.WeekendTourney.round', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tournament_id', full_name='CMsgDOTAPartyRichPresence.WeekendTourney.tournament_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state_seq_num', full_name='CMsgDOTAPartyRichPresence.WeekendTourney.state_seq_num', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event', full_name='CMsgDOTAPartyRichPresence.WeekendTourney.event', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_round', full_name='CMsgDOTAPartyRichPresence.WeekendTourney.event_round', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22701,
  serialized_end=22929,
)

_CMSGDOTAPARTYRICHPRESENCE = _descriptor.Descriptor(
  name='CMsgDOTAPartyRichPresence',
  full_name='CMsgDOTAPartyRichPresence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='party_id', full_name='CMsgDOTAPartyRichPresence.party_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='party_state', full_name='CMsgDOTAPartyRichPresence.party_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='open', full_name='CMsgDOTAPartyRichPresence.open', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='low_priority', full_name='CMsgDOTAPartyRichPresence.low_priority', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTAPartyRichPresence.team_id', index=4,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgDOTAPartyRichPresence.team_name', index=5,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ugc_team_ui_logo', full_name='CMsgDOTAPartyRichPresence.ugc_team_ui_logo', index=6,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='members', full_name='CMsgDOTAPartyRichPresence.members', index=7,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weekend_tourney', full_name='CMsgDOTAPartyRichPresence.weekend_tourney', index=8,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAPARTYRICHPRESENCE_MEMBER, _CMSGDOTAPARTYRICHPRESENCE_WEEKENDTOURNEY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22346,
  serialized_end=22929,
)


_CMSGDOTALOBBYRICHPRESENCE = _descriptor.Descriptor(
  name='CMsgDOTALobbyRichPresence',
  full_name='CMsgDOTALobbyRichPresence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CMsgDOTALobbyRichPresence.lobby_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_state', full_name='CMsgDOTALobbyRichPresence.lobby_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='password', full_name='CMsgDOTALobbyRichPresence.password', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_mode', full_name='CMsgDOTALobbyRichPresence.game_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member_count', full_name='CMsgDOTALobbyRichPresence.member_count', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_member_count', full_name='CMsgDOTALobbyRichPresence.max_member_count', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CMsgDOTALobbyRichPresence.custom_game_id', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTALobbyRichPresence.name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='CMsgDOTALobbyRichPresence.lobby_type', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22932,
  serialized_end=23202,
)


_CMSGDOTACUSTOMGAMELISTENSERVERSTARTEDLOADING = _descriptor.Descriptor(
  name='CMsgDOTACustomGameListenServerStartedLoading',
  full_name='CMsgDOTACustomGameListenServerStartedLoading',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CMsgDOTACustomGameListenServerStartedLoading.lobby_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_id', full_name='CMsgDOTACustomGameListenServerStartedLoading.custom_game_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lobby_members', full_name='CMsgDOTACustomGameListenServerStartedLoading.lobby_members', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='CMsgDOTACustomGameListenServerStartedLoading.start_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23205,
  serialized_end=23336,
)


_CMSGDOTACUSTOMGAMECLIENTFINISHEDLOADING = _descriptor.Descriptor(
  name='CMsgDOTACustomGameClientFinishedLoading',
  full_name='CMsgDOTACustomGameClientFinishedLoading',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CMsgDOTACustomGameClientFinishedLoading.lobby_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='loading_duration', full_name='CMsgDOTACustomGameClientFinishedLoading.loading_duration', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result_code', full_name='CMsgDOTACustomGameClientFinishedLoading.result_code', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result_string', full_name='CMsgDOTACustomGameClientFinishedLoading.result_string', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signon_states', full_name='CMsgDOTACustomGameClientFinishedLoading.signon_states', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comment', full_name='CMsgDOTACustomGameClientFinishedLoading.comment', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23339,
  serialized_end=23508,
)


_CMSGCLIENTTOGCGETLEAGUESERIES = _descriptor.Descriptor(
  name='CMsgClientToGCGetLeagueSeries',
  full_name='CMsgClientToGCGetLeagueSeries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgClientToGCGetLeagueSeries.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23510,
  serialized_end=23560,
)


_CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE_SERIES_TEAM = _descriptor.Descriptor(
  name='Team',
  full_name='CMsgClientToGCGetLeagueSeriesResponse.Series.Team',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgClientToGCGetLeagueSeriesResponse.Series.Team.team_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgClientToGCGetLeagueSeriesResponse.Series.Team.team_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_tag', full_name='CMsgClientToGCGetLeagueSeriesResponse.Series.Team.team_tag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_score', full_name='CMsgClientToGCGetLeagueSeriesResponse.Series.Team.team_score', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_wins', full_name='CMsgClientToGCGetLeagueSeriesResponse.Series.Team.team_wins', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23898,
  serialized_end=23997,
)

_CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE_SERIES = _descriptor.Descriptor(
  name='Series',
  full_name='CMsgClientToGCGetLeagueSeriesResponse.Series',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='series_id', full_name='CMsgClientToGCGetLeagueSeriesResponse.Series.series_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_games', full_name='CMsgClientToGCGetLeagueSeriesResponse.Series.num_games', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teams', full_name='CMsgClientToGCGetLeagueSeriesResponse.Series.teams', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_name', full_name='CMsgClientToGCGetLeagueSeriesResponse.Series.series_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='phase_name', full_name='CMsgClientToGCGetLeagueSeriesResponse.Series.phase_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='CMsgClientToGCGetLeagueSeriesResponse.Series.start_time', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='after_series_id', full_name='CMsgClientToGCGetLeagueSeriesResponse.Series.after_series_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_completed_games', full_name='CMsgClientToGCGetLeagueSeriesResponse.Series.num_completed_games', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE_SERIES_TEAM, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23668,
  serialized_end=23997,
)

_CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGetLeagueSeriesResponse',
  full_name='CMsgClientToGCGetLeagueSeriesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='series', full_name='CMsgClientToGCGetLeagueSeriesResponse.series', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE_SERIES, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23563,
  serialized_end=23997,
)


_CMSGCLIENTTOGCAPPLYGEMCOMBINER = _descriptor.Descriptor(
  name='CMsgClientToGCApplyGemCombiner',
  full_name='CMsgClientToGCApplyGemCombiner',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id_1', full_name='CMsgClientToGCApplyGemCombiner.item_id_1', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id_2', full_name='CMsgClientToGCApplyGemCombiner.item_id_2', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23999,
  serialized_end=24069,
)


_CMSGCLIENTTOGCH264UNSUPPORTED = _descriptor.Descriptor(
  name='CMsgClientToGCH264Unsupported',
  full_name='CMsgClientToGCH264Unsupported',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24071,
  serialized_end=24102,
)


_CMSGCLIENTTOGCREQUESTH264SUPPORT = _descriptor.Descriptor(
  name='CMsgClientToGCRequestH264Support',
  full_name='CMsgClientToGCRequestH264Support',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24104,
  serialized_end=24138,
)


_CMSGCLIENTTOGCGETQUESTPROGRESS = _descriptor.Descriptor(
  name='CMsgClientToGCGetQuestProgress',
  full_name='CMsgClientToGCGetQuestProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quest_ids', full_name='CMsgClientToGCGetQuestProgress.quest_ids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24140,
  serialized_end=24191,
)


_CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_CHALLENGE = _descriptor.Descriptor(
  name='Challenge',
  full_name='CMsgClientToGCGetQuestProgressResponse.Challenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='challenge_id', full_name='CMsgClientToGCGetQuestProgressResponse.Challenge.challenge_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_completed', full_name='CMsgClientToGCGetQuestProgressResponse.Challenge.time_completed', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attempts', full_name='CMsgClientToGCGetQuestProgressResponse.Challenge.attempts', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgClientToGCGetQuestProgressResponse.Challenge.hero_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='challenge_type', full_name='CMsgClientToGCGetQuestProgressResponse.Challenge.challenge_type', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quest_rank', full_name='CMsgClientToGCGetQuestProgressResponse.Challenge.quest_rank', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24317,
  serialized_end=24453,
)

_CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_QUEST = _descriptor.Descriptor(
  name='Quest',
  full_name='CMsgClientToGCGetQuestProgressResponse.Quest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quest_id', full_name='CMsgClientToGCGetQuestProgressResponse.Quest.quest_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='completed_challenges', full_name='CMsgClientToGCGetQuestProgressResponse.Quest.completed_challenges', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24455,
  serialized_end=24561,
)

_CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGetQuestProgressResponse',
  full_name='CMsgClientToGCGetQuestProgressResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CMsgClientToGCGetQuestProgressResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quests', full_name='CMsgClientToGCGetQuestProgressResponse.quests', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_CHALLENGE, _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_QUEST, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24194,
  serialized_end=24561,
)


_CMSGGCTOCLIENTMATCHSIGNEDOUT = _descriptor.Descriptor(
  name='CMsgGCToClientMatchSignedOut',
  full_name='CMsgGCToClientMatchSignedOut',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgGCToClientMatchSignedOut.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24563,
  serialized_end=24611,
)


_CMSGGCGETHEROSTATSHISTORY = _descriptor.Descriptor(
  name='CMsgGCGetHeroStatsHistory',
  full_name='CMsgGCGetHeroStatsHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgGCGetHeroStatsHistory.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24613,
  serialized_end=24657,
)


_CMSGGCGETHEROSTATSHISTORYRESPONSE = _descriptor.Descriptor(
  name='CMsgGCGetHeroStatsHistoryResponse',
  full_name='CMsgGCGetHeroStatsHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgGCGetHeroStatsHistoryResponse.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records', full_name='CMsgGCGetHeroStatsHistoryResponse.records', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24659,
  serialized_end=24758,
)


_CMSGPLAYERCONDUCTSCORECARDREQUEST = _descriptor.Descriptor(
  name='CMsgPlayerConductScorecardRequest',
  full_name='CMsgPlayerConductScorecardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24760,
  serialized_end=24795,
)


_CMSGPLAYERCONDUCTSCORECARD = _descriptor.Descriptor(
  name='CMsgPlayerConductScorecard',
  full_name='CMsgPlayerConductScorecard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgPlayerConductScorecard.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgPlayerConductScorecard.match_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seq_num', full_name='CMsgPlayerConductScorecard.seq_num', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reasons', full_name='CMsgPlayerConductScorecard.reasons', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matches_in_report', full_name='CMsgPlayerConductScorecard.matches_in_report', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matches_clean', full_name='CMsgPlayerConductScorecard.matches_clean', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matches_reported', full_name='CMsgPlayerConductScorecard.matches_reported', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matches_abandoned', full_name='CMsgPlayerConductScorecard.matches_abandoned', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reports_count', full_name='CMsgPlayerConductScorecard.reports_count', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reports_parties', full_name='CMsgPlayerConductScorecard.reports_parties', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='commend_count', full_name='CMsgPlayerConductScorecard.commend_count', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_score', full_name='CMsgPlayerConductScorecard.end_score', index=11,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='date', full_name='CMsgPlayerConductScorecard.date', index=12,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24798,
  serialized_end=25105,
)


_CMSGCLIENTTOGCWAGERINGREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCWageringRequest',
  full_name='CMsgClientToGCWageringRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgClientToGCWageringRequest.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25107,
  serialized_end=25156,
)


_CMSGGCTOCLIENTWAGERINGRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientWageringResponse',
  full_name='CMsgGCToClientWageringResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coins_remaining', full_name='CMsgGCToClientWageringResponse.coins_remaining', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_points_won', full_name='CMsgGCToClientWageringResponse.total_points_won', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_points_wagered', full_name='CMsgGCToClientWageringResponse.total_points_wagered', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_points_tipped', full_name='CMsgGCToClientWageringResponse.total_points_tipped', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='success_rate', full_name='CMsgGCToClientWageringResponse.success_rate', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_games_wagered', full_name='CMsgGCToClientWageringResponse.total_games_wagered', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='coins_max', full_name='CMsgGCToClientWageringResponse.coins_max', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25159,
  serialized_end=25371,
)


_CMSGGCTOCLIENTWAGERINGUPDATE = _descriptor.Descriptor(
  name='CMsgGCToClientWageringUpdate',
  full_name='CMsgGCToClientWageringUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgGCToClientWageringUpdate.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wagering_info', full_name='CMsgGCToClientWageringUpdate.wagering_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25373,
  serialized_end=25477,
)


_CMSGGCTOCLIENTARCANAVOTESUPDATE = _descriptor.Descriptor(
  name='CMsgGCToClientArcanaVotesUpdate',
  full_name='CMsgGCToClientArcanaVotesUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgGCToClientArcanaVotesUpdate.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='arcana_votes', full_name='CMsgGCToClientArcanaVotesUpdate.arcana_votes', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25479,
  serialized_end=25604,
)


_CMSGCLIENTTOGCMYSTERYITEM = _descriptor.Descriptor(
  name='CMsgClientToGCMysteryItem',
  full_name='CMsgClientToGCMysteryItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgClientToGCMysteryItem.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='action_id', full_name='CMsgClientToGCMysteryItem.action_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25606,
  serialized_end=25670,
)


_CMSGGCTOCLIENTMYSTERYITEMRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientMysteryItemResponse',
  full_name='CMsgGCToClientMysteryItemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCToClientMysteryItemResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reward_type', full_name='CMsgGCToClientMysteryItemResponse.reward_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemdef', full_name='CMsgGCToClientMysteryItemResponse.itemdef', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGGCTOCLIENTMYSTERYITEMRESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25673,
  serialized_end=26078,
)


_CMSGCLIENTTOGCGETEVENTGOALS = _descriptor.Descriptor(
  name='CMsgClientToGCGetEventGoals',
  full_name='CMsgClientToGCGetEventGoals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_ids', full_name='CMsgClientToGCGetEventGoals.event_ids', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26080,
  serialized_end=26137,
)


_CMSGEVENTGOALS_EVENTGOAL = _descriptor.Descriptor(
  name='EventGoal',
  full_name='CMsgEventGoals.EventGoal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgEventGoals.EventGoal.event_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='goal_id', full_name='CMsgEventGoals.EventGoal.goal_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='CMsgEventGoals.EventGoal.value', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26206,
  serialized_end=26291,
)

_CMSGEVENTGOALS = _descriptor.Descriptor(
  name='CMsgEventGoals',
  full_name='CMsgEventGoals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_goals', full_name='CMsgEventGoals.event_goals', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGEVENTGOALS_EVENTGOAL, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26140,
  serialized_end=26291,
)


_CMSGGCTOGCLEAGUEPREDICTIONS = _descriptor.Descriptor(
  name='CMsgGCToGCLeaguePredictions',
  full_name='CMsgGCToGCLeaguePredictions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgGCToGCLeaguePredictions.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26293,
  serialized_end=26341,
)


_CMSGPREDICTIONRANKINGS_PREDICTIONLINE = _descriptor.Descriptor(
  name='PredictionLine',
  full_name='CMsgPredictionRankings.PredictionLine',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answer_id', full_name='CMsgPredictionRankings.PredictionLine.answer_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='answer_name', full_name='CMsgPredictionRankings.PredictionLine.answer_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='answer_logo', full_name='CMsgPredictionRankings.PredictionLine.answer_logo', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='answer_value', full_name='CMsgPredictionRankings.PredictionLine.answer_value', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26427,
  serialized_end=26526,
)

_CMSGPREDICTIONRANKINGS_PREDICTION = _descriptor.Descriptor(
  name='Prediction',
  full_name='CMsgPredictionRankings.Prediction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selection_id', full_name='CMsgPredictionRankings.Prediction.selection_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prediction_lines', full_name='CMsgPredictionRankings.Prediction.prediction_lines', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26528,
  serialized_end=26628,
)

_CMSGPREDICTIONRANKINGS = _descriptor.Descriptor(
  name='CMsgPredictionRankings',
  full_name='CMsgPredictionRankings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='predictions', full_name='CMsgPredictionRankings.predictions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGPREDICTIONRANKINGS_PREDICTIONLINE, _CMSGPREDICTIONRANKINGS_PREDICTION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26344,
  serialized_end=26628,
)


_CMSGPREDICTIONRESULTS_RESULTBREAKDOWN = _descriptor.Descriptor(
  name='ResultBreakdown',
  full_name='CMsgPredictionResults.ResultBreakdown',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answer_selection', full_name='CMsgPredictionResults.ResultBreakdown.answer_selection', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='answer_value', full_name='CMsgPredictionResults.ResultBreakdown.answer_value', index=1,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26704,
  serialized_end=26769,
)

_CMSGPREDICTIONRESULTS_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='CMsgPredictionResults.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selection_id', full_name='CMsgPredictionResults.Result.selection_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result_breakdown', full_name='CMsgPredictionResults.Result.result_breakdown', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26771,
  serialized_end=26867,
)

_CMSGPREDICTIONRESULTS = _descriptor.Descriptor(
  name='CMsgPredictionResults',
  full_name='CMsgPredictionResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CMsgPredictionResults.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGPREDICTIONRESULTS_RESULTBREAKDOWN, _CMSGPREDICTIONRESULTS_RESULT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26631,
  serialized_end=26867,
)


_CMSGCLIENTTOGCSUSPICIOUSACTIVITY = _descriptor.Descriptor(
  name='CMsgClientToGCSuspiciousActivity',
  full_name='CMsgClientToGCSuspiciousActivity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_data', full_name='CMsgClientToGCSuspiciousActivity.app_data', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26869,
  serialized_end=26921,
)


_CMSGCLIENTTOGCHASPLAYERVOTEDFORMVP = _descriptor.Descriptor(
  name='CMsgClientToGCHasPlayerVotedForMVP',
  full_name='CMsgClientToGCHasPlayerVotedForMVP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgClientToGCHasPlayerVotedForMVP.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26923,
  serialized_end=26977,
)


_CMSGCLIENTTOGCHASPLAYERVOTEDFORMVPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCHasPlayerVotedForMVPResponse',
  full_name='CMsgClientToGCHasPlayerVotedForMVPResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientToGCHasPlayerVotedForMVPResponse.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26979,
  serialized_end=27039,
)


_CMSGCLIENTTOGCVOTEFORMVP = _descriptor.Descriptor(
  name='CMsgClientToGCVoteForMVP',
  full_name='CMsgClientToGCVoteForMVP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgClientToGCVoteForMVP.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgClientToGCVoteForMVP.account_id', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27041,
  serialized_end=27105,
)


_CMSGCLIENTTOGCVOTEFORMVPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCVoteForMVPResponse',
  full_name='CMsgClientToGCVoteForMVPResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientToGCVoteForMVPResponse.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27107,
  serialized_end=27157,
)


_CMSGMVPVOTESFORMATCH_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='CMsgMVPVotesForMatch.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgMVPVotesForMatch.Player.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vote_count', full_name='CMsgMVPVotesForMatch.Player.vote_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27230,
  serialized_end=27278,
)

_CMSGMVPVOTESFORMATCH = _descriptor.Descriptor(
  name='CMsgMVPVotesForMatch',
  full_name='CMsgMVPVotesForMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='players', full_name='CMsgMVPVotesForMatch.players', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGMVPVOTESFORMATCH_PLAYER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27159,
  serialized_end=27278,
)


_CMSGLEAGUEPRIZEPOOL = _descriptor.Descriptor(
  name='CMsgLeaguePrizePool',
  full_name='CMsgLeaguePrizePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prize_pool', full_name='CMsgLeaguePrizePool.prize_pool', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='increment_per_second', full_name='CMsgLeaguePrizePool.increment_per_second', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27280,
  serialized_end=27351,
)


_CMSGCLIENTTOGCTEAMMATESTATSREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCTeammateStatsRequest',
  full_name='CMsgClientToGCTeammateStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27353,
  serialized_end=27389,
)


_CMSGCLIENTTOGCTEAMMATESTATSRESPONSE_TEAMMATESTAT = _descriptor.Descriptor(
  name='TeammateStat',
  full_name='CMsgClientToGCTeammateStatsResponse.TeammateStat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgClientToGCTeammateStatsResponse.TeammateStat.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='games', full_name='CMsgClientToGCTeammateStatsResponse.TeammateStat.games', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wins', full_name='CMsgClientToGCTeammateStatsResponse.TeammateStat.wins', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='most_recent_game_timestamp', full_name='CMsgClientToGCTeammateStatsResponse.TeammateStat.most_recent_game_timestamp', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='most_recent_game_match_id', full_name='CMsgClientToGCTeammateStatsResponse.TeammateStat.most_recent_game_match_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='performance', full_name='CMsgClientToGCTeammateStatsResponse.TeammateStat.performance', index=5,
      number=100, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27524,
  serialized_end=27679,
)

_CMSGCLIENTTOGCTEAMMATESTATSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCTeammateStatsResponse',
  full_name='CMsgClientToGCTeammateStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CMsgClientToGCTeammateStatsResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teammate_stats', full_name='CMsgClientToGCTeammateStatsResponse.teammate_stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCTEAMMATESTATSRESPONSE_TEAMMATESTAT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27392,
  serialized_end=27679,
)


_CMSGCLIENTTOGCVOTEFORARCANA_MATCHVOTE = _descriptor.Descriptor(
  name='MatchVote',
  full_name='CMsgClientToGCVoteForArcana.MatchVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgClientToGCVoteForArcana.MatchVote.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgClientToGCVoteForArcana.MatchVote.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vote_count', full_name='CMsgClientToGCVoteForArcana.MatchVote.vote_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27770,
  serialized_end=27836,
)

_CMSGCLIENTTOGCVOTEFORARCANA = _descriptor.Descriptor(
  name='CMsgClientToGCVoteForArcana',
  full_name='CMsgClientToGCVoteForArcana',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='CMsgClientToGCVoteForArcana.matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCVOTEFORARCANA_MATCHVOTE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27682,
  serialized_end=27836,
)


_CMSGCLIENTTOGCVOTEFORARCANARESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCVoteForArcanaResponse',
  full_name='CMsgClientToGCVoteForArcanaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientToGCVoteForArcanaResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCVOTEFORARCANARESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27839,
  serialized_end=28028,
)


_CMSGARCANAVOTES_MATCH = _descriptor.Descriptor(
  name='Match',
  full_name='CMsgArcanaVotes.Match',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgArcanaVotes.Match.match_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id_0', full_name='CMsgArcanaVotes.Match.hero_id_0', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id_1', full_name='CMsgArcanaVotes.Match.hero_id_1', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_seeding_0', full_name='CMsgArcanaVotes.Match.hero_seeding_0', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_seeding_1', full_name='CMsgArcanaVotes.Match.hero_seeding_1', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vote_count_0', full_name='CMsgArcanaVotes.Match.vote_count_0', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vote_count_1', full_name='CMsgArcanaVotes.Match.vote_count_1', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='voting_state', full_name='CMsgArcanaVotes.Match.voting_state', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='round_number', full_name='CMsgArcanaVotes.Match.round_number', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_votes_hidden', full_name='CMsgArcanaVotes.Match.is_votes_hidden', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calibration_time_remaining', full_name='CMsgArcanaVotes.Match.calibration_time_remaining', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28237,
  serialized_end=28497,
)

_CMSGARCANAVOTES = _descriptor.Descriptor(
  name='CMsgArcanaVotes',
  full_name='CMsgArcanaVotes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='CMsgArcanaVotes.matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='round_time_remaining', full_name='CMsgArcanaVotes.round_time_remaining', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='round_number', full_name='CMsgArcanaVotes.round_number', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='voting_state', full_name='CMsgArcanaVotes.voting_state', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_current_round_calibrating', full_name='CMsgArcanaVotes.is_current_round_calibrating', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='closest_active_match_id', full_name='CMsgArcanaVotes.closest_active_match_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGARCANAVOTES_MATCH, ],
  enum_types=[
    _CMSGARCANAVOTES_VOTINGSTATE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28031,
  serialized_end=28558,
)


_CMSGCLIENTTOGCREQUESTARCANAVOTESREMAINING = _descriptor.Descriptor(
  name='CMsgClientToGCRequestArcanaVotesRemaining',
  full_name='CMsgClientToGCRequestArcanaVotesRemaining',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28560,
  serialized_end=28603,
)


_CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE_MATCHVOTE = _descriptor.Descriptor(
  name='MatchVote',
  full_name='CMsgClientToGCRequestArcanaVotesRemainingResponse.MatchVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgClientToGCRequestArcanaVotesRemainingResponse.MatchVote.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgClientToGCRequestArcanaVotesRemainingResponse.MatchVote.hero_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vote_count', full_name='CMsgClientToGCRequestArcanaVotesRemainingResponse.MatchVote.vote_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27770,
  serialized_end=27836,
)

_CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRequestArcanaVotesRemainingResponse',
  full_name='CMsgClientToGCRequestArcanaVotesRemainingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientToGCRequestArcanaVotesRemainingResponse.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='votes_remaining', full_name='CMsgClientToGCRequestArcanaVotesRemainingResponse.votes_remaining', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='votes_total', full_name='CMsgClientToGCRequestArcanaVotesRemainingResponse.votes_total', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matches_previously_voted_for', full_name='CMsgClientToGCRequestArcanaVotesRemainingResponse.matches_previously_voted_for', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE_MATCHVOTE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28606,
  serialized_end=28887,
)


_CMSGCLIENTTOGCREQUESTEVENTPOINTLOG = _descriptor.Descriptor(
  name='CMsgClientToGCRequestEventPointLog',
  full_name='CMsgClientToGCRequestEventPointLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgClientToGCRequestEventPointLog.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28889,
  serialized_end=28943,
)


_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_QUESTCHALLENGEEVENT = _descriptor.Descriptor(
  name='QuestChallengeEvent',
  full_name='CMsgClientToGCRequestEventPointLogResponse.QuestChallengeEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quest_id', full_name='CMsgClientToGCRequestEventPointLogResponse.QuestChallengeEvent.quest_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='challenge_id', full_name='CMsgClientToGCRequestEventPointLogResponse.QuestChallengeEvent.challenge_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rank', full_name='CMsgClientToGCRequestEventPointLogResponse.QuestChallengeEvent.rank', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29115,
  serialized_end=29190,
)

_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_WAGERWONEVENT = _descriptor.Descriptor(
  name='WagerWonEvent',
  full_name='CMsgClientToGCRequestEventPointLogResponse.WagerWonEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgClientToGCRequestEventPointLogResponse.WagerWonEvent.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29192,
  serialized_end=29225,
)

_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_TIPGIVENEVENT = _descriptor.Descriptor(
  name='TipGivenEvent',
  full_name='CMsgClientToGCRequestEventPointLogResponse.TipGivenEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipient_account_id', full_name='CMsgClientToGCRequestEventPointLogResponse.TipGivenEvent.recipient_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recipient_name', full_name='CMsgClientToGCRequestEventPointLogResponse.TipGivenEvent.recipient_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29227,
  serialized_end=29296,
)

_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_TIPRECEIVEDEVENT = _descriptor.Descriptor(
  name='TipReceivedEvent',
  full_name='CMsgClientToGCRequestEventPointLogResponse.TipReceivedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='giver_account_id', full_name='CMsgClientToGCRequestEventPointLogResponse.TipReceivedEvent.giver_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='giver_name', full_name='CMsgClientToGCRequestEventPointLogResponse.TipReceivedEvent.giver_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29298,
  serialized_end=29362,
)

_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_RECYCLEDITEMEVENT = _descriptor.Descriptor(
  name='RecycledItemEvent',
  full_name='CMsgClientToGCRequestEventPointLogResponse.RecycledItemEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipe_item_def_index', full_name='CMsgClientToGCRequestEventPointLogResponse.RecycledItemEvent.recipe_item_def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29364,
  serialized_end=29414,
)

_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_ACHIEVEMENTEVENT = _descriptor.Descriptor(
  name='AchievementEvent',
  full_name='CMsgClientToGCRequestEventPointLogResponse.AchievementEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='action_id', full_name='CMsgClientToGCRequestEventPointLogResponse.AchievementEvent.action_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29416,
  serialized_end=29453,
)

_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_MYSTERYITEMRECEIVEDEVENT = _descriptor.Descriptor(
  name='MysteryItemReceivedEvent',
  full_name='CMsgClientToGCRequestEventPointLogResponse.MysteryItemReceivedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='community_goal_item', full_name='CMsgClientToGCRequestEventPointLogResponse.MysteryItemReceivedEvent.community_goal_item', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29455,
  serialized_end=29510,
)

_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_CORRECTPREDICTIONEVENT = _descriptor.Descriptor(
  name='CorrectPredictionEvent',
  full_name='CMsgClientToGCRequestEventPointLogResponse.CorrectPredictionEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prediction_id', full_name='CMsgClientToGCRequestEventPointLogResponse.CorrectPredictionEvent.prediction_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29512,
  serialized_end=29559,
)

_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_INGAMEPREDICTIONCORRECTEVENT = _descriptor.Descriptor(
  name='InGamePredictionCorrectEvent',
  full_name='CMsgClientToGCRequestEventPointLogResponse.InGamePredictionCorrectEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgClientToGCRequestEventPointLogResponse.InGamePredictionCorrectEvent.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29561,
  serialized_end=29609,
)

_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_WEEKENDTOURNEYPAYOUTEVENT = _descriptor.Descriptor(
  name='WeekendTourneyPayoutEvent',
  full_name='CMsgClientToGCRequestEventPointLogResponse.WeekendTourneyPayoutEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_gid', full_name='CMsgClientToGCRequestEventPointLogResponse.WeekendTourneyPayoutEvent.team_gid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29611,
  serialized_end=29656,
)

_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_FANTASYREWARDEVENT = _descriptor.Descriptor(
  name='FantasyRewardEvent',
  full_name='CMsgClientToGCRequestEventPointLogResponse.FantasyRewardEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='percentile', full_name='CMsgClientToGCRequestEventPointLogResponse.FantasyRewardEvent.percentile', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29658,
  serialized_end=29698,
)

_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_BRACKETREWARDEVENT = _descriptor.Descriptor(
  name='BracketRewardEvent',
  full_name='CMsgClientToGCRequestEventPointLogResponse.BracketRewardEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='correct_answers', full_name='CMsgClientToGCRequestEventPointLogResponse.BracketRewardEvent.correct_answers', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29700,
  serialized_end=29745,
)

_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION = _descriptor.Descriptor(
  name='EventPointTransaction',
  full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction.time', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_points', full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction.event_points', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='compendium_activated_event', full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction.compendium_activated_event', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='point_item_used_event', full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction.point_item_used_event', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wager_won_event', full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction.wager_won_event', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mystery_item_received_event', full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction.mystery_item_received_event', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quest_challenge_event', full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction.quest_challenge_event', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tip_given_event', full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction.tip_given_event', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tip_received_event', full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction.tip_received_event', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recycled_item_event', full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction.recycled_item_event', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='achievement_event', full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction.achievement_event', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_game_prediction_event', full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction.in_game_prediction_event', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prediction_event', full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction.prediction_event', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weekend_tourney_payout_event', full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction.weekend_tourney_payout_event', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_reward_event', full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction.fantasy_reward_event', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bracket_reward_event', full_name='CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction.bracket_reward_event', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29748,
  serialized_end=31015,
)

_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRequestEventPointLogResponse',
  full_name='CMsgClientToGCRequestEventPointLogResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientToGCRequestEventPointLogResponse.result', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='transactions', full_name='CMsgClientToGCRequestEventPointLogResponse.transactions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgClientToGCRequestEventPointLogResponse.event_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_QUESTCHALLENGEEVENT, _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_WAGERWONEVENT, _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_TIPGIVENEVENT, _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_TIPRECEIVEDEVENT, _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_RECYCLEDITEMEVENT, _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_ACHIEVEMENTEVENT, _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_MYSTERYITEMRECEIVEDEVENT, _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_CORRECTPREDICTIONEVENT, _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_INGAMEPREDICTIONCORRECTEVENT, _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_WEEKENDTOURNEYPAYOUTEVENT, _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_FANTASYREWARDEVENT, _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_BRACKETREWARDEVENT, _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28946,
  serialized_end=31015,
)


_CMSGCLIENTTOGCPUBLISHUSERSTAT = _descriptor.Descriptor(
  name='CMsgClientToGCPublishUserStat',
  full_name='CMsgClientToGCPublishUserStat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_stats_event', full_name='CMsgClientToGCPublishUserStat.user_stats_event', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reference_data', full_name='CMsgClientToGCPublishUserStat.reference_data', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31017,
  serialized_end=31098,
)


_CMSGCLIENTTOGCADDTI6TREEPROGRESS = _descriptor.Descriptor(
  name='CMsgClientToGCAddTI6TreeProgress',
  full_name='CMsgClientToGCAddTI6TreeProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trees', full_name='CMsgClientToGCAddTI6TreeProgress.trees', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31100,
  serialized_end=31149,
)


_CMSGCLIENTTOGCREDEEMREWARD = _descriptor.Descriptor(
  name='CMsgClientToGCRedeemReward',
  full_name='CMsgClientToGCRedeemReward',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgClientToGCRedeemReward.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='action_id', full_name='CMsgClientToGCRedeemReward.action_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_action_id', full_name='CMsgClientToGCRedeemReward.base_action_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31151,
  serialized_end=31240,
)


_CMSGGCTOCLIENTREDEEMREWARDRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientRedeemRewardResponse',
  full_name='CMsgGCToClientRedeemRewardResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCToClientRedeemRewardResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGGCTOCLIENTREDEEMREWARDRESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31243,
  serialized_end=31587,
)


_CMSGCLIENTTOGCREQUESTLINAPLAYSREMAINING = _descriptor.Descriptor(
  name='CMsgClientToGCRequestLinaPlaysRemaining',
  full_name='CMsgClientToGCRequestLinaPlaysRemaining',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgClientToGCRequestLinaPlaysRemaining.event_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31589,
  serialized_end=31672,
)


_CMSGCLIENTTOGCREQUESTLINAPLAYSREMAININGRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRequestLinaPlaysRemainingResponse',
  full_name='CMsgClientToGCRequestLinaPlaysRemainingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plays_remaining', full_name='CMsgClientToGCRequestLinaPlaysRemainingResponse.plays_remaining', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='plays_total', full_name='CMsgClientToGCRequestLinaPlaysRemainingResponse.plays_total', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31674,
  serialized_end=31769,
)


_CMSGCLIENTTOGCREQUESTLINAGAMERESULT = _descriptor.Descriptor(
  name='CMsgClientToGCRequestLinaGameResult',
  full_name='CMsgClientToGCRequestLinaGameResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgClientToGCRequestLinaGameResult.event_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot_chosen', full_name='CMsgClientToGCRequestLinaGameResult.slot_chosen', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31771,
  serialized_end=31871,
)


_CMSGCLIENTTOGCREQUESTLINAGAMERESULTRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRequestLinaGameResultResponse',
  full_name='CMsgClientToGCRequestLinaGameResultResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientToGCRequestLinaGameResultResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31873,
  serialized_end=31934,
)


_CMSGGCTOCLIENTQUESTPROGRESSUPDATED_CHALLENGE = _descriptor.Descriptor(
  name='Challenge',
  full_name='CMsgGCToClientQuestProgressUpdated.Challenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='challenge_id', full_name='CMsgGCToClientQuestProgressUpdated.Challenge.challenge_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_completed', full_name='CMsgGCToClientQuestProgressUpdated.Challenge.time_completed', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attempts', full_name='CMsgGCToClientQuestProgressUpdated.Challenge.attempts', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='CMsgGCToClientQuestProgressUpdated.Challenge.hero_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='challenge_type', full_name='CMsgGCToClientQuestProgressUpdated.Challenge.challenge_type', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quest_rank', full_name='CMsgGCToClientQuestProgressUpdated.Challenge.quest_rank', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24317,
  serialized_end=24453,
)

_CMSGGCTOCLIENTQUESTPROGRESSUPDATED = _descriptor.Descriptor(
  name='CMsgGCToClientQuestProgressUpdated',
  full_name='CMsgGCToClientQuestProgressUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quest_id', full_name='CMsgGCToClientQuestProgressUpdated.quest_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='completed_challenges', full_name='CMsgGCToClientQuestProgressUpdated.completed_challenges', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTQUESTPROGRESSUPDATED_CHALLENGE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31937,
  serialized_end=32207,
)


_CMSGDOTAREDEEMITEM = _descriptor.Descriptor(
  name='CMsgDOTARedeemItem',
  full_name='CMsgDOTARedeemItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currency_id', full_name='CMsgDOTARedeemItem.currency_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='purchase_def', full_name='CMsgDOTARedeemItem.purchase_def', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32209,
  serialized_end=32272,
)


_CMSGDOTAREDEEMITEMRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTARedeemItemResponse',
  full_name='CMsgDOTARedeemItemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='CMsgDOTARedeemItemResponse.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAREDEEMITEMRESPONSE_ERESULTCODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32275,
  serialized_end=32421,
)


_CMSGPERFECTWORLDUSERLOOKUPREQUEST = _descriptor.Descriptor(
  name='CMsgPerfectWorldUserLookupRequest',
  full_name='CMsgPerfectWorldUserLookupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_name', full_name='CMsgPerfectWorldUserLookupRequest.user_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32423,
  serialized_end=32477,
)


_CMSGPERFECTWORLDUSERLOOKUPRESPONSE = _descriptor.Descriptor(
  name='CMsgPerfectWorldUserLookupResponse',
  full_name='CMsgPerfectWorldUserLookupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result_code', full_name='CMsgPerfectWorldUserLookupResponse.result_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgPerfectWorldUserLookupResponse.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGPERFECTWORLDUSERLOOKUPRESPONSE_ERESULTCODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32480,
  serialized_end=32808,
)


_CMSGNEXONPARTNERUPDATE = _descriptor.Descriptor(
  name='CMsgNexonPartnerUpdate',
  full_name='CMsgNexonPartnerUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='messagetype', full_name='CMsgNexonPartnerUpdate.messagetype', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timeremaining', full_name='CMsgNexonPartnerUpdate.timeremaining', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='terminate', full_name='CMsgNexonPartnerUpdate.terminate', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32810,
  serialized_end=32897,
)


_CMSGMAKEOFFERING = _descriptor.Descriptor(
  name='CMsgMakeOffering',
  full_name='CMsgMakeOffering',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgMakeOffering.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32899,
  serialized_end=32934,
)


_CMSGREQUESTOFFERINGS = _descriptor.Descriptor(
  name='CMsgRequestOfferings',
  full_name='CMsgRequestOfferings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32936,
  serialized_end=32958,
)


_CMSGREQUESTOFFERINGSRESPONSE_NEWYEARSOFFERING = _descriptor.Descriptor(
  name='NewYearsOffering',
  full_name='CMsgRequestOfferingsResponse.NewYearsOffering',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CMsgRequestOfferingsResponse.NewYearsOffering.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgRequestOfferingsResponse.NewYearsOffering.item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33079,
  serialized_end=33133,
)

_CMSGREQUESTOFFERINGSRESPONSE = _descriptor.Descriptor(
  name='CMsgRequestOfferingsResponse',
  full_name='CMsgRequestOfferingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offerings', full_name='CMsgRequestOfferingsResponse.offerings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='completed', full_name='CMsgRequestOfferingsResponse.completed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGREQUESTOFFERINGSRESPONSE_NEWYEARSOFFERING, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32961,
  serialized_end=33133,
)


_CMSGDOTAPCBANGTIMEDREWARD = _descriptor.Descriptor(
  name='CMsgDOTAPCBangTimedReward',
  full_name='CMsgDOTAPCBangTimedReward',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='persona', full_name='CMsgDOTAPCBangTimedReward.persona', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemdef', full_name='CMsgDOTAPCBangTimedReward.itemdef', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pcbangname', full_name='CMsgDOTAPCBangTimedReward.pcbangname', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33135,
  serialized_end=33216,
)


_CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS_PREDICTIONRESULT = _descriptor.Descriptor(
  name='PredictionResult',
  full_name='CMsgDOTACompendiumInGamePredictionResults.PredictionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prediction_id', full_name='CMsgDOTACompendiumInGamePredictionResults.PredictionResult.prediction_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prediction_value', full_name='CMsgDOTACompendiumInGamePredictionResults.PredictionResult.prediction_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33389,
  serialized_end=33456,
)

_CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS = _descriptor.Descriptor(
  name='CMsgDOTACompendiumInGamePredictionResults',
  full_name='CMsgDOTACompendiumInGamePredictionResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CMsgDOTACompendiumInGamePredictionResults.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgDOTACompendiumInGamePredictionResults.league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='predictions_closed', full_name='CMsgDOTACompendiumInGamePredictionResults.predictions_closed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS_PREDICTIONRESULT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33219,
  serialized_end=33456,
)


_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION_PREDICTION = _descriptor.Descriptor(
  name='Prediction',
  full_name='CMsgClientToGCSelectCompendiumInGamePrediction.Prediction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prediction_id', full_name='CMsgClientToGCSelectCompendiumInGamePrediction.Prediction.prediction_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prediction_value', full_name='CMsgClientToGCSelectCompendiumInGamePrediction.Prediction.prediction_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33608,
  serialized_end=33669,
)

_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION = _descriptor.Descriptor(
  name='CMsgClientToGCSelectCompendiumInGamePrediction',
  full_name='CMsgClientToGCSelectCompendiumInGamePrediction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgClientToGCSelectCompendiumInGamePrediction.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='predictions', full_name='CMsgClientToGCSelectCompendiumInGamePrediction.predictions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION_PREDICTION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33459,
  serialized_end=33669,
)


_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCSelectCompendiumInGamePredictionResponse',
  full_name='CMsgClientToGCSelectCompendiumInGamePredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientToGCSelectCompendiumInGamePredictionResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33672,
  serialized_end=33906,
)


_CMSGCLIENTTOGCOPENPLAYERCARDPACK = _descriptor.Descriptor(
  name='CMsgClientToGCOpenPlayerCardPack',
  full_name='CMsgClientToGCOpenPlayerCardPack',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_card_pack_item_id', full_name='CMsgClientToGCOpenPlayerCardPack.player_card_pack_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33908,
  serialized_end=33976,
)


_CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCOpenPlayerCardPackResponse',
  full_name='CMsgClientToGCOpenPlayerCardPackResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientToGCOpenPlayerCardPackResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_card_item_ids', full_name='CMsgClientToGCOpenPlayerCardPackResponse.player_card_item_ids', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33979,
  serialized_end=34261,
)


_CMSGCLIENTTOGCRECYCLEPLAYERCARD = _descriptor.Descriptor(
  name='CMsgClientToGCRecyclePlayerCard',
  full_name='CMsgClientToGCRecyclePlayerCard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_card_item_id', full_name='CMsgClientToGCRecyclePlayerCard.player_card_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34263,
  serialized_end=34325,
)


_CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRecyclePlayerCardResponse',
  full_name='CMsgClientToGCRecyclePlayerCardResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientToGCRecyclePlayerCardResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dust_amount', full_name='CMsgClientToGCRecyclePlayerCardResponse.dust_amount', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34328,
  serialized_end=34636,
)


_CMSGCLIENTTOGCCREATEPLAYERCARDPACK = _descriptor.Descriptor(
  name='CMsgClientToGCCreatePlayerCardPack',
  full_name='CMsgClientToGCCreatePlayerCardPack',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='card_dust_item_id', full_name='CMsgClientToGCCreatePlayerCardPack.card_dust_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34638,
  serialized_end=34701,
)


_CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCCreatePlayerCardPackResponse',
  full_name='CMsgClientToGCCreatePlayerCardPackResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientToGCCreatePlayerCardPackResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34704,
  serialized_end=34963,
)


_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_QUESTLINES = _descriptor.Descriptor(
  name='Questlines',
  full_name='CMsgGCToClientBattlePassRollup_International2016.Questlines',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgGCToClientBattlePassRollup_International2016.Questlines.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='onestar', full_name='CMsgGCToClientBattlePassRollup_International2016.Questlines.onestar', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='twostar', full_name='CMsgGCToClientBattlePassRollup_International2016.Questlines.twostar', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='threestar', full_name='CMsgGCToClientBattlePassRollup_International2016.Questlines.threestar', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total', full_name='CMsgGCToClientBattlePassRollup_International2016.Questlines.total', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35711,
  serialized_end=35805,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_WAGERING = _descriptor.Descriptor(
  name='Wagering',
  full_name='CMsgGCToClientBattlePassRollup_International2016.Wagering',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_wagered', full_name='CMsgGCToClientBattlePassRollup_International2016.Wagering.total_wagered', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_won', full_name='CMsgGCToClientBattlePassRollup_International2016.Wagering.total_won', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='average_won', full_name='CMsgGCToClientBattlePassRollup_International2016.Wagering.average_won', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='success_rate', full_name='CMsgGCToClientBattlePassRollup_International2016.Wagering.success_rate', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_tips', full_name='CMsgGCToClientBattlePassRollup_International2016.Wagering.total_tips', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35807,
  serialized_end=35922,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_ACHIEVEMENTS = _descriptor.Descriptor(
  name='Achievements',
  full_name='CMsgGCToClientBattlePassRollup_International2016.Achievements',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='completed', full_name='CMsgGCToClientBattlePassRollup_International2016.Achievements.completed', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total', full_name='CMsgGCToClientBattlePassRollup_International2016.Achievements.total', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='points', full_name='CMsgGCToClientBattlePassRollup_International2016.Achievements.points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35924,
  serialized_end=35988,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BATTLECUP = _descriptor.Descriptor(
  name='BattleCup',
  full_name='CMsgGCToClientBattlePassRollup_International2016.BattleCup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wins', full_name='CMsgGCToClientBattlePassRollup_International2016.BattleCup.wins', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgGCToClientBattlePassRollup_International2016.BattleCup.score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35990,
  serialized_end=36030,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PREDICTIONS = _descriptor.Descriptor(
  name='Predictions',
  full_name='CMsgGCToClientBattlePassRollup_International2016.Predictions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='correct', full_name='CMsgGCToClientBattlePassRollup_International2016.Predictions.correct', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total', full_name='CMsgGCToClientBattlePassRollup_International2016.Predictions.total', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='points', full_name='CMsgGCToClientBattlePassRollup_International2016.Predictions.points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36032,
  serialized_end=36093,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BRACKET = _descriptor.Descriptor(
  name='Bracket',
  full_name='CMsgGCToClientBattlePassRollup_International2016.Bracket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='correct', full_name='CMsgGCToClientBattlePassRollup_International2016.Bracket.correct', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='points', full_name='CMsgGCToClientBattlePassRollup_International2016.Bracket.points', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36095,
  serialized_end=36137,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PLAYERCARD = _descriptor.Descriptor(
  name='PlayerCard',
  full_name='CMsgGCToClientBattlePassRollup_International2016.PlayerCard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCToClientBattlePassRollup_International2016.PlayerCard.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality', full_name='CMsgGCToClientBattlePassRollup_International2016.PlayerCard.quality', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36139,
  serialized_end=36188,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_FANTASYCHALLENGE = _descriptor.Descriptor(
  name='FantasyChallenge',
  full_name='CMsgGCToClientBattlePassRollup_International2016.FantasyChallenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_score', full_name='CMsgGCToClientBattlePassRollup_International2016.FantasyChallenge.total_score', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile', full_name='CMsgGCToClientBattlePassRollup_International2016.FantasyChallenge.percentile', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36190,
  serialized_end=36249,
)

_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016 = _descriptor.Descriptor(
  name='CMsgGCToClientBattlePassRollup_International2016',
  full_name='CMsgGCToClientBattlePassRollup_International2016',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='battle_pass_level', full_name='CMsgGCToClientBattlePassRollup_International2016.battle_pass_level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='questlines', full_name='CMsgGCToClientBattlePassRollup_International2016.questlines', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wagering', full_name='CMsgGCToClientBattlePassRollup_International2016.wagering', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='achievements', full_name='CMsgGCToClientBattlePassRollup_International2016.achievements', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='battle_cup', full_name='CMsgGCToClientBattlePassRollup_International2016.battle_cup', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='predictions', full_name='CMsgGCToClientBattlePassRollup_International2016.predictions', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bracket', full_name='CMsgGCToClientBattlePassRollup_International2016.bracket', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_cards', full_name='CMsgGCToClientBattlePassRollup_International2016.player_cards', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_challenge', full_name='CMsgGCToClientBattlePassRollup_International2016.fantasy_challenge', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_QUESTLINES, _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_WAGERING, _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_ACHIEVEMENTS, _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BATTLECUP, _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PREDICTIONS, _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BRACKET, _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PLAYERCARD, _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_FANTASYCHALLENGE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34966,
  serialized_end=36249,
)


_CMSGGCTOCLIENTBATTLEPASSROLLUPREQUEST = _descriptor.Descriptor(
  name='CMsgGCToClientBattlePassRollupRequest',
  full_name='CMsgGCToClientBattlePassRollupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgGCToClientBattlePassRollupRequest.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCToClientBattlePassRollupRequest.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36251,
  serialized_end=36328,
)


_CMSGGCTOCLIENTBATTLEPASSROLLUPRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientBattlePassRollupResponse',
  full_name='CMsgGCToClientBattlePassRollupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_ti6', full_name='CMsgGCToClientBattlePassRollupResponse.event_ti6', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36330,
  serialized_end=36440,
)


_CMSGGCTOCLIENTBATTLEPASSROLLUPLISTREQUEST = _descriptor.Descriptor(
  name='CMsgGCToClientBattlePassRollupListRequest',
  full_name='CMsgGCToClientBattlePassRollupListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCToClientBattlePassRollupListRequest.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36442,
  serialized_end=36505,
)


_CMSGGCTOCLIENTBATTLEPASSROLLUPLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientBattlePassRollupListResponse',
  full_name='CMsgGCToClientBattlePassRollupListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CMsgGCToClientBattlePassRollupListResponse.event_id', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36507,
  serialized_end=36569,
)


_CMSGCLIENTTOGCTRANSFERSEASONALMMRREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCTransferSeasonalMMRRequest',
  full_name='CMsgClientToGCTransferSeasonalMMRRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_party', full_name='CMsgClientToGCTransferSeasonalMMRRequest.is_party', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36571,
  serialized_end=36631,
)


_CMSGCLIENTTOGCTRANSFERSEASONALMMRRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCTransferSeasonalMMRResponse',
  full_name='CMsgClientToGCTransferSeasonalMMRResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CMsgClientToGCTransferSeasonalMMRResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36633,
  serialized_end=36693,
)


_CMSGDOTAEVENTINVITE_TEAM = _descriptor.Descriptor(
  name='Team',
  full_name='CMsgDOTAEventInvite.Team',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTAEventInvite.Team.team_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='announcement_date', full_name='CMsgDOTAEventInvite.Team.announcement_date', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgDOTAEventInvite.Team.team_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invite_type', full_name='CMsgDOTAEventInvite.Team.invite_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36761,
  serialized_end=36851,
)

_CMSGDOTAEVENTINVITE = _descriptor.Descriptor(
  name='CMsgDOTAEventInvite',
  full_name='CMsgDOTAEventInvite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='teams', full_name='CMsgDOTAEventInvite.teams', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAEVENTINVITE_TEAM, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36696,
  serialized_end=36851,
)


_CMSGDOTASETFAVORITETEAM = _descriptor.Descriptor(
  name='CMsgDOTASetFavoriteTeam',
  full_name='CMsgDOTASetFavoriteTeam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgDOTASetFavoriteTeam.team_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36853,
  serialized_end=36895,
)

_CMSGDOTAREQUESTMATCHES.fields_by_name['skill'].enum_type = _CMSGDOTAREQUESTMATCHES_SKILLLEVEL
_CMSGDOTAREQUESTMATCHES_SKILLLEVEL.containing_type = _CMSGDOTAREQUESTMATCHES
_CMSGDOTAREQUESTMATCHESRESPONSE_SERIES.fields_by_name['matches'].message_type = dota__gcmessages__common__pb2._CMSGDOTAMATCH
_CMSGDOTAREQUESTMATCHESRESPONSE_SERIES.containing_type = _CMSGDOTAREQUESTMATCHESRESPONSE
_CMSGDOTAREQUESTMATCHESRESPONSE.fields_by_name['matches'].message_type = dota__gcmessages__common__pb2._CMSGDOTAMATCH
_CMSGDOTAREQUESTMATCHESRESPONSE.fields_by_name['series'].message_type = _CMSGDOTAREQUESTMATCHESRESPONSE_SERIES
_CMSGDOTAPOPUP.fields_by_name['id'].enum_type = _CMSGDOTAPOPUP_POPUPID
_CMSGDOTAPOPUP_POPUPID.containing_type = _CMSGDOTAPOPUP
_CMSGDOTAKICKEDFROMMATCHMAKINGQUEUE.fields_by_name['match_type'].enum_type = dota__shared__enums__pb2._MATCHTYPE
_CMSGDOTAREQUESTSAVEGAMESRESPONSE.fields_by_name['save_games'].message_type = dota__shared__enums__pb2._CDOTASAVEGAME
_CMSGGCMATCHDETAILSRESPONSE.fields_by_name['match'].message_type = dota__gcmessages__common__pb2._CMSGDOTAMATCH
_CMSGGCMATCHDETAILSRESPONSE.fields_by_name['vote'].enum_type = dota__shared__enums__pb2._DOTAMATCHVOTE
_CMSGGCTOSERVERMATCHDETAILSRESPONSE.fields_by_name['matches'].message_type = dota__gcmessages__common__pb2._CMSGDOTAMATCH
_CMSGDOTAPROFILEREQUEST.fields_by_name['engine'].enum_type = gcsdk__gcmessages__pb2._ESOURCEENGINE
_CMSGDOTAPROFILERESPONSE_PLAYEDHERO.containing_type = _CMSGDOTAPROFILERESPONSE
_CMSGDOTAPROFILERESPONSE_SHOWCASEHERO.containing_type = _CMSGDOTAPROFILERESPONSE
_CMSGDOTAPROFILERESPONSE_LEAGUEPASS.containing_type = _CMSGDOTAPROFILERESPONSE
_CMSGDOTAPROFILERESPONSE_EVENTTICKET.containing_type = _CMSGDOTAPROFILERESPONSE
_CMSGDOTAPROFILERESPONSE_FEATUREDITEM.containing_type = _CMSGDOTAPROFILERESPONSE
_CMSGDOTAPROFILERESPONSE.fields_by_name['game_account_client'].message_type = dota__gcmessages__common__pb2._CSODOTAGAMEACCOUNTCLIENT
_CMSGDOTAPROFILERESPONSE.fields_by_name['latest_matches'].message_type = dota__gcmessages__common__pb2._CMSGDOTAMATCH
_CMSGDOTAPROFILERESPONSE.fields_by_name['heroes'].message_type = _CMSGDOTAPROFILERESPONSE_PLAYEDHERO
_CMSGDOTAPROFILERESPONSE.fields_by_name['showcase_hero'].message_type = _CMSGDOTAPROFILERESPONSE_SHOWCASEHERO
_CMSGDOTAPROFILERESPONSE.fields_by_name['league_passes'].message_type = _CMSGDOTAPROFILERESPONSE_LEAGUEPASS
_CMSGDOTAPROFILERESPONSE.fields_by_name['event_tickets'].message_type = _CMSGDOTAPROFILERESPONSE_EVENTTICKET
_CMSGDOTAPROFILERESPONSE.fields_by_name['featured_items'].message_type = _CMSGDOTAPROFILERESPONSE_FEATUREDITEM
_CMSGDOTAPROFILETICKETS_LEAGUEPASS.containing_type = _CMSGDOTAPROFILETICKETS
_CMSGDOTAPROFILETICKETS_EVENTTICKET.containing_type = _CMSGDOTAPROFILETICKETS
_CMSGDOTAPROFILETICKETS.fields_by_name['league_passes'].message_type = _CMSGDOTAPROFILETICKETS_LEAGUEPASS
_CMSGDOTAPROFILETICKETS.fields_by_name['event_tickets'].message_type = _CMSGDOTAPROFILETICKETS_EVENTTICKET
_CMSGDOTAWELCOME_LOCALIZATIONDIGEST.fields_by_name['english_language_file_sha1'].message_type = gcsdk__gcmessages__pb2._CMSGSHA1DIGEST
_CMSGDOTAWELCOME_LOCALIZATIONDIGEST.fields_by_name['client_language_file_sha1'].message_type = gcsdk__gcmessages__pb2._CMSGSHA1DIGEST
_CMSGDOTAWELCOME_LOCALIZATIONDIGEST.containing_type = _CMSGDOTAWELCOME
_CMSGDOTAWELCOME_CEXTRAMSG.containing_type = _CMSGDOTAWELCOME
_CMSGDOTAWELCOME.fields_by_name['partner_account_type'].enum_type = gcsdk__gcmessages__pb2._PARTNERACCOUNTTYPE
_CMSGDOTAWELCOME.fields_by_name['localization_digests'].message_type = _CMSGDOTAWELCOME_LOCALIZATIONDIGEST
_CMSGDOTAWELCOME.fields_by_name['active_events'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGDOTAWELCOME.fields_by_name['extra_messages'].message_type = _CMSGDOTAWELCOME_CEXTRAMSG
_CLEAGUEDATA.fields_by_name['dynamic_data'].message_type = _CDYNAMICLEAGUEDATA
_CLEAGUEDATA.fields_by_name['static_data'].message_type = _CSTATICLEAGUEDATA
_CMSGRESPONSELEAGUEINFO.fields_by_name['leagues'].message_type = _CDYNAMICLEAGUEDATA
_CMSGDOTAMATCHVOTES_PLAYERVOTE.containing_type = _CMSGDOTAMATCHVOTES
_CMSGDOTAMATCHVOTES.fields_by_name['votes'].message_type = _CMSGDOTAMATCHVOTES_PLAYERVOTE
_CMSGCASTMATCHVOTE.fields_by_name['vote'].enum_type = dota__shared__enums__pb2._DOTAMATCHVOTE
_CMSGMATCHVOTERESPONSE.fields_by_name['vote'].enum_type = dota__shared__enums__pb2._DOTAMATCHVOTE
_CMSGDOTAHALLOFFAME_FEATUREDPLAYER.containing_type = _CMSGDOTAHALLOFFAME
_CMSGDOTAHALLOFFAME_FEATUREDFARMER.containing_type = _CMSGDOTAHALLOFFAME
_CMSGDOTAHALLOFFAME.fields_by_name['featured_players'].message_type = _CMSGDOTAHALLOFFAME_FEATUREDPLAYER
_CMSGDOTAHALLOFFAME.fields_by_name['featured_farmer'].message_type = _CMSGDOTAHALLOFFAME_FEATUREDFARMER
_CMSGDOTAHALLOFFAMERESPONSE.fields_by_name['hall_of_fame'].message_type = _CMSGDOTAHALLOFFAME
_CMSGDOTAHALLOWEENHIGHSCORERESPONSE.fields_by_name['match'].message_type = dota__gcmessages__common__pb2._CMSGDOTAMATCH
_CMSGDOTASTOREPROMOPAGESRESPONSE_PROMOPAGE.containing_type = _CMSGDOTASTOREPROMOPAGESRESPONSE
_CMSGDOTASTOREPROMOPAGESRESPONSE.fields_by_name['pages'].message_type = _CMSGDOTASTOREPROMOPAGESRESPONSE_PROMOPAGE
_CMSGLEAGUESCHEDULEBLOCK.fields_by_name['teams'].message_type = _CMSGLEAGUESCHEDULEBLOCKTEAMINFO
_CMSGDOTALEAGUE.fields_by_name['schedule'].message_type = _CMSGLEAGUESCHEDULEBLOCK
_CMSGDOTALEAGUESCHEDULERESPONSE.fields_by_name['league'].message_type = _CMSGDOTALEAGUE
_CMSGDOTALEAGUESCHEDULEEDIT.fields_by_name['schedule'].message_type = _CMSGLEAGUESCHEDULEBLOCK
_CMSGDOTALEAGUESCHEDULEEDITRESPONSE.fields_by_name['league'].message_type = _CMSGDOTALEAGUE
_CMSGDOTALEAGUESINMONTHRESPONSE.fields_by_name['leagues'].message_type = _CMSGDOTALEAGUE
_CMSGMATCHMAKINGMATCHGROUPINFO.fields_by_name['status'].enum_type = dota__shared__enums__pb2._EMATCHGROUPSERVERSTATUS
_CMSGDOTAMATCHMAKINGSTATSRESPONSE.fields_by_name['match_groups'].message_type = _CMSGMATCHMAKINGMATCHGROUPINFO
_CMSGDOTAUPDATEMATCHMAKINGSTATS.fields_by_name['stats'].message_type = _CMSGDOTAMATCHMAKINGSTATSRESPONSE
_CMSGDOTAUPDATEMATCHMANAGEMENTSTATS.fields_by_name['stats'].message_type = _CMSGDOTAMATCHMAKINGSTATSRESPONSE
_CMSGGCWATCHDOWNLOADEDREPLAY.fields_by_name['watch_type'].enum_type = _DOTA_WATCHREPLAYTYPE
_CMSGDOTAFRIENDRECRUITSRESPONSE_FRIENDRECRUITSTATUS.containing_type = _CMSGDOTAFRIENDRECRUITSRESPONSE
_CMSGDOTAFRIENDRECRUITSRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFRIENDRECRUITSRESPONSE_ERESULT
_CMSGDOTAFRIENDRECRUITSRESPONSE.fields_by_name['recruits'].message_type = _CMSGDOTAFRIENDRECRUITSRESPONSE_FRIENDRECRUITSTATUS
_CMSGDOTAFRIENDRECRUITSRESPONSE.fields_by_name['recruiters'].message_type = _CMSGDOTAFRIENDRECRUITSRESPONSE_FRIENDRECRUITSTATUS
_CMSGDOTAFRIENDRECRUITSRESPONSE_ERESULT.containing_type = _CMSGDOTAFRIENDRECRUITSRESPONSE
_CMSGGCGETHEROSTANDINGSRESPONSE_HERO.containing_type = _CMSGGCGETHEROSTANDINGSRESPONSE
_CMSGGCGETHEROSTANDINGSRESPONSE.fields_by_name['standings'].message_type = _CMSGGCGETHEROSTANDINGSRESPONSE_HERO
_CMSGGCITEMEDITORRESERVATIONSRESPONSE.fields_by_name['reservations'].message_type = _CMSGGCITEMEDITORRESERVATION
_CMSGDOTAREDEEMEVENTPRIZERESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAREDEEMEVENTPRIZERESPONSE_RESULTCODE
_CMSGDOTAREDEEMEVENTPRIZERESPONSE_RESULTCODE.containing_type = _CMSGDOTAREDEEMEVENTPRIZERESPONSE
_CMSGDOTAGETEVENTPOINTSRESPONSE_ACTION.containing_type = _CMSGDOTAGETEVENTPOINTSRESPONSE
_CMSGDOTAGETEVENTPOINTSRESPONSE.fields_by_name['completed_actions'].message_type = _CMSGDOTAGETEVENTPOINTSRESPONSE_ACTION
_CMSGDOTACOMPENDIUMSELECTIONRESPONSE.fields_by_name['extra_selections'].message_type = _CMSGDOTACOMPENDIUMSELECTION
_CMSGDOTACOMPENDIUMDATA.fields_by_name['selections'].message_type = _CMSGDOTACOMPENDIUMSELECTION
_CMSGDOTACOMPENDIUMDATARESPONSE.fields_by_name['compendium_data'].message_type = _CMSGDOTACOMPENDIUMDATA
_CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE_MATCH.containing_type = _CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE
_CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE.fields_by_name['matches'].message_type = _CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE_MATCH
_CMSGGCNOTIFICATIONSRESPONSE_NOTIFICATION.containing_type = _CMSGGCNOTIFICATIONSRESPONSE
_CMSGGCNOTIFICATIONSRESPONSE.fields_by_name['result'].enum_type = _CMSGGCNOTIFICATIONSRESPONSE_ERESULT
_CMSGGCNOTIFICATIONSRESPONSE.fields_by_name['notifications'].message_type = _CMSGGCNOTIFICATIONSRESPONSE_NOTIFICATION
_CMSGGCNOTIFICATIONSRESPONSE_ERESULT.containing_type = _CMSGGCNOTIFICATIONSRESPONSE
_CMSGGCLEAGUEADMINSTATE_PRIVATELEAGUEKEYS.containing_type = _CMSGGCLEAGUEADMINSTATE
_CMSGGCLEAGUEADMINSTATE.fields_by_name['keys'].message_type = _CMSGGCLEAGUEADMINSTATE_PRIVATELEAGUEKEYS
_CMSGGCPLAYERINFOREQUEST_PLAYERINFO.containing_type = _CMSGGCPLAYERINFOREQUEST
_CMSGGCPLAYERINFOREQUEST.fields_by_name['player_infos'].message_type = _CMSGGCPLAYERINFOREQUEST_PLAYERINFO
_CMSGGCPLAYERINFOSUBMITRESPONSE.fields_by_name['result'].enum_type = _CMSGGCPLAYERINFOSUBMITRESPONSE_ERESULT
_CMSGGCPLAYERINFOSUBMITRESPONSE_ERESULT.containing_type = _CMSGGCPLAYERINFOSUBMITRESPONSE
_CMSGCLIENTPROVIDESURVEYRESULT_RESPONSE.containing_type = _CMSGCLIENTPROVIDESURVEYRESULT
_CMSGCLIENTPROVIDESURVEYRESULT.fields_by_name['responses'].message_type = _CMSGCLIENTPROVIDESURVEYRESULT_RESPONSE
_CMSGGCTOCLIENTEMOTICONDATA.fields_by_name['emoticon_access'].message_type = _CMSGDOTAEMOTICONACCESSSDO
_CMSGCLIENTTOGCSETADDITIONALEQUIPS.fields_by_name['equips'].message_type = dota__gcmessages__common__pb2._CADDITIONALEQUIPSLOT
_CMSGCLIENTTOGCGETADDITIONALEQUIPSRESPONSE.fields_by_name['equips'].message_type = dota__gcmessages__common__pb2._CADDITIONALEQUIPSLOT
_CMSGCLIENTTOGCGETTROPHYLISTRESPONSE_TROPHY.containing_type = _CMSGCLIENTTOGCGETTROPHYLISTRESPONSE
_CMSGCLIENTTOGCGETTROPHYLISTRESPONSE.fields_by_name['trophies'].message_type = _CMSGCLIENTTOGCGETTROPHYLISTRESPONSE_TROPHY
_CMSGCLIENTTOGCSETPROFILECARDSLOTS_CARDSLOT.fields_by_name['slot_type'].enum_type = dota__shared__enums__pb2._EPROFILECARDSLOTTYPE
_CMSGCLIENTTOGCSETPROFILECARDSLOTS_CARDSLOT.containing_type = _CMSGCLIENTTOGCSETPROFILECARDSLOTS
_CMSGCLIENTTOGCSETPROFILECARDSLOTS.fields_by_name['slots'].message_type = _CMSGCLIENTTOGCSETPROFILECARDSLOTS_CARDSLOT
_CMSGGCTOCLIENTEVENTSTATUSCHANGED.fields_by_name['active_events'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE_CUSTOMGAME.containing_type = _CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE
_CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE.fields_by_name['games'].message_type = _CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE_CUSTOMGAME
_CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_DATAFIELD.fields_by_name['data_type'].enum_type = _EFEATUREDHERODATATYPE
_CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_DATAFIELD.containing_type = _CMSGGCTOCLIENTFEATUREDHEROESRESPONSE
_CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_FEATUREDHERO.fields_by_name['data_fields'].message_type = _CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_DATAFIELD
_CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_FEATUREDHERO.containing_type = _CMSGGCTOCLIENTFEATUREDHEROESRESPONSE
_CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_CATEGORY.fields_by_name['text_fields'].enum_type = _EFEATUREDHEROTEXTFIELD
_CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_CATEGORY.fields_by_name['featured_heroes'].message_type = _CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_FEATUREDHERO
_CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_CATEGORY.containing_type = _CMSGGCTOCLIENTFEATUREDHEROESRESPONSE
_CMSGGCTOCLIENTFEATUREDHEROESRESPONSE.fields_by_name['categories'].message_type = _CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_CATEGORY
_CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE_COMMENT.containing_type = _CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE
_CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE.fields_by_name['comments'].message_type = _CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE_COMMENT
_CMSGDOTAPARTYRICHPRESENCE_MEMBER.containing_type = _CMSGDOTAPARTYRICHPRESENCE
_CMSGDOTAPARTYRICHPRESENCE_WEEKENDTOURNEY.fields_by_name['event'].enum_type = _EWEEKENDTOURNEYRICHPRESENCEEVENT
_CMSGDOTAPARTYRICHPRESENCE_WEEKENDTOURNEY.containing_type = _CMSGDOTAPARTYRICHPRESENCE
_CMSGDOTAPARTYRICHPRESENCE.fields_by_name['party_state'].enum_type = dota__gcmessages__common__match__management__pb2._CSODOTAPARTY_STATE
_CMSGDOTAPARTYRICHPRESENCE.fields_by_name['members'].message_type = _CMSGDOTAPARTYRICHPRESENCE_MEMBER
_CMSGDOTAPARTYRICHPRESENCE.fields_by_name['weekend_tourney'].message_type = _CMSGDOTAPARTYRICHPRESENCE_WEEKENDTOURNEY
_CMSGDOTALOBBYRICHPRESENCE.fields_by_name['lobby_state'].enum_type = dota__gcmessages__common__match__management__pb2._CSODOTALOBBY_STATE
_CMSGDOTALOBBYRICHPRESENCE.fields_by_name['game_mode'].enum_type = dota__shared__enums__pb2._DOTA_GAMEMODE
_CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE_SERIES_TEAM.containing_type = _CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE_SERIES
_CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE_SERIES.fields_by_name['teams'].message_type = _CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE_SERIES_TEAM
_CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE_SERIES.containing_type = _CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE
_CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE.fields_by_name['series'].message_type = _CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE_SERIES
_CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_CHALLENGE.containing_type = _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE
_CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_QUEST.fields_by_name['completed_challenges'].message_type = _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_CHALLENGE
_CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_QUEST.containing_type = _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE
_CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE.fields_by_name['quests'].message_type = _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_QUEST
_CMSGGCGETHEROSTATSHISTORYRESPONSE.fields_by_name['records'].message_type = dota__gcmessages__common__pb2._CMSGDOTASDOHEROSTATSHISTORY
_CMSGGCTOCLIENTWAGERINGUPDATE.fields_by_name['wagering_info'].message_type = _CMSGGCTOCLIENTWAGERINGRESPONSE
_CMSGGCTOCLIENTARCANAVOTESUPDATE.fields_by_name['arcana_votes'].message_type = _CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE
_CMSGGCTOCLIENTMYSTERYITEMRESPONSE.fields_by_name['result'].enum_type = _CMSGGCTOCLIENTMYSTERYITEMRESPONSE_RESULT
_CMSGGCTOCLIENTMYSTERYITEMRESPONSE_RESULT.containing_type = _CMSGGCTOCLIENTMYSTERYITEMRESPONSE
_CMSGCLIENTTOGCGETEVENTGOALS.fields_by_name['event_ids'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGEVENTGOALS_EVENTGOAL.fields_by_name['event_id'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGEVENTGOALS_EVENTGOAL.containing_type = _CMSGEVENTGOALS
_CMSGEVENTGOALS.fields_by_name['event_goals'].message_type = _CMSGEVENTGOALS_EVENTGOAL
_CMSGPREDICTIONRANKINGS_PREDICTIONLINE.containing_type = _CMSGPREDICTIONRANKINGS
_CMSGPREDICTIONRANKINGS_PREDICTION.fields_by_name['prediction_lines'].message_type = _CMSGPREDICTIONRANKINGS_PREDICTIONLINE
_CMSGPREDICTIONRANKINGS_PREDICTION.containing_type = _CMSGPREDICTIONRANKINGS
_CMSGPREDICTIONRANKINGS.fields_by_name['predictions'].message_type = _CMSGPREDICTIONRANKINGS_PREDICTION
_CMSGPREDICTIONRESULTS_RESULTBREAKDOWN.containing_type = _CMSGPREDICTIONRESULTS
_CMSGPREDICTIONRESULTS_RESULT.fields_by_name['result_breakdown'].message_type = _CMSGPREDICTIONRESULTS_RESULTBREAKDOWN
_CMSGPREDICTIONRESULTS_RESULT.containing_type = _CMSGPREDICTIONRESULTS
_CMSGPREDICTIONRESULTS.fields_by_name['results'].message_type = _CMSGPREDICTIONRESULTS_RESULT
_CMSGMVPVOTESFORMATCH_PLAYER.containing_type = _CMSGMVPVOTESFORMATCH
_CMSGMVPVOTESFORMATCH.fields_by_name['players'].message_type = _CMSGMVPVOTESFORMATCH_PLAYER
_CMSGCLIENTTOGCTEAMMATESTATSRESPONSE_TEAMMATESTAT.containing_type = _CMSGCLIENTTOGCTEAMMATESTATSRESPONSE
_CMSGCLIENTTOGCTEAMMATESTATSRESPONSE.fields_by_name['teammate_stats'].message_type = _CMSGCLIENTTOGCTEAMMATESTATSRESPONSE_TEAMMATESTAT
_CMSGCLIENTTOGCVOTEFORARCANA_MATCHVOTE.containing_type = _CMSGCLIENTTOGCVOTEFORARCANA
_CMSGCLIENTTOGCVOTEFORARCANA.fields_by_name['matches'].message_type = _CMSGCLIENTTOGCVOTEFORARCANA_MATCHVOTE
_CMSGCLIENTTOGCVOTEFORARCANARESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCVOTEFORARCANARESPONSE_RESULT
_CMSGCLIENTTOGCVOTEFORARCANARESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCVOTEFORARCANARESPONSE
_CMSGARCANAVOTES_MATCH.containing_type = _CMSGARCANAVOTES
_CMSGARCANAVOTES.fields_by_name['matches'].message_type = _CMSGARCANAVOTES_MATCH
_CMSGARCANAVOTES_VOTINGSTATE.containing_type = _CMSGARCANAVOTES
_CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE_MATCHVOTE.containing_type = _CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE
_CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE.fields_by_name['matches_previously_voted_for'].message_type = _CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE_MATCHVOTE
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_QUESTCHALLENGEEVENT.containing_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_WAGERWONEVENT.containing_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_TIPGIVENEVENT.containing_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_TIPRECEIVEDEVENT.containing_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_RECYCLEDITEMEVENT.containing_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_ACHIEVEMENTEVENT.containing_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_MYSTERYITEMRECEIVEDEVENT.containing_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_CORRECTPREDICTIONEVENT.containing_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_INGAMEPREDICTIONCORRECTEVENT.containing_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_WEEKENDTOURNEYPAYOUTEVENT.containing_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_FANTASYREWARDEVENT.containing_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_BRACKETREWARDEVENT.containing_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION.fields_by_name['wager_won_event'].message_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_WAGERWONEVENT
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION.fields_by_name['mystery_item_received_event'].message_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_MYSTERYITEMRECEIVEDEVENT
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION.fields_by_name['quest_challenge_event'].message_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_QUESTCHALLENGEEVENT
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION.fields_by_name['tip_given_event'].message_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_TIPGIVENEVENT
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION.fields_by_name['tip_received_event'].message_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_TIPRECEIVEDEVENT
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION.fields_by_name['recycled_item_event'].message_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_RECYCLEDITEMEVENT
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION.fields_by_name['achievement_event'].message_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_ACHIEVEMENTEVENT
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION.fields_by_name['in_game_prediction_event'].message_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_INGAMEPREDICTIONCORRECTEVENT
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION.fields_by_name['prediction_event'].message_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_CORRECTPREDICTIONEVENT
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION.fields_by_name['weekend_tourney_payout_event'].message_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_WEEKENDTOURNEYPAYOUTEVENT
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION.fields_by_name['fantasy_reward_event'].message_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_FANTASYREWARDEVENT
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION.fields_by_name['bracket_reward_event'].message_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_BRACKETREWARDEVENT
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION.containing_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE
_CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE.fields_by_name['transactions'].message_type = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION
_CMSGGCTOCLIENTREDEEMREWARDRESPONSE.fields_by_name['result'].enum_type = _CMSGGCTOCLIENTREDEEMREWARDRESPONSE_RESULT
_CMSGGCTOCLIENTREDEEMREWARDRESPONSE_RESULT.containing_type = _CMSGGCTOCLIENTREDEEMREWARDRESPONSE
_CMSGCLIENTTOGCREQUESTLINAPLAYSREMAINING.fields_by_name['event_id'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGCLIENTTOGCREQUESTLINAGAMERESULT.fields_by_name['event_id'].enum_type = dota__shared__enums__pb2._EEVENT
_CMSGGCTOCLIENTQUESTPROGRESSUPDATED_CHALLENGE.containing_type = _CMSGGCTOCLIENTQUESTPROGRESSUPDATED
_CMSGGCTOCLIENTQUESTPROGRESSUPDATED.fields_by_name['completed_challenges'].message_type = _CMSGGCTOCLIENTQUESTPROGRESSUPDATED_CHALLENGE
_CMSGDOTAREDEEMITEMRESPONSE.fields_by_name['response'].enum_type = _CMSGDOTAREDEEMITEMRESPONSE_ERESULTCODE
_CMSGDOTAREDEEMITEMRESPONSE_ERESULTCODE.containing_type = _CMSGDOTAREDEEMITEMRESPONSE
_CMSGPERFECTWORLDUSERLOOKUPRESPONSE.fields_by_name['result_code'].enum_type = _CMSGPERFECTWORLDUSERLOOKUPRESPONSE_ERESULTCODE
_CMSGPERFECTWORLDUSERLOOKUPRESPONSE_ERESULTCODE.containing_type = _CMSGPERFECTWORLDUSERLOOKUPRESPONSE
_CMSGREQUESTOFFERINGSRESPONSE_NEWYEARSOFFERING.containing_type = _CMSGREQUESTOFFERINGSRESPONSE
_CMSGREQUESTOFFERINGSRESPONSE.fields_by_name['offerings'].message_type = _CMSGREQUESTOFFERINGSRESPONSE_NEWYEARSOFFERING
_CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS_PREDICTIONRESULT.containing_type = _CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS
_CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS.fields_by_name['results'].message_type = _CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS_PREDICTIONRESULT
_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION_PREDICTION.containing_type = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION
_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION.fields_by_name['predictions'].message_type = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION_PREDICTION
_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE_ERESULT
_CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE_ERESULT.containing_type = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE
_CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE_RESULT
_CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE
_CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE_RESULT
_CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE
_CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE_RESULT
_CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_QUESTLINES.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_WAGERING.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_ACHIEVEMENTS.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BATTLECUP.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PREDICTIONS.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BRACKET.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PLAYERCARD.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_FANTASYCHALLENGE.containing_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016.fields_by_name['questlines'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_QUESTLINES
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016.fields_by_name['wagering'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_WAGERING
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016.fields_by_name['achievements'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_ACHIEVEMENTS
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016.fields_by_name['battle_cup'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BATTLECUP
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016.fields_by_name['predictions'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PREDICTIONS
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016.fields_by_name['bracket'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BRACKET
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016.fields_by_name['player_cards'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PLAYERCARD
_CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016.fields_by_name['fantasy_challenge'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_FANTASYCHALLENGE
_CMSGGCTOCLIENTBATTLEPASSROLLUPRESPONSE.fields_by_name['event_ti6'].message_type = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
_CMSGDOTAEVENTINVITE_TEAM.containing_type = _CMSGDOTAEVENTINVITE
_CMSGDOTAEVENTINVITE.fields_by_name['teams'].message_type = _CMSGDOTAEVENTINVITE_TEAM
DESCRIPTOR.message_types_by_name['CMsgClientSuspended'] = _CMSGCLIENTSUSPENDED
DESCRIPTOR.message_types_by_name['CMsgRequestInternationalTicket'] = _CMSGREQUESTINTERNATIONALTICKET
DESCRIPTOR.message_types_by_name['CMsgBalancedShuffleLobby'] = _CMSGBALANCEDSHUFFLELOBBY
DESCRIPTOR.message_types_by_name['CMsgInitialQuestionnaireResponse'] = _CMSGINITIALQUESTIONNAIRERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAPlayerMatchHistory'] = _CMSGDOTAPLAYERMATCHHISTORY
DESCRIPTOR.message_types_by_name['CMsgDOTAMatchHistoryFilter'] = _CMSGDOTAMATCHHISTORYFILTER
DESCRIPTOR.message_types_by_name['CMsgDOTARequestMatches'] = _CMSGDOTAREQUESTMATCHES
DESCRIPTOR.message_types_by_name['CMsgDOTARequestMatchesResponse'] = _CMSGDOTAREQUESTMATCHESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAPopup'] = _CMSGDOTAPOPUP
DESCRIPTOR.message_types_by_name['CMsgDOTAReportsRemainingRequest'] = _CMSGDOTAREPORTSREMAININGREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAReportsRemainingResponse'] = _CMSGDOTAREPORTSREMAININGRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTASubmitPlayerReport'] = _CMSGDOTASUBMITPLAYERREPORT
DESCRIPTOR.message_types_by_name['CMsgDOTASubmitPlayerReportResponse'] = _CMSGDOTASUBMITPLAYERREPORTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAReportCountsRequest'] = _CMSGDOTAREPORTCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAReportCountsResponse'] = _CMSGDOTAREPORTCOUNTSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTASubmitLobbyMVPVote'] = _CMSGDOTASUBMITLOBBYMVPVOTE
DESCRIPTOR.message_types_by_name['CMsgDOTASubmitLobbyMVPVoteResponse'] = _CMSGDOTASUBMITLOBBYMVPVOTERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTALobbyMVPNotifyRecipient'] = _CMSGDOTALOBBYMVPNOTIFYRECIPIENT
DESCRIPTOR.message_types_by_name['CMsgDOTALobbyMVPAwarded'] = _CMSGDOTALOBBYMVPAWARDED
DESCRIPTOR.message_types_by_name['CMsgDOTAKickedFromMatchmakingQueue'] = _CMSGDOTAKICKEDFROMMATCHMAKINGQUEUE
DESCRIPTOR.message_types_by_name['CMsgDOTARequestSaveGames'] = _CMSGDOTAREQUESTSAVEGAMES
DESCRIPTOR.message_types_by_name['CMsgDOTARequestSaveGamesResponse'] = _CMSGDOTAREQUESTSAVEGAMESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCMatchDetailsRequest'] = _CMSGGCMATCHDETAILSREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCMatchDetailsResponse'] = _CMSGGCMATCHDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgServerToGCMatchDetailsRequest'] = _CMSGSERVERTOGCMATCHDETAILSREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToServerMatchDetailsResponse'] = _CMSGGCTOSERVERMATCHDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAProfileRequest'] = _CMSGDOTAPROFILEREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAProfileResponse'] = _CMSGDOTAPROFILERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAProfileTickets'] = _CMSGDOTAPROFILETICKETS
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetProfileTickets'] = _CMSGCLIENTTOGCGETPROFILETICKETS
DESCRIPTOR.message_types_by_name['CMsgGCSteamProfileRequest'] = _CMSGGCSTEAMPROFILEREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCSteamProfileRequestResponse'] = _CMSGGCSTEAMPROFILEREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAClearNotifySuccessfulReport'] = _CMSGDOTACLEARNOTIFYSUCCESSFULREPORT
DESCRIPTOR.message_types_by_name['CMsgDOTAWelcome'] = _CMSGDOTAWELCOME
DESCRIPTOR.message_types_by_name['CSODOTAGameHeroFavorites'] = _CSODOTAGAMEHEROFAVORITES
DESCRIPTOR.message_types_by_name['CMsgDOTAHeroFavoritesAdd'] = _CMSGDOTAHEROFAVORITESADD
DESCRIPTOR.message_types_by_name['CMsgDOTAHeroFavoritesRemove'] = _CMSGDOTAHEROFAVORITESREMOVE
DESCRIPTOR.message_types_by_name['CMsgSetShowcaseHero'] = _CMSGSETSHOWCASEHERO
DESCRIPTOR.message_types_by_name['CMsgSetFeaturedItems'] = _CMSGSETFEATUREDITEMS
DESCRIPTOR.message_types_by_name['CMsgDOTAFeaturedItems'] = _CMSGDOTAFEATUREDITEMS
DESCRIPTOR.message_types_by_name['CMsgRequestLeagueInfo'] = _CMSGREQUESTLEAGUEINFO
DESCRIPTOR.message_types_by_name['CDynamicLeagueData'] = _CDYNAMICLEAGUEDATA
DESCRIPTOR.message_types_by_name['CStaticLeagueData'] = _CSTATICLEAGUEDATA
DESCRIPTOR.message_types_by_name['CLeagueData'] = _CLEAGUEDATA
DESCRIPTOR.message_types_by_name['CMsgResponseLeagueInfo'] = _CMSGRESPONSELEAGUEINFO
DESCRIPTOR.message_types_by_name['CMsgDOTAMatchVotes'] = _CMSGDOTAMATCHVOTES
DESCRIPTOR.message_types_by_name['CMsgCastMatchVote'] = _CMSGCASTMATCHVOTE
DESCRIPTOR.message_types_by_name['CMsgRetrieveMatchVote'] = _CMSGRETRIEVEMATCHVOTE
DESCRIPTOR.message_types_by_name['CMsgMatchVoteResponse'] = _CMSGMATCHVOTERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAHallOfFame'] = _CMSGDOTAHALLOFFAME
DESCRIPTOR.message_types_by_name['CMsgDOTAHallOfFameRequest'] = _CMSGDOTAHALLOFFAMEREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAHallOfFameResponse'] = _CMSGDOTAHALLOFFAMERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAHalloweenHighScoreRequest'] = _CMSGDOTAHALLOWEENHIGHSCOREREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAHalloweenHighScoreResponse'] = _CMSGDOTAHALLOWEENHIGHSCORERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAStorePromoPagesRequest'] = _CMSGDOTASTOREPROMOPAGESREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAStorePromoPagesResponse'] = _CMSGDOTASTOREPROMOPAGESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgLeagueScheduleBlockTeamInfo'] = _CMSGLEAGUESCHEDULEBLOCKTEAMINFO
DESCRIPTOR.message_types_by_name['CMsgLeagueScheduleBlock'] = _CMSGLEAGUESCHEDULEBLOCK
DESCRIPTOR.message_types_by_name['CMsgDOTALeague'] = _CMSGDOTALEAGUE
DESCRIPTOR.message_types_by_name['CMsgDOTALeagueScheduleRequest'] = _CMSGDOTALEAGUESCHEDULEREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTALeagueScheduleResponse'] = _CMSGDOTALEAGUESCHEDULERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTALeagueScheduleEdit'] = _CMSGDOTALEAGUESCHEDULEEDIT
DESCRIPTOR.message_types_by_name['CMsgDOTALeagueScheduleEditResponse'] = _CMSGDOTALEAGUESCHEDULEEDITRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTALeaguesInMonthRequest'] = _CMSGDOTALEAGUESINMONTHREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTALeaguesInMonthResponse'] = _CMSGDOTALEAGUESINMONTHRESPONSE
DESCRIPTOR.message_types_by_name['CMsgMatchmakingMatchGroupInfo'] = _CMSGMATCHMAKINGMATCHGROUPINFO
DESCRIPTOR.message_types_by_name['CMsgDOTAMatchmakingStatsRequest'] = _CMSGDOTAMATCHMAKINGSTATSREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAMatchmakingStatsResponse'] = _CMSGDOTAMATCHMAKINGSTATSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAUpdateMatchmakingStats'] = _CMSGDOTAUPDATEMATCHMAKINGSTATS
DESCRIPTOR.message_types_by_name['CMsgDOTAUpdateMatchManagementStats'] = _CMSGDOTAUPDATEMATCHMANAGEMENTSTATS
DESCRIPTOR.message_types_by_name['CMsgDOTASetMatchHistoryAccess'] = _CMSGDOTASETMATCHHISTORYACCESS
DESCRIPTOR.message_types_by_name['CMsgDOTASetMatchHistoryAccessResponse'] = _CMSGDOTASETMATCHHISTORYACCESSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTANotifyAccountFlagsChange'] = _CMSGDOTANOTIFYACCOUNTFLAGSCHANGE
DESCRIPTOR.message_types_by_name['CMsgDOTASetProfilePrivacy'] = _CMSGDOTASETPROFILEPRIVACY
DESCRIPTOR.message_types_by_name['CMsgDOTASetProfilePrivacyResponse'] = _CMSGDOTASETPROFILEPRIVACYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgUpgradeLeagueItem'] = _CMSGUPGRADELEAGUEITEM
DESCRIPTOR.message_types_by_name['CMsgUpgradeLeagueItemResponse'] = _CMSGUPGRADELEAGUEITEMRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCWatchDownloadedReplay'] = _CMSGGCWATCHDOWNLOADEDREPLAY
DESCRIPTOR.message_types_by_name['CMsgSetMapLocationState'] = _CMSGSETMAPLOCATIONSTATE
DESCRIPTOR.message_types_by_name['CMsgSetMapLocationStateResponse'] = _CMSGSETMAPLOCATIONSTATERESPONSE
DESCRIPTOR.message_types_by_name['CMsgResetMapLocations'] = _CMSGRESETMAPLOCATIONS
DESCRIPTOR.message_types_by_name['CMsgResetMapLocationsResponse'] = _CMSGRESETMAPLOCATIONSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgRefreshPartnerAccountLink'] = _CMSGREFRESHPARTNERACCOUNTLINK
DESCRIPTOR.message_types_by_name['CMsgClientsRejoinChatChannels'] = _CMSGCLIENTSREJOINCHATCHANNELS
DESCRIPTOR.message_types_by_name['CMsgDOTASendFriendRecruits'] = _CMSGDOTASENDFRIENDRECRUITS
DESCRIPTOR.message_types_by_name['CMsgDOTAFriendRecruitsRequest'] = _CMSGDOTAFRIENDRECRUITSREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFriendRecruitsResponse'] = _CMSGDOTAFRIENDRECRUITSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFriendRecruitInviteAcceptDecline'] = _CMSGDOTAFRIENDRECRUITINVITEACCEPTDECLINE
DESCRIPTOR.message_types_by_name['CMsgRequestLeaguePrizePool'] = _CMSGREQUESTLEAGUEPRIZEPOOL
DESCRIPTOR.message_types_by_name['CMsgRequestLeaguePrizePoolResponse'] = _CMSGREQUESTLEAGUEPRIZEPOOLRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCGetHeroStandings'] = _CMSGGCGETHEROSTANDINGS
DESCRIPTOR.message_types_by_name['CMsgGCGetHeroStandingsResponse'] = _CMSGGCGETHEROSTANDINGSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCItemEditorReservationsRequest'] = _CMSGGCITEMEDITORRESERVATIONSREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCItemEditorReservation'] = _CMSGGCITEMEDITORRESERVATION
DESCRIPTOR.message_types_by_name['CMsgGCItemEditorReservationsResponse'] = _CMSGGCITEMEDITORRESERVATIONSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCItemEditorReserveItemDef'] = _CMSGGCITEMEDITORRESERVEITEMDEF
DESCRIPTOR.message_types_by_name['CMsgGCItemEditorReserveItemDefResponse'] = _CMSGGCITEMEDITORRESERVEITEMDEFRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCItemEditorReleaseReservation'] = _CMSGGCITEMEDITORRELEASERESERVATION
DESCRIPTOR.message_types_by_name['CMsgGCItemEditorReleaseReservationResponse'] = _CMSGGCITEMEDITORRELEASERESERVATIONRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCItemEditorRequestLeagueInfo'] = _CMSGGCITEMEDITORREQUESTLEAGUEINFO
DESCRIPTOR.message_types_by_name['CMsgGCItemEditorLeagueInfoResponse'] = _CMSGGCITEMEDITORLEAGUEINFORESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTARewardTutorialPrizes'] = _CMSGDOTAREWARDTUTORIALPRIZES
DESCRIPTOR.message_types_by_name['CMsgDOTALastHitChallengeHighScorePost'] = _CMSGDOTALASTHITCHALLENGEHIGHSCOREPOST
DESCRIPTOR.message_types_by_name['CMsgDOTALastHitChallengeHighScoreRequest'] = _CMSGDOTALASTHITCHALLENGEHIGHSCOREREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTALastHitChallengeHighScoreResponse'] = _CMSGDOTALASTHITCHALLENGEHIGHSCORERESPONSE
DESCRIPTOR.message_types_by_name['CMsgFlipLobbyTeams'] = _CMSGFLIPLOBBYTEAMS
DESCRIPTOR.message_types_by_name['CMsgPresentedClientTerminateDlg'] = _CMSGPRESENTEDCLIENTTERMINATEDLG
DESCRIPTOR.message_types_by_name['CMsgGCLobbyUpdateBroadcastChannelInfo'] = _CMSGGCLOBBYUPDATEBROADCASTCHANNELINFO
DESCRIPTOR.message_types_by_name['CMsgDOTARedeemEventPrize'] = _CMSGDOTAREDEEMEVENTPRIZE
DESCRIPTOR.message_types_by_name['CMsgDOTARedeemEventPrizeResponse'] = _CMSGDOTAREDEEMEVENTPRIZERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAGetEventPoints'] = _CMSGDOTAGETEVENTPOINTS
DESCRIPTOR.message_types_by_name['CMsgDOTAGetEventPointsResponse'] = _CMSGDOTAGETEVENTPOINTSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTALiveLeagueGameUpdate'] = _CMSGDOTALIVELEAGUEGAMEUPDATE
DESCRIPTOR.message_types_by_name['CMsgDOTACompendiumSelection'] = _CMSGDOTACOMPENDIUMSELECTION
DESCRIPTOR.message_types_by_name['CMsgDOTACompendiumSelectionResponse'] = _CMSGDOTACOMPENDIUMSELECTIONRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTACompendiumData'] = _CMSGDOTACOMPENDIUMDATA
DESCRIPTOR.message_types_by_name['CMsgDOTACompendiumDataRequest'] = _CMSGDOTACOMPENDIUMDATAREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTACompendiumDataResponse'] = _CMSGDOTACOMPENDIUMDATARESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAGetPlayerMatchHistory'] = _CMSGDOTAGETPLAYERMATCHHISTORY
DESCRIPTOR.message_types_by_name['CMsgDOTAGetPlayerMatchHistoryResponse'] = _CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAStartDailyHeroChallenge'] = _CMSGDOTASTARTDAILYHEROCHALLENGE
DESCRIPTOR.message_types_by_name['CMsgGCNotificationsRequest'] = _CMSGGCNOTIFICATIONSREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCNotificationsResponse'] = _CMSGGCNOTIFICATIONSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCNotificationsMarkReadRequest'] = _CMSGGCNOTIFICATIONSMARKREADREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCMarkNotificationListRead'] = _CMSGCLIENTTOGCMARKNOTIFICATIONLISTREAD
DESCRIPTOR.message_types_by_name['CMsgGCLeagueAdminState'] = _CMSGGCLEAGUEADMINSTATE
DESCRIPTOR.message_types_by_name['CMsgGCPlayerInfoRequest'] = _CMSGGCPLAYERINFOREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCPlayerInfoSubmit'] = _CMSGGCPLAYERINFOSUBMIT
DESCRIPTOR.message_types_by_name['CMsgGCPlayerInfoSubmitResponse'] = _CMSGGCPLAYERINFOSUBMITRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientProvideSurveyResult'] = _CMSGCLIENTPROVIDESURVEYRESULT
DESCRIPTOR.message_types_by_name['CMsgDOTAEmoticonAccessSDO'] = _CMSGDOTAEMOTICONACCESSSDO
DESCRIPTOR.message_types_by_name['CMsgClientToGCEmoticonDataRequest'] = _CMSGCLIENTTOGCEMOTICONDATAREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientEmoticonData'] = _CMSGGCTOCLIENTEMOTICONDATA
DESCRIPTOR.message_types_by_name['CMsgClientToGCTrackDialogResult'] = _CMSGCLIENTTOGCTRACKDIALOGRESULT
DESCRIPTOR.message_types_by_name['CMsgGCToClientTournamentItemDrop'] = _CMSGGCTOCLIENTTOURNAMENTITEMDROP
DESCRIPTOR.message_types_by_name['CMsgClientToGCSetAdditionalEquips'] = _CMSGCLIENTTOGCSETADDITIONALEQUIPS
DESCRIPTOR.message_types_by_name['CMsgClientToGCSetAdditionalEquipsResponse'] = _CMSGCLIENTTOGCSETADDITIONALEQUIPSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetAdditionalEquips'] = _CMSGCLIENTTOGCGETADDITIONALEQUIPS
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetAdditionalEquipsResponse'] = _CMSGCLIENTTOGCGETADDITIONALEQUIPSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetAllHeroOrder'] = _CMSGCLIENTTOGCGETALLHEROORDER
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetAllHeroOrderResponse'] = _CMSGCLIENTTOGCGETALLHEROORDERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetAllHeroProgress'] = _CMSGCLIENTTOGCGETALLHEROPROGRESS
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetAllHeroProgressResponse'] = _CMSGCLIENTTOGCGETALLHEROPROGRESSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetTrophyList'] = _CMSGCLIENTTOGCGETTROPHYLIST
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetTrophyListResponse'] = _CMSGCLIENTTOGCGETTROPHYLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientTrophyAwarded'] = _CMSGGCTOCLIENTTROPHYAWARDED
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetProfileCard'] = _CMSGCLIENTTOGCGETPROFILECARD
DESCRIPTOR.message_types_by_name['CMsgClientToGCSetProfileCardSlots'] = _CMSGCLIENTTOGCSETPROFILECARDSLOTS
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetProfileCardStats'] = _CMSGCLIENTTOGCGETPROFILECARDSTATS
DESCRIPTOR.message_types_by_name['CMsgClientToGCCreateHeroStatue'] = _CMSGCLIENTTOGCCREATEHEROSTATUE
DESCRIPTOR.message_types_by_name['CMsgGCToClientHeroStatueCreateResult'] = _CMSGGCTOCLIENTHEROSTATUECREATERESULT
DESCRIPTOR.message_types_by_name['CMsgClientToGCRecordCompendiumStats'] = _CMSGCLIENTTOGCRECORDCOMPENDIUMSTATS
DESCRIPTOR.message_types_by_name['CMsgGCToClientEventStatusChanged'] = _CMSGGCTOCLIENTEVENTSTATUSCHANGED
DESCRIPTOR.message_types_by_name['CMsgClientToGCPlayerStatsRequest'] = _CMSGCLIENTTOGCPLAYERSTATSREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientPlayerStatsResponse'] = _CMSGGCTOCLIENTPLAYERSTATSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCCustomGamePlayerCountRequest'] = _CMSGCLIENTTOGCCUSTOMGAMEPLAYERCOUNTREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientCustomGamePlayerCountResponse'] = _CMSGGCTOCLIENTCUSTOMGAMEPLAYERCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCCustomGamesFriendsPlayedRequest'] = _CMSGCLIENTTOGCCUSTOMGAMESFRIENDSPLAYEDREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientCustomGamesFriendsPlayedResponse'] = _CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCSocialFeedPostCommentRequest'] = _CMSGCLIENTTOGCSOCIALFEEDPOSTCOMMENTREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientSocialFeedPostCommentResponse'] = _CMSGGCTOCLIENTSOCIALFEEDPOSTCOMMENTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCSocialFeedPostMessageRequest'] = _CMSGCLIENTTOGCSOCIALFEEDPOSTMESSAGEREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientSocialFeedPostMessageResponse'] = _CMSGGCTOCLIENTSOCIALFEEDPOSTMESSAGERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCFriendsPlayedCustomGameRequest'] = _CMSGCLIENTTOGCFRIENDSPLAYEDCUSTOMGAMEREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientFriendsPlayedCustomGameResponse'] = _CMSGGCTOCLIENTFRIENDSPLAYEDCUSTOMGAMERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCFeaturedHeroesRequest'] = _CMSGCLIENTTOGCFEATUREDHEROESREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientFeaturedHeroesResponse'] = _CMSGGCTOCLIENTFEATUREDHEROESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCSocialMatchPostCommentRequest'] = _CMSGCLIENTTOGCSOCIALMATCHPOSTCOMMENTREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientSocialMatchPostCommentResponse'] = _CMSGGCTOCLIENTSOCIALMATCHPOSTCOMMENTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCSocialMatchDetailsRequest'] = _CMSGCLIENTTOGCSOCIALMATCHDETAILSREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientSocialMatchDetailsResponse'] = _CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAPartyRichPresence'] = _CMSGDOTAPARTYRICHPRESENCE
DESCRIPTOR.message_types_by_name['CMsgDOTALobbyRichPresence'] = _CMSGDOTALOBBYRICHPRESENCE
DESCRIPTOR.message_types_by_name['CMsgDOTACustomGameListenServerStartedLoading'] = _CMSGDOTACUSTOMGAMELISTENSERVERSTARTEDLOADING
DESCRIPTOR.message_types_by_name['CMsgDOTACustomGameClientFinishedLoading'] = _CMSGDOTACUSTOMGAMECLIENTFINISHEDLOADING
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetLeagueSeries'] = _CMSGCLIENTTOGCGETLEAGUESERIES
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetLeagueSeriesResponse'] = _CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCApplyGemCombiner'] = _CMSGCLIENTTOGCAPPLYGEMCOMBINER
DESCRIPTOR.message_types_by_name['CMsgClientToGCH264Unsupported'] = _CMSGCLIENTTOGCH264UNSUPPORTED
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestH264Support'] = _CMSGCLIENTTOGCREQUESTH264SUPPORT
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetQuestProgress'] = _CMSGCLIENTTOGCGETQUESTPROGRESS
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetQuestProgressResponse'] = _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientMatchSignedOut'] = _CMSGGCTOCLIENTMATCHSIGNEDOUT
DESCRIPTOR.message_types_by_name['CMsgGCGetHeroStatsHistory'] = _CMSGGCGETHEROSTATSHISTORY
DESCRIPTOR.message_types_by_name['CMsgGCGetHeroStatsHistoryResponse'] = _CMSGGCGETHEROSTATSHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgPlayerConductScorecardRequest'] = _CMSGPLAYERCONDUCTSCORECARDREQUEST
DESCRIPTOR.message_types_by_name['CMsgPlayerConductScorecard'] = _CMSGPLAYERCONDUCTSCORECARD
DESCRIPTOR.message_types_by_name['CMsgClientToGCWageringRequest'] = _CMSGCLIENTTOGCWAGERINGREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientWageringResponse'] = _CMSGGCTOCLIENTWAGERINGRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientWageringUpdate'] = _CMSGGCTOCLIENTWAGERINGUPDATE
DESCRIPTOR.message_types_by_name['CMsgGCToClientArcanaVotesUpdate'] = _CMSGGCTOCLIENTARCANAVOTESUPDATE
DESCRIPTOR.message_types_by_name['CMsgClientToGCMysteryItem'] = _CMSGCLIENTTOGCMYSTERYITEM
DESCRIPTOR.message_types_by_name['CMsgGCToClientMysteryItemResponse'] = _CMSGGCTOCLIENTMYSTERYITEMRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetEventGoals'] = _CMSGCLIENTTOGCGETEVENTGOALS
DESCRIPTOR.message_types_by_name['CMsgEventGoals'] = _CMSGEVENTGOALS
DESCRIPTOR.message_types_by_name['CMsgGCToGCLeaguePredictions'] = _CMSGGCTOGCLEAGUEPREDICTIONS
DESCRIPTOR.message_types_by_name['CMsgPredictionRankings'] = _CMSGPREDICTIONRANKINGS
DESCRIPTOR.message_types_by_name['CMsgPredictionResults'] = _CMSGPREDICTIONRESULTS
DESCRIPTOR.message_types_by_name['CMsgClientToGCSuspiciousActivity'] = _CMSGCLIENTTOGCSUSPICIOUSACTIVITY
DESCRIPTOR.message_types_by_name['CMsgClientToGCHasPlayerVotedForMVP'] = _CMSGCLIENTTOGCHASPLAYERVOTEDFORMVP
DESCRIPTOR.message_types_by_name['CMsgClientToGCHasPlayerVotedForMVPResponse'] = _CMSGCLIENTTOGCHASPLAYERVOTEDFORMVPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCVoteForMVP'] = _CMSGCLIENTTOGCVOTEFORMVP
DESCRIPTOR.message_types_by_name['CMsgClientToGCVoteForMVPResponse'] = _CMSGCLIENTTOGCVOTEFORMVPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgMVPVotesForMatch'] = _CMSGMVPVOTESFORMATCH
DESCRIPTOR.message_types_by_name['CMsgLeaguePrizePool'] = _CMSGLEAGUEPRIZEPOOL
DESCRIPTOR.message_types_by_name['CMsgClientToGCTeammateStatsRequest'] = _CMSGCLIENTTOGCTEAMMATESTATSREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCTeammateStatsResponse'] = _CMSGCLIENTTOGCTEAMMATESTATSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCVoteForArcana'] = _CMSGCLIENTTOGCVOTEFORARCANA
DESCRIPTOR.message_types_by_name['CMsgClientToGCVoteForArcanaResponse'] = _CMSGCLIENTTOGCVOTEFORARCANARESPONSE
DESCRIPTOR.message_types_by_name['CMsgArcanaVotes'] = _CMSGARCANAVOTES
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestArcanaVotesRemaining'] = _CMSGCLIENTTOGCREQUESTARCANAVOTESREMAINING
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestArcanaVotesRemainingResponse'] = _CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestEventPointLog'] = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOG
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestEventPointLogResponse'] = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCPublishUserStat'] = _CMSGCLIENTTOGCPUBLISHUSERSTAT
DESCRIPTOR.message_types_by_name['CMsgClientToGCAddTI6TreeProgress'] = _CMSGCLIENTTOGCADDTI6TREEPROGRESS
DESCRIPTOR.message_types_by_name['CMsgClientToGCRedeemReward'] = _CMSGCLIENTTOGCREDEEMREWARD
DESCRIPTOR.message_types_by_name['CMsgGCToClientRedeemRewardResponse'] = _CMSGGCTOCLIENTREDEEMREWARDRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestLinaPlaysRemaining'] = _CMSGCLIENTTOGCREQUESTLINAPLAYSREMAINING
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestLinaPlaysRemainingResponse'] = _CMSGCLIENTTOGCREQUESTLINAPLAYSREMAININGRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestLinaGameResult'] = _CMSGCLIENTTOGCREQUESTLINAGAMERESULT
DESCRIPTOR.message_types_by_name['CMsgClientToGCRequestLinaGameResultResponse'] = _CMSGCLIENTTOGCREQUESTLINAGAMERESULTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientQuestProgressUpdated'] = _CMSGGCTOCLIENTQUESTPROGRESSUPDATED
DESCRIPTOR.message_types_by_name['CMsgDOTARedeemItem'] = _CMSGDOTAREDEEMITEM
DESCRIPTOR.message_types_by_name['CMsgDOTARedeemItemResponse'] = _CMSGDOTAREDEEMITEMRESPONSE
DESCRIPTOR.message_types_by_name['CMsgPerfectWorldUserLookupRequest'] = _CMSGPERFECTWORLDUSERLOOKUPREQUEST
DESCRIPTOR.message_types_by_name['CMsgPerfectWorldUserLookupResponse'] = _CMSGPERFECTWORLDUSERLOOKUPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgNexonPartnerUpdate'] = _CMSGNEXONPARTNERUPDATE
DESCRIPTOR.message_types_by_name['CMsgMakeOffering'] = _CMSGMAKEOFFERING
DESCRIPTOR.message_types_by_name['CMsgRequestOfferings'] = _CMSGREQUESTOFFERINGS
DESCRIPTOR.message_types_by_name['CMsgRequestOfferingsResponse'] = _CMSGREQUESTOFFERINGSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAPCBangTimedReward'] = _CMSGDOTAPCBANGTIMEDREWARD
DESCRIPTOR.message_types_by_name['CMsgDOTACompendiumInGamePredictionResults'] = _CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS
DESCRIPTOR.message_types_by_name['CMsgClientToGCSelectCompendiumInGamePrediction'] = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION
DESCRIPTOR.message_types_by_name['CMsgClientToGCSelectCompendiumInGamePredictionResponse'] = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCOpenPlayerCardPack'] = _CMSGCLIENTTOGCOPENPLAYERCARDPACK
DESCRIPTOR.message_types_by_name['CMsgClientToGCOpenPlayerCardPackResponse'] = _CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRecyclePlayerCard'] = _CMSGCLIENTTOGCRECYCLEPLAYERCARD
DESCRIPTOR.message_types_by_name['CMsgClientToGCRecyclePlayerCardResponse'] = _CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCCreatePlayerCardPack'] = _CMSGCLIENTTOGCCREATEPLAYERCARDPACK
DESCRIPTOR.message_types_by_name['CMsgClientToGCCreatePlayerCardPackResponse'] = _CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientBattlePassRollup_International2016'] = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016
DESCRIPTOR.message_types_by_name['CMsgGCToClientBattlePassRollupRequest'] = _CMSGGCTOCLIENTBATTLEPASSROLLUPREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientBattlePassRollupResponse'] = _CMSGGCTOCLIENTBATTLEPASSROLLUPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientBattlePassRollupListRequest'] = _CMSGGCTOCLIENTBATTLEPASSROLLUPLISTREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientBattlePassRollupListResponse'] = _CMSGGCTOCLIENTBATTLEPASSROLLUPLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCTransferSeasonalMMRRequest'] = _CMSGCLIENTTOGCTRANSFERSEASONALMMRREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCTransferSeasonalMMRResponse'] = _CMSGCLIENTTOGCTRANSFERSEASONALMMRRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAEventInvite'] = _CMSGDOTAEVENTINVITE
DESCRIPTOR.message_types_by_name['CMsgDOTASetFavoriteTeam'] = _CMSGDOTASETFAVORITETEAM
DESCRIPTOR.enum_types_by_name['DOTA_WatchReplayType'] = _DOTA_WATCHREPLAYTYPE
DESCRIPTOR.enum_types_by_name['EItemEditorReservationResult'] = _EITEMEDITORRESERVATIONRESULT
DESCRIPTOR.enum_types_by_name['EFeaturedHeroTextField'] = _EFEATUREDHEROTEXTFIELD
DESCRIPTOR.enum_types_by_name['EFeaturedHeroDataType'] = _EFEATUREDHERODATATYPE
DESCRIPTOR.enum_types_by_name['EWeekendTourneyRichPresenceEvent'] = _EWEEKENDTOURNEYRICHPRESENCEEVENT

CMsgClientSuspended = _reflection.GeneratedProtocolMessageType('CMsgClientSuspended', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTSUSPENDED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientSuspended)
  ))
_sym_db.RegisterMessage(CMsgClientSuspended)

CMsgRequestInternationalTicket = _reflection.GeneratedProtocolMessageType('CMsgRequestInternationalTicket', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTINTERNATIONALTICKET,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRequestInternationalTicket)
  ))
_sym_db.RegisterMessage(CMsgRequestInternationalTicket)

CMsgBalancedShuffleLobby = _reflection.GeneratedProtocolMessageType('CMsgBalancedShuffleLobby', (_message.Message,), dict(
  DESCRIPTOR = _CMSGBALANCEDSHUFFLELOBBY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgBalancedShuffleLobby)
  ))
_sym_db.RegisterMessage(CMsgBalancedShuffleLobby)

CMsgInitialQuestionnaireResponse = _reflection.GeneratedProtocolMessageType('CMsgInitialQuestionnaireResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGINITIALQUESTIONNAIRERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgInitialQuestionnaireResponse)
  ))
_sym_db.RegisterMessage(CMsgInitialQuestionnaireResponse)

CMsgDOTAPlayerMatchHistory = _reflection.GeneratedProtocolMessageType('CMsgDOTAPlayerMatchHistory', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPLAYERMATCHHISTORY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAPlayerMatchHistory)
  ))
_sym_db.RegisterMessage(CMsgDOTAPlayerMatchHistory)

CMsgDOTAMatchHistoryFilter = _reflection.GeneratedProtocolMessageType('CMsgDOTAMatchHistoryFilter', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAMATCHHISTORYFILTER,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAMatchHistoryFilter)
  ))
_sym_db.RegisterMessage(CMsgDOTAMatchHistoryFilter)

CMsgDOTARequestMatches = _reflection.GeneratedProtocolMessageType('CMsgDOTARequestMatches', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREQUESTMATCHES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTARequestMatches)
  ))
_sym_db.RegisterMessage(CMsgDOTARequestMatches)

CMsgDOTARequestMatchesResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTARequestMatchesResponse', (_message.Message,), dict(

  Series = _reflection.GeneratedProtocolMessageType('Series', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAREQUESTMATCHESRESPONSE_SERIES,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTARequestMatchesResponse.Series)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAREQUESTMATCHESRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTARequestMatchesResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTARequestMatchesResponse)
_sym_db.RegisterMessage(CMsgDOTARequestMatchesResponse.Series)

CMsgDOTAPopup = _reflection.GeneratedProtocolMessageType('CMsgDOTAPopup', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPOPUP,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAPopup)
  ))
_sym_db.RegisterMessage(CMsgDOTAPopup)

CMsgDOTAReportsRemainingRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAReportsRemainingRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREPORTSREMAININGREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAReportsRemainingRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAReportsRemainingRequest)

CMsgDOTAReportsRemainingResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAReportsRemainingResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREPORTSREMAININGRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAReportsRemainingResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAReportsRemainingResponse)

CMsgDOTASubmitPlayerReport = _reflection.GeneratedProtocolMessageType('CMsgDOTASubmitPlayerReport', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASUBMITPLAYERREPORT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTASubmitPlayerReport)
  ))
_sym_db.RegisterMessage(CMsgDOTASubmitPlayerReport)

CMsgDOTASubmitPlayerReportResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTASubmitPlayerReportResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASUBMITPLAYERREPORTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTASubmitPlayerReportResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTASubmitPlayerReportResponse)

CMsgDOTAReportCountsRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAReportCountsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREPORTCOUNTSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAReportCountsRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAReportCountsRequest)

CMsgDOTAReportCountsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAReportCountsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREPORTCOUNTSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAReportCountsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAReportCountsResponse)

CMsgDOTASubmitLobbyMVPVote = _reflection.GeneratedProtocolMessageType('CMsgDOTASubmitLobbyMVPVote', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASUBMITLOBBYMVPVOTE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTASubmitLobbyMVPVote)
  ))
_sym_db.RegisterMessage(CMsgDOTASubmitLobbyMVPVote)

CMsgDOTASubmitLobbyMVPVoteResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTASubmitLobbyMVPVoteResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASUBMITLOBBYMVPVOTERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTASubmitLobbyMVPVoteResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTASubmitLobbyMVPVoteResponse)

CMsgDOTALobbyMVPNotifyRecipient = _reflection.GeneratedProtocolMessageType('CMsgDOTALobbyMVPNotifyRecipient', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALOBBYMVPNOTIFYRECIPIENT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALobbyMVPNotifyRecipient)
  ))
_sym_db.RegisterMessage(CMsgDOTALobbyMVPNotifyRecipient)

CMsgDOTALobbyMVPAwarded = _reflection.GeneratedProtocolMessageType('CMsgDOTALobbyMVPAwarded', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALOBBYMVPAWARDED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALobbyMVPAwarded)
  ))
_sym_db.RegisterMessage(CMsgDOTALobbyMVPAwarded)

CMsgDOTAKickedFromMatchmakingQueue = _reflection.GeneratedProtocolMessageType('CMsgDOTAKickedFromMatchmakingQueue', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAKICKEDFROMMATCHMAKINGQUEUE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAKickedFromMatchmakingQueue)
  ))
_sym_db.RegisterMessage(CMsgDOTAKickedFromMatchmakingQueue)

CMsgDOTARequestSaveGames = _reflection.GeneratedProtocolMessageType('CMsgDOTARequestSaveGames', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREQUESTSAVEGAMES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTARequestSaveGames)
  ))
_sym_db.RegisterMessage(CMsgDOTARequestSaveGames)

CMsgDOTARequestSaveGamesResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTARequestSaveGamesResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREQUESTSAVEGAMESRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTARequestSaveGamesResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTARequestSaveGamesResponse)

CMsgGCMatchDetailsRequest = _reflection.GeneratedProtocolMessageType('CMsgGCMatchDetailsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCMATCHDETAILSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCMatchDetailsRequest)
  ))
_sym_db.RegisterMessage(CMsgGCMatchDetailsRequest)

CMsgGCMatchDetailsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCMatchDetailsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCMATCHDETAILSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCMatchDetailsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCMatchDetailsResponse)

CMsgServerToGCMatchDetailsRequest = _reflection.GeneratedProtocolMessageType('CMsgServerToGCMatchDetailsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSERVERTOGCMATCHDETAILSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgServerToGCMatchDetailsRequest)
  ))
_sym_db.RegisterMessage(CMsgServerToGCMatchDetailsRequest)

CMsgGCToServerMatchDetailsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToServerMatchDetailsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOSERVERMATCHDETAILSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToServerMatchDetailsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToServerMatchDetailsResponse)

CMsgDOTAProfileRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAProfileRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPROFILEREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAProfileRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAProfileRequest)

CMsgDOTAProfileResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAProfileResponse', (_message.Message,), dict(

  PlayedHero = _reflection.GeneratedProtocolMessageType('PlayedHero', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAPROFILERESPONSE_PLAYEDHERO,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAProfileResponse.PlayedHero)
    ))
  ,

  ShowcaseHero = _reflection.GeneratedProtocolMessageType('ShowcaseHero', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAPROFILERESPONSE_SHOWCASEHERO,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAProfileResponse.ShowcaseHero)
    ))
  ,

  LeaguePass = _reflection.GeneratedProtocolMessageType('LeaguePass', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAPROFILERESPONSE_LEAGUEPASS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAProfileResponse.LeaguePass)
    ))
  ,

  EventTicket = _reflection.GeneratedProtocolMessageType('EventTicket', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAPROFILERESPONSE_EVENTTICKET,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAProfileResponse.EventTicket)
    ))
  ,

  FeaturedItem = _reflection.GeneratedProtocolMessageType('FeaturedItem', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAPROFILERESPONSE_FEATUREDITEM,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAProfileResponse.FeaturedItem)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAPROFILERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAProfileResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAProfileResponse)
_sym_db.RegisterMessage(CMsgDOTAProfileResponse.PlayedHero)
_sym_db.RegisterMessage(CMsgDOTAProfileResponse.ShowcaseHero)
_sym_db.RegisterMessage(CMsgDOTAProfileResponse.LeaguePass)
_sym_db.RegisterMessage(CMsgDOTAProfileResponse.EventTicket)
_sym_db.RegisterMessage(CMsgDOTAProfileResponse.FeaturedItem)

CMsgDOTAProfileTickets = _reflection.GeneratedProtocolMessageType('CMsgDOTAProfileTickets', (_message.Message,), dict(

  LeaguePass = _reflection.GeneratedProtocolMessageType('LeaguePass', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAPROFILETICKETS_LEAGUEPASS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAProfileTickets.LeaguePass)
    ))
  ,

  EventTicket = _reflection.GeneratedProtocolMessageType('EventTicket', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAPROFILETICKETS_EVENTTICKET,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAProfileTickets.EventTicket)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAPROFILETICKETS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAProfileTickets)
  ))
_sym_db.RegisterMessage(CMsgDOTAProfileTickets)
_sym_db.RegisterMessage(CMsgDOTAProfileTickets.LeaguePass)
_sym_db.RegisterMessage(CMsgDOTAProfileTickets.EventTicket)

CMsgClientToGCGetProfileTickets = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetProfileTickets', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETPROFILETICKETS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetProfileTickets)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetProfileTickets)

CMsgGCSteamProfileRequest = _reflection.GeneratedProtocolMessageType('CMsgGCSteamProfileRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTEAMPROFILEREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCSteamProfileRequest)
  ))
_sym_db.RegisterMessage(CMsgGCSteamProfileRequest)

CMsgGCSteamProfileRequestResponse = _reflection.GeneratedProtocolMessageType('CMsgGCSteamProfileRequestResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTEAMPROFILEREQUESTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCSteamProfileRequestResponse)
  ))
_sym_db.RegisterMessage(CMsgGCSteamProfileRequestResponse)

CMsgDOTAClearNotifySuccessfulReport = _reflection.GeneratedProtocolMessageType('CMsgDOTAClearNotifySuccessfulReport', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACLEARNOTIFYSUCCESSFULREPORT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAClearNotifySuccessfulReport)
  ))
_sym_db.RegisterMessage(CMsgDOTAClearNotifySuccessfulReport)

CMsgDOTAWelcome = _reflection.GeneratedProtocolMessageType('CMsgDOTAWelcome', (_message.Message,), dict(

  LocalizationDigest = _reflection.GeneratedProtocolMessageType('LocalizationDigest', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAWELCOME_LOCALIZATIONDIGEST,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAWelcome.LocalizationDigest)
    ))
  ,

  CExtraMsg = _reflection.GeneratedProtocolMessageType('CExtraMsg', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAWELCOME_CEXTRAMSG,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAWelcome.CExtraMsg)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAWELCOME,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAWelcome)
  ))
_sym_db.RegisterMessage(CMsgDOTAWelcome)
_sym_db.RegisterMessage(CMsgDOTAWelcome.LocalizationDigest)
_sym_db.RegisterMessage(CMsgDOTAWelcome.CExtraMsg)

CSODOTAGameHeroFavorites = _reflection.GeneratedProtocolMessageType('CSODOTAGameHeroFavorites', (_message.Message,), dict(
  DESCRIPTOR = _CSODOTAGAMEHEROFAVORITES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CSODOTAGameHeroFavorites)
  ))
_sym_db.RegisterMessage(CSODOTAGameHeroFavorites)

CMsgDOTAHeroFavoritesAdd = _reflection.GeneratedProtocolMessageType('CMsgDOTAHeroFavoritesAdd', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAHEROFAVORITESADD,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAHeroFavoritesAdd)
  ))
_sym_db.RegisterMessage(CMsgDOTAHeroFavoritesAdd)

CMsgDOTAHeroFavoritesRemove = _reflection.GeneratedProtocolMessageType('CMsgDOTAHeroFavoritesRemove', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAHEROFAVORITESREMOVE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAHeroFavoritesRemove)
  ))
_sym_db.RegisterMessage(CMsgDOTAHeroFavoritesRemove)

CMsgSetShowcaseHero = _reflection.GeneratedProtocolMessageType('CMsgSetShowcaseHero', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSETSHOWCASEHERO,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSetShowcaseHero)
  ))
_sym_db.RegisterMessage(CMsgSetShowcaseHero)

CMsgSetFeaturedItems = _reflection.GeneratedProtocolMessageType('CMsgSetFeaturedItems', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSETFEATUREDITEMS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSetFeaturedItems)
  ))
_sym_db.RegisterMessage(CMsgSetFeaturedItems)

CMsgDOTAFeaturedItems = _reflection.GeneratedProtocolMessageType('CMsgDOTAFeaturedItems', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFEATUREDITEMS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFeaturedItems)
  ))
_sym_db.RegisterMessage(CMsgDOTAFeaturedItems)

CMsgRequestLeagueInfo = _reflection.GeneratedProtocolMessageType('CMsgRequestLeagueInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTLEAGUEINFO,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRequestLeagueInfo)
  ))
_sym_db.RegisterMessage(CMsgRequestLeagueInfo)

CDynamicLeagueData = _reflection.GeneratedProtocolMessageType('CDynamicLeagueData', (_message.Message,), dict(
  DESCRIPTOR = _CDYNAMICLEAGUEDATA,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CDynamicLeagueData)
  ))
_sym_db.RegisterMessage(CDynamicLeagueData)

CStaticLeagueData = _reflection.GeneratedProtocolMessageType('CStaticLeagueData', (_message.Message,), dict(
  DESCRIPTOR = _CSTATICLEAGUEDATA,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CStaticLeagueData)
  ))
_sym_db.RegisterMessage(CStaticLeagueData)

CLeagueData = _reflection.GeneratedProtocolMessageType('CLeagueData', (_message.Message,), dict(
  DESCRIPTOR = _CLEAGUEDATA,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CLeagueData)
  ))
_sym_db.RegisterMessage(CLeagueData)

CMsgResponseLeagueInfo = _reflection.GeneratedProtocolMessageType('CMsgResponseLeagueInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGRESPONSELEAGUEINFO,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgResponseLeagueInfo)
  ))
_sym_db.RegisterMessage(CMsgResponseLeagueInfo)

CMsgDOTAMatchVotes = _reflection.GeneratedProtocolMessageType('CMsgDOTAMatchVotes', (_message.Message,), dict(

  PlayerVote = _reflection.GeneratedProtocolMessageType('PlayerVote', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAMATCHVOTES_PLAYERVOTE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAMatchVotes.PlayerVote)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAMATCHVOTES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAMatchVotes)
  ))
_sym_db.RegisterMessage(CMsgDOTAMatchVotes)
_sym_db.RegisterMessage(CMsgDOTAMatchVotes.PlayerVote)

CMsgCastMatchVote = _reflection.GeneratedProtocolMessageType('CMsgCastMatchVote', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCASTMATCHVOTE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCastMatchVote)
  ))
_sym_db.RegisterMessage(CMsgCastMatchVote)

CMsgRetrieveMatchVote = _reflection.GeneratedProtocolMessageType('CMsgRetrieveMatchVote', (_message.Message,), dict(
  DESCRIPTOR = _CMSGRETRIEVEMATCHVOTE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRetrieveMatchVote)
  ))
_sym_db.RegisterMessage(CMsgRetrieveMatchVote)

CMsgMatchVoteResponse = _reflection.GeneratedProtocolMessageType('CMsgMatchVoteResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGMATCHVOTERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgMatchVoteResponse)
  ))
_sym_db.RegisterMessage(CMsgMatchVoteResponse)

CMsgDOTAHallOfFame = _reflection.GeneratedProtocolMessageType('CMsgDOTAHallOfFame', (_message.Message,), dict(

  FeaturedPlayer = _reflection.GeneratedProtocolMessageType('FeaturedPlayer', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAHALLOFFAME_FEATUREDPLAYER,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAHallOfFame.FeaturedPlayer)
    ))
  ,

  FeaturedFarmer = _reflection.GeneratedProtocolMessageType('FeaturedFarmer', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAHALLOFFAME_FEATUREDFARMER,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAHallOfFame.FeaturedFarmer)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAHALLOFFAME,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAHallOfFame)
  ))
_sym_db.RegisterMessage(CMsgDOTAHallOfFame)
_sym_db.RegisterMessage(CMsgDOTAHallOfFame.FeaturedPlayer)
_sym_db.RegisterMessage(CMsgDOTAHallOfFame.FeaturedFarmer)

CMsgDOTAHallOfFameRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAHallOfFameRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAHALLOFFAMEREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAHallOfFameRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAHallOfFameRequest)

CMsgDOTAHallOfFameResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAHallOfFameResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAHALLOFFAMERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAHallOfFameResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAHallOfFameResponse)

CMsgDOTAHalloweenHighScoreRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAHalloweenHighScoreRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAHALLOWEENHIGHSCOREREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAHalloweenHighScoreRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAHalloweenHighScoreRequest)

CMsgDOTAHalloweenHighScoreResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAHalloweenHighScoreResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAHALLOWEENHIGHSCORERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAHalloweenHighScoreResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAHalloweenHighScoreResponse)

CMsgDOTAStorePromoPagesRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAStorePromoPagesRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASTOREPROMOPAGESREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAStorePromoPagesRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAStorePromoPagesRequest)

CMsgDOTAStorePromoPagesResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAStorePromoPagesResponse', (_message.Message,), dict(

  PromoPage = _reflection.GeneratedProtocolMessageType('PromoPage', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTASTOREPROMOPAGESRESPONSE_PROMOPAGE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAStorePromoPagesResponse.PromoPage)
    ))
  ,
  DESCRIPTOR = _CMSGDOTASTOREPROMOPAGESRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAStorePromoPagesResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAStorePromoPagesResponse)
_sym_db.RegisterMessage(CMsgDOTAStorePromoPagesResponse.PromoPage)

CMsgLeagueScheduleBlockTeamInfo = _reflection.GeneratedProtocolMessageType('CMsgLeagueScheduleBlockTeamInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLEAGUESCHEDULEBLOCKTEAMINFO,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgLeagueScheduleBlockTeamInfo)
  ))
_sym_db.RegisterMessage(CMsgLeagueScheduleBlockTeamInfo)

CMsgLeagueScheduleBlock = _reflection.GeneratedProtocolMessageType('CMsgLeagueScheduleBlock', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLEAGUESCHEDULEBLOCK,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgLeagueScheduleBlock)
  ))
_sym_db.RegisterMessage(CMsgLeagueScheduleBlock)

CMsgDOTALeague = _reflection.GeneratedProtocolMessageType('CMsgDOTALeague', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALEAGUE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALeague)
  ))
_sym_db.RegisterMessage(CMsgDOTALeague)

CMsgDOTALeagueScheduleRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTALeagueScheduleRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALEAGUESCHEDULEREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALeagueScheduleRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTALeagueScheduleRequest)

CMsgDOTALeagueScheduleResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTALeagueScheduleResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALEAGUESCHEDULERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALeagueScheduleResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTALeagueScheduleResponse)

CMsgDOTALeagueScheduleEdit = _reflection.GeneratedProtocolMessageType('CMsgDOTALeagueScheduleEdit', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALEAGUESCHEDULEEDIT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALeagueScheduleEdit)
  ))
_sym_db.RegisterMessage(CMsgDOTALeagueScheduleEdit)

CMsgDOTALeagueScheduleEditResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTALeagueScheduleEditResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALEAGUESCHEDULEEDITRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALeagueScheduleEditResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTALeagueScheduleEditResponse)

CMsgDOTALeaguesInMonthRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTALeaguesInMonthRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALEAGUESINMONTHREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALeaguesInMonthRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTALeaguesInMonthRequest)

CMsgDOTALeaguesInMonthResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTALeaguesInMonthResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALEAGUESINMONTHRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALeaguesInMonthResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTALeaguesInMonthResponse)

CMsgMatchmakingMatchGroupInfo = _reflection.GeneratedProtocolMessageType('CMsgMatchmakingMatchGroupInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGMATCHMAKINGMATCHGROUPINFO,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgMatchmakingMatchGroupInfo)
  ))
_sym_db.RegisterMessage(CMsgMatchmakingMatchGroupInfo)

CMsgDOTAMatchmakingStatsRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAMatchmakingStatsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAMATCHMAKINGSTATSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAMatchmakingStatsRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAMatchmakingStatsRequest)

CMsgDOTAMatchmakingStatsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAMatchmakingStatsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAMATCHMAKINGSTATSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAMatchmakingStatsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAMatchmakingStatsResponse)

CMsgDOTAUpdateMatchmakingStats = _reflection.GeneratedProtocolMessageType('CMsgDOTAUpdateMatchmakingStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAUPDATEMATCHMAKINGSTATS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAUpdateMatchmakingStats)
  ))
_sym_db.RegisterMessage(CMsgDOTAUpdateMatchmakingStats)

CMsgDOTAUpdateMatchManagementStats = _reflection.GeneratedProtocolMessageType('CMsgDOTAUpdateMatchManagementStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAUPDATEMATCHMANAGEMENTSTATS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAUpdateMatchManagementStats)
  ))
_sym_db.RegisterMessage(CMsgDOTAUpdateMatchManagementStats)

CMsgDOTASetMatchHistoryAccess = _reflection.GeneratedProtocolMessageType('CMsgDOTASetMatchHistoryAccess', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASETMATCHHISTORYACCESS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTASetMatchHistoryAccess)
  ))
_sym_db.RegisterMessage(CMsgDOTASetMatchHistoryAccess)

CMsgDOTASetMatchHistoryAccessResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTASetMatchHistoryAccessResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASETMATCHHISTORYACCESSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTASetMatchHistoryAccessResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTASetMatchHistoryAccessResponse)

CMsgDOTANotifyAccountFlagsChange = _reflection.GeneratedProtocolMessageType('CMsgDOTANotifyAccountFlagsChange', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTANOTIFYACCOUNTFLAGSCHANGE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTANotifyAccountFlagsChange)
  ))
_sym_db.RegisterMessage(CMsgDOTANotifyAccountFlagsChange)

CMsgDOTASetProfilePrivacy = _reflection.GeneratedProtocolMessageType('CMsgDOTASetProfilePrivacy', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASETPROFILEPRIVACY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTASetProfilePrivacy)
  ))
_sym_db.RegisterMessage(CMsgDOTASetProfilePrivacy)

CMsgDOTASetProfilePrivacyResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTASetProfilePrivacyResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASETPROFILEPRIVACYRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTASetProfilePrivacyResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTASetProfilePrivacyResponse)

CMsgUpgradeLeagueItem = _reflection.GeneratedProtocolMessageType('CMsgUpgradeLeagueItem', (_message.Message,), dict(
  DESCRIPTOR = _CMSGUPGRADELEAGUEITEM,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgUpgradeLeagueItem)
  ))
_sym_db.RegisterMessage(CMsgUpgradeLeagueItem)

CMsgUpgradeLeagueItemResponse = _reflection.GeneratedProtocolMessageType('CMsgUpgradeLeagueItemResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGUPGRADELEAGUEITEMRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgUpgradeLeagueItemResponse)
  ))
_sym_db.RegisterMessage(CMsgUpgradeLeagueItemResponse)

CMsgGCWatchDownloadedReplay = _reflection.GeneratedProtocolMessageType('CMsgGCWatchDownloadedReplay', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCWATCHDOWNLOADEDREPLAY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCWatchDownloadedReplay)
  ))
_sym_db.RegisterMessage(CMsgGCWatchDownloadedReplay)

CMsgSetMapLocationState = _reflection.GeneratedProtocolMessageType('CMsgSetMapLocationState', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSETMAPLOCATIONSTATE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSetMapLocationState)
  ))
_sym_db.RegisterMessage(CMsgSetMapLocationState)

CMsgSetMapLocationStateResponse = _reflection.GeneratedProtocolMessageType('CMsgSetMapLocationStateResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSETMAPLOCATIONSTATERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSetMapLocationStateResponse)
  ))
_sym_db.RegisterMessage(CMsgSetMapLocationStateResponse)

CMsgResetMapLocations = _reflection.GeneratedProtocolMessageType('CMsgResetMapLocations', (_message.Message,), dict(
  DESCRIPTOR = _CMSGRESETMAPLOCATIONS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgResetMapLocations)
  ))
_sym_db.RegisterMessage(CMsgResetMapLocations)

CMsgResetMapLocationsResponse = _reflection.GeneratedProtocolMessageType('CMsgResetMapLocationsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGRESETMAPLOCATIONSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgResetMapLocationsResponse)
  ))
_sym_db.RegisterMessage(CMsgResetMapLocationsResponse)

CMsgRefreshPartnerAccountLink = _reflection.GeneratedProtocolMessageType('CMsgRefreshPartnerAccountLink', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREFRESHPARTNERACCOUNTLINK,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRefreshPartnerAccountLink)
  ))
_sym_db.RegisterMessage(CMsgRefreshPartnerAccountLink)

CMsgClientsRejoinChatChannels = _reflection.GeneratedProtocolMessageType('CMsgClientsRejoinChatChannels', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTSREJOINCHATCHANNELS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientsRejoinChatChannels)
  ))
_sym_db.RegisterMessage(CMsgClientsRejoinChatChannels)

CMsgDOTASendFriendRecruits = _reflection.GeneratedProtocolMessageType('CMsgDOTASendFriendRecruits', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASENDFRIENDRECRUITS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTASendFriendRecruits)
  ))
_sym_db.RegisterMessage(CMsgDOTASendFriendRecruits)

CMsgDOTAFriendRecruitsRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFriendRecruitsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFRIENDRECRUITSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFriendRecruitsRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFriendRecruitsRequest)

CMsgDOTAFriendRecruitsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFriendRecruitsResponse', (_message.Message,), dict(

  FriendRecruitStatus = _reflection.GeneratedProtocolMessageType('FriendRecruitStatus', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAFRIENDRECRUITSRESPONSE_FRIENDRECRUITSTATUS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAFRIENDRECRUITSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFriendRecruitsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFriendRecruitsResponse)
_sym_db.RegisterMessage(CMsgDOTAFriendRecruitsResponse.FriendRecruitStatus)

CMsgDOTAFriendRecruitInviteAcceptDecline = _reflection.GeneratedProtocolMessageType('CMsgDOTAFriendRecruitInviteAcceptDecline', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFRIENDRECRUITINVITEACCEPTDECLINE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFriendRecruitInviteAcceptDecline)
  ))
_sym_db.RegisterMessage(CMsgDOTAFriendRecruitInviteAcceptDecline)

CMsgRequestLeaguePrizePool = _reflection.GeneratedProtocolMessageType('CMsgRequestLeaguePrizePool', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTLEAGUEPRIZEPOOL,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRequestLeaguePrizePool)
  ))
_sym_db.RegisterMessage(CMsgRequestLeaguePrizePool)

CMsgRequestLeaguePrizePoolResponse = _reflection.GeneratedProtocolMessageType('CMsgRequestLeaguePrizePoolResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTLEAGUEPRIZEPOOLRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRequestLeaguePrizePoolResponse)
  ))
_sym_db.RegisterMessage(CMsgRequestLeaguePrizePoolResponse)

CMsgGCGetHeroStandings = _reflection.GeneratedProtocolMessageType('CMsgGCGetHeroStandings', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCGETHEROSTANDINGS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCGetHeroStandings)
  ))
_sym_db.RegisterMessage(CMsgGCGetHeroStandings)

CMsgGCGetHeroStandingsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCGetHeroStandingsResponse', (_message.Message,), dict(

  Hero = _reflection.GeneratedProtocolMessageType('Hero', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCGETHEROSTANDINGSRESPONSE_HERO,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCGetHeroStandingsResponse.Hero)
    ))
  ,
  DESCRIPTOR = _CMSGGCGETHEROSTANDINGSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCGetHeroStandingsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCGetHeroStandingsResponse)
_sym_db.RegisterMessage(CMsgGCGetHeroStandingsResponse.Hero)

CMsgGCItemEditorReservationsRequest = _reflection.GeneratedProtocolMessageType('CMsgGCItemEditorReservationsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMEDITORRESERVATIONSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCItemEditorReservationsRequest)
  ))
_sym_db.RegisterMessage(CMsgGCItemEditorReservationsRequest)

CMsgGCItemEditorReservation = _reflection.GeneratedProtocolMessageType('CMsgGCItemEditorReservation', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMEDITORRESERVATION,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCItemEditorReservation)
  ))
_sym_db.RegisterMessage(CMsgGCItemEditorReservation)

CMsgGCItemEditorReservationsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCItemEditorReservationsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMEDITORRESERVATIONSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCItemEditorReservationsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCItemEditorReservationsResponse)

CMsgGCItemEditorReserveItemDef = _reflection.GeneratedProtocolMessageType('CMsgGCItemEditorReserveItemDef', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMEDITORRESERVEITEMDEF,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCItemEditorReserveItemDef)
  ))
_sym_db.RegisterMessage(CMsgGCItemEditorReserveItemDef)

CMsgGCItemEditorReserveItemDefResponse = _reflection.GeneratedProtocolMessageType('CMsgGCItemEditorReserveItemDefResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMEDITORRESERVEITEMDEFRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCItemEditorReserveItemDefResponse)
  ))
_sym_db.RegisterMessage(CMsgGCItemEditorReserveItemDefResponse)

CMsgGCItemEditorReleaseReservation = _reflection.GeneratedProtocolMessageType('CMsgGCItemEditorReleaseReservation', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMEDITORRELEASERESERVATION,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCItemEditorReleaseReservation)
  ))
_sym_db.RegisterMessage(CMsgGCItemEditorReleaseReservation)

CMsgGCItemEditorReleaseReservationResponse = _reflection.GeneratedProtocolMessageType('CMsgGCItemEditorReleaseReservationResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMEDITORRELEASERESERVATIONRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCItemEditorReleaseReservationResponse)
  ))
_sym_db.RegisterMessage(CMsgGCItemEditorReleaseReservationResponse)

CMsgGCItemEditorRequestLeagueInfo = _reflection.GeneratedProtocolMessageType('CMsgGCItemEditorRequestLeagueInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMEDITORREQUESTLEAGUEINFO,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCItemEditorRequestLeagueInfo)
  ))
_sym_db.RegisterMessage(CMsgGCItemEditorRequestLeagueInfo)

CMsgGCItemEditorLeagueInfoResponse = _reflection.GeneratedProtocolMessageType('CMsgGCItemEditorLeagueInfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCITEMEDITORLEAGUEINFORESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCItemEditorLeagueInfoResponse)
  ))
_sym_db.RegisterMessage(CMsgGCItemEditorLeagueInfoResponse)

CMsgDOTARewardTutorialPrizes = _reflection.GeneratedProtocolMessageType('CMsgDOTARewardTutorialPrizes', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREWARDTUTORIALPRIZES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTARewardTutorialPrizes)
  ))
_sym_db.RegisterMessage(CMsgDOTARewardTutorialPrizes)

CMsgDOTALastHitChallengeHighScorePost = _reflection.GeneratedProtocolMessageType('CMsgDOTALastHitChallengeHighScorePost', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALASTHITCHALLENGEHIGHSCOREPOST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALastHitChallengeHighScorePost)
  ))
_sym_db.RegisterMessage(CMsgDOTALastHitChallengeHighScorePost)

CMsgDOTALastHitChallengeHighScoreRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTALastHitChallengeHighScoreRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALASTHITCHALLENGEHIGHSCOREREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALastHitChallengeHighScoreRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTALastHitChallengeHighScoreRequest)

CMsgDOTALastHitChallengeHighScoreResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTALastHitChallengeHighScoreResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALASTHITCHALLENGEHIGHSCORERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALastHitChallengeHighScoreResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTALastHitChallengeHighScoreResponse)

CMsgFlipLobbyTeams = _reflection.GeneratedProtocolMessageType('CMsgFlipLobbyTeams', (_message.Message,), dict(
  DESCRIPTOR = _CMSGFLIPLOBBYTEAMS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgFlipLobbyTeams)
  ))
_sym_db.RegisterMessage(CMsgFlipLobbyTeams)

CMsgPresentedClientTerminateDlg = _reflection.GeneratedProtocolMessageType('CMsgPresentedClientTerminateDlg', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPRESENTEDCLIENTTERMINATEDLG,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPresentedClientTerminateDlg)
  ))
_sym_db.RegisterMessage(CMsgPresentedClientTerminateDlg)

CMsgGCLobbyUpdateBroadcastChannelInfo = _reflection.GeneratedProtocolMessageType('CMsgGCLobbyUpdateBroadcastChannelInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCLOBBYUPDATEBROADCASTCHANNELINFO,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCLobbyUpdateBroadcastChannelInfo)
  ))
_sym_db.RegisterMessage(CMsgGCLobbyUpdateBroadcastChannelInfo)

CMsgDOTARedeemEventPrize = _reflection.GeneratedProtocolMessageType('CMsgDOTARedeemEventPrize', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREDEEMEVENTPRIZE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTARedeemEventPrize)
  ))
_sym_db.RegisterMessage(CMsgDOTARedeemEventPrize)

CMsgDOTARedeemEventPrizeResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTARedeemEventPrizeResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREDEEMEVENTPRIZERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTARedeemEventPrizeResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTARedeemEventPrizeResponse)

CMsgDOTAGetEventPoints = _reflection.GeneratedProtocolMessageType('CMsgDOTAGetEventPoints', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGETEVENTPOINTS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGetEventPoints)
  ))
_sym_db.RegisterMessage(CMsgDOTAGetEventPoints)

CMsgDOTAGetEventPointsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGetEventPointsResponse', (_message.Message,), dict(

  Action = _reflection.GeneratedProtocolMessageType('Action', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAGETEVENTPOINTSRESPONSE_ACTION,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAGetEventPointsResponse.Action)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAGETEVENTPOINTSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGetEventPointsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGetEventPointsResponse)
_sym_db.RegisterMessage(CMsgDOTAGetEventPointsResponse.Action)

CMsgDOTALiveLeagueGameUpdate = _reflection.GeneratedProtocolMessageType('CMsgDOTALiveLeagueGameUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALIVELEAGUEGAMEUPDATE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALiveLeagueGameUpdate)
  ))
_sym_db.RegisterMessage(CMsgDOTALiveLeagueGameUpdate)

CMsgDOTACompendiumSelection = _reflection.GeneratedProtocolMessageType('CMsgDOTACompendiumSelection', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACOMPENDIUMSELECTION,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTACompendiumSelection)
  ))
_sym_db.RegisterMessage(CMsgDOTACompendiumSelection)

CMsgDOTACompendiumSelectionResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTACompendiumSelectionResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACOMPENDIUMSELECTIONRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTACompendiumSelectionResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTACompendiumSelectionResponse)

CMsgDOTACompendiumData = _reflection.GeneratedProtocolMessageType('CMsgDOTACompendiumData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACOMPENDIUMDATA,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTACompendiumData)
  ))
_sym_db.RegisterMessage(CMsgDOTACompendiumData)

CMsgDOTACompendiumDataRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTACompendiumDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACOMPENDIUMDATAREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTACompendiumDataRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTACompendiumDataRequest)

CMsgDOTACompendiumDataResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTACompendiumDataResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACOMPENDIUMDATARESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTACompendiumDataResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTACompendiumDataResponse)

CMsgDOTAGetPlayerMatchHistory = _reflection.GeneratedProtocolMessageType('CMsgDOTAGetPlayerMatchHistory', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGETPLAYERMATCHHISTORY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGetPlayerMatchHistory)
  ))
_sym_db.RegisterMessage(CMsgDOTAGetPlayerMatchHistory)

CMsgDOTAGetPlayerMatchHistoryResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGetPlayerMatchHistoryResponse', (_message.Message,), dict(

  Match = _reflection.GeneratedProtocolMessageType('Match', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE_MATCH,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAGetPlayerMatchHistoryResponse.Match)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAGETPLAYERMATCHHISTORYRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGetPlayerMatchHistoryResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGetPlayerMatchHistoryResponse)
_sym_db.RegisterMessage(CMsgDOTAGetPlayerMatchHistoryResponse.Match)

CMsgDOTAStartDailyHeroChallenge = _reflection.GeneratedProtocolMessageType('CMsgDOTAStartDailyHeroChallenge', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASTARTDAILYHEROCHALLENGE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAStartDailyHeroChallenge)
  ))
_sym_db.RegisterMessage(CMsgDOTAStartDailyHeroChallenge)

CMsgGCNotificationsRequest = _reflection.GeneratedProtocolMessageType('CMsgGCNotificationsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCNOTIFICATIONSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCNotificationsRequest)
  ))
_sym_db.RegisterMessage(CMsgGCNotificationsRequest)

CMsgGCNotificationsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCNotificationsResponse', (_message.Message,), dict(

  Notification = _reflection.GeneratedProtocolMessageType('Notification', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCNOTIFICATIONSRESPONSE_NOTIFICATION,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCNotificationsResponse.Notification)
    ))
  ,
  DESCRIPTOR = _CMSGGCNOTIFICATIONSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCNotificationsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCNotificationsResponse)
_sym_db.RegisterMessage(CMsgGCNotificationsResponse.Notification)

CMsgGCNotificationsMarkReadRequest = _reflection.GeneratedProtocolMessageType('CMsgGCNotificationsMarkReadRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCNOTIFICATIONSMARKREADREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCNotificationsMarkReadRequest)
  ))
_sym_db.RegisterMessage(CMsgGCNotificationsMarkReadRequest)

CMsgClientToGCMarkNotificationListRead = _reflection.GeneratedProtocolMessageType('CMsgClientToGCMarkNotificationListRead', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCMARKNOTIFICATIONLISTREAD,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCMarkNotificationListRead)
  ))
_sym_db.RegisterMessage(CMsgClientToGCMarkNotificationListRead)

CMsgGCLeagueAdminState = _reflection.GeneratedProtocolMessageType('CMsgGCLeagueAdminState', (_message.Message,), dict(

  PrivateLeagueKeys = _reflection.GeneratedProtocolMessageType('PrivateLeagueKeys', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCLEAGUEADMINSTATE_PRIVATELEAGUEKEYS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCLeagueAdminState.PrivateLeagueKeys)
    ))
  ,
  DESCRIPTOR = _CMSGGCLEAGUEADMINSTATE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCLeagueAdminState)
  ))
_sym_db.RegisterMessage(CMsgGCLeagueAdminState)
_sym_db.RegisterMessage(CMsgGCLeagueAdminState.PrivateLeagueKeys)

CMsgGCPlayerInfoRequest = _reflection.GeneratedProtocolMessageType('CMsgGCPlayerInfoRequest', (_message.Message,), dict(

  PlayerInfo = _reflection.GeneratedProtocolMessageType('PlayerInfo', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCPLAYERINFOREQUEST_PLAYERINFO,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCPlayerInfoRequest.PlayerInfo)
    ))
  ,
  DESCRIPTOR = _CMSGGCPLAYERINFOREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCPlayerInfoRequest)
  ))
_sym_db.RegisterMessage(CMsgGCPlayerInfoRequest)
_sym_db.RegisterMessage(CMsgGCPlayerInfoRequest.PlayerInfo)

CMsgGCPlayerInfoSubmit = _reflection.GeneratedProtocolMessageType('CMsgGCPlayerInfoSubmit', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCPLAYERINFOSUBMIT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCPlayerInfoSubmit)
  ))
_sym_db.RegisterMessage(CMsgGCPlayerInfoSubmit)

CMsgGCPlayerInfoSubmitResponse = _reflection.GeneratedProtocolMessageType('CMsgGCPlayerInfoSubmitResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCPLAYERINFOSUBMITRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCPlayerInfoSubmitResponse)
  ))
_sym_db.RegisterMessage(CMsgGCPlayerInfoSubmitResponse)

CMsgClientProvideSurveyResult = _reflection.GeneratedProtocolMessageType('CMsgClientProvideSurveyResult', (_message.Message,), dict(

  Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTPROVIDESURVEYRESULT_RESPONSE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientProvideSurveyResult.Response)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTPROVIDESURVEYRESULT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientProvideSurveyResult)
  ))
_sym_db.RegisterMessage(CMsgClientProvideSurveyResult)
_sym_db.RegisterMessage(CMsgClientProvideSurveyResult.Response)

CMsgDOTAEmoticonAccessSDO = _reflection.GeneratedProtocolMessageType('CMsgDOTAEmoticonAccessSDO', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAEMOTICONACCESSSDO,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAEmoticonAccessSDO)
  ))
_sym_db.RegisterMessage(CMsgDOTAEmoticonAccessSDO)

CMsgClientToGCEmoticonDataRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCEmoticonDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCEMOTICONDATAREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCEmoticonDataRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCEmoticonDataRequest)

CMsgGCToClientEmoticonData = _reflection.GeneratedProtocolMessageType('CMsgGCToClientEmoticonData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTEMOTICONDATA,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientEmoticonData)
  ))
_sym_db.RegisterMessage(CMsgGCToClientEmoticonData)

CMsgClientToGCTrackDialogResult = _reflection.GeneratedProtocolMessageType('CMsgClientToGCTrackDialogResult', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCTRACKDIALOGRESULT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCTrackDialogResult)
  ))
_sym_db.RegisterMessage(CMsgClientToGCTrackDialogResult)

CMsgGCToClientTournamentItemDrop = _reflection.GeneratedProtocolMessageType('CMsgGCToClientTournamentItemDrop', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTTOURNAMENTITEMDROP,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientTournamentItemDrop)
  ))
_sym_db.RegisterMessage(CMsgGCToClientTournamentItemDrop)

CMsgClientToGCSetAdditionalEquips = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSetAdditionalEquips', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSETADDITIONALEQUIPS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCSetAdditionalEquips)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSetAdditionalEquips)

CMsgClientToGCSetAdditionalEquipsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSetAdditionalEquipsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSETADDITIONALEQUIPSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCSetAdditionalEquipsResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSetAdditionalEquipsResponse)

CMsgClientToGCGetAdditionalEquips = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetAdditionalEquips', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETADDITIONALEQUIPS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetAdditionalEquips)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetAdditionalEquips)

CMsgClientToGCGetAdditionalEquipsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetAdditionalEquipsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETADDITIONALEQUIPSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetAdditionalEquipsResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetAdditionalEquipsResponse)

CMsgClientToGCGetAllHeroOrder = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetAllHeroOrder', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETALLHEROORDER,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetAllHeroOrder)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetAllHeroOrder)

CMsgClientToGCGetAllHeroOrderResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetAllHeroOrderResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETALLHEROORDERRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetAllHeroOrderResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetAllHeroOrderResponse)

CMsgClientToGCGetAllHeroProgress = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetAllHeroProgress', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETALLHEROPROGRESS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetAllHeroProgress)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetAllHeroProgress)

CMsgClientToGCGetAllHeroProgressResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetAllHeroProgressResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETALLHEROPROGRESSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetAllHeroProgressResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetAllHeroProgressResponse)

CMsgClientToGCGetTrophyList = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetTrophyList', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETTROPHYLIST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetTrophyList)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetTrophyList)

CMsgClientToGCGetTrophyListResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetTrophyListResponse', (_message.Message,), dict(

  Trophy = _reflection.GeneratedProtocolMessageType('Trophy', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCGETTROPHYLISTRESPONSE_TROPHY,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCGetTrophyListResponse.Trophy)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCGETTROPHYLISTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetTrophyListResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetTrophyListResponse)
_sym_db.RegisterMessage(CMsgClientToGCGetTrophyListResponse.Trophy)

CMsgGCToClientTrophyAwarded = _reflection.GeneratedProtocolMessageType('CMsgGCToClientTrophyAwarded', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTTROPHYAWARDED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientTrophyAwarded)
  ))
_sym_db.RegisterMessage(CMsgGCToClientTrophyAwarded)

CMsgClientToGCGetProfileCard = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetProfileCard', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETPROFILECARD,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetProfileCard)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetProfileCard)

CMsgClientToGCSetProfileCardSlots = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSetProfileCardSlots', (_message.Message,), dict(

  CardSlot = _reflection.GeneratedProtocolMessageType('CardSlot', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCSETPROFILECARDSLOTS_CARDSLOT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCSetProfileCardSlots.CardSlot)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCSETPROFILECARDSLOTS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCSetProfileCardSlots)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSetProfileCardSlots)
_sym_db.RegisterMessage(CMsgClientToGCSetProfileCardSlots.CardSlot)

CMsgClientToGCGetProfileCardStats = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetProfileCardStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETPROFILECARDSTATS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetProfileCardStats)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetProfileCardStats)

CMsgClientToGCCreateHeroStatue = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCreateHeroStatue', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCREATEHEROSTATUE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCCreateHeroStatue)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCreateHeroStatue)

CMsgGCToClientHeroStatueCreateResult = _reflection.GeneratedProtocolMessageType('CMsgGCToClientHeroStatueCreateResult', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTHEROSTATUECREATERESULT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientHeroStatueCreateResult)
  ))
_sym_db.RegisterMessage(CMsgGCToClientHeroStatueCreateResult)

CMsgClientToGCRecordCompendiumStats = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRecordCompendiumStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCRECORDCOMPENDIUMSTATS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRecordCompendiumStats)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRecordCompendiumStats)

CMsgGCToClientEventStatusChanged = _reflection.GeneratedProtocolMessageType('CMsgGCToClientEventStatusChanged', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTEVENTSTATUSCHANGED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientEventStatusChanged)
  ))
_sym_db.RegisterMessage(CMsgGCToClientEventStatusChanged)

CMsgClientToGCPlayerStatsRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCPlayerStatsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCPLAYERSTATSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCPlayerStatsRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCPlayerStatsRequest)

CMsgGCToClientPlayerStatsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientPlayerStatsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTPLAYERSTATSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientPlayerStatsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientPlayerStatsResponse)

CMsgClientToGCCustomGamePlayerCountRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCustomGamePlayerCountRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCUSTOMGAMEPLAYERCOUNTREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCCustomGamePlayerCountRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCustomGamePlayerCountRequest)

CMsgGCToClientCustomGamePlayerCountResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientCustomGamePlayerCountResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTCUSTOMGAMEPLAYERCOUNTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientCustomGamePlayerCountResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientCustomGamePlayerCountResponse)

CMsgClientToGCCustomGamesFriendsPlayedRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCustomGamesFriendsPlayedRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCUSTOMGAMESFRIENDSPLAYEDREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCCustomGamesFriendsPlayedRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCustomGamesFriendsPlayedRequest)

CMsgGCToClientCustomGamesFriendsPlayedResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientCustomGamesFriendsPlayedResponse', (_message.Message,), dict(

  CustomGame = _reflection.GeneratedProtocolMessageType('CustomGame', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE_CUSTOMGAME,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToClientCustomGamesFriendsPlayedResponse.CustomGame)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTCUSTOMGAMESFRIENDSPLAYEDRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientCustomGamesFriendsPlayedResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientCustomGamesFriendsPlayedResponse)
_sym_db.RegisterMessage(CMsgGCToClientCustomGamesFriendsPlayedResponse.CustomGame)

CMsgClientToGCSocialFeedPostCommentRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSocialFeedPostCommentRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSOCIALFEEDPOSTCOMMENTREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCSocialFeedPostCommentRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSocialFeedPostCommentRequest)

CMsgGCToClientSocialFeedPostCommentResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientSocialFeedPostCommentResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTSOCIALFEEDPOSTCOMMENTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientSocialFeedPostCommentResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientSocialFeedPostCommentResponse)

CMsgClientToGCSocialFeedPostMessageRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSocialFeedPostMessageRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSOCIALFEEDPOSTMESSAGEREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCSocialFeedPostMessageRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSocialFeedPostMessageRequest)

CMsgGCToClientSocialFeedPostMessageResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientSocialFeedPostMessageResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTSOCIALFEEDPOSTMESSAGERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientSocialFeedPostMessageResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientSocialFeedPostMessageResponse)

CMsgClientToGCFriendsPlayedCustomGameRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCFriendsPlayedCustomGameRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCFRIENDSPLAYEDCUSTOMGAMEREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCFriendsPlayedCustomGameRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCFriendsPlayedCustomGameRequest)

CMsgGCToClientFriendsPlayedCustomGameResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientFriendsPlayedCustomGameResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTFRIENDSPLAYEDCUSTOMGAMERESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientFriendsPlayedCustomGameResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientFriendsPlayedCustomGameResponse)

CMsgClientToGCFeaturedHeroesRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCFeaturedHeroesRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCFEATUREDHEROESREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCFeaturedHeroesRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCFeaturedHeroesRequest)

CMsgGCToClientFeaturedHeroesResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientFeaturedHeroesResponse', (_message.Message,), dict(

  DataField = _reflection.GeneratedProtocolMessageType('DataField', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_DATAFIELD,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToClientFeaturedHeroesResponse.DataField)
    ))
  ,

  FeaturedHero = _reflection.GeneratedProtocolMessageType('FeaturedHero', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_FEATUREDHERO,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToClientFeaturedHeroesResponse.FeaturedHero)
    ))
  ,

  Category = _reflection.GeneratedProtocolMessageType('Category', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTFEATUREDHEROESRESPONSE_CATEGORY,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToClientFeaturedHeroesResponse.Category)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTFEATUREDHEROESRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientFeaturedHeroesResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientFeaturedHeroesResponse)
_sym_db.RegisterMessage(CMsgGCToClientFeaturedHeroesResponse.DataField)
_sym_db.RegisterMessage(CMsgGCToClientFeaturedHeroesResponse.FeaturedHero)
_sym_db.RegisterMessage(CMsgGCToClientFeaturedHeroesResponse.Category)

CMsgClientToGCSocialMatchPostCommentRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSocialMatchPostCommentRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSOCIALMATCHPOSTCOMMENTREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCSocialMatchPostCommentRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSocialMatchPostCommentRequest)

CMsgGCToClientSocialMatchPostCommentResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientSocialMatchPostCommentResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTSOCIALMATCHPOSTCOMMENTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientSocialMatchPostCommentResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientSocialMatchPostCommentResponse)

CMsgClientToGCSocialMatchDetailsRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSocialMatchDetailsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSOCIALMATCHDETAILSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCSocialMatchDetailsRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSocialMatchDetailsRequest)

CMsgGCToClientSocialMatchDetailsResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientSocialMatchDetailsResponse', (_message.Message,), dict(

  Comment = _reflection.GeneratedProtocolMessageType('Comment', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE_COMMENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToClientSocialMatchDetailsResponse.Comment)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTSOCIALMATCHDETAILSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientSocialMatchDetailsResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientSocialMatchDetailsResponse)
_sym_db.RegisterMessage(CMsgGCToClientSocialMatchDetailsResponse.Comment)

CMsgDOTAPartyRichPresence = _reflection.GeneratedProtocolMessageType('CMsgDOTAPartyRichPresence', (_message.Message,), dict(

  Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAPARTYRICHPRESENCE_MEMBER,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAPartyRichPresence.Member)
    ))
  ,

  WeekendTourney = _reflection.GeneratedProtocolMessageType('WeekendTourney', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAPARTYRICHPRESENCE_WEEKENDTOURNEY,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAPartyRichPresence.WeekendTourney)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAPARTYRICHPRESENCE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAPartyRichPresence)
  ))
_sym_db.RegisterMessage(CMsgDOTAPartyRichPresence)
_sym_db.RegisterMessage(CMsgDOTAPartyRichPresence.Member)
_sym_db.RegisterMessage(CMsgDOTAPartyRichPresence.WeekendTourney)

CMsgDOTALobbyRichPresence = _reflection.GeneratedProtocolMessageType('CMsgDOTALobbyRichPresence', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTALOBBYRICHPRESENCE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTALobbyRichPresence)
  ))
_sym_db.RegisterMessage(CMsgDOTALobbyRichPresence)

CMsgDOTACustomGameListenServerStartedLoading = _reflection.GeneratedProtocolMessageType('CMsgDOTACustomGameListenServerStartedLoading', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACUSTOMGAMELISTENSERVERSTARTEDLOADING,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTACustomGameListenServerStartedLoading)
  ))
_sym_db.RegisterMessage(CMsgDOTACustomGameListenServerStartedLoading)

CMsgDOTACustomGameClientFinishedLoading = _reflection.GeneratedProtocolMessageType('CMsgDOTACustomGameClientFinishedLoading', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACUSTOMGAMECLIENTFINISHEDLOADING,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTACustomGameClientFinishedLoading)
  ))
_sym_db.RegisterMessage(CMsgDOTACustomGameClientFinishedLoading)

CMsgClientToGCGetLeagueSeries = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetLeagueSeries', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETLEAGUESERIES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetLeagueSeries)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetLeagueSeries)

CMsgClientToGCGetLeagueSeriesResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetLeagueSeriesResponse', (_message.Message,), dict(

  Series = _reflection.GeneratedProtocolMessageType('Series', (_message.Message,), dict(

    Team = _reflection.GeneratedProtocolMessageType('Team', (_message.Message,), dict(
      DESCRIPTOR = _CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE_SERIES_TEAM,
      __module__ = 'dota_gcmessages_client_pb2'
      # @@protoc_insertion_point(class_scope:CMsgClientToGCGetLeagueSeriesResponse.Series.Team)
      ))
    ,
    DESCRIPTOR = _CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE_SERIES,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCGetLeagueSeriesResponse.Series)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCGETLEAGUESERIESRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetLeagueSeriesResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetLeagueSeriesResponse)
_sym_db.RegisterMessage(CMsgClientToGCGetLeagueSeriesResponse.Series)
_sym_db.RegisterMessage(CMsgClientToGCGetLeagueSeriesResponse.Series.Team)

CMsgClientToGCApplyGemCombiner = _reflection.GeneratedProtocolMessageType('CMsgClientToGCApplyGemCombiner', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCAPPLYGEMCOMBINER,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCApplyGemCombiner)
  ))
_sym_db.RegisterMessage(CMsgClientToGCApplyGemCombiner)

CMsgClientToGCH264Unsupported = _reflection.GeneratedProtocolMessageType('CMsgClientToGCH264Unsupported', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCH264UNSUPPORTED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCH264Unsupported)
  ))
_sym_db.RegisterMessage(CMsgClientToGCH264Unsupported)

CMsgClientToGCRequestH264Support = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestH264Support', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTH264SUPPORT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestH264Support)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestH264Support)

CMsgClientToGCGetQuestProgress = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetQuestProgress', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETQUESTPROGRESS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetQuestProgress)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetQuestProgress)

CMsgClientToGCGetQuestProgressResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetQuestProgressResponse', (_message.Message,), dict(

  Challenge = _reflection.GeneratedProtocolMessageType('Challenge', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_CHALLENGE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCGetQuestProgressResponse.Challenge)
    ))
  ,

  Quest = _reflection.GeneratedProtocolMessageType('Quest', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE_QUEST,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCGetQuestProgressResponse.Quest)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCGETQUESTPROGRESSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetQuestProgressResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetQuestProgressResponse)
_sym_db.RegisterMessage(CMsgClientToGCGetQuestProgressResponse.Challenge)
_sym_db.RegisterMessage(CMsgClientToGCGetQuestProgressResponse.Quest)

CMsgGCToClientMatchSignedOut = _reflection.GeneratedProtocolMessageType('CMsgGCToClientMatchSignedOut', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTMATCHSIGNEDOUT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientMatchSignedOut)
  ))
_sym_db.RegisterMessage(CMsgGCToClientMatchSignedOut)

CMsgGCGetHeroStatsHistory = _reflection.GeneratedProtocolMessageType('CMsgGCGetHeroStatsHistory', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCGETHEROSTATSHISTORY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCGetHeroStatsHistory)
  ))
_sym_db.RegisterMessage(CMsgGCGetHeroStatsHistory)

CMsgGCGetHeroStatsHistoryResponse = _reflection.GeneratedProtocolMessageType('CMsgGCGetHeroStatsHistoryResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCGETHEROSTATSHISTORYRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCGetHeroStatsHistoryResponse)
  ))
_sym_db.RegisterMessage(CMsgGCGetHeroStatsHistoryResponse)

CMsgPlayerConductScorecardRequest = _reflection.GeneratedProtocolMessageType('CMsgPlayerConductScorecardRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPLAYERCONDUCTSCORECARDREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPlayerConductScorecardRequest)
  ))
_sym_db.RegisterMessage(CMsgPlayerConductScorecardRequest)

CMsgPlayerConductScorecard = _reflection.GeneratedProtocolMessageType('CMsgPlayerConductScorecard', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPLAYERCONDUCTSCORECARD,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPlayerConductScorecard)
  ))
_sym_db.RegisterMessage(CMsgPlayerConductScorecard)

CMsgClientToGCWageringRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCWageringRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCWAGERINGREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCWageringRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCWageringRequest)

CMsgGCToClientWageringResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientWageringResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTWAGERINGRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientWageringResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientWageringResponse)

CMsgGCToClientWageringUpdate = _reflection.GeneratedProtocolMessageType('CMsgGCToClientWageringUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTWAGERINGUPDATE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientWageringUpdate)
  ))
_sym_db.RegisterMessage(CMsgGCToClientWageringUpdate)

CMsgGCToClientArcanaVotesUpdate = _reflection.GeneratedProtocolMessageType('CMsgGCToClientArcanaVotesUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTARCANAVOTESUPDATE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientArcanaVotesUpdate)
  ))
_sym_db.RegisterMessage(CMsgGCToClientArcanaVotesUpdate)

CMsgClientToGCMysteryItem = _reflection.GeneratedProtocolMessageType('CMsgClientToGCMysteryItem', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCMYSTERYITEM,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCMysteryItem)
  ))
_sym_db.RegisterMessage(CMsgClientToGCMysteryItem)

CMsgGCToClientMysteryItemResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientMysteryItemResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTMYSTERYITEMRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientMysteryItemResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientMysteryItemResponse)

CMsgClientToGCGetEventGoals = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetEventGoals', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETEVENTGOALS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetEventGoals)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetEventGoals)

CMsgEventGoals = _reflection.GeneratedProtocolMessageType('CMsgEventGoals', (_message.Message,), dict(

  EventGoal = _reflection.GeneratedProtocolMessageType('EventGoal', (_message.Message,), dict(
    DESCRIPTOR = _CMSGEVENTGOALS_EVENTGOAL,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgEventGoals.EventGoal)
    ))
  ,
  DESCRIPTOR = _CMSGEVENTGOALS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgEventGoals)
  ))
_sym_db.RegisterMessage(CMsgEventGoals)
_sym_db.RegisterMessage(CMsgEventGoals.EventGoal)

CMsgGCToGCLeaguePredictions = _reflection.GeneratedProtocolMessageType('CMsgGCToGCLeaguePredictions', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCLEAGUEPREDICTIONS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCLeaguePredictions)
  ))
_sym_db.RegisterMessage(CMsgGCToGCLeaguePredictions)

CMsgPredictionRankings = _reflection.GeneratedProtocolMessageType('CMsgPredictionRankings', (_message.Message,), dict(

  PredictionLine = _reflection.GeneratedProtocolMessageType('PredictionLine', (_message.Message,), dict(
    DESCRIPTOR = _CMSGPREDICTIONRANKINGS_PREDICTIONLINE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgPredictionRankings.PredictionLine)
    ))
  ,

  Prediction = _reflection.GeneratedProtocolMessageType('Prediction', (_message.Message,), dict(
    DESCRIPTOR = _CMSGPREDICTIONRANKINGS_PREDICTION,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgPredictionRankings.Prediction)
    ))
  ,
  DESCRIPTOR = _CMSGPREDICTIONRANKINGS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPredictionRankings)
  ))
_sym_db.RegisterMessage(CMsgPredictionRankings)
_sym_db.RegisterMessage(CMsgPredictionRankings.PredictionLine)
_sym_db.RegisterMessage(CMsgPredictionRankings.Prediction)

CMsgPredictionResults = _reflection.GeneratedProtocolMessageType('CMsgPredictionResults', (_message.Message,), dict(

  ResultBreakdown = _reflection.GeneratedProtocolMessageType('ResultBreakdown', (_message.Message,), dict(
    DESCRIPTOR = _CMSGPREDICTIONRESULTS_RESULTBREAKDOWN,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgPredictionResults.ResultBreakdown)
    ))
  ,

  Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), dict(
    DESCRIPTOR = _CMSGPREDICTIONRESULTS_RESULT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgPredictionResults.Result)
    ))
  ,
  DESCRIPTOR = _CMSGPREDICTIONRESULTS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPredictionResults)
  ))
_sym_db.RegisterMessage(CMsgPredictionResults)
_sym_db.RegisterMessage(CMsgPredictionResults.ResultBreakdown)
_sym_db.RegisterMessage(CMsgPredictionResults.Result)

CMsgClientToGCSuspiciousActivity = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSuspiciousActivity', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSUSPICIOUSACTIVITY,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCSuspiciousActivity)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSuspiciousActivity)

CMsgClientToGCHasPlayerVotedForMVP = _reflection.GeneratedProtocolMessageType('CMsgClientToGCHasPlayerVotedForMVP', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCHASPLAYERVOTEDFORMVP,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCHasPlayerVotedForMVP)
  ))
_sym_db.RegisterMessage(CMsgClientToGCHasPlayerVotedForMVP)

CMsgClientToGCHasPlayerVotedForMVPResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCHasPlayerVotedForMVPResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCHASPLAYERVOTEDFORMVPRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCHasPlayerVotedForMVPResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCHasPlayerVotedForMVPResponse)

CMsgClientToGCVoteForMVP = _reflection.GeneratedProtocolMessageType('CMsgClientToGCVoteForMVP', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCVOTEFORMVP,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCVoteForMVP)
  ))
_sym_db.RegisterMessage(CMsgClientToGCVoteForMVP)

CMsgClientToGCVoteForMVPResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCVoteForMVPResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCVOTEFORMVPRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCVoteForMVPResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCVoteForMVPResponse)

CMsgMVPVotesForMatch = _reflection.GeneratedProtocolMessageType('CMsgMVPVotesForMatch', (_message.Message,), dict(

  Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), dict(
    DESCRIPTOR = _CMSGMVPVOTESFORMATCH_PLAYER,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgMVPVotesForMatch.Player)
    ))
  ,
  DESCRIPTOR = _CMSGMVPVOTESFORMATCH,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgMVPVotesForMatch)
  ))
_sym_db.RegisterMessage(CMsgMVPVotesForMatch)
_sym_db.RegisterMessage(CMsgMVPVotesForMatch.Player)

CMsgLeaguePrizePool = _reflection.GeneratedProtocolMessageType('CMsgLeaguePrizePool', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLEAGUEPRIZEPOOL,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgLeaguePrizePool)
  ))
_sym_db.RegisterMessage(CMsgLeaguePrizePool)

CMsgClientToGCTeammateStatsRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCTeammateStatsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCTEAMMATESTATSREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCTeammateStatsRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCTeammateStatsRequest)

CMsgClientToGCTeammateStatsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCTeammateStatsResponse', (_message.Message,), dict(

  TeammateStat = _reflection.GeneratedProtocolMessageType('TeammateStat', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCTEAMMATESTATSRESPONSE_TEAMMATESTAT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCTeammateStatsResponse.TeammateStat)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCTEAMMATESTATSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCTeammateStatsResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCTeammateStatsResponse)
_sym_db.RegisterMessage(CMsgClientToGCTeammateStatsResponse.TeammateStat)

CMsgClientToGCVoteForArcana = _reflection.GeneratedProtocolMessageType('CMsgClientToGCVoteForArcana', (_message.Message,), dict(

  MatchVote = _reflection.GeneratedProtocolMessageType('MatchVote', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCVOTEFORARCANA_MATCHVOTE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCVoteForArcana.MatchVote)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCVOTEFORARCANA,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCVoteForArcana)
  ))
_sym_db.RegisterMessage(CMsgClientToGCVoteForArcana)
_sym_db.RegisterMessage(CMsgClientToGCVoteForArcana.MatchVote)

CMsgClientToGCVoteForArcanaResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCVoteForArcanaResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCVOTEFORARCANARESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCVoteForArcanaResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCVoteForArcanaResponse)

CMsgArcanaVotes = _reflection.GeneratedProtocolMessageType('CMsgArcanaVotes', (_message.Message,), dict(

  Match = _reflection.GeneratedProtocolMessageType('Match', (_message.Message,), dict(
    DESCRIPTOR = _CMSGARCANAVOTES_MATCH,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgArcanaVotes.Match)
    ))
  ,
  DESCRIPTOR = _CMSGARCANAVOTES,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgArcanaVotes)
  ))
_sym_db.RegisterMessage(CMsgArcanaVotes)
_sym_db.RegisterMessage(CMsgArcanaVotes.Match)

CMsgClientToGCRequestArcanaVotesRemaining = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestArcanaVotesRemaining', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTARCANAVOTESREMAINING,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestArcanaVotesRemaining)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestArcanaVotesRemaining)

CMsgClientToGCRequestArcanaVotesRemainingResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestArcanaVotesRemainingResponse', (_message.Message,), dict(

  MatchVote = _reflection.GeneratedProtocolMessageType('MatchVote', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE_MATCHVOTE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestArcanaVotesRemainingResponse.MatchVote)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTARCANAVOTESREMAININGRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestArcanaVotesRemainingResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestArcanaVotesRemainingResponse)
_sym_db.RegisterMessage(CMsgClientToGCRequestArcanaVotesRemainingResponse.MatchVote)

CMsgClientToGCRequestEventPointLog = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestEventPointLog', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOG,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestEventPointLog)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLog)

CMsgClientToGCRequestEventPointLogResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestEventPointLogResponse', (_message.Message,), dict(

  QuestChallengeEvent = _reflection.GeneratedProtocolMessageType('QuestChallengeEvent', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_QUESTCHALLENGEEVENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestEventPointLogResponse.QuestChallengeEvent)
    ))
  ,

  WagerWonEvent = _reflection.GeneratedProtocolMessageType('WagerWonEvent', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_WAGERWONEVENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestEventPointLogResponse.WagerWonEvent)
    ))
  ,

  TipGivenEvent = _reflection.GeneratedProtocolMessageType('TipGivenEvent', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_TIPGIVENEVENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestEventPointLogResponse.TipGivenEvent)
    ))
  ,

  TipReceivedEvent = _reflection.GeneratedProtocolMessageType('TipReceivedEvent', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_TIPRECEIVEDEVENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestEventPointLogResponse.TipReceivedEvent)
    ))
  ,

  RecycledItemEvent = _reflection.GeneratedProtocolMessageType('RecycledItemEvent', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_RECYCLEDITEMEVENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestEventPointLogResponse.RecycledItemEvent)
    ))
  ,

  AchievementEvent = _reflection.GeneratedProtocolMessageType('AchievementEvent', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_ACHIEVEMENTEVENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestEventPointLogResponse.AchievementEvent)
    ))
  ,

  MysteryItemReceivedEvent = _reflection.GeneratedProtocolMessageType('MysteryItemReceivedEvent', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_MYSTERYITEMRECEIVEDEVENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestEventPointLogResponse.MysteryItemReceivedEvent)
    ))
  ,

  CorrectPredictionEvent = _reflection.GeneratedProtocolMessageType('CorrectPredictionEvent', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_CORRECTPREDICTIONEVENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestEventPointLogResponse.CorrectPredictionEvent)
    ))
  ,

  InGamePredictionCorrectEvent = _reflection.GeneratedProtocolMessageType('InGamePredictionCorrectEvent', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_INGAMEPREDICTIONCORRECTEVENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestEventPointLogResponse.InGamePredictionCorrectEvent)
    ))
  ,

  WeekendTourneyPayoutEvent = _reflection.GeneratedProtocolMessageType('WeekendTourneyPayoutEvent', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_WEEKENDTOURNEYPAYOUTEVENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestEventPointLogResponse.WeekendTourneyPayoutEvent)
    ))
  ,

  FantasyRewardEvent = _reflection.GeneratedProtocolMessageType('FantasyRewardEvent', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_FANTASYREWARDEVENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestEventPointLogResponse.FantasyRewardEvent)
    ))
  ,

  BracketRewardEvent = _reflection.GeneratedProtocolMessageType('BracketRewardEvent', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_BRACKETREWARDEVENT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestEventPointLogResponse.BracketRewardEvent)
    ))
  ,

  EventPointTransaction = _reflection.GeneratedProtocolMessageType('EventPointTransaction', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE_EVENTPOINTTRANSACTION,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTEVENTPOINTLOGRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestEventPointLogResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogResponse)
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogResponse.QuestChallengeEvent)
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogResponse.WagerWonEvent)
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogResponse.TipGivenEvent)
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogResponse.TipReceivedEvent)
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogResponse.RecycledItemEvent)
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogResponse.AchievementEvent)
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogResponse.MysteryItemReceivedEvent)
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogResponse.CorrectPredictionEvent)
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogResponse.InGamePredictionCorrectEvent)
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogResponse.WeekendTourneyPayoutEvent)
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogResponse.FantasyRewardEvent)
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogResponse.BracketRewardEvent)
_sym_db.RegisterMessage(CMsgClientToGCRequestEventPointLogResponse.EventPointTransaction)

CMsgClientToGCPublishUserStat = _reflection.GeneratedProtocolMessageType('CMsgClientToGCPublishUserStat', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCPUBLISHUSERSTAT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCPublishUserStat)
  ))
_sym_db.RegisterMessage(CMsgClientToGCPublishUserStat)

CMsgClientToGCAddTI6TreeProgress = _reflection.GeneratedProtocolMessageType('CMsgClientToGCAddTI6TreeProgress', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCADDTI6TREEPROGRESS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCAddTI6TreeProgress)
  ))
_sym_db.RegisterMessage(CMsgClientToGCAddTI6TreeProgress)

CMsgClientToGCRedeemReward = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRedeemReward', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREDEEMREWARD,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRedeemReward)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRedeemReward)

CMsgGCToClientRedeemRewardResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientRedeemRewardResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTREDEEMREWARDRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientRedeemRewardResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientRedeemRewardResponse)

CMsgClientToGCRequestLinaPlaysRemaining = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestLinaPlaysRemaining', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTLINAPLAYSREMAINING,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestLinaPlaysRemaining)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestLinaPlaysRemaining)

CMsgClientToGCRequestLinaPlaysRemainingResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestLinaPlaysRemainingResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTLINAPLAYSREMAININGRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestLinaPlaysRemainingResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestLinaPlaysRemainingResponse)

CMsgClientToGCRequestLinaGameResult = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestLinaGameResult', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTLINAGAMERESULT,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestLinaGameResult)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestLinaGameResult)

CMsgClientToGCRequestLinaGameResultResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRequestLinaGameResultResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREQUESTLINAGAMERESULTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRequestLinaGameResultResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRequestLinaGameResultResponse)

CMsgGCToClientQuestProgressUpdated = _reflection.GeneratedProtocolMessageType('CMsgGCToClientQuestProgressUpdated', (_message.Message,), dict(

  Challenge = _reflection.GeneratedProtocolMessageType('Challenge', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTQUESTPROGRESSUPDATED_CHALLENGE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToClientQuestProgressUpdated.Challenge)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTQUESTPROGRESSUPDATED,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientQuestProgressUpdated)
  ))
_sym_db.RegisterMessage(CMsgGCToClientQuestProgressUpdated)
_sym_db.RegisterMessage(CMsgGCToClientQuestProgressUpdated.Challenge)

CMsgDOTARedeemItem = _reflection.GeneratedProtocolMessageType('CMsgDOTARedeemItem', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREDEEMITEM,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTARedeemItem)
  ))
_sym_db.RegisterMessage(CMsgDOTARedeemItem)

CMsgDOTARedeemItemResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTARedeemItemResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREDEEMITEMRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTARedeemItemResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTARedeemItemResponse)

CMsgPerfectWorldUserLookupRequest = _reflection.GeneratedProtocolMessageType('CMsgPerfectWorldUserLookupRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPERFECTWORLDUSERLOOKUPREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPerfectWorldUserLookupRequest)
  ))
_sym_db.RegisterMessage(CMsgPerfectWorldUserLookupRequest)

CMsgPerfectWorldUserLookupResponse = _reflection.GeneratedProtocolMessageType('CMsgPerfectWorldUserLookupResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPERFECTWORLDUSERLOOKUPRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPerfectWorldUserLookupResponse)
  ))
_sym_db.RegisterMessage(CMsgPerfectWorldUserLookupResponse)

CMsgNexonPartnerUpdate = _reflection.GeneratedProtocolMessageType('CMsgNexonPartnerUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGNEXONPARTNERUPDATE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgNexonPartnerUpdate)
  ))
_sym_db.RegisterMessage(CMsgNexonPartnerUpdate)

CMsgMakeOffering = _reflection.GeneratedProtocolMessageType('CMsgMakeOffering', (_message.Message,), dict(
  DESCRIPTOR = _CMSGMAKEOFFERING,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgMakeOffering)
  ))
_sym_db.RegisterMessage(CMsgMakeOffering)

CMsgRequestOfferings = _reflection.GeneratedProtocolMessageType('CMsgRequestOfferings', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTOFFERINGS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRequestOfferings)
  ))
_sym_db.RegisterMessage(CMsgRequestOfferings)

CMsgRequestOfferingsResponse = _reflection.GeneratedProtocolMessageType('CMsgRequestOfferingsResponse', (_message.Message,), dict(

  NewYearsOffering = _reflection.GeneratedProtocolMessageType('NewYearsOffering', (_message.Message,), dict(
    DESCRIPTOR = _CMSGREQUESTOFFERINGSRESPONSE_NEWYEARSOFFERING,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgRequestOfferingsResponse.NewYearsOffering)
    ))
  ,
  DESCRIPTOR = _CMSGREQUESTOFFERINGSRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRequestOfferingsResponse)
  ))
_sym_db.RegisterMessage(CMsgRequestOfferingsResponse)
_sym_db.RegisterMessage(CMsgRequestOfferingsResponse.NewYearsOffering)

CMsgDOTAPCBangTimedReward = _reflection.GeneratedProtocolMessageType('CMsgDOTAPCBangTimedReward', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPCBANGTIMEDREWARD,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAPCBangTimedReward)
  ))
_sym_db.RegisterMessage(CMsgDOTAPCBangTimedReward)

CMsgDOTACompendiumInGamePredictionResults = _reflection.GeneratedProtocolMessageType('CMsgDOTACompendiumInGamePredictionResults', (_message.Message,), dict(

  PredictionResult = _reflection.GeneratedProtocolMessageType('PredictionResult', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS_PREDICTIONRESULT,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTACompendiumInGamePredictionResults.PredictionResult)
    ))
  ,
  DESCRIPTOR = _CMSGDOTACOMPENDIUMINGAMEPREDICTIONRESULTS,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTACompendiumInGamePredictionResults)
  ))
_sym_db.RegisterMessage(CMsgDOTACompendiumInGamePredictionResults)
_sym_db.RegisterMessage(CMsgDOTACompendiumInGamePredictionResults.PredictionResult)

CMsgClientToGCSelectCompendiumInGamePrediction = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSelectCompendiumInGamePrediction', (_message.Message,), dict(

  Prediction = _reflection.GeneratedProtocolMessageType('Prediction', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION_PREDICTION,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCSelectCompendiumInGamePrediction.Prediction)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTION,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCSelectCompendiumInGamePrediction)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSelectCompendiumInGamePrediction)
_sym_db.RegisterMessage(CMsgClientToGCSelectCompendiumInGamePrediction.Prediction)

CMsgClientToGCSelectCompendiumInGamePredictionResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSelectCompendiumInGamePredictionResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSELECTCOMPENDIUMINGAMEPREDICTIONRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCSelectCompendiumInGamePredictionResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSelectCompendiumInGamePredictionResponse)

CMsgClientToGCOpenPlayerCardPack = _reflection.GeneratedProtocolMessageType('CMsgClientToGCOpenPlayerCardPack', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCOPENPLAYERCARDPACK,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCOpenPlayerCardPack)
  ))
_sym_db.RegisterMessage(CMsgClientToGCOpenPlayerCardPack)

CMsgClientToGCOpenPlayerCardPackResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCOpenPlayerCardPackResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCOPENPLAYERCARDPACKRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCOpenPlayerCardPackResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCOpenPlayerCardPackResponse)

CMsgClientToGCRecyclePlayerCard = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRecyclePlayerCard', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCRECYCLEPLAYERCARD,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRecyclePlayerCard)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRecyclePlayerCard)

CMsgClientToGCRecyclePlayerCardResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRecyclePlayerCardResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCRECYCLEPLAYERCARDRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRecyclePlayerCardResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRecyclePlayerCardResponse)

CMsgClientToGCCreatePlayerCardPack = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCreatePlayerCardPack', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCREATEPLAYERCARDPACK,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCCreatePlayerCardPack)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCreatePlayerCardPack)

CMsgClientToGCCreatePlayerCardPackResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCreatePlayerCardPackResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCCREATEPLAYERCARDPACKRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCCreatePlayerCardPackResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCreatePlayerCardPackResponse)

CMsgGCToClientBattlePassRollup_International2016 = _reflection.GeneratedProtocolMessageType('CMsgGCToClientBattlePassRollup_International2016', (_message.Message,), dict(

  Questlines = _reflection.GeneratedProtocolMessageType('Questlines', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_QUESTLINES,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToClientBattlePassRollup_International2016.Questlines)
    ))
  ,

  Wagering = _reflection.GeneratedProtocolMessageType('Wagering', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_WAGERING,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToClientBattlePassRollup_International2016.Wagering)
    ))
  ,

  Achievements = _reflection.GeneratedProtocolMessageType('Achievements', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_ACHIEVEMENTS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToClientBattlePassRollup_International2016.Achievements)
    ))
  ,

  BattleCup = _reflection.GeneratedProtocolMessageType('BattleCup', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BATTLECUP,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToClientBattlePassRollup_International2016.BattleCup)
    ))
  ,

  Predictions = _reflection.GeneratedProtocolMessageType('Predictions', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PREDICTIONS,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToClientBattlePassRollup_International2016.Predictions)
    ))
  ,

  Bracket = _reflection.GeneratedProtocolMessageType('Bracket', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_BRACKET,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToClientBattlePassRollup_International2016.Bracket)
    ))
  ,

  PlayerCard = _reflection.GeneratedProtocolMessageType('PlayerCard', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_PLAYERCARD,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToClientBattlePassRollup_International2016.PlayerCard)
    ))
  ,

  FantasyChallenge = _reflection.GeneratedProtocolMessageType('FantasyChallenge', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016_FANTASYCHALLENGE,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToClientBattlePassRollup_International2016.FantasyChallenge)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUP_INTERNATIONAL2016,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientBattlePassRollup_International2016)
  ))
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016.Questlines)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016.Wagering)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016.Achievements)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016.BattleCup)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016.Predictions)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016.Bracket)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016.PlayerCard)
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollup_International2016.FantasyChallenge)

CMsgGCToClientBattlePassRollupRequest = _reflection.GeneratedProtocolMessageType('CMsgGCToClientBattlePassRollupRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUPREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientBattlePassRollupRequest)
  ))
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollupRequest)

CMsgGCToClientBattlePassRollupResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientBattlePassRollupResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUPRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientBattlePassRollupResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollupResponse)

CMsgGCToClientBattlePassRollupListRequest = _reflection.GeneratedProtocolMessageType('CMsgGCToClientBattlePassRollupListRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUPLISTREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientBattlePassRollupListRequest)
  ))
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollupListRequest)

CMsgGCToClientBattlePassRollupListResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientBattlePassRollupListResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTBATTLEPASSROLLUPLISTRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientBattlePassRollupListResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientBattlePassRollupListResponse)

CMsgClientToGCTransferSeasonalMMRRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCTransferSeasonalMMRRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCTRANSFERSEASONALMMRREQUEST,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCTransferSeasonalMMRRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCTransferSeasonalMMRRequest)

CMsgClientToGCTransferSeasonalMMRResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCTransferSeasonalMMRResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCTRANSFERSEASONALMMRRESPONSE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCTransferSeasonalMMRResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCTransferSeasonalMMRResponse)

CMsgDOTAEventInvite = _reflection.GeneratedProtocolMessageType('CMsgDOTAEventInvite', (_message.Message,), dict(

  Team = _reflection.GeneratedProtocolMessageType('Team', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAEVENTINVITE_TEAM,
    __module__ = 'dota_gcmessages_client_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAEventInvite.Team)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAEVENTINVITE,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAEventInvite)
  ))
_sym_db.RegisterMessage(CMsgDOTAEventInvite)
_sym_db.RegisterMessage(CMsgDOTAEventInvite.Team)

CMsgDOTASetFavoriteTeam = _reflection.GeneratedProtocolMessageType('CMsgDOTASetFavoriteTeam', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTASETFAVORITETEAM,
  __module__ = 'dota_gcmessages_client_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTASetFavoriteTeam)
  ))
_sym_db.RegisterMessage(CMsgDOTASetFavoriteTeam)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
_CSODOTAGAMEHEROFAVORITES.fields_by_name['account_id'].has_options = True
_CSODOTAGAMEHEROFAVORITES.fields_by_name['account_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
_CSODOTAGAMEHEROFAVORITES.fields_by_name['hero_id'].has_options = True
_CSODOTAGAMEHEROFAVORITES.fields_by_name['hero_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
# @@protoc_insertion_point(module_scope)
