# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: econ_gcmessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import dota2.protobufs.steammessages_pb2 as steammessages__pb2
import dota2.protobufs.econ_shared_enums_pb2 as econ__shared__enums__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='econ_gcmessages.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x15\x65\x63on_gcmessages.proto\x1a\x13steammessages.proto\x1a\x17\x65\x63on_shared_enums.proto\"E\n\x12\x43MsgApplyAutograph\x12\x19\n\x11\x61utograph_item_id\x18\x01 \x01(\x04\x12\x14\n\x0citem_item_id\x18\x02 \x01(\x04\"h\n\x1b\x43MsgAdjustItemEquippedState\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x11\n\tnew_class\x18\x02 \x01(\r\x12\x10\n\x08new_slot\x18\x03 \x01(\r\x12\x13\n\x0bstyle_index\x18\x04 \x01(\r\"\xf0\x01\n$CMsgEconPlayerStrangeCountAdjustment\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12`\n\x19strange_count_adjustments\x18\x02 \x03(\x0b\x32=.CMsgEconPlayerStrangeCountAdjustment.CStrangeCountAdjustment\x1aR\n\x17\x43StrangeCountAdjustment\x12\x12\n\nevent_type\x18\x01 \x01(\r\x12\x0f\n\x07item_id\x18\x02 \x01(\x04\x12\x12\n\nadjustment\x18\x03 \x01(\r\"=\n)CMsgRequestItemPurgatory_FinalizePurchase\x12\x10\n\x08item_ids\x18\x01 \x03(\x04\"U\n1CMsgRequestItemPurgatory_FinalizePurchaseResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x10\n\x08item_ids\x18\x02 \x03(\x04\";\n\'CMsgRequestItemPurgatory_RefundPurchase\x12\x10\n\x08item_ids\x18\x01 \x03(\x04\"A\n/CMsgRequestItemPurgatory_RefundPurchaseResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"(\n\x14\x43MsgCraftingResponse\x12\x10\n\x08item_ids\x18\x01 \x03(\x04\"@\n\x1b\x43MsgGCRequestStoreSalesData\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x10\n\x08\x63urrency\x18\x02 \x01(\r\"\xb9\x01\n#CMsgGCRequestStoreSalesDataResponse\x12>\n\nsale_price\x18\x01 \x03(\x0b\x32*.CMsgGCRequestStoreSalesDataResponse.Price\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x17\n\x0f\x65xpiration_time\x18\x03 \x01(\r\x1a(\n\x05Price\x12\x10\n\x08item_def\x18\x01 \x01(\r\x12\r\n\x05price\x18\x02 \x01(\r\"W\n+CMsgGCRequestStoreSalesDataUpToDateResponse\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x17\n\x0f\x65xpiration_time\x18\x02 \x01(\r\"\x17\n\x15\x43MsgGCToGCPingRequest\"\x18\n\x16\x43MsgGCToGCPingResponse\"4\n\x1e\x43MsgGCToGCGetUserSessionServer\x12\x12\n\naccount_id\x18\x01 \x01(\r\"A\n&CMsgGCToGCGetUserSessionServerResponse\x12\x17\n\x0fserver_steam_id\x18\x01 \x01(\x06\"L\n\x1e\x43MsgGCToGCGetUserServerMembers\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x16\n\x0emax_spectators\x18\x02 \x01(\r\"C\n&CMsgGCToGCGetUserServerMembersResponse\x12\x19\n\x11member_account_id\x18\x01 \x03(\r\"8\n\x1e\x43MsgLookupMultipleAccountNames\x12\x16\n\naccountids\x18\x01 \x03(\rB\x02\x10\x01\"\x9a\x01\n&CMsgLookupMultipleAccountNamesResponse\x12\x41\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32/.CMsgLookupMultipleAccountNamesResponse.Account\x1a-\n\x07\x41\x63\x63ount\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x0f\n\x07persona\x18\x02 \x01(\t\"/\n\x19\x43MsgGCToGCGetUserPCBangNo\x12\x12\n\naccount_id\x18\x01 \x01(\r\"7\n!CMsgGCToGCGetUserPCBangNoResponse\x12\x12\n\npc_bang_no\x18\x01 \x01(\r\"/\n\x15\x43MsgRequestCrateItems\x12\x16\n\x0e\x63rate_item_def\x18\x01 \x01(\r\"\x85\x01\n\x1d\x43MsgRequestCrateItemsResponse\x12\x10\n\x08response\x18\x01 \x01(\r\x12\x11\n\titem_defs\x18\x02 \x03(\r\x12\x15\n\rpeek_item_def\x18\x03 \x01(\r\"(\n\x07\x45Result\x12\x0f\n\x0bk_Succeeded\x10\x00\x12\x0c\n\x08k_Failed\x10\x01\"\x98\x01\n\x1d\x43MsgGCToGCCanUseDropRateBonus\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x17\n\x0f\x64rop_rate_bonus\x18\x02 \x01(\x02\x12\x14\n\x0c\x62ooster_type\x18\x03 \x01(\r\x12\x1a\n\x12\x65xclusive_item_def\x18\x04 \x01(\r\x12\x18\n\x10\x61llow_equal_rate\x18\x05 \x01(\x08\"\xb1\x01\n\x17\x43MsgSQLAddDropRateBonus\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07item_id\x18\x02 \x01(\x04\x12\x10\n\x08item_def\x18\x03 \x01(\r\x12\x17\n\x0f\x64rop_rate_bonus\x18\x04 \x01(\x02\x12\x14\n\x0c\x62ooster_type\x18\x05 \x01(\r\x12\x18\n\x10seconds_duration\x18\x06 \x01(\r\x12\x16\n\x0e\x65nd_time_stamp\x18\x07 \x01(\r\"o\n\x1b\x43MsgSQLUpgradeBattleBooster\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x10\n\x08item_def\x18\x02 \x01(\r\x12\x14\n\x0c\x62onus_to_add\x18\x03 \x01(\x02\x12\x14\n\x0c\x62ooster_type\x18\x04 \x01(\r\">\n\x18\x43MsgGCToGCRefreshSOCache\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0e\n\x06reload\x18\x02 \x01(\x08\"J\n!CMsgGCToGCCheckAccountTradeStatus\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x11\n\tinitiator\x18\x02 \x01(\x08\"R\n)CMsgGCToGCCheckAccountTradeStatusResponse\x12\x11\n\tcan_trade\x18\x01 \x01(\x08\x12\x12\n\nerror_code\x18\x02 \x01(\r\"\xe6\x04\n!CMsgGCToGCGrantAccountRolledItems\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x36\n\x05items\x18\x02 \x03(\x0b\x32\'.CMsgGCToGCGrantAccountRolledItems.Item\x12\x14\n\x0c\x61udit_action\x18\x03 \x01(\r\x12\x12\n\naudit_data\x18\x04 \x01(\x04\x1a\xca\x03\n\x04Item\x12\x10\n\x08item_def\x18\x01 \x01(\r\x12\x12\n\nloot_lists\x18\x02 \x03(\t\x12\x14\n\x0cignore_limit\x18\x03 \x01(\x08\x12\x0e\n\x06origin\x18\x04 \x01(\r\x12T\n\x12\x64ynamic_attributes\x18\x05 \x03(\x0b\x32\x38.CMsgGCToGCGrantAccountRolledItems.Item.DynamicAttribute\x12^\n\x18\x61\x64\x64itional_audit_entries\x18\x06 \x03(\x0b\x32<.CMsgGCToGCGrantAccountRolledItems.Item.AdditionalAuditEntry\x12\x17\n\x0finventory_token\x18\x07 \x01(\r\x1aK\n\x10\x44ynamicAttribute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cvalue_uint32\x18\x02 \x01(\r\x12\x13\n\x0bvalue_float\x18\x03 \x01(\x02\x1aZ\n\x14\x41\x64\x64itionalAuditEntry\x12\x18\n\x10owner_account_id\x18\x01 \x01(\r\x12\x14\n\x0c\x61udit_action\x18\x02 \x01(\r\x12\x12\n\naudit_data\x18\x03 \x01(\x04\"Q\n$CMsgGCToGCGrantSelfMadeItemToAccount\x12\x16\n\x0eitem_def_index\x18\x01 \x01(\r\x12\x11\n\taccountid\x18\x02 \x01(\r\"\xb1\x01\n\x0b\x43MsgUseItem\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x17\n\x0ftarget_steam_id\x18\x02 \x01(\x06\x12\x1f\n\x17gift__potential_targets\x18\x03 \x03(\r\x12\x18\n\x10\x64uel__class_lock\x18\x04 \x01(\r\x12\x1a\n\x12initiator_steam_id\x18\x05 \x01(\x04\x12!\n\x19itempack__ack_immediately\x18\x06 \x01(\x08\"U\n\x11\x43MsgServerUseItem\x12\x1c\n\x14initiator_account_id\x18\x01 \x01(\r\x12\"\n\x0cuse_item_msg\x18\x02 \x01(\x0b\x32\x0c.CMsgUseItem\"(\n\x14\x43MsgUseMultipleItems\x12\x10\n\x08item_ids\x18\x01 \x03(\x04\"\x1d\n\x1b\x43MsgGCPartnerBalanceRequest\"p\n\x1c\x43MsgGCPartnerBalanceResponse\x12?\n\x06result\x18\x01 \x01(\x0e\x32\x1a.EGCPartnerRequestResponse:\x13k_EPartnerRequestOK\x12\x0f\n\x07\x62\x61lance\x18\x02 \x01(\r\"J\n!CGCStoreRechargeRedirect_LineItem\x12\x13\n\x0bitem_def_id\x18\x01 \x01(\r\x12\x10\n\x08quantity\x18\x02 \x01(\r\"a\n\'CMsgGCPartnerRechargeRedirectURLRequest\x12\x36\n\nline_items\x18\x01 \x03(\x0b\x32\".CGCStoreRechargeRedirect_LineItem\"x\n(CMsgGCPartnerRechargeRedirectURLResponse\x12?\n\x06result\x18\x01 \x01(\x0e\x32\x1a.EGCPartnerRequestResponse:\x13k_EPartnerRequestOK\x12\x0b\n\x03url\x18\x02 \x01(\t\"X\n)CMsgGCEconSQLWorkItemEmbeddedRollbackData\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x17\n\x0f\x64\x65leted_item_id\x18\x02 \x01(\x04\"\x85\x01\n\x0f\x43MsgCraftStatue\x12\x0e\n\x06heroid\x18\x01 \x01(\r\x12\x14\n\x0csequencename\x18\x02 \x01(\t\x12\r\n\x05\x63ycle\x18\x03 \x01(\x02\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x18\n\x10pedestal_itemdef\x18\x05 \x01(\r\x12\x0e\n\x06toolid\x18\x06 \x01(\x04\"\x1e\n\x0e\x43MsgRedeemCode\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"\xad\x01\n\x16\x43MsgRedeemCodeResponse\x12\x10\n\x08response\x18\x01 \x01(\r\x12\x0f\n\x07item_id\x18\x02 \x01(\x04\"p\n\x0b\x45ResultCode\x12\x0f\n\x0bk_Succeeded\x10\x00\x12\x19\n\x15k_Failed_CodeNotFound\x10\x01\x12\x1c\n\x18k_Failed_CodeAlreadyUsed\x10\x02\x12\x17\n\x13k_Failed_OtherError\x10\x03\"q\n\x15\x43MsgDevNewItemRequest\x12\x15\n\ritem_def_name\x18\x03 \x01(\t\x12\x16\n\x0eloot_list_name\x18\x04 \x01(\t\x12\x15\n\rattr_def_name\x18\x05 \x03(\t\x12\x12\n\nattr_value\x18\x06 \x03(\t\"0\n\x1d\x43MsgDevNewItemRequestResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"8\n\x11\x43MsgGCAddGiftItem\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07item_id\x18\x02 \x01(\x04\"e\n CMsgClientToGCWrapAndDeliverGift\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x1a\n\x12give_to_account_id\x18\x02 \x01(\r\x12\x14\n\x0cgift_message\x18\x03 \x01(\t\"\xc4\x02\n(CMsgClientToGCWrapAndDeliverGiftResponse\x12\x35\n\x08response\x18\x01 \x01(\x0e\x32\x0f.EGCMsgResponse:\x12k_EGCMsgResponseOK\x12\x1b\n\x13gifting_charge_uses\x18\x02 \x01(\r\x12\x1a\n\x12gifting_charge_max\x18\x03 \x01(\x05\x12\x14\n\x0cgifting_uses\x18\x04 \x01(\r\x12\x13\n\x0bgifting_max\x18\x05 \x01(\x05\x12\x1c\n\x14gifting_window_hours\x18\x06 \x01(\r\x12_\n\x11trade_restriction\x18\x07 \x01(\x0e\x32\x1c.EGCMsgInitiateTradeResponse:&k_EGCMsgInitiateTradeResponse_Accepted\"+\n\x18\x43MsgClientToGCUnwrapGift\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\"\"\n CMsgClientToGCGetGiftPermissions\"\xe7\x03\n(CMsgClientToGCGetGiftPermissionsResponse\x12\x14\n\x0cis_unlimited\x18\x01 \x01(\x08\x12\x16\n\x0ehas_two_factor\x18\x03 \x01(\x08\x12_\n\x11sender_permission\x18\x06 \x01(\x0e\x32\x1c.EGCMsgInitiateTradeResponse:&k_EGCMsgInitiateTradeResponse_Accepted\x12\"\n\x1a\x66riendship_age_requirement\x18\x07 \x01(\r\x12-\n%friendship_age_requirement_two_factor\x18\x08 \x01(\r\x12V\n\x12\x66riend_permissions\x18\t \x03(\x0b\x32:.CMsgClientToGCGetGiftPermissionsResponse.FriendPermission\x1a\x80\x01\n\x10\x46riendPermission\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12X\n\npermission\x18\x02 \x01(\x0e\x32\x1c.EGCMsgInitiateTradeResponse:&k_EGCMsgInitiateTradeResponse_Accepted\"-\n\x1a\x43MsgClientToGCUnpackBundle\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\"\xda\x03\n\"CMsgClientToGCUnpackBundleResponse\x12\x19\n\x11unpacked_item_ids\x18\x01 \x03(\x04\x12]\n\x08response\x18\x02 \x01(\x0e\x32\x31.CMsgClientToGCUnpackBundleResponse.EUnpackBundle:\x18k_UnpackBundle_Succeeded\"\xb9\x02\n\rEUnpackBundle\x12\x1c\n\x18k_UnpackBundle_Succeeded\x10\x00\x12)\n%k_UnpackBundle_Failed_ItemIsNotBundle\x10\x01\x12\x35\n1k_UnpackBundle_Failed_UnableToCreateContainedItem\x10\x02\x12&\n\"k_UnpackBundle_Failed_SOCacheError\x10\x03\x12\'\n#k_UnpackBundle_Failed_ItemIsInvalid\x10\x04\x12)\n%k_UnpackBundle_Failed_BadItemQuantity\x10\x05\x12,\n(k_UnpackBundle_Failed_UnableToDeleteItem\x10\x06\"K\n\'CMsgGCToClientStoreTransactionCompleted\x12\x0e\n\x06txn_id\x18\x01 \x01(\x04\x12\x10\n\x08item_ids\x18\x02 \x03(\x04\"H\n\x18\x43MsgClientToGCEquipItems\x12,\n\x06\x65quips\x18\x01 \x03(\x0b\x32\x1c.CMsgAdjustItemEquippedState\"?\n CMsgClientToGCEquipItemsResponse\x12\x1b\n\x13so_cache_version_id\x18\x01 \x01(\x06\"B\n\x1a\x43MsgClientToGCSetItemStyle\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x13\n\x0bstyle_index\x18\x02 \x01(\r\"\xde\x01\n\"CMsgClientToGCSetItemStyleResponse\x12U\n\x08response\x18\x01 \x01(\x0e\x32-.CMsgClientToGCSetItemStyleResponse.ESetStyle:\x14k_SetStyle_Succeeded\"a\n\tESetStyle\x12\x18\n\x14k_SetStyle_Succeeded\x10\x00\x12\x15\n\x11k_SetStyle_Failed\x10\x01\x12#\n\x1fk_SetStyle_Failed_StyleIsLocked\x10\x02\"i\n\x1d\x43MsgClientToGCUnlockItemStyle\x12\x16\n\x0eitem_to_unlock\x18\x01 \x01(\x04\x12\x13\n\x0bstyle_index\x18\x02 \x01(\r\x12\x1b\n\x13\x63onsumable_item_ids\x18\x03 \x03(\x04\"\xa2\x05\n%CMsgClientToGCUnlockItemStyleResponse\x12^\n\x08response\x18\x01 \x01(\x0e\x32\x33.CMsgClientToGCUnlockItemStyleResponse.EUnlockStyle:\x17k_UnlockStyle_Succeeded\x12\x0f\n\x07item_id\x18\x02 \x01(\x04\x12\x13\n\x0bstyle_index\x18\x03 \x01(\r\x12\x14\n\x0cstyle_prereq\x18\x04 \x01(\r\"\xdc\x03\n\x0c\x45UnlockStyle\x12\x1b\n\x17k_UnlockStyle_Succeeded\x10\x00\x12\x1f\n\x1bk_UnlockStyle_Failed_PreReq\x10\x01\x12#\n\x1fk_UnlockStyle_Failed_CantAfford\x10\x02\x12#\n\x1fk_UnlockStyle_Failed_CantCommit\x10\x03\x12&\n\"k_UnlockStyle_Failed_CantLockCache\x10\x04\x12)\n%k_UnlockStyle_Failed_CantAffordAttrib\x10\x05\x12&\n\"k_UnlockStyle_Failed_CantAffordGem\x10\x06\x12*\n&k_UnlockStyle_Failed_NoCompendiumLevel\x10\x07\x12(\n$k_UnlockStyle_Failed_AlreadyUnlocked\x10\x08\x12#\n\x1fk_UnlockStyle_Failed_OtherError\x10\t\x12&\n\"k_UnlockStyle_Failed_ItemIsInvalid\x10\n\x12&\n\"k_UnlockStyle_Failed_ToolIsInvalid\x10\x0b\"\x83\x01\n&CMsgClientToGCSetItemInventoryCategory\x12\x10\n\x08item_ids\x18\x01 \x03(\x04\x12\x14\n\x0cset_to_value\x18\x02 \x01(\r\x12\x19\n\x11remove_categories\x18\x03 \x01(\r\x12\x16\n\x0e\x61\x64\x64_categories\x18\x04 \x01(\r\"G\n\x19\x43MsgClientToGCUnlockCrate\x12\x15\n\rcrate_item_id\x18\x01 \x01(\x04\x12\x13\n\x0bkey_item_id\x18\x02 \x01(\x04\"\xc4\x01\n!CMsgClientToGCUnlockCrateResponse\x12\x33\n\x06result\x18\x01 \x01(\x0e\x32\x0f.EGCMsgResponse:\x12k_EGCMsgResponseOK\x12>\n\rgranted_items\x18\x02 \x03(\x0b\x32\'.CMsgClientToGCUnlockCrateResponse.Item\x1a*\n\x04Item\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x11\n\tdef_index\x18\x02 \x01(\r\"4\n!CMsgClientToGCRemoveItemAttribute\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\"\xb2\x03\n)CMsgClientToGCRemoveItemAttributeResponse\x12r\n\x08response\x18\x01 \x01(\x0e\x32?.CMsgClientToGCRemoveItemAttributeResponse.ERemoveItemAttribute:\x1fk_RemoveItemAttribute_Succeeded\x12\x0f\n\x07item_id\x18\x02 \x01(\x04\"\xff\x01\n\x14\x45RemoveItemAttribute\x12#\n\x1fk_RemoveItemAttribute_Succeeded\x10\x00\x12 \n\x1ck_RemoveItemAttribute_Failed\x10\x01\x12.\n*k_RemoveItemAttribute_Failed_ItemIsInvalid\x10\x02\x12\x39\n5k_RemoveItemAttribute_Failed_AttributeCannotBeRemoved\x10\x03\x12\x35\n1k_RemoveItemAttribute_Failed_AttributeDoesntExist\x10\x04\"U\n\x16\x43MsgClientToGCNameItem\x12\x17\n\x0fsubject_item_id\x18\x01 \x01(\x04\x12\x14\n\x0ctool_item_id\x18\x02 \x01(\x04\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xb2\x02\n\x1e\x43MsgClientToGCNameItemResponse\x12Q\n\x08response\x18\x01 \x01(\x0e\x32).CMsgClientToGCNameItemResponse.ENameItem:\x14k_NameItem_Succeeded\x12\x0f\n\x07item_id\x18\x02 \x01(\x04\"\xab\x01\n\tENameItem\x12\x18\n\x14k_NameItem_Succeeded\x10\x00\x12\x15\n\x11k_NameItem_Failed\x10\x01\x12#\n\x1fk_NameItem_Failed_ToolIsInvalid\x10\x02\x12#\n\x1fk_NameItem_Failed_ItemIsInvalid\x10\x03\x12#\n\x1fk_NameItem_Failed_NameIsInvalid\x10\x04\">\n\x15\x43MsgGCSetItemPosition\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x14\n\x0cnew_position\x18\x02 \x01(\r\"\xed\x01\n%CAttribute_ItemDynamicRecipeComponent\x12\x10\n\x08item_def\x18\x01 \x01(\r\x12\x14\n\x0citem_quality\x18\x02 \x01(\r\x12\x12\n\nitem_flags\x18\x03 \x01(\r\x12\x19\n\x11\x61ttributes_string\x18\x04 \x01(\t\x12\x12\n\nitem_count\x18\x05 \x01(\r\x12\x17\n\x0fitems_fulfilled\x18\x06 \x01(\r\x12\x13\n\x0bitem_rarity\x18\x07 \x01(\r\x12\x10\n\x08lootlist\x18\x08 \x01(\t\x12\x19\n\x11\x66ulfilled_item_id\x18\t \x01(\x04\"\xb2\x01\n\x10\x43ProtoItemSocket\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x16\n\x0e\x61ttr_def_index\x18\x02 \x01(\r\x12\x15\n\rrequired_type\x18\x03 \x01(\r\x12\x15\n\rrequired_hero\x18\x04 \x01(\t\x12\x15\n\rgem_def_index\x18\x05 \x01(\r\x12\x14\n\x0cnot_tradable\x18\x06 \x01(\x08\x12\x1a\n\x12required_item_slot\x18\x07 \x01(\t\";\n\x16\x43ProtoItemSocket_Empty\x12!\n\x06socket\x18\x01 \x01(\x0b\x32\x11.CProtoItemSocket\"L\n\x17\x43ProtoItemSocket_Effect\x12!\n\x06socket\x18\x01 \x01(\x0b\x32\x11.CProtoItemSocket\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x02 \x01(\r\"e\n\x16\x43ProtoItemSocket_Color\x12!\n\x06socket\x18\x01 \x01(\x0b\x32\x11.CProtoItemSocket\x12\x0b\n\x03red\x18\x02 \x01(\r\x12\r\n\x05green\x18\x03 \x01(\r\x12\x0c\n\x04\x62lue\x18\x04 \x01(\r\"j\n\x18\x43ProtoItemSocket_Strange\x12!\n\x06socket\x18\x01 \x01(\x0b\x32\x11.CProtoItemSocket\x12\x14\n\x0cstrange_type\x18\x02 \x01(\r\x12\x15\n\rstrange_value\x18\x03 \x01(\r\"\x91\x01\n\x1a\x43ProtoItemSocket_Spectator\x12!\n\x06socket\x18\x01 \x01(\x0b\x32\x11.CProtoItemSocket\x12\x14\n\x0cgames_viewed\x18\x02 \x01(\r\x12\x16\n\x0e\x63orporation_id\x18\x03 \x01(\r\x12\x11\n\tleague_id\x18\x04 \x01(\r\x12\x0f\n\x07team_id\x18\x05 \x01(\r\"[\n\x1e\x43ProtoItemSocket_AssetModifier\x12!\n\x06socket\x18\x01 \x01(\x0b\x32\x11.CProtoItemSocket\x12\x16\n\x0e\x61sset_modifier\x18\x02 \x01(\r\"\xa7\x01\n;CProtoItemSocket_AssetModifier_DESERIALIZE_FROM_STRING_ONLY\x12!\n\x06socket\x18\x01 \x01(\x0b\x32\x11.CProtoItemSocket\x12\x16\n\x0e\x61sset_modifier\x18\x02 \x01(\r\x12\x15\n\ranim_modifier\x18\x03 \x01(\r\x12\x16\n\x0e\x61\x62ility_effect\x18\x04 \x01(\r\"\x81\x01\n\x1a\x43ProtoItemSocket_Autograph\x12!\n\x06socket\x18\x01 \x01(\x0b\x32\x11.CProtoItemSocket\x12\x11\n\tautograph\x18\x02 \x01(\t\x12\x14\n\x0c\x61utograph_id\x18\x03 \x01(\r\x12\x17\n\x0f\x61utograph_score\x18\x04 \x01(\r\"C\n\x1e\x43ProtoItemSocket_StaticVisuals\x12!\n\x06socket\x18\x01 \x01(\x0b\x32\x11.CProtoItemSocket\"\"\n\x11\x43\x41ttribute_String\x12\r\n\x05value\x18\x01 \x01(\t\"m\n%CWorkshop_GetItemDailyRevenue_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07item_id\x18\x02 \x01(\r\x12\x12\n\ndate_start\x18\x03 \x01(\r\x12\x10\n\x08\x64\x61te_end\x18\x04 \x01(\r\"\xdd\x01\n&CWorkshop_GetItemDailyRevenue_Response\x12T\n\x0f\x63ountry_revenue\x18\x01 \x03(\x0b\x32;.CWorkshop_GetItemDailyRevenue_Response.CountryDailyRevenue\x1a]\n\x13\x43ountryDailyRevenue\x12\x14\n\x0c\x63ountry_code\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x02 \x01(\r\x12\x13\n\x0brevenue_usd\x18\x03 \x01(\x03\x12\r\n\x05units\x18\x04 \x01(\x05\"H\n\x1f\x43MsgSQLGCToGCGrantBackpackSlots\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x11\n\tadd_slots\x18\x02 \x01(\r\"5\n\x1f\x43MsgClientToGCLookupAccountName\x12\x12\n\naccount_id\x18\x01 \x01(\r\"S\n\'CMsgClientToGCLookupAccountNameResponse\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\"d\n\x1c\x43MsgGCToGCDevRevokeUserItems\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x12\n\naudit_data\x18\x02 \x01(\x04\x12\x1c\n\x14\x64\x65lete_audit_history\x18\x03 \x01(\x08\"\x9d\x01\n CMsgClientToGCCreateStaticRecipe\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.CMsgClientToGCCreateStaticRecipe.Item\x12\x18\n\x10recipe_def_index\x18\x02 \x01(\r\x1a(\n\x04Item\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x0f\n\x07slot_id\x18\x02 \x01(\r\"\xfc\x05\n(CMsgClientToGCCreateStaticRecipeResponse\x12X\n\x08response\x18\x01 \x01(\x0e\x32\x33.CMsgClientToGCCreateStaticRecipeResponse.EResponse:\x11\x65Response_Success\x12J\n\x0coutput_items\x18\x02 \x03(\x0b\x32\x34.CMsgClientToGCCreateStaticRecipeResponse.OutputItem\x12J\n\x0cinput_errors\x18\x03 \x03(\x0b\x32\x34.CMsgClientToGCCreateStaticRecipeResponse.InputError\x12V\n\x12\x61\x64\x64itional_outputs\x18\x04 \x03(\x0b\x32:.CMsgClientToGCCreateStaticRecipeResponse.AdditionalOutput\x1a\x41\n\nOutputItem\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\x0f\n\x07item_id\x18\x02 \x01(\x04\x12\x0f\n\x07slot_id\x18\x03 \x01(\r\x1at\n\nInputError\x12\x0f\n\x07slot_id\x18\x01 \x01(\r\x12U\n\x05\x65rror\x18\x02 \x01(\x0e\x32\x33.CMsgClientToGCCreateStaticRecipeResponse.EResponse:\x11\x65Response_Success\x1a\x32\n\x10\x41\x64\x64itionalOutput\x12\x0f\n\x07slot_id\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x04\"\x98\x01\n\tEResponse\x12\x15\n\x11\x65Response_Success\x10\x00\x12\x1e\n\x1a\x65Response_OfferingDisabled\x10\x01\x12\x1a\n\x16\x65Response_InvalidItems\x10\x02\x12\x1b\n\x17\x65Response_InternalError\x10\x03\x12\x1b\n\x17\x65Response_MissingLeague\x10\x04\"\xdb\x03\n\x1b\x43MsgProcessTransactionOrder\x12\x0e\n\x06txn_id\x18\x01 \x01(\x04\x12\x14\n\x0csteam_txn_id\x18\x02 \x01(\x04\x12\x16\n\x0epartner_txn_id\x18\x03 \x01(\x04\x12\x10\n\x08steam_id\x18\x04 \x01(\x06\x12\x12\n\ntime_stamp\x18\x05 \x01(\r\x12\x11\n\twatermark\x18\x06 \x01(\x04\x12\x1e\n\x16purchase_report_status\x18\x07 \x01(\x05\x12\x10\n\x08\x63urrency\x18\x08 \x01(\r\x12\x30\n\x05items\x18\t \x03(\x0b\x32!.CMsgProcessTransactionOrder.Item\x1a\xe0\x01\n\x04Item\x12\x16\n\x0eitem_def_index\x18\x01 \x01(\r\x12\x12\n\nitem_price\x18\x02 \x01(\r\x12\x10\n\x08quantity\x18\x03 \x01(\r\x12\x15\n\rcategory_desc\x18\x04 \x01(\t\x12\x1b\n\x13store_purchase_type\x18\x05 \x01(\r\x12\x1b\n\x13source_reference_id\x18\x06 \x01(\x04\x12\x1a\n\x12parent_stack_index\x18\x07 \x01(\x05\x12\x15\n\rdefault_price\x18\x08 \x01(\x08\x12\x16\n\x0eis_user_facing\x18\t \x01(\x08\"j\n&CMsgGCToGCStoreProcessCDKeyTransaction\x12+\n\x05order\x18\x01 \x01(\x0b\x32\x1c.CMsgProcessTransactionOrder\x12\x13\n\x0breason_code\x18\x02 \x01(\r\"A\n.CMsgGCToGCStoreProcessCDKeyTransactionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"`\n CMsgGCToGCStoreProcessSettlement\x12+\n\x05order\x18\x01 \x01(\x0b\x32\x1c.CMsgProcessTransactionOrder\x12\x0f\n\x07partner\x18\x02 \x01(\r\";\n(CMsgGCToGCStoreProcessSettlementResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"}\n!CMsgGCToGCBroadcastConsoleCommand\x12\x13\n\x0b\x63on_command\x18\x01 \x01(\t\x12\x15\n\rreport_output\x18\x02 \x01(\x08\x12\x12\n\nsending_gc\x18\x03 \x01(\r\x12\x18\n\x10output_initiator\x18\x04 \x01(\t\"\xa3\x01\n\x17\x43MsgGCToGCConsoleOutput\x12\x11\n\tinitiator\x18\x01 \x01(\t\x12\x12\n\nsending_gc\x18\x02 \x01(\r\x12\x31\n\x04msgs\x18\x03 \x03(\x0b\x32#.CMsgGCToGCConsoleOutput.OutputLine\x1a.\n\nOutputLine\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\nspew_level\x18\x02 \x01(\r\"\x8e\x01\n\x0c\x43MsgItemAges\x12@\n\x16max_item_id_timestamps\x18\x01 \x03(\x0b\x32 .CMsgItemAges.MaxItemIDTimestamp\x1a<\n\x12MaxItemIDTimestamp\x12\x11\n\ttimestamp\x18\x01 \x01(\r\x12\x13\n\x0bmax_item_id\x18\x02 \x01(\x04\"\xab\x01\n\x19\x43MsgGCToGCInternalTestMsg\x12\x12\n\nsending_gc\x18\x01 \x01(\r\x12\x11\n\tsender_id\x18\x02 \x01(\x06\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\r\x12\x12\n\nmessage_id\x18\x04 \x01(\r\x12\x14\n\x0cmessage_body\x18\x05 \x01(\x0c\x12\x15\n\rjob_id_source\x18\x06 \x01(\x06\x12\x15\n\rjob_id_target\x18\x07 \x01(\x06\"\xaa\x01\n%CMsgGCToGCClientServerVersionsUpdated\x12\"\n\x1a\x63lient_min_allowed_version\x18\x01 \x01(\r\x12\x1d\n\x15\x63lient_active_version\x18\x02 \x01(\r\x12\x1d\n\x15server_active_version\x18\x03 \x01(\r\x12\x1f\n\x17server_deployed_version\x18\x04 \x01(\r*\xc6\x34\n\nEGCItemMsg\x12\x11\n\x0ck_EMsgGCBase\x10\xe8\x07\x12\x1c\n\x17k_EMsgGCSetItemPosition\x10\xe9\x07\x12\x13\n\x0ek_EMsgGCDelete\x10\xec\x07\x12$\n\x1fk_EMsgGCVerifyCacheSubscription\x10\xed\x07\x12\x1d\n\x18k_EMsgClientToGCNameItem\x10\xee\x07\x12\x16\n\x11k_EMsgGCPaintItem\x10\xf1\x07\x12\x1e\n\x19k_EMsgGCPaintItemResponse\x10\xf2\x07\x12\"\n\x1dk_EMsgGCGoldenWrenchBroadcast\x10\xf3\x07\x12\x18\n\x13k_EMsgGCMOTDRequest\x10\xf4\x07\x12 \n\x1bk_EMsgGCMOTDRequestResponse\x10\xf5\x07\x12\'\n\"k_EMsgGCAddItemToSocket_DEPRECATED\x10\xf6\x07\x12/\n*k_EMsgGCAddItemToSocketResponse_DEPRECATED\x10\xf7\x07\x12+\n&k_EMsgGCAddSocketToBaseItem_DEPRECATED\x10\xf8\x07\x12\'\n\"k_EMsgGCAddSocketToItem_DEPRECATED\x10\xf9\x07\x12/\n*k_EMsgGCAddSocketToItemResponse_DEPRECATED\x10\xfa\x07\x12\x19\n\x14k_EMsgGCNameBaseItem\x10\xfb\x07\x12!\n\x1ck_EMsgGCNameBaseItemResponse\x10\xfc\x07\x12(\n#k_EMsgGCRemoveSocketItem_DEPRECATED\x10\xfd\x07\x12\x30\n+k_EMsgGCRemoveSocketItemResponse_DEPRECATED\x10\xfe\x07\x12!\n\x1ck_EMsgGCCustomizeItemTexture\x10\xff\x07\x12)\n$k_EMsgGCCustomizeItemTextureResponse\x10\x80\x08\x12\x1b\n\x16k_EMsgGCUseItemRequest\x10\x81\x08\x12\x1c\n\x17k_EMsgGCUseItemResponse\x10\x82\x08\x12\x18\n\x13k_EMsgGCGiftedItems\x10\x83\x08\x12\x1b\n\x16k_EMsgGCRemoveItemName\x10\x86\x08\x12\x1c\n\x17k_EMsgGCRemoveItemPaint\x10\x87\x08\x12\x1e\n\x19k_EMsgGCUnwrapGiftRequest\x10\x8d\x08\x12\x1f\n\x1ak_EMsgGCUnwrapGiftResponse\x10\x8e\x08\x12$\n\x1fk_EMsgGCSetItemStyle_DEPRECATED\x10\x8f\x08\x12\x1e\n\x19k_EMsgGCUsedClaimCodeItem\x10\x90\x08\x12\x16\n\x11k_EMsgGCSortItems\x10\x91\x08\x12*\n%k_EMsgGC_RevolvingLootList_DEPRECATED\x10\x92\x08\x12\x1d\n\x18k_EMsgGCUpdateItemSchema\x10\x99\x08\x12 \n\x1bk_EMsgGCRemoveCustomTexture\x10\x9b\x08\x12(\n#k_EMsgGCRemoveCustomTextureResponse\x10\x9c\x08\x12\x1d\n\x18k_EMsgGCRemoveMakersMark\x10\x9d\x08\x12%\n k_EMsgGCRemoveMakersMarkResponse\x10\x9e\x08\x12#\n\x1ek_EMsgGCRemoveUniqueCraftIndex\x10\x9f\x08\x12+\n&k_EMsgGCRemoveUniqueCraftIndexResponse\x10\xa0\x08\x12\x1b\n\x16k_EMsgGCSaxxyBroadcast\x10\xa1\x08\x12!\n\x1ck_EMsgGCBackpackSortFinished\x10\xa2\x08\x12$\n\x1fk_EMsgGCAdjustItemEquippedState\x10\xa3\x08\x12\x18\n\x13k_EMsgGCCollectItem\x10\xa5\x08\x12\x1d\n\x18k_EMsgGCItemAcknowledged\x10\xa6\x08\x12)\n$k_EMsgGCPresets_SelectPresetForClass\x10\xa7\x08\x12$\n\x1fk_EMsgGCPresets_SetItemPosition\x10\xa8\x08\x12.\n)k_EMsgGCPresets_SelectPresetForClassReply\x10\xab\x08\x12%\n k_EMsgClientToGCNameItemResponse\x10\xac\x08\x12#\n\x1ek_EMsgGCApplyConsumableEffects\x10\xad\x08\x12 \n\x1bk_EMsgGCConsumableExhausted\x10\xae\x08\x12\x1e\n\x19k_EMsgGCShowItemsPickedUp\x10\xaf\x08\x12&\n!k_EMsgGCClientDisplayNotification\x10\xb0\x08\x12\x1d\n\x18k_EMsgGCApplyStrangePart\x10\xb1\x08\x12(\n#k_EMsgGC_IncrementKillCountResponse\x10\xb3\x08\x12 \n\x1bk_EMsgGCApplyPennantUpgrade\x10\xb4\x08\x12\x1d\n\x18k_EMsgGCSetItemPositions\x10\xb5\x08\x12)\n$k_EMsgGCSetItemPositions_RateLimited\x10\xc8\x08\x12\x1c\n\x17k_EMsgGCApplyEggEssence\x10\xb6\x08\x12#\n\x1ek_EMsgGCNameEggEssenceResponse\x10\xb7\x08\x12*\n%k_EMsgGCFulfillDynamicRecipeComponent\x10\xba\x08\x12\x32\n-k_EMsgGCFulfillDynamicRecipeComponentResponse\x10\xbb\x08\x12$\n\x1fk_EMsgGCClientRequestMarketData\x10\xbc\x08\x12,\n\'k_EMsgGCClientRequestMarketDataResponse\x10\xbd\x08\x12\x18\n\x13k_EMsgGCExtractGems\x10\xbe\x08\x12\x16\n\x11k_EMsgGCAddSocket\x10\xbf\x08\x12\x1c\n\x17k_EMsgGCAddItemToSocket\x10\xc0\x08\x12$\n\x1fk_EMsgGCAddItemToSocketResponse\x10\xc1\x08\x12\x1e\n\x19k_EMsgGCAddSocketResponse\x10\xc2\x08\x12!\n\x1ck_EMsgGCResetStrangeGemCount\x10\xc3\x08\x12\x1e\n\x19k_EMsgGCRequestCrateItems\x10\xc4\x08\x12&\n!k_EMsgGCRequestCrateItemsResponse\x10\xc5\x08\x12 \n\x1bk_EMsgGCExtractGemsResponse\x10\xc6\x08\x12)\n$k_EMsgGCResetStrangeGemCountResponse\x10\xc7\x08\x12!\n\x1ck_EMsgGCServerUseItemRequest\x10\xcf\x08\x12\x18\n\x13k_EMsgGCAddGiftItem\x10\xd0\x08\x12\"\n\x1dk_EMsgGCRemoveItemGiftMessage\x10\xd1\x08\x12*\n%k_EMsgGCRemoveItemGiftMessageResponse\x10\xd2\x08\x12&\n!k_EMsgGCRemoveItemGifterAccountId\x10\xd3\x08\x12.\n)k_EMsgGCRemoveItemGifterAccountIdResponse\x10\xd4\x08\x12/\n*k_EMsgClientToGCRemoveItemGifterAttributes\x10\xd5\x08\x12#\n\x1ek_EMsgClientToGCRemoveItemName\x10\xd6\x08\x12*\n%k_EMsgClientToGCRemoveItemDescription\x10\xd7\x08\x12\x30\n+k_EMsgClientToGCRemoveItemAttributeResponse\x10\xd8\x08\x12\x18\n\x13k_EMsgGCTradingBase\x10\xdc\x0b\x12)\n$k_EMsgGCTrading_InitiateTradeRequest\x10\xdd\x0b\x12*\n%k_EMsgGCTrading_InitiateTradeResponse\x10\xde\x0b\x12!\n\x1ck_EMsgGCTrading_StartSession\x10\xdf\x0b\x12\"\n\x1dk_EMsgGCTrading_SessionClosed\x10\xe5\x0b\x12\x31\n,k_EMsgGCTrading_InitiateTradeRequestResponse\x10\xea\x0b\x12)\n$k_EMsgGCServerBrowser_FavoriteServer\x10\xc1\x0c\x12*\n%k_EMsgGCServerBrowser_BlacklistServer\x10\xc2\x0c\x12\x1e\n\x19k_EMsgGCServerRentalsBase\x10\xa4\r\x12\x1f\n\x1ak_EMsgGCDev_NewItemRequest\x10\xd1\x0f\x12\'\n\"k_EMsgGCDev_NewItemRequestResponse\x10\xd2\x0f\x12\x1d\n\x18k_EMsgGCStoreGetUserData\x10\xc4\x13\x12%\n k_EMsgGCStoreGetUserDataResponse\x10\xc5\x13\x12\"\n\x1dk_EMsgGCStorePurchaseFinalize\x10\xc8\x13\x12*\n%k_EMsgGCStorePurchaseFinalizeResponse\x10\xc9\x13\x12 \n\x1bk_EMsgGCStorePurchaseCancel\x10\xca\x13\x12(\n#k_EMsgGCStorePurchaseCancelResponse\x10\xcb\x13\x12\x1e\n\x19k_EMsgGCStorePurchaseInit\x10\xce\x13\x12&\n!k_EMsgGCStorePurchaseInitResponse\x10\xcf\x13\x12\"\n\x1dk_EMsgGCBannedWordListRequest\x10\xd0\x13\x12#\n\x1ek_EMsgGCBannedWordListResponse\x10\xd1\x13\x12(\n#k_EMsgGCToGCBannedWordListBroadcast\x10\xd2\x13\x12&\n!k_EMsgGCToGCBannedWordListUpdated\x10\xd3\x13\x12\x1e\n\x19k_EMsgGCToGCDirtySDOCache\x10\xd4\x13\x12&\n!k_EMsgGCToGCDirtyMultipleSDOCache\x10\xd5\x13\x12\"\n\x1dk_EMsgGCToGCUpdateSQLKeyValue\x10\xd6\x13\x12(\n#k_EMsgGCToGCBroadcastConsoleCommand\x10\xd9\x13\x12!\n\x1ck_EMsgGCServerVersionUpdated\x10\xda\x13\x12\x1b\n\x16k_EMsgGCApplyAutograph\x10\xdb\x13\x12%\n k_EMsgGCToGCWebAPIAccountChanged\x10\xdc\x13\x12!\n\x1ck_EMsgGCClientVersionUpdated\x10\xe0\x13\x12+\n&k_EMsgGCItemPurgatory_FinalizePurchase\x10\xe3\x13\x12\x33\n.k_EMsgGCItemPurgatory_FinalizePurchaseResponse\x10\xe4\x13\x12)\n$k_EMsgGCItemPurgatory_RefundPurchase\x10\xe5\x13\x12\x31\n,k_EMsgGCItemPurgatory_RefundPurchaseResponse\x10\xe6\x13\x12.\n)k_EMsgGCToGCPlayerStrangeCountAdjustments\x10\xe7\x13\x12\"\n\x1dk_EMsgGCRequestStoreSalesData\x10\xe8\x13\x12*\n%k_EMsgGCRequestStoreSalesDataResponse\x10\xe9\x13\x12\x32\n-k_EMsgGCRequestStoreSalesDataUpToDateResponse\x10\xea\x13\x12\x1c\n\x17k_EMsgGCToGCPingRequest\x10\xeb\x13\x12\x1d\n\x18k_EMsgGCToGCPingResponse\x10\xec\x13\x12%\n k_EMsgGCToGCGetUserSessionServer\x10\xed\x13\x12-\n(k_EMsgGCToGCGetUserSessionServerResponse\x10\xee\x13\x12%\n k_EMsgGCToGCGetUserServerMembers\x10\xef\x13\x12-\n(k_EMsgGCToGCGetUserServerMembersResponse\x10\xf0\x13\x12 \n\x1bk_EMsgGCToGCGetUserPCBangNo\x10\xf1\x13\x12(\n#k_EMsgGCToGCGetUserPCBangNoResponse\x10\xf2\x13\x12$\n\x1fk_EMsgGCToGCCanUseDropRateBonus\x10\xf3\x13\x12\x1e\n\x19k_EMsgSQLAddDropRateBonus\x10\xf4\x13\x12\x1f\n\x1ak_EMsgGCToGCRefreshSOCache\x10\xf5\x13\x12&\n!k_EMsgGCToGCApplyLocalizationDiff\x10\xf6\x13\x12.\n)k_EMsgGCToGCApplyLocalizationDiffResponse\x10\xf7\x13\x12(\n#k_EMsgGCToGCCheckAccountTradeStatus\x10\xf8\x13\x12\x30\n+k_EMsgGCToGCCheckAccountTradeStatusResponse\x10\xf9\x13\x12(\n#k_EMsgGCToGCGrantAccountRolledItems\x10\xfa\x13\x12+\n&k_EMsgGCToGCGrantSelfMadeItemToAccount\x10\xfb\x13\x12\"\n\x1dk_EMsgGCPartnerBalanceRequest\x10\xfd\x13\x12#\n\x1ek_EMsgGCPartnerBalanceResponse\x10\xfe\x13\x12.\n)k_EMsgGCPartnerRechargeRedirectURLRequest\x10\xff\x13\x12/\n*k_EMsgGCPartnerRechargeRedirectURLResponse\x10\x80\x14\x12\x18\n\x13k_EMsgGCStatueCraft\x10\x81\x14\x12\x17\n\x12k_EMsgGCRedeemCode\x10\x82\x14\x12\x1f\n\x1ak_EMsgGCRedeemCodeResponse\x10\x83\x14\x12(\n#k_EMsgGCToGCItemConsumptionRollback\x10\x84\x14\x12\'\n\"k_EMsgClientToGCWrapAndDeliverGift\x10\x85\x14\x12/\n*k_EMsgClientToGCWrapAndDeliverGiftResponse\x10\x86\x14\x12)\n$k_EMsgClientToGCUnpackBundleResponse\x10\x87\x14\x12.\n)k_EMsgGCToClientStoreTransactionCompleted\x10\x88\x14\x12\x1f\n\x1ak_EMsgClientToGCEquipItems\x10\x89\x14\x12\'\n\"k_EMsgClientToGCEquipItemsResponse\x10\x8a\x14\x12$\n\x1fk_EMsgClientToGCUnlockItemStyle\x10\x8b\x14\x12,\n\'k_EMsgClientToGCUnlockItemStyleResponse\x10\x8c\x14\x12-\n(k_EMsgClientToGCSetItemInventoryCategory\x10\x8d\x14\x12 \n\x1bk_EMsgClientToGCUnlockCrate\x10\x8e\x14\x12(\n#k_EMsgClientToGCUnlockCrateResponse\x10\x8f\x14\x12!\n\x1ck_EMsgClientToGCUnpackBundle\x10\x90\x14\x12!\n\x1ck_EMsgClientToGCSetItemStyle\x10\x91\x14\x12)\n$k_EMsgClientToGCSetItemStyleResponse\x10\x92\x14\x12&\n!k_EMsgSQLGCToGCGrantBackpackSlots\x10\x94\x14\x12&\n!k_EMsgClientToGCLookupAccountName\x10\x95\x14\x12.\n)k_EMsgClientToGCLookupAccountNameResponse\x10\x96\x14\x12#\n\x1ek_EMsgGCToGCDevRevokeUserItems\x10\x97\x14\x12\'\n\"k_EMsgClientToGCCreateStaticRecipe\x10\x98\x14\x12/\n*k_EMsgClientToGCCreateStaticRecipeResponse\x10\x99\x14\x12-\n(k_EMsgGCToGCStoreProcessCDKeyTransaction\x10\x9a\x14\x12\x35\n0k_EMsgGCToGCStoreProcessCDKeyTransactionResponse\x10\x9b\x14\x12\'\n\"k_EMsgGCToGCStoreProcessSettlement\x10\x9c\x14\x12/\n*k_EMsgGCToGCStoreProcessSettlementResponse\x10\x9d\x14\x12\x1e\n\x19k_EMsgGCToGCConsoleOutput\x10\x9e\x14\x12\x1d\n\x18k_EMsgGCToClientItemAges\x10\x9f\x14\x12 \n\x1bk_EMsgGCToGCInternalTestMsg\x10\xa0\x14\x12,\n\'k_EMsgGCToGCClientServerVersionsUpdated\x10\xa1\x14\x12$\n\x1fk_EMsgGCUseMultipleItemsRequest\x10\xa2\x14*\xf3\x02\n\x1f\x45ItemPurgatoryResponse_Finalize\x12.\n*k_ItemPurgatoryResponse_Finalize_Succeeded\x10\x00\x12\x36\n2k_ItemPurgatoryResponse_Finalize_Failed_Incomplete\x10\x01\x12?\n;k_ItemPurgatoryResponse_Finalize_Failed_ItemsNotInPurgatory\x10\x02\x12=\n9k_ItemPurgatoryResponse_Finalize_Failed_CouldNotFindItems\x10\x03\x12\x35\n1k_ItemPurgatoryResponse_Finalize_Failed_NoSOCache\x10\x04\x12\x31\n-k_ItemPurgatoryResponse_Finalize_BackpackFull\x10\x05*\xe7\x02\n\x1d\x45ItemPurgatoryResponse_Refund\x12,\n(k_ItemPurgatoryResponse_Refund_Succeeded\x10\x00\x12<\n8k_ItemPurgatoryResponse_Refund_Failed_ItemNotInPurgatory\x10\x01\x12:\n6k_ItemPurgatoryResponse_Refund_Failed_CouldNotFindItem\x10\x02\x12\x33\n/k_ItemPurgatoryResponse_Refund_Failed_NoSOCache\x10\x03\x12\x32\n.k_ItemPurgatoryResponse_Refund_Failed_NoDetail\x10\x04\x12\x35\n1k_ItemPurgatoryResponse_Refund_Failed_NexonWebAPI\x10\x05*\x80\n\n\x1b\x45GCMsgInitiateTradeResponse\x12*\n&k_EGCMsgInitiateTradeResponse_Accepted\x10\x00\x12*\n&k_EGCMsgInitiateTradeResponse_Declined\x10\x01\x12\x36\n2k_EGCMsgInitiateTradeResponse_VAC_Banned_Initiator\x10\x02\x12\x33\n/k_EGCMsgInitiateTradeResponse_VAC_Banned_Target\x10\x03\x12\x38\n4k_EGCMsgInitiateTradeResponse_Target_Already_Trading\x10\x04\x12*\n&k_EGCMsgInitiateTradeResponse_Disabled\x10\x05\x12-\n)k_EGCMsgInitiateTradeResponse_NotLoggedIn\x10\x06\x12(\n$k_EGCMsgInitiateTradeResponse_Cancel\x10\x07\x12)\n%k_EGCMsgInitiateTradeResponse_TooSoon\x10\x08\x12\x30\n,k_EGCMsgInitiateTradeResponse_TooSoonPenalty\x10\t\x12\x38\n4k_EGCMsgInitiateTradeResponse_Trade_Banned_Initiator\x10\n\x12\x35\n1k_EGCMsgInitiateTradeResponse_Trade_Banned_Target\x10\x0b\x12\x43\n?k_EGCMsgInitiateTradeResponse_Free_Account_Initiator_DEPRECATED\x10\x0c\x12:\n6k_EGCMsgInitiateTradeResponse_Shared_Account_Initiator\x10\r\x12\x35\n1k_EGCMsgInitiateTradeResponse_Service_Unavailable\x10\x0e\x12\x30\n,k_EGCMsgInitiateTradeResponse_Target_Blocked\x10\x0f\x12\x33\n/k_EGCMsgInitiateTradeResponse_NeedVerifiedEmail\x10\x10\x12\x30\n,k_EGCMsgInitiateTradeResponse_NeedSteamGuard\x10\x11\x12\x34\n0k_EGCMsgInitiateTradeResponse_SteamGuardDuration\x10\x12\x12\x31\n-k_EGCMsgInitiateTradeResponse_TheyCannotTrade\x10\x13\x12\x37\n3k_EGCMsgInitiateTradeResponse_Recent_Password_Reset\x10\x14\x12\x32\n.k_EGCMsgInitiateTradeResponse_Using_New_Device\x10\x15\x12\x35\n1k_EGCMsgInitiateTradeResponse_Sent_Invalid_Cookie\x10\x16\x12\x31\n-k_EGCMsgInitiateTradeResponse_TooRecentFriend\x10\x17\x42\x05H\x01\x90\x01\x00')
  ,
  dependencies=[steammessages__pb2.DESCRIPTOR,econ__shared__enums__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_EGCITEMMSG = _descriptor.EnumDescriptor(
  name='EGCItemMsg',
  full_name='EGCItemMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBase', index=0, number=1000,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetItemPosition', index=1, number=1001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDelete', index=2, number=1004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCVerifyCacheSubscription', index=3, number=1005,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCNameItem', index=4, number=1006,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPaintItem', index=5, number=1009,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPaintItemResponse', index=6, number=1010,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGoldenWrenchBroadcast', index=7, number=1011,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCMOTDRequest', index=8, number=1012,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCMOTDRequestResponse', index=9, number=1013,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddItemToSocket_DEPRECATED', index=10, number=1014,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddItemToSocketResponse_DEPRECATED', index=11, number=1015,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddSocketToBaseItem_DEPRECATED', index=12, number=1016,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddSocketToItem_DEPRECATED', index=13, number=1017,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddSocketToItemResponse_DEPRECATED', index=14, number=1018,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNameBaseItem', index=15, number=1019,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNameBaseItemResponse', index=16, number=1020,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveSocketItem_DEPRECATED', index=17, number=1021,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveSocketItemResponse_DEPRECATED', index=18, number=1022,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCustomizeItemTexture', index=19, number=1023,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCustomizeItemTextureResponse', index=20, number=1024,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUseItemRequest', index=21, number=1025,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUseItemResponse', index=22, number=1026,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGiftedItems', index=23, number=1027,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveItemName', index=24, number=1030,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveItemPaint', index=25, number=1031,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUnwrapGiftRequest', index=26, number=1037,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUnwrapGiftResponse', index=27, number=1038,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetItemStyle_DEPRECATED', index=28, number=1039,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUsedClaimCodeItem', index=29, number=1040,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSortItems', index=30, number=1041,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_RevolvingLootList_DEPRECATED', index=31, number=1042,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUpdateItemSchema', index=32, number=1049,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveCustomTexture', index=33, number=1051,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveCustomTextureResponse', index=34, number=1052,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveMakersMark', index=35, number=1053,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveMakersMarkResponse', index=36, number=1054,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveUniqueCraftIndex', index=37, number=1055,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveUniqueCraftIndexResponse', index=38, number=1056,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSaxxyBroadcast', index=39, number=1057,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBackpackSortFinished', index=40, number=1058,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAdjustItemEquippedState', index=41, number=1059,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCCollectItem', index=42, number=1061,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemAcknowledged', index=43, number=1062,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPresets_SelectPresetForClass', index=44, number=1063,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPresets_SetItemPosition', index=45, number=1064,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPresets_SelectPresetForClassReply', index=46, number=1067,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCNameItemResponse', index=47, number=1068,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplyConsumableEffects', index=48, number=1069,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCConsumableExhausted', index=49, number=1070,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCShowItemsPickedUp', index=50, number=1071,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientDisplayNotification', index=51, number=1072,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplyStrangePart', index=52, number=1073,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGC_IncrementKillCountResponse', index=53, number=1075,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplyPennantUpgrade', index=54, number=1076,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetItemPositions', index=55, number=1077,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSetItemPositions_RateLimited', index=56, number=1096,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplyEggEssence', index=57, number=1078,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCNameEggEssenceResponse', index=58, number=1079,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFulfillDynamicRecipeComponent', index=59, number=1082,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCFulfillDynamicRecipeComponentResponse', index=60, number=1083,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientRequestMarketData', index=61, number=1084,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientRequestMarketDataResponse', index=62, number=1085,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCExtractGems', index=63, number=1086,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddSocket', index=64, number=1087,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddItemToSocket', index=65, number=1088,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddItemToSocketResponse', index=66, number=1089,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddSocketResponse', index=67, number=1090,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCResetStrangeGemCount', index=68, number=1091,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestCrateItems', index=69, number=1092,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestCrateItemsResponse', index=70, number=1093,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCExtractGemsResponse', index=71, number=1094,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCResetStrangeGemCountResponse', index=72, number=1095,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerUseItemRequest', index=73, number=1103,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCAddGiftItem', index=74, number=1104,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveItemGiftMessage', index=75, number=1105,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveItemGiftMessageResponse', index=76, number=1106,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveItemGifterAccountId', index=77, number=1107,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRemoveItemGifterAccountIdResponse', index=78, number=1108,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRemoveItemGifterAttributes', index=79, number=1109,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRemoveItemName', index=80, number=1110,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRemoveItemDescription', index=81, number=1111,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCRemoveItemAttributeResponse', index=82, number=1112,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTradingBase', index=83, number=1500,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_InitiateTradeRequest', index=84, number=1501,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_InitiateTradeResponse', index=85, number=1502,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_StartSession', index=86, number=1503,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_SessionClosed', index=87, number=1509,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCTrading_InitiateTradeRequestResponse', index=88, number=1514,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerBrowser_FavoriteServer', index=89, number=1601,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerBrowser_BlacklistServer', index=90, number=1602,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerRentalsBase', index=91, number=1700,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDev_NewItemRequest', index=92, number=2001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCDev_NewItemRequestResponse', index=93, number=2002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStoreGetUserData', index=94, number=2500,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStoreGetUserDataResponse', index=95, number=2501,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseFinalize', index=96, number=2504,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseFinalizeResponse', index=97, number=2505,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseCancel', index=98, number=2506,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseCancelResponse', index=99, number=2507,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseInit', index=100, number=2510,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStorePurchaseInitResponse', index=101, number=2511,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBannedWordListRequest', index=102, number=2512,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCBannedWordListResponse', index=103, number=2513,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCBannedWordListBroadcast', index=104, number=2514,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCBannedWordListUpdated', index=105, number=2515,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCDirtySDOCache', index=106, number=2516,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCDirtyMultipleSDOCache', index=107, number=2517,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCUpdateSQLKeyValue', index=108, number=2518,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCBroadcastConsoleCommand', index=109, number=2521,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerVersionUpdated', index=110, number=2522,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCApplyAutograph', index=111, number=2523,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCWebAPIAccountChanged', index=112, number=2524,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientVersionUpdated', index=113, number=2528,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPurgatory_FinalizePurchase', index=114, number=2531,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPurgatory_FinalizePurchaseResponse', index=115, number=2532,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPurgatory_RefundPurchase', index=116, number=2533,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCItemPurgatory_RefundPurchaseResponse', index=117, number=2534,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCPlayerStrangeCountAdjustments', index=118, number=2535,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestStoreSalesData', index=119, number=2536,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestStoreSalesDataResponse', index=120, number=2537,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRequestStoreSalesDataUpToDateResponse', index=121, number=2538,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCPingRequest', index=122, number=2539,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCPingResponse', index=123, number=2540,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetUserSessionServer', index=124, number=2541,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetUserSessionServerResponse', index=125, number=2542,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetUserServerMembers', index=126, number=2543,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetUserServerMembersResponse', index=127, number=2544,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetUserPCBangNo', index=128, number=2545,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGetUserPCBangNoResponse', index=129, number=2546,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCCanUseDropRateBonus', index=130, number=2547,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSQLAddDropRateBonus', index=131, number=2548,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCRefreshSOCache', index=132, number=2549,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCApplyLocalizationDiff', index=133, number=2550,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCApplyLocalizationDiffResponse', index=134, number=2551,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCCheckAccountTradeStatus', index=135, number=2552,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCCheckAccountTradeStatusResponse', index=136, number=2553,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGrantAccountRolledItems', index=137, number=2554,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCGrantSelfMadeItemToAccount', index=138, number=2555,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPartnerBalanceRequest', index=139, number=2557,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPartnerBalanceResponse', index=140, number=2558,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPartnerRechargeRedirectURLRequest', index=141, number=2559,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPartnerRechargeRedirectURLResponse', index=142, number=2560,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCStatueCraft', index=143, number=2561,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRedeemCode', index=144, number=2562,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCRedeemCodeResponse', index=145, number=2563,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCItemConsumptionRollback', index=146, number=2564,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCWrapAndDeliverGift', index=147, number=2565,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCWrapAndDeliverGiftResponse', index=148, number=2566,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCUnpackBundleResponse', index=149, number=2567,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientStoreTransactionCompleted', index=150, number=2568,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCEquipItems', index=151, number=2569,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCEquipItemsResponse', index=152, number=2570,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCUnlockItemStyle', index=153, number=2571,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCUnlockItemStyleResponse', index=154, number=2572,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSetItemInventoryCategory', index=155, number=2573,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCUnlockCrate', index=156, number=2574,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCUnlockCrateResponse', index=157, number=2575,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCUnpackBundle', index=158, number=2576,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSetItemStyle', index=159, number=2577,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCSetItemStyleResponse', index=160, number=2578,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgSQLGCToGCGrantBackpackSlots', index=161, number=2580,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCLookupAccountName', index=162, number=2581,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCLookupAccountNameResponse', index=163, number=2582,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCDevRevokeUserItems', index=164, number=2583,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCCreateStaticRecipe', index=165, number=2584,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgClientToGCCreateStaticRecipeResponse', index=166, number=2585,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCStoreProcessCDKeyTransaction', index=167, number=2586,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCStoreProcessCDKeyTransactionResponse', index=168, number=2587,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCStoreProcessSettlement', index=169, number=2588,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCStoreProcessSettlementResponse', index=170, number=2589,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCConsoleOutput', index=171, number=2590,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientItemAges', index=172, number=2591,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCInternalTestMsg', index=173, number=2592,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCClientServerVersionsUpdated', index=174, number=2593,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCUseMultipleItemsRequest', index=175, number=2594,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=13529,
  serialized_end=20255,
)
_sym_db.RegisterEnumDescriptor(_EGCITEMMSG)

EGCItemMsg = enum_type_wrapper.EnumTypeWrapper(_EGCITEMMSG)
_EITEMPURGATORYRESPONSE_FINALIZE = _descriptor.EnumDescriptor(
  name='EItemPurgatoryResponse_Finalize',
  full_name='EItemPurgatoryResponse_Finalize',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ItemPurgatoryResponse_Finalize_Succeeded', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ItemPurgatoryResponse_Finalize_Failed_Incomplete', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ItemPurgatoryResponse_Finalize_Failed_ItemsNotInPurgatory', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ItemPurgatoryResponse_Finalize_Failed_CouldNotFindItems', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ItemPurgatoryResponse_Finalize_Failed_NoSOCache', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ItemPurgatoryResponse_Finalize_BackpackFull', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=20258,
  serialized_end=20629,
)
_sym_db.RegisterEnumDescriptor(_EITEMPURGATORYRESPONSE_FINALIZE)

EItemPurgatoryResponse_Finalize = enum_type_wrapper.EnumTypeWrapper(_EITEMPURGATORYRESPONSE_FINALIZE)
_EITEMPURGATORYRESPONSE_REFUND = _descriptor.EnumDescriptor(
  name='EItemPurgatoryResponse_Refund',
  full_name='EItemPurgatoryResponse_Refund',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ItemPurgatoryResponse_Refund_Succeeded', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ItemPurgatoryResponse_Refund_Failed_ItemNotInPurgatory', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ItemPurgatoryResponse_Refund_Failed_CouldNotFindItem', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ItemPurgatoryResponse_Refund_Failed_NoSOCache', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ItemPurgatoryResponse_Refund_Failed_NoDetail', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ItemPurgatoryResponse_Refund_Failed_NexonWebAPI', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=20632,
  serialized_end=20991,
)
_sym_db.RegisterEnumDescriptor(_EITEMPURGATORYRESPONSE_REFUND)

EItemPurgatoryResponse_Refund = enum_type_wrapper.EnumTypeWrapper(_EITEMPURGATORYRESPONSE_REFUND)
_EGCMSGINITIATETRADERESPONSE = _descriptor.EnumDescriptor(
  name='EGCMsgInitiateTradeResponse',
  full_name='EGCMsgInitiateTradeResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_Accepted', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_Declined', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_VAC_Banned_Initiator', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_VAC_Banned_Target', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_Target_Already_Trading', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_Disabled', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_NotLoggedIn', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_Cancel', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_TooSoon', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_TooSoonPenalty', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_Trade_Banned_Initiator', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_Trade_Banned_Target', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_Free_Account_Initiator_DEPRECATED', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_Shared_Account_Initiator', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_Service_Unavailable', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_Target_Blocked', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_NeedVerifiedEmail', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_NeedSteamGuard', index=17, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_SteamGuardDuration', index=18, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_TheyCannotTrade', index=19, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_Recent_Password_Reset', index=20, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_Using_New_Device', index=21, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_Sent_Invalid_Cookie', index=22, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgInitiateTradeResponse_TooRecentFriend', index=23, number=23,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=20994,
  serialized_end=22274,
)
_sym_db.RegisterEnumDescriptor(_EGCMSGINITIATETRADERESPONSE)

EGCMsgInitiateTradeResponse = enum_type_wrapper.EnumTypeWrapper(_EGCMSGINITIATETRADERESPONSE)
k_EMsgGCBase = 1000
k_EMsgGCSetItemPosition = 1001
k_EMsgGCDelete = 1004
k_EMsgGCVerifyCacheSubscription = 1005
k_EMsgClientToGCNameItem = 1006
k_EMsgGCPaintItem = 1009
k_EMsgGCPaintItemResponse = 1010
k_EMsgGCGoldenWrenchBroadcast = 1011
k_EMsgGCMOTDRequest = 1012
k_EMsgGCMOTDRequestResponse = 1013
k_EMsgGCAddItemToSocket_DEPRECATED = 1014
k_EMsgGCAddItemToSocketResponse_DEPRECATED = 1015
k_EMsgGCAddSocketToBaseItem_DEPRECATED = 1016
k_EMsgGCAddSocketToItem_DEPRECATED = 1017
k_EMsgGCAddSocketToItemResponse_DEPRECATED = 1018
k_EMsgGCNameBaseItem = 1019
k_EMsgGCNameBaseItemResponse = 1020
k_EMsgGCRemoveSocketItem_DEPRECATED = 1021
k_EMsgGCRemoveSocketItemResponse_DEPRECATED = 1022
k_EMsgGCCustomizeItemTexture = 1023
k_EMsgGCCustomizeItemTextureResponse = 1024
k_EMsgGCUseItemRequest = 1025
k_EMsgGCUseItemResponse = 1026
k_EMsgGCGiftedItems = 1027
k_EMsgGCRemoveItemName = 1030
k_EMsgGCRemoveItemPaint = 1031
k_EMsgGCUnwrapGiftRequest = 1037
k_EMsgGCUnwrapGiftResponse = 1038
k_EMsgGCSetItemStyle_DEPRECATED = 1039
k_EMsgGCUsedClaimCodeItem = 1040
k_EMsgGCSortItems = 1041
k_EMsgGC_RevolvingLootList_DEPRECATED = 1042
k_EMsgGCUpdateItemSchema = 1049
k_EMsgGCRemoveCustomTexture = 1051
k_EMsgGCRemoveCustomTextureResponse = 1052
k_EMsgGCRemoveMakersMark = 1053
k_EMsgGCRemoveMakersMarkResponse = 1054
k_EMsgGCRemoveUniqueCraftIndex = 1055
k_EMsgGCRemoveUniqueCraftIndexResponse = 1056
k_EMsgGCSaxxyBroadcast = 1057
k_EMsgGCBackpackSortFinished = 1058
k_EMsgGCAdjustItemEquippedState = 1059
k_EMsgGCCollectItem = 1061
k_EMsgGCItemAcknowledged = 1062
k_EMsgGCPresets_SelectPresetForClass = 1063
k_EMsgGCPresets_SetItemPosition = 1064
k_EMsgGCPresets_SelectPresetForClassReply = 1067
k_EMsgClientToGCNameItemResponse = 1068
k_EMsgGCApplyConsumableEffects = 1069
k_EMsgGCConsumableExhausted = 1070
k_EMsgGCShowItemsPickedUp = 1071
k_EMsgGCClientDisplayNotification = 1072
k_EMsgGCApplyStrangePart = 1073
k_EMsgGC_IncrementKillCountResponse = 1075
k_EMsgGCApplyPennantUpgrade = 1076
k_EMsgGCSetItemPositions = 1077
k_EMsgGCSetItemPositions_RateLimited = 1096
k_EMsgGCApplyEggEssence = 1078
k_EMsgGCNameEggEssenceResponse = 1079
k_EMsgGCFulfillDynamicRecipeComponent = 1082
k_EMsgGCFulfillDynamicRecipeComponentResponse = 1083
k_EMsgGCClientRequestMarketData = 1084
k_EMsgGCClientRequestMarketDataResponse = 1085
k_EMsgGCExtractGems = 1086
k_EMsgGCAddSocket = 1087
k_EMsgGCAddItemToSocket = 1088
k_EMsgGCAddItemToSocketResponse = 1089
k_EMsgGCAddSocketResponse = 1090
k_EMsgGCResetStrangeGemCount = 1091
k_EMsgGCRequestCrateItems = 1092
k_EMsgGCRequestCrateItemsResponse = 1093
k_EMsgGCExtractGemsResponse = 1094
k_EMsgGCResetStrangeGemCountResponse = 1095
k_EMsgGCServerUseItemRequest = 1103
k_EMsgGCAddGiftItem = 1104
k_EMsgGCRemoveItemGiftMessage = 1105
k_EMsgGCRemoveItemGiftMessageResponse = 1106
k_EMsgGCRemoveItemGifterAccountId = 1107
k_EMsgGCRemoveItemGifterAccountIdResponse = 1108
k_EMsgClientToGCRemoveItemGifterAttributes = 1109
k_EMsgClientToGCRemoveItemName = 1110
k_EMsgClientToGCRemoveItemDescription = 1111
k_EMsgClientToGCRemoveItemAttributeResponse = 1112
k_EMsgGCTradingBase = 1500
k_EMsgGCTrading_InitiateTradeRequest = 1501
k_EMsgGCTrading_InitiateTradeResponse = 1502
k_EMsgGCTrading_StartSession = 1503
k_EMsgGCTrading_SessionClosed = 1509
k_EMsgGCTrading_InitiateTradeRequestResponse = 1514
k_EMsgGCServerBrowser_FavoriteServer = 1601
k_EMsgGCServerBrowser_BlacklistServer = 1602
k_EMsgGCServerRentalsBase = 1700
k_EMsgGCDev_NewItemRequest = 2001
k_EMsgGCDev_NewItemRequestResponse = 2002
k_EMsgGCStoreGetUserData = 2500
k_EMsgGCStoreGetUserDataResponse = 2501
k_EMsgGCStorePurchaseFinalize = 2504
k_EMsgGCStorePurchaseFinalizeResponse = 2505
k_EMsgGCStorePurchaseCancel = 2506
k_EMsgGCStorePurchaseCancelResponse = 2507
k_EMsgGCStorePurchaseInit = 2510
k_EMsgGCStorePurchaseInitResponse = 2511
k_EMsgGCBannedWordListRequest = 2512
k_EMsgGCBannedWordListResponse = 2513
k_EMsgGCToGCBannedWordListBroadcast = 2514
k_EMsgGCToGCBannedWordListUpdated = 2515
k_EMsgGCToGCDirtySDOCache = 2516
k_EMsgGCToGCDirtyMultipleSDOCache = 2517
k_EMsgGCToGCUpdateSQLKeyValue = 2518
k_EMsgGCToGCBroadcastConsoleCommand = 2521
k_EMsgGCServerVersionUpdated = 2522
k_EMsgGCApplyAutograph = 2523
k_EMsgGCToGCWebAPIAccountChanged = 2524
k_EMsgGCClientVersionUpdated = 2528
k_EMsgGCItemPurgatory_FinalizePurchase = 2531
k_EMsgGCItemPurgatory_FinalizePurchaseResponse = 2532
k_EMsgGCItemPurgatory_RefundPurchase = 2533
k_EMsgGCItemPurgatory_RefundPurchaseResponse = 2534
k_EMsgGCToGCPlayerStrangeCountAdjustments = 2535
k_EMsgGCRequestStoreSalesData = 2536
k_EMsgGCRequestStoreSalesDataResponse = 2537
k_EMsgGCRequestStoreSalesDataUpToDateResponse = 2538
k_EMsgGCToGCPingRequest = 2539
k_EMsgGCToGCPingResponse = 2540
k_EMsgGCToGCGetUserSessionServer = 2541
k_EMsgGCToGCGetUserSessionServerResponse = 2542
k_EMsgGCToGCGetUserServerMembers = 2543
k_EMsgGCToGCGetUserServerMembersResponse = 2544
k_EMsgGCToGCGetUserPCBangNo = 2545
k_EMsgGCToGCGetUserPCBangNoResponse = 2546
k_EMsgGCToGCCanUseDropRateBonus = 2547
k_EMsgSQLAddDropRateBonus = 2548
k_EMsgGCToGCRefreshSOCache = 2549
k_EMsgGCToGCApplyLocalizationDiff = 2550
k_EMsgGCToGCApplyLocalizationDiffResponse = 2551
k_EMsgGCToGCCheckAccountTradeStatus = 2552
k_EMsgGCToGCCheckAccountTradeStatusResponse = 2553
k_EMsgGCToGCGrantAccountRolledItems = 2554
k_EMsgGCToGCGrantSelfMadeItemToAccount = 2555
k_EMsgGCPartnerBalanceRequest = 2557
k_EMsgGCPartnerBalanceResponse = 2558
k_EMsgGCPartnerRechargeRedirectURLRequest = 2559
k_EMsgGCPartnerRechargeRedirectURLResponse = 2560
k_EMsgGCStatueCraft = 2561
k_EMsgGCRedeemCode = 2562
k_EMsgGCRedeemCodeResponse = 2563
k_EMsgGCToGCItemConsumptionRollback = 2564
k_EMsgClientToGCWrapAndDeliverGift = 2565
k_EMsgClientToGCWrapAndDeliverGiftResponse = 2566
k_EMsgClientToGCUnpackBundleResponse = 2567
k_EMsgGCToClientStoreTransactionCompleted = 2568
k_EMsgClientToGCEquipItems = 2569
k_EMsgClientToGCEquipItemsResponse = 2570
k_EMsgClientToGCUnlockItemStyle = 2571
k_EMsgClientToGCUnlockItemStyleResponse = 2572
k_EMsgClientToGCSetItemInventoryCategory = 2573
k_EMsgClientToGCUnlockCrate = 2574
k_EMsgClientToGCUnlockCrateResponse = 2575
k_EMsgClientToGCUnpackBundle = 2576
k_EMsgClientToGCSetItemStyle = 2577
k_EMsgClientToGCSetItemStyleResponse = 2578
k_EMsgSQLGCToGCGrantBackpackSlots = 2580
k_EMsgClientToGCLookupAccountName = 2581
k_EMsgClientToGCLookupAccountNameResponse = 2582
k_EMsgGCToGCDevRevokeUserItems = 2583
k_EMsgClientToGCCreateStaticRecipe = 2584
k_EMsgClientToGCCreateStaticRecipeResponse = 2585
k_EMsgGCToGCStoreProcessCDKeyTransaction = 2586
k_EMsgGCToGCStoreProcessCDKeyTransactionResponse = 2587
k_EMsgGCToGCStoreProcessSettlement = 2588
k_EMsgGCToGCStoreProcessSettlementResponse = 2589
k_EMsgGCToGCConsoleOutput = 2590
k_EMsgGCToClientItemAges = 2591
k_EMsgGCToGCInternalTestMsg = 2592
k_EMsgGCToGCClientServerVersionsUpdated = 2593
k_EMsgGCUseMultipleItemsRequest = 2594
k_ItemPurgatoryResponse_Finalize_Succeeded = 0
k_ItemPurgatoryResponse_Finalize_Failed_Incomplete = 1
k_ItemPurgatoryResponse_Finalize_Failed_ItemsNotInPurgatory = 2
k_ItemPurgatoryResponse_Finalize_Failed_CouldNotFindItems = 3
k_ItemPurgatoryResponse_Finalize_Failed_NoSOCache = 4
k_ItemPurgatoryResponse_Finalize_BackpackFull = 5
k_ItemPurgatoryResponse_Refund_Succeeded = 0
k_ItemPurgatoryResponse_Refund_Failed_ItemNotInPurgatory = 1
k_ItemPurgatoryResponse_Refund_Failed_CouldNotFindItem = 2
k_ItemPurgatoryResponse_Refund_Failed_NoSOCache = 3
k_ItemPurgatoryResponse_Refund_Failed_NoDetail = 4
k_ItemPurgatoryResponse_Refund_Failed_NexonWebAPI = 5
k_EGCMsgInitiateTradeResponse_Accepted = 0
k_EGCMsgInitiateTradeResponse_Declined = 1
k_EGCMsgInitiateTradeResponse_VAC_Banned_Initiator = 2
k_EGCMsgInitiateTradeResponse_VAC_Banned_Target = 3
k_EGCMsgInitiateTradeResponse_Target_Already_Trading = 4
k_EGCMsgInitiateTradeResponse_Disabled = 5
k_EGCMsgInitiateTradeResponse_NotLoggedIn = 6
k_EGCMsgInitiateTradeResponse_Cancel = 7
k_EGCMsgInitiateTradeResponse_TooSoon = 8
k_EGCMsgInitiateTradeResponse_TooSoonPenalty = 9
k_EGCMsgInitiateTradeResponse_Trade_Banned_Initiator = 10
k_EGCMsgInitiateTradeResponse_Trade_Banned_Target = 11
k_EGCMsgInitiateTradeResponse_Free_Account_Initiator_DEPRECATED = 12
k_EGCMsgInitiateTradeResponse_Shared_Account_Initiator = 13
k_EGCMsgInitiateTradeResponse_Service_Unavailable = 14
k_EGCMsgInitiateTradeResponse_Target_Blocked = 15
k_EGCMsgInitiateTradeResponse_NeedVerifiedEmail = 16
k_EGCMsgInitiateTradeResponse_NeedSteamGuard = 17
k_EGCMsgInitiateTradeResponse_SteamGuardDuration = 18
k_EGCMsgInitiateTradeResponse_TheyCannotTrade = 19
k_EGCMsgInitiateTradeResponse_Recent_Password_Reset = 20
k_EGCMsgInitiateTradeResponse_Using_New_Device = 21
k_EGCMsgInitiateTradeResponse_Sent_Invalid_Cookie = 22
k_EGCMsgInitiateTradeResponse_TooRecentFriend = 23


_CMSGREQUESTCRATEITEMSRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgRequestCrateItemsResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_Succeeded', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_Failed', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1937,
  serialized_end=1977,
)
_sym_db.RegisterEnumDescriptor(_CMSGREQUESTCRATEITEMSRESPONSE_ERESULT)

_CMSGREDEEMCODERESPONSE_ERESULTCODE = _descriptor.EnumDescriptor(
  name='EResultCode',
  full_name='CMsgRedeemCodeResponse.EResultCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_Succeeded', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_Failed_CodeNotFound', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_Failed_CodeAlreadyUsed', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_Failed_OtherError', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4422,
  serialized_end=4534,
)
_sym_db.RegisterEnumDescriptor(_CMSGREDEEMCODERESPONSE_ERESULTCODE)

_CMSGCLIENTTOGCUNPACKBUNDLERESPONSE_EUNPACKBUNDLE = _descriptor.EnumDescriptor(
  name='EUnpackBundle',
  full_name='CMsgClientToGCUnpackBundleResponse.EUnpackBundle',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_UnpackBundle_Succeeded', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnpackBundle_Failed_ItemIsNotBundle', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnpackBundle_Failed_UnableToCreateContainedItem', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnpackBundle_Failed_SOCacheError', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnpackBundle_Failed_ItemIsInvalid', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnpackBundle_Failed_BadItemQuantity', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnpackBundle_Failed_UnableToDeleteItem', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5969,
  serialized_end=6282,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCUNPACKBUNDLERESPONSE_EUNPACKBUNDLE)

_CMSGCLIENTTOGCSETITEMSTYLERESPONSE_ESETSTYLE = _descriptor.EnumDescriptor(
  name='ESetStyle',
  full_name='CMsgClientToGCSetItemStyleResponse.ESetStyle',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_SetStyle_Succeeded', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_SetStyle_Failed', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_SetStyle_Failed_StyleIsLocked', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6694,
  serialized_end=6791,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCSETITEMSTYLERESPONSE_ESETSTYLE)

_CMSGCLIENTTOGCUNLOCKITEMSTYLERESPONSE_EUNLOCKSTYLE = _descriptor.EnumDescriptor(
  name='EUnlockStyle',
  full_name='CMsgClientToGCUnlockItemStyleResponse.EUnlockStyle',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Succeeded', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_PreReq', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_CantAfford', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_CantCommit', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_CantLockCache', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_CantAffordAttrib', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_CantAffordGem', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_NoCompendiumLevel', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_AlreadyUnlocked', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_OtherError', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_ItemIsInvalid', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_UnlockStyle_Failed_ToolIsInvalid', index=11, number=11,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7099,
  serialized_end=7575,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCUNLOCKITEMSTYLERESPONSE_EUNLOCKSTYLE)

_CMSGCLIENTTOGCREMOVEITEMATTRIBUTERESPONSE_EREMOVEITEMATTRIBUTE = _descriptor.EnumDescriptor(
  name='ERemoveItemAttribute',
  full_name='CMsgClientToGCRemoveItemAttributeResponse.ERemoveItemAttribute',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_RemoveItemAttribute_Succeeded', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_RemoveItemAttribute_Failed', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_RemoveItemAttribute_Failed_ItemIsInvalid', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_RemoveItemAttribute_Failed_AttributeCannotBeRemoved', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_RemoveItemAttribute_Failed_AttributeDoesntExist', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8217,
  serialized_end=8472,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCREMOVEITEMATTRIBUTERESPONSE_EREMOVEITEMATTRIBUTE)

_CMSGCLIENTTOGCNAMEITEMRESPONSE_ENAMEITEM = _descriptor.EnumDescriptor(
  name='ENameItem',
  full_name='CMsgClientToGCNameItemResponse.ENameItem',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_NameItem_Succeeded', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_NameItem_Failed', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_NameItem_Failed_ToolIsInvalid', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_NameItem_Failed_ItemIsInvalid', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_NameItem_Failed_NameIsInvalid', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8697,
  serialized_end=8868,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCNAMEITEMRESPONSE_ENAMEITEM)

_CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_ERESPONSE = _descriptor.EnumDescriptor(
  name='EResponse',
  full_name='CMsgClientToGCCreateStaticRecipeResponse.EResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='eResponse_Success', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='eResponse_OfferingDisabled', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='eResponse_InvalidItems', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='eResponse_InternalError', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='eResponse_MissingLeague', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11777,
  serialized_end=11929,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_ERESPONSE)


_CMSGAPPLYAUTOGRAPH = _descriptor.Descriptor(
  name='CMsgApplyAutograph',
  full_name='CMsgApplyAutograph',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='autograph_item_id', full_name='CMsgApplyAutograph.autograph_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='CMsgApplyAutograph.item_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=140,
)


_CMSGADJUSTITEMEQUIPPEDSTATE = _descriptor.Descriptor(
  name='CMsgAdjustItemEquippedState',
  full_name='CMsgAdjustItemEquippedState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgAdjustItemEquippedState.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='new_class', full_name='CMsgAdjustItemEquippedState.new_class', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='new_slot', full_name='CMsgAdjustItemEquippedState.new_slot', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='style_index', full_name='CMsgAdjustItemEquippedState.style_index', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=246,
)


_CMSGECONPLAYERSTRANGECOUNTADJUSTMENT_CSTRANGECOUNTADJUSTMENT = _descriptor.Descriptor(
  name='CStrangeCountAdjustment',
  full_name='CMsgEconPlayerStrangeCountAdjustment.CStrangeCountAdjustment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_type', full_name='CMsgEconPlayerStrangeCountAdjustment.CStrangeCountAdjustment.event_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgEconPlayerStrangeCountAdjustment.CStrangeCountAdjustment.item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='CMsgEconPlayerStrangeCountAdjustment.CStrangeCountAdjustment.adjustment', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=489,
)

_CMSGECONPLAYERSTRANGECOUNTADJUSTMENT = _descriptor.Descriptor(
  name='CMsgEconPlayerStrangeCountAdjustment',
  full_name='CMsgEconPlayerStrangeCountAdjustment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgEconPlayerStrangeCountAdjustment.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strange_count_adjustments', full_name='CMsgEconPlayerStrangeCountAdjustment.strange_count_adjustments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGECONPLAYERSTRANGECOUNTADJUSTMENT_CSTRANGECOUNTADJUSTMENT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=249,
  serialized_end=489,
)


_CMSGREQUESTITEMPURGATORY_FINALIZEPURCHASE = _descriptor.Descriptor(
  name='CMsgRequestItemPurgatory_FinalizePurchase',
  full_name='CMsgRequestItemPurgatory_FinalizePurchase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_ids', full_name='CMsgRequestItemPurgatory_FinalizePurchase.item_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=552,
)


_CMSGREQUESTITEMPURGATORY_FINALIZEPURCHASERESPONSE = _descriptor.Descriptor(
  name='CMsgRequestItemPurgatory_FinalizePurchaseResponse',
  full_name='CMsgRequestItemPurgatory_FinalizePurchaseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgRequestItemPurgatory_FinalizePurchaseResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_ids', full_name='CMsgRequestItemPurgatory_FinalizePurchaseResponse.item_ids', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=554,
  serialized_end=639,
)


_CMSGREQUESTITEMPURGATORY_REFUNDPURCHASE = _descriptor.Descriptor(
  name='CMsgRequestItemPurgatory_RefundPurchase',
  full_name='CMsgRequestItemPurgatory_RefundPurchase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_ids', full_name='CMsgRequestItemPurgatory_RefundPurchase.item_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=641,
  serialized_end=700,
)


_CMSGREQUESTITEMPURGATORY_REFUNDPURCHASERESPONSE = _descriptor.Descriptor(
  name='CMsgRequestItemPurgatory_RefundPurchaseResponse',
  full_name='CMsgRequestItemPurgatory_RefundPurchaseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgRequestItemPurgatory_RefundPurchaseResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=702,
  serialized_end=767,
)


_CMSGCRAFTINGRESPONSE = _descriptor.Descriptor(
  name='CMsgCraftingResponse',
  full_name='CMsgCraftingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_ids', full_name='CMsgCraftingResponse.item_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=769,
  serialized_end=809,
)


_CMSGGCREQUESTSTORESALESDATA = _descriptor.Descriptor(
  name='CMsgGCRequestStoreSalesData',
  full_name='CMsgGCRequestStoreSalesData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgGCRequestStoreSalesData.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currency', full_name='CMsgGCRequestStoreSalesData.currency', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=811,
  serialized_end=875,
)


_CMSGGCREQUESTSTORESALESDATARESPONSE_PRICE = _descriptor.Descriptor(
  name='Price',
  full_name='CMsgGCRequestStoreSalesDataResponse.Price',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def', full_name='CMsgGCRequestStoreSalesDataResponse.Price.item_def', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='price', full_name='CMsgGCRequestStoreSalesDataResponse.Price.price', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1023,
  serialized_end=1063,
)

_CMSGGCREQUESTSTORESALESDATARESPONSE = _descriptor.Descriptor(
  name='CMsgGCRequestStoreSalesDataResponse',
  full_name='CMsgGCRequestStoreSalesDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sale_price', full_name='CMsgGCRequestStoreSalesDataResponse.sale_price', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgGCRequestStoreSalesDataResponse.version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expiration_time', full_name='CMsgGCRequestStoreSalesDataResponse.expiration_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCREQUESTSTORESALESDATARESPONSE_PRICE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=878,
  serialized_end=1063,
)


_CMSGGCREQUESTSTORESALESDATAUPTODATERESPONSE = _descriptor.Descriptor(
  name='CMsgGCRequestStoreSalesDataUpToDateResponse',
  full_name='CMsgGCRequestStoreSalesDataUpToDateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgGCRequestStoreSalesDataUpToDateResponse.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expiration_time', full_name='CMsgGCRequestStoreSalesDataUpToDateResponse.expiration_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1065,
  serialized_end=1152,
)


_CMSGGCTOGCPINGREQUEST = _descriptor.Descriptor(
  name='CMsgGCToGCPingRequest',
  full_name='CMsgGCToGCPingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1154,
  serialized_end=1177,
)


_CMSGGCTOGCPINGRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToGCPingResponse',
  full_name='CMsgGCToGCPingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1179,
  serialized_end=1203,
)


_CMSGGCTOGCGETUSERSESSIONSERVER = _descriptor.Descriptor(
  name='CMsgGCToGCGetUserSessionServer',
  full_name='CMsgGCToGCGetUserSessionServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCToGCGetUserSessionServer.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1205,
  serialized_end=1257,
)


_CMSGGCTOGCGETUSERSESSIONSERVERRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToGCGetUserSessionServerResponse',
  full_name='CMsgGCToGCGetUserSessionServerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_steam_id', full_name='CMsgGCToGCGetUserSessionServerResponse.server_steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1259,
  serialized_end=1324,
)


_CMSGGCTOGCGETUSERSERVERMEMBERS = _descriptor.Descriptor(
  name='CMsgGCToGCGetUserServerMembers',
  full_name='CMsgGCToGCGetUserServerMembers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCToGCGetUserServerMembers.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_spectators', full_name='CMsgGCToGCGetUserServerMembers.max_spectators', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1326,
  serialized_end=1402,
)


_CMSGGCTOGCGETUSERSERVERMEMBERSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToGCGetUserServerMembersResponse',
  full_name='CMsgGCToGCGetUserServerMembersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_account_id', full_name='CMsgGCToGCGetUserServerMembersResponse.member_account_id', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1404,
  serialized_end=1471,
)


_CMSGLOOKUPMULTIPLEACCOUNTNAMES = _descriptor.Descriptor(
  name='CMsgLookupMultipleAccountNames',
  full_name='CMsgLookupMultipleAccountNames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountids', full_name='CMsgLookupMultipleAccountNames.accountids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1473,
  serialized_end=1529,
)


_CMSGLOOKUPMULTIPLEACCOUNTNAMESRESPONSE_ACCOUNT = _descriptor.Descriptor(
  name='Account',
  full_name='CMsgLookupMultipleAccountNamesResponse.Account',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgLookupMultipleAccountNamesResponse.Account.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='persona', full_name='CMsgLookupMultipleAccountNamesResponse.Account.persona', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1641,
  serialized_end=1686,
)

_CMSGLOOKUPMULTIPLEACCOUNTNAMESRESPONSE = _descriptor.Descriptor(
  name='CMsgLookupMultipleAccountNamesResponse',
  full_name='CMsgLookupMultipleAccountNamesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accounts', full_name='CMsgLookupMultipleAccountNamesResponse.accounts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGLOOKUPMULTIPLEACCOUNTNAMESRESPONSE_ACCOUNT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1532,
  serialized_end=1686,
)


_CMSGGCTOGCGETUSERPCBANGNO = _descriptor.Descriptor(
  name='CMsgGCToGCGetUserPCBangNo',
  full_name='CMsgGCToGCGetUserPCBangNo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCToGCGetUserPCBangNo.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1688,
  serialized_end=1735,
)


_CMSGGCTOGCGETUSERPCBANGNORESPONSE = _descriptor.Descriptor(
  name='CMsgGCToGCGetUserPCBangNoResponse',
  full_name='CMsgGCToGCGetUserPCBangNoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pc_bang_no', full_name='CMsgGCToGCGetUserPCBangNoResponse.pc_bang_no', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1737,
  serialized_end=1792,
)


_CMSGREQUESTCRATEITEMS = _descriptor.Descriptor(
  name='CMsgRequestCrateItems',
  full_name='CMsgRequestCrateItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='crate_item_def', full_name='CMsgRequestCrateItems.crate_item_def', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1794,
  serialized_end=1841,
)


_CMSGREQUESTCRATEITEMSRESPONSE = _descriptor.Descriptor(
  name='CMsgRequestCrateItemsResponse',
  full_name='CMsgRequestCrateItemsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='CMsgRequestCrateItemsResponse.response', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_defs', full_name='CMsgRequestCrateItemsResponse.item_defs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='peek_item_def', full_name='CMsgRequestCrateItemsResponse.peek_item_def', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGREQUESTCRATEITEMSRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1844,
  serialized_end=1977,
)


_CMSGGCTOGCCANUSEDROPRATEBONUS = _descriptor.Descriptor(
  name='CMsgGCToGCCanUseDropRateBonus',
  full_name='CMsgGCToGCCanUseDropRateBonus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCToGCCanUseDropRateBonus.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='drop_rate_bonus', full_name='CMsgGCToGCCanUseDropRateBonus.drop_rate_bonus', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='booster_type', full_name='CMsgGCToGCCanUseDropRateBonus.booster_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exclusive_item_def', full_name='CMsgGCToGCCanUseDropRateBonus.exclusive_item_def', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='allow_equal_rate', full_name='CMsgGCToGCCanUseDropRateBonus.allow_equal_rate', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1980,
  serialized_end=2132,
)


_CMSGSQLADDDROPRATEBONUS = _descriptor.Descriptor(
  name='CMsgSQLAddDropRateBonus',
  full_name='CMsgSQLAddDropRateBonus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgSQLAddDropRateBonus.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgSQLAddDropRateBonus.item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_def', full_name='CMsgSQLAddDropRateBonus.item_def', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='drop_rate_bonus', full_name='CMsgSQLAddDropRateBonus.drop_rate_bonus', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='booster_type', full_name='CMsgSQLAddDropRateBonus.booster_type', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seconds_duration', full_name='CMsgSQLAddDropRateBonus.seconds_duration', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_time_stamp', full_name='CMsgSQLAddDropRateBonus.end_time_stamp', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2135,
  serialized_end=2312,
)


_CMSGSQLUPGRADEBATTLEBOOSTER = _descriptor.Descriptor(
  name='CMsgSQLUpgradeBattleBooster',
  full_name='CMsgSQLUpgradeBattleBooster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgSQLUpgradeBattleBooster.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_def', full_name='CMsgSQLUpgradeBattleBooster.item_def', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bonus_to_add', full_name='CMsgSQLUpgradeBattleBooster.bonus_to_add', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='booster_type', full_name='CMsgSQLUpgradeBattleBooster.booster_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2314,
  serialized_end=2425,
)


_CMSGGCTOGCREFRESHSOCACHE = _descriptor.Descriptor(
  name='CMsgGCToGCRefreshSOCache',
  full_name='CMsgGCToGCRefreshSOCache',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCToGCRefreshSOCache.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reload', full_name='CMsgGCToGCRefreshSOCache.reload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2427,
  serialized_end=2489,
)


_CMSGGCTOGCCHECKACCOUNTTRADESTATUS = _descriptor.Descriptor(
  name='CMsgGCToGCCheckAccountTradeStatus',
  full_name='CMsgGCToGCCheckAccountTradeStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCToGCCheckAccountTradeStatus.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initiator', full_name='CMsgGCToGCCheckAccountTradeStatus.initiator', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2491,
  serialized_end=2565,
)


_CMSGGCTOGCCHECKACCOUNTTRADESTATUSRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToGCCheckAccountTradeStatusResponse',
  full_name='CMsgGCToGCCheckAccountTradeStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='can_trade', full_name='CMsgGCToGCCheckAccountTradeStatusResponse.can_trade', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error_code', full_name='CMsgGCToGCCheckAccountTradeStatusResponse.error_code', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2567,
  serialized_end=2649,
)


_CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM_DYNAMICATTRIBUTE = _descriptor.Descriptor(
  name='DynamicAttribute',
  full_name='CMsgGCToGCGrantAccountRolledItems.Item.DynamicAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgGCToGCGrantAccountRolledItems.Item.DynamicAttribute.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value_uint32', full_name='CMsgGCToGCGrantAccountRolledItems.Item.DynamicAttribute.value_uint32', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value_float', full_name='CMsgGCToGCGrantAccountRolledItems.Item.DynamicAttribute.value_float', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3099,
  serialized_end=3174,
)

_CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM_ADDITIONALAUDITENTRY = _descriptor.Descriptor(
  name='AdditionalAuditEntry',
  full_name='CMsgGCToGCGrantAccountRolledItems.Item.AdditionalAuditEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_account_id', full_name='CMsgGCToGCGrantAccountRolledItems.Item.AdditionalAuditEntry.owner_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audit_action', full_name='CMsgGCToGCGrantAccountRolledItems.Item.AdditionalAuditEntry.audit_action', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audit_data', full_name='CMsgGCToGCGrantAccountRolledItems.Item.AdditionalAuditEntry.audit_data', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3176,
  serialized_end=3266,
)

_CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='CMsgGCToGCGrantAccountRolledItems.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def', full_name='CMsgGCToGCGrantAccountRolledItems.Item.item_def', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='loot_lists', full_name='CMsgGCToGCGrantAccountRolledItems.Item.loot_lists', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ignore_limit', full_name='CMsgGCToGCGrantAccountRolledItems.Item.ignore_limit', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin', full_name='CMsgGCToGCGrantAccountRolledItems.Item.origin', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dynamic_attributes', full_name='CMsgGCToGCGrantAccountRolledItems.Item.dynamic_attributes', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='additional_audit_entries', full_name='CMsgGCToGCGrantAccountRolledItems.Item.additional_audit_entries', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inventory_token', full_name='CMsgGCToGCGrantAccountRolledItems.Item.inventory_token', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM_DYNAMICATTRIBUTE, _CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM_ADDITIONALAUDITENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2808,
  serialized_end=3266,
)

_CMSGGCTOGCGRANTACCOUNTROLLEDITEMS = _descriptor.Descriptor(
  name='CMsgGCToGCGrantAccountRolledItems',
  full_name='CMsgGCToGCGrantAccountRolledItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCToGCGrantAccountRolledItems.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='items', full_name='CMsgGCToGCGrantAccountRolledItems.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audit_action', full_name='CMsgGCToGCGrantAccountRolledItems.audit_action', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audit_data', full_name='CMsgGCToGCGrantAccountRolledItems.audit_data', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2652,
  serialized_end=3266,
)


_CMSGGCTOGCGRANTSELFMADEITEMTOACCOUNT = _descriptor.Descriptor(
  name='CMsgGCToGCGrantSelfMadeItemToAccount',
  full_name='CMsgGCToGCGrantSelfMadeItemToAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def_index', full_name='CMsgGCToGCGrantSelfMadeItemToAccount.item_def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CMsgGCToGCGrantSelfMadeItemToAccount.accountid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3268,
  serialized_end=3349,
)


_CMSGUSEITEM = _descriptor.Descriptor(
  name='CMsgUseItem',
  full_name='CMsgUseItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgUseItem.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_steam_id', full_name='CMsgUseItem.target_steam_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gift__potential_targets', full_name='CMsgUseItem.gift__potential_targets', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duel__class_lock', full_name='CMsgUseItem.duel__class_lock', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initiator_steam_id', full_name='CMsgUseItem.initiator_steam_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itempack__ack_immediately', full_name='CMsgUseItem.itempack__ack_immediately', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3352,
  serialized_end=3529,
)


_CMSGSERVERUSEITEM = _descriptor.Descriptor(
  name='CMsgServerUseItem',
  full_name='CMsgServerUseItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='initiator_account_id', full_name='CMsgServerUseItem.initiator_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='use_item_msg', full_name='CMsgServerUseItem.use_item_msg', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3531,
  serialized_end=3616,
)


_CMSGUSEMULTIPLEITEMS = _descriptor.Descriptor(
  name='CMsgUseMultipleItems',
  full_name='CMsgUseMultipleItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_ids', full_name='CMsgUseMultipleItems.item_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3618,
  serialized_end=3658,
)


_CMSGGCPARTNERBALANCEREQUEST = _descriptor.Descriptor(
  name='CMsgGCPartnerBalanceRequest',
  full_name='CMsgGCPartnerBalanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3660,
  serialized_end=3689,
)


_CMSGGCPARTNERBALANCERESPONSE = _descriptor.Descriptor(
  name='CMsgGCPartnerBalanceResponse',
  full_name='CMsgGCPartnerBalanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCPartnerBalanceResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='balance', full_name='CMsgGCPartnerBalanceResponse.balance', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3691,
  serialized_end=3803,
)


_CGCSTORERECHARGEREDIRECT_LINEITEM = _descriptor.Descriptor(
  name='CGCStoreRechargeRedirect_LineItem',
  full_name='CGCStoreRechargeRedirect_LineItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def_id', full_name='CGCStoreRechargeRedirect_LineItem.item_def_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='CGCStoreRechargeRedirect_LineItem.quantity', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3805,
  serialized_end=3879,
)


_CMSGGCPARTNERRECHARGEREDIRECTURLREQUEST = _descriptor.Descriptor(
  name='CMsgGCPartnerRechargeRedirectURLRequest',
  full_name='CMsgGCPartnerRechargeRedirectURLRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='line_items', full_name='CMsgGCPartnerRechargeRedirectURLRequest.line_items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3881,
  serialized_end=3978,
)


_CMSGGCPARTNERRECHARGEREDIRECTURLRESPONSE = _descriptor.Descriptor(
  name='CMsgGCPartnerRechargeRedirectURLResponse',
  full_name='CMsgGCPartnerRechargeRedirectURLResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCPartnerRechargeRedirectURLResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='url', full_name='CMsgGCPartnerRechargeRedirectURLResponse.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3980,
  serialized_end=4100,
)


_CMSGGCECONSQLWORKITEMEMBEDDEDROLLBACKDATA = _descriptor.Descriptor(
  name='CMsgGCEconSQLWorkItemEmbeddedRollbackData',
  full_name='CMsgGCEconSQLWorkItemEmbeddedRollbackData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCEconSQLWorkItemEmbeddedRollbackData.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deleted_item_id', full_name='CMsgGCEconSQLWorkItemEmbeddedRollbackData.deleted_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4102,
  serialized_end=4190,
)


_CMSGCRAFTSTATUE = _descriptor.Descriptor(
  name='CMsgCraftStatue',
  full_name='CMsgCraftStatue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='heroid', full_name='CMsgCraftStatue.heroid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sequencename', full_name='CMsgCraftStatue.sequencename', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cycle', full_name='CMsgCraftStatue.cycle', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='CMsgCraftStatue.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pedestal_itemdef', full_name='CMsgCraftStatue.pedestal_itemdef', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='toolid', full_name='CMsgCraftStatue.toolid', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4193,
  serialized_end=4326,
)


_CMSGREDEEMCODE = _descriptor.Descriptor(
  name='CMsgRedeemCode',
  full_name='CMsgRedeemCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='CMsgRedeemCode.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4328,
  serialized_end=4358,
)


_CMSGREDEEMCODERESPONSE = _descriptor.Descriptor(
  name='CMsgRedeemCodeResponse',
  full_name='CMsgRedeemCodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='CMsgRedeemCodeResponse.response', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgRedeemCodeResponse.item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGREDEEMCODERESPONSE_ERESULTCODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4361,
  serialized_end=4534,
)


_CMSGDEVNEWITEMREQUEST = _descriptor.Descriptor(
  name='CMsgDevNewItemRequest',
  full_name='CMsgDevNewItemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def_name', full_name='CMsgDevNewItemRequest.item_def_name', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='loot_list_name', full_name='CMsgDevNewItemRequest.loot_list_name', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attr_def_name', full_name='CMsgDevNewItemRequest.attr_def_name', index=2,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attr_value', full_name='CMsgDevNewItemRequest.attr_value', index=3,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4536,
  serialized_end=4649,
)


_CMSGDEVNEWITEMREQUESTRESPONSE = _descriptor.Descriptor(
  name='CMsgDevNewItemRequestResponse',
  full_name='CMsgDevNewItemRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CMsgDevNewItemRequestResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4651,
  serialized_end=4699,
)


_CMSGGCADDGIFTITEM = _descriptor.Descriptor(
  name='CMsgGCAddGiftItem',
  full_name='CMsgGCAddGiftItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCAddGiftItem.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgGCAddGiftItem.item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4701,
  serialized_end=4757,
)


_CMSGCLIENTTOGCWRAPANDDELIVERGIFT = _descriptor.Descriptor(
  name='CMsgClientToGCWrapAndDeliverGift',
  full_name='CMsgClientToGCWrapAndDeliverGift',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgClientToGCWrapAndDeliverGift.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='give_to_account_id', full_name='CMsgClientToGCWrapAndDeliverGift.give_to_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gift_message', full_name='CMsgClientToGCWrapAndDeliverGift.gift_message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4759,
  serialized_end=4860,
)


_CMSGCLIENTTOGCWRAPANDDELIVERGIFTRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCWrapAndDeliverGiftResponse',
  full_name='CMsgClientToGCWrapAndDeliverGiftResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='CMsgClientToGCWrapAndDeliverGiftResponse.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gifting_charge_uses', full_name='CMsgClientToGCWrapAndDeliverGiftResponse.gifting_charge_uses', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gifting_charge_max', full_name='CMsgClientToGCWrapAndDeliverGiftResponse.gifting_charge_max', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gifting_uses', full_name='CMsgClientToGCWrapAndDeliverGiftResponse.gifting_uses', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gifting_max', full_name='CMsgClientToGCWrapAndDeliverGiftResponse.gifting_max', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gifting_window_hours', full_name='CMsgClientToGCWrapAndDeliverGiftResponse.gifting_window_hours', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trade_restriction', full_name='CMsgClientToGCWrapAndDeliverGiftResponse.trade_restriction', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4863,
  serialized_end=5187,
)


_CMSGCLIENTTOGCUNWRAPGIFT = _descriptor.Descriptor(
  name='CMsgClientToGCUnwrapGift',
  full_name='CMsgClientToGCUnwrapGift',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgClientToGCUnwrapGift.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5189,
  serialized_end=5232,
)


_CMSGCLIENTTOGCGETGIFTPERMISSIONS = _descriptor.Descriptor(
  name='CMsgClientToGCGetGiftPermissions',
  full_name='CMsgClientToGCGetGiftPermissions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5234,
  serialized_end=5268,
)


_CMSGCLIENTTOGCGETGIFTPERMISSIONSRESPONSE_FRIENDPERMISSION = _descriptor.Descriptor(
  name='FriendPermission',
  full_name='CMsgClientToGCGetGiftPermissionsResponse.FriendPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgClientToGCGetGiftPermissionsResponse.FriendPermission.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permission', full_name='CMsgClientToGCGetGiftPermissionsResponse.FriendPermission.permission', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5630,
  serialized_end=5758,
)

_CMSGCLIENTTOGCGETGIFTPERMISSIONSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGetGiftPermissionsResponse',
  full_name='CMsgClientToGCGetGiftPermissionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_unlimited', full_name='CMsgClientToGCGetGiftPermissionsResponse.is_unlimited', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='has_two_factor', full_name='CMsgClientToGCGetGiftPermissionsResponse.has_two_factor', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sender_permission', full_name='CMsgClientToGCGetGiftPermissionsResponse.sender_permission', index=2,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='friendship_age_requirement', full_name='CMsgClientToGCGetGiftPermissionsResponse.friendship_age_requirement', index=3,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='friendship_age_requirement_two_factor', full_name='CMsgClientToGCGetGiftPermissionsResponse.friendship_age_requirement_two_factor', index=4,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='friend_permissions', full_name='CMsgClientToGCGetGiftPermissionsResponse.friend_permissions', index=5,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCGETGIFTPERMISSIONSRESPONSE_FRIENDPERMISSION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5271,
  serialized_end=5758,
)


_CMSGCLIENTTOGCUNPACKBUNDLE = _descriptor.Descriptor(
  name='CMsgClientToGCUnpackBundle',
  full_name='CMsgClientToGCUnpackBundle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgClientToGCUnpackBundle.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5760,
  serialized_end=5805,
)


_CMSGCLIENTTOGCUNPACKBUNDLERESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCUnpackBundleResponse',
  full_name='CMsgClientToGCUnpackBundleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unpacked_item_ids', full_name='CMsgClientToGCUnpackBundleResponse.unpacked_item_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='response', full_name='CMsgClientToGCUnpackBundleResponse.response', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCUNPACKBUNDLERESPONSE_EUNPACKBUNDLE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5808,
  serialized_end=6282,
)


_CMSGGCTOCLIENTSTORETRANSACTIONCOMPLETED = _descriptor.Descriptor(
  name='CMsgGCToClientStoreTransactionCompleted',
  full_name='CMsgGCToClientStoreTransactionCompleted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txn_id', full_name='CMsgGCToClientStoreTransactionCompleted.txn_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_ids', full_name='CMsgGCToClientStoreTransactionCompleted.item_ids', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6284,
  serialized_end=6359,
)


_CMSGCLIENTTOGCEQUIPITEMS = _descriptor.Descriptor(
  name='CMsgClientToGCEquipItems',
  full_name='CMsgClientToGCEquipItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='equips', full_name='CMsgClientToGCEquipItems.equips', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6361,
  serialized_end=6433,
)


_CMSGCLIENTTOGCEQUIPITEMSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCEquipItemsResponse',
  full_name='CMsgClientToGCEquipItemsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='so_cache_version_id', full_name='CMsgClientToGCEquipItemsResponse.so_cache_version_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6435,
  serialized_end=6498,
)


_CMSGCLIENTTOGCSETITEMSTYLE = _descriptor.Descriptor(
  name='CMsgClientToGCSetItemStyle',
  full_name='CMsgClientToGCSetItemStyle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgClientToGCSetItemStyle.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='style_index', full_name='CMsgClientToGCSetItemStyle.style_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6500,
  serialized_end=6566,
)


_CMSGCLIENTTOGCSETITEMSTYLERESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCSetItemStyleResponse',
  full_name='CMsgClientToGCSetItemStyleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='CMsgClientToGCSetItemStyleResponse.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCSETITEMSTYLERESPONSE_ESETSTYLE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6569,
  serialized_end=6791,
)


_CMSGCLIENTTOGCUNLOCKITEMSTYLE = _descriptor.Descriptor(
  name='CMsgClientToGCUnlockItemStyle',
  full_name='CMsgClientToGCUnlockItemStyle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_to_unlock', full_name='CMsgClientToGCUnlockItemStyle.item_to_unlock', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='style_index', full_name='CMsgClientToGCUnlockItemStyle.style_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='consumable_item_ids', full_name='CMsgClientToGCUnlockItemStyle.consumable_item_ids', index=2,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6793,
  serialized_end=6898,
)


_CMSGCLIENTTOGCUNLOCKITEMSTYLERESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCUnlockItemStyleResponse',
  full_name='CMsgClientToGCUnlockItemStyleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='CMsgClientToGCUnlockItemStyleResponse.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgClientToGCUnlockItemStyleResponse.item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='style_index', full_name='CMsgClientToGCUnlockItemStyleResponse.style_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='style_prereq', full_name='CMsgClientToGCUnlockItemStyleResponse.style_prereq', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCUNLOCKITEMSTYLERESPONSE_EUNLOCKSTYLE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6901,
  serialized_end=7575,
)


_CMSGCLIENTTOGCSETITEMINVENTORYCATEGORY = _descriptor.Descriptor(
  name='CMsgClientToGCSetItemInventoryCategory',
  full_name='CMsgClientToGCSetItemInventoryCategory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_ids', full_name='CMsgClientToGCSetItemInventoryCategory.item_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='set_to_value', full_name='CMsgClientToGCSetItemInventoryCategory.set_to_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remove_categories', full_name='CMsgClientToGCSetItemInventoryCategory.remove_categories', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='add_categories', full_name='CMsgClientToGCSetItemInventoryCategory.add_categories', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7578,
  serialized_end=7709,
)


_CMSGCLIENTTOGCUNLOCKCRATE = _descriptor.Descriptor(
  name='CMsgClientToGCUnlockCrate',
  full_name='CMsgClientToGCUnlockCrate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='crate_item_id', full_name='CMsgClientToGCUnlockCrate.crate_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='key_item_id', full_name='CMsgClientToGCUnlockCrate.key_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7711,
  serialized_end=7782,
)


_CMSGCLIENTTOGCUNLOCKCRATERESPONSE_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='CMsgClientToGCUnlockCrateResponse.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgClientToGCUnlockCrateResponse.Item.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CMsgClientToGCUnlockCrateResponse.Item.def_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7939,
  serialized_end=7981,
)

_CMSGCLIENTTOGCUNLOCKCRATERESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCUnlockCrateResponse',
  full_name='CMsgClientToGCUnlockCrateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientToGCUnlockCrateResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='granted_items', full_name='CMsgClientToGCUnlockCrateResponse.granted_items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCUNLOCKCRATERESPONSE_ITEM, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7785,
  serialized_end=7981,
)


_CMSGCLIENTTOGCREMOVEITEMATTRIBUTE = _descriptor.Descriptor(
  name='CMsgClientToGCRemoveItemAttribute',
  full_name='CMsgClientToGCRemoveItemAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgClientToGCRemoveItemAttribute.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7983,
  serialized_end=8035,
)


_CMSGCLIENTTOGCREMOVEITEMATTRIBUTERESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCRemoveItemAttributeResponse',
  full_name='CMsgClientToGCRemoveItemAttributeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='CMsgClientToGCRemoveItemAttributeResponse.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgClientToGCRemoveItemAttributeResponse.item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCREMOVEITEMATTRIBUTERESPONSE_EREMOVEITEMATTRIBUTE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8038,
  serialized_end=8472,
)


_CMSGCLIENTTOGCNAMEITEM = _descriptor.Descriptor(
  name='CMsgClientToGCNameItem',
  full_name='CMsgClientToGCNameItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject_item_id', full_name='CMsgClientToGCNameItem.subject_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tool_item_id', full_name='CMsgClientToGCNameItem.tool_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgClientToGCNameItem.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8474,
  serialized_end=8559,
)


_CMSGCLIENTTOGCNAMEITEMRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCNameItemResponse',
  full_name='CMsgClientToGCNameItemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='CMsgClientToGCNameItemResponse.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgClientToGCNameItemResponse.item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCNAMEITEMRESPONSE_ENAMEITEM,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8562,
  serialized_end=8868,
)


_CMSGGCSETITEMPOSITION = _descriptor.Descriptor(
  name='CMsgGCSetItemPosition',
  full_name='CMsgGCSetItemPosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgGCSetItemPosition.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='new_position', full_name='CMsgGCSetItemPosition.new_position', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8870,
  serialized_end=8932,
)


_CATTRIBUTE_ITEMDYNAMICRECIPECOMPONENT = _descriptor.Descriptor(
  name='CAttribute_ItemDynamicRecipeComponent',
  full_name='CAttribute_ItemDynamicRecipeComponent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def', full_name='CAttribute_ItemDynamicRecipeComponent.item_def', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_quality', full_name='CAttribute_ItemDynamicRecipeComponent.item_quality', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_flags', full_name='CAttribute_ItemDynamicRecipeComponent.item_flags', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attributes_string', full_name='CAttribute_ItemDynamicRecipeComponent.attributes_string', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_count', full_name='CAttribute_ItemDynamicRecipeComponent.item_count', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='items_fulfilled', full_name='CAttribute_ItemDynamicRecipeComponent.items_fulfilled', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_rarity', full_name='CAttribute_ItemDynamicRecipeComponent.item_rarity', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lootlist', full_name='CAttribute_ItemDynamicRecipeComponent.lootlist', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fulfilled_item_id', full_name='CAttribute_ItemDynamicRecipeComponent.fulfilled_item_id', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8935,
  serialized_end=9172,
)


_CPROTOITEMSOCKET = _descriptor.Descriptor(
  name='CProtoItemSocket',
  full_name='CProtoItemSocket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CProtoItemSocket.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attr_def_index', full_name='CProtoItemSocket.attr_def_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='required_type', full_name='CProtoItemSocket.required_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='required_hero', full_name='CProtoItemSocket.required_hero', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gem_def_index', full_name='CProtoItemSocket.gem_def_index', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='not_tradable', full_name='CProtoItemSocket.not_tradable', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='required_item_slot', full_name='CProtoItemSocket.required_item_slot', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9175,
  serialized_end=9353,
)


_CPROTOITEMSOCKET_EMPTY = _descriptor.Descriptor(
  name='CProtoItemSocket_Empty',
  full_name='CProtoItemSocket_Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket', full_name='CProtoItemSocket_Empty.socket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9355,
  serialized_end=9414,
)


_CPROTOITEMSOCKET_EFFECT = _descriptor.Descriptor(
  name='CProtoItemSocket_Effect',
  full_name='CProtoItemSocket_Effect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket', full_name='CProtoItemSocket_Effect.socket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='effect', full_name='CProtoItemSocket_Effect.effect', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9416,
  serialized_end=9492,
)


_CPROTOITEMSOCKET_COLOR = _descriptor.Descriptor(
  name='CProtoItemSocket_Color',
  full_name='CProtoItemSocket_Color',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket', full_name='CProtoItemSocket_Color.socket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='red', full_name='CProtoItemSocket_Color.red', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='green', full_name='CProtoItemSocket_Color.green', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blue', full_name='CProtoItemSocket_Color.blue', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9494,
  serialized_end=9595,
)


_CPROTOITEMSOCKET_STRANGE = _descriptor.Descriptor(
  name='CProtoItemSocket_Strange',
  full_name='CProtoItemSocket_Strange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket', full_name='CProtoItemSocket_Strange.socket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strange_type', full_name='CProtoItemSocket_Strange.strange_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strange_value', full_name='CProtoItemSocket_Strange.strange_value', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9597,
  serialized_end=9703,
)


_CPROTOITEMSOCKET_SPECTATOR = _descriptor.Descriptor(
  name='CProtoItemSocket_Spectator',
  full_name='CProtoItemSocket_Spectator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket', full_name='CProtoItemSocket_Spectator.socket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='games_viewed', full_name='CProtoItemSocket_Spectator.games_viewed', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='corporation_id', full_name='CProtoItemSocket_Spectator.corporation_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CProtoItemSocket_Spectator.league_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CProtoItemSocket_Spectator.team_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9706,
  serialized_end=9851,
)


_CPROTOITEMSOCKET_ASSETMODIFIER = _descriptor.Descriptor(
  name='CProtoItemSocket_AssetModifier',
  full_name='CProtoItemSocket_AssetModifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket', full_name='CProtoItemSocket_AssetModifier.socket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='asset_modifier', full_name='CProtoItemSocket_AssetModifier.asset_modifier', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9853,
  serialized_end=9944,
)


_CPROTOITEMSOCKET_ASSETMODIFIER_DESERIALIZE_FROM_STRING_ONLY = _descriptor.Descriptor(
  name='CProtoItemSocket_AssetModifier_DESERIALIZE_FROM_STRING_ONLY',
  full_name='CProtoItemSocket_AssetModifier_DESERIALIZE_FROM_STRING_ONLY',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket', full_name='CProtoItemSocket_AssetModifier_DESERIALIZE_FROM_STRING_ONLY.socket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='asset_modifier', full_name='CProtoItemSocket_AssetModifier_DESERIALIZE_FROM_STRING_ONLY.asset_modifier', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='anim_modifier', full_name='CProtoItemSocket_AssetModifier_DESERIALIZE_FROM_STRING_ONLY.anim_modifier', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ability_effect', full_name='CProtoItemSocket_AssetModifier_DESERIALIZE_FROM_STRING_ONLY.ability_effect', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9947,
  serialized_end=10114,
)


_CPROTOITEMSOCKET_AUTOGRAPH = _descriptor.Descriptor(
  name='CProtoItemSocket_Autograph',
  full_name='CProtoItemSocket_Autograph',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket', full_name='CProtoItemSocket_Autograph.socket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='autograph', full_name='CProtoItemSocket_Autograph.autograph', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='autograph_id', full_name='CProtoItemSocket_Autograph.autograph_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='autograph_score', full_name='CProtoItemSocket_Autograph.autograph_score', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10117,
  serialized_end=10246,
)


_CPROTOITEMSOCKET_STATICVISUALS = _descriptor.Descriptor(
  name='CProtoItemSocket_StaticVisuals',
  full_name='CProtoItemSocket_StaticVisuals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket', full_name='CProtoItemSocket_StaticVisuals.socket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10248,
  serialized_end=10315,
)


_CATTRIBUTE_STRING = _descriptor.Descriptor(
  name='CAttribute_String',
  full_name='CAttribute_String',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='CAttribute_String.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10317,
  serialized_end=10351,
)


_CWORKSHOP_GETITEMDAILYREVENUE_REQUEST = _descriptor.Descriptor(
  name='CWorkshop_GetItemDailyRevenue_Request',
  full_name='CWorkshop_GetItemDailyRevenue_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CWorkshop_GetItemDailyRevenue_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CWorkshop_GetItemDailyRevenue_Request.item_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='date_start', full_name='CWorkshop_GetItemDailyRevenue_Request.date_start', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='date_end', full_name='CWorkshop_GetItemDailyRevenue_Request.date_end', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10353,
  serialized_end=10462,
)


_CWORKSHOP_GETITEMDAILYREVENUE_RESPONSE_COUNTRYDAILYREVENUE = _descriptor.Descriptor(
  name='CountryDailyRevenue',
  full_name='CWorkshop_GetItemDailyRevenue_Response.CountryDailyRevenue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CWorkshop_GetItemDailyRevenue_Response.CountryDailyRevenue.country_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='date', full_name='CWorkshop_GetItemDailyRevenue_Response.CountryDailyRevenue.date', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='revenue_usd', full_name='CWorkshop_GetItemDailyRevenue_Response.CountryDailyRevenue.revenue_usd', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='units', full_name='CWorkshop_GetItemDailyRevenue_Response.CountryDailyRevenue.units', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10593,
  serialized_end=10686,
)

_CWORKSHOP_GETITEMDAILYREVENUE_RESPONSE = _descriptor.Descriptor(
  name='CWorkshop_GetItemDailyRevenue_Response',
  full_name='CWorkshop_GetItemDailyRevenue_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='country_revenue', full_name='CWorkshop_GetItemDailyRevenue_Response.country_revenue', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CWORKSHOP_GETITEMDAILYREVENUE_RESPONSE_COUNTRYDAILYREVENUE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10465,
  serialized_end=10686,
)


_CMSGSQLGCTOGCGRANTBACKPACKSLOTS = _descriptor.Descriptor(
  name='CMsgSQLGCToGCGrantBackpackSlots',
  full_name='CMsgSQLGCToGCGrantBackpackSlots',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgSQLGCToGCGrantBackpackSlots.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='add_slots', full_name='CMsgSQLGCToGCGrantBackpackSlots.add_slots', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10688,
  serialized_end=10760,
)


_CMSGCLIENTTOGCLOOKUPACCOUNTNAME = _descriptor.Descriptor(
  name='CMsgClientToGCLookupAccountName',
  full_name='CMsgClientToGCLookupAccountName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgClientToGCLookupAccountName.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10762,
  serialized_end=10815,
)


_CMSGCLIENTTOGCLOOKUPACCOUNTNAMERESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCLookupAccountNameResponse',
  full_name='CMsgClientToGCLookupAccountNameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgClientToGCLookupAccountNameResponse.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_name', full_name='CMsgClientToGCLookupAccountNameResponse.account_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10817,
  serialized_end=10900,
)


_CMSGGCTOGCDEVREVOKEUSERITEMS = _descriptor.Descriptor(
  name='CMsgGCToGCDevRevokeUserItems',
  full_name='CMsgGCToGCDevRevokeUserItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCToGCDevRevokeUserItems.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audit_data', full_name='CMsgGCToGCDevRevokeUserItems.audit_data', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delete_audit_history', full_name='CMsgGCToGCDevRevokeUserItems.delete_audit_history', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10902,
  serialized_end=11002,
)


_CMSGCLIENTTOGCCREATESTATICRECIPE_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='CMsgClientToGCCreateStaticRecipe.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgClientToGCCreateStaticRecipe.Item.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot_id', full_name='CMsgClientToGCCreateStaticRecipe.Item.slot_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11122,
  serialized_end=11162,
)

_CMSGCLIENTTOGCCREATESTATICRECIPE = _descriptor.Descriptor(
  name='CMsgClientToGCCreateStaticRecipe',
  full_name='CMsgClientToGCCreateStaticRecipe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='CMsgClientToGCCreateStaticRecipe.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recipe_def_index', full_name='CMsgClientToGCCreateStaticRecipe.recipe_def_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCCREATESTATICRECIPE_ITEM, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11005,
  serialized_end=11162,
)


_CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_OUTPUTITEM = _descriptor.Descriptor(
  name='OutputItem',
  full_name='CMsgClientToGCCreateStaticRecipeResponse.OutputItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CMsgClientToGCCreateStaticRecipeResponse.OutputItem.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgClientToGCCreateStaticRecipeResponse.OutputItem.item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot_id', full_name='CMsgClientToGCCreateStaticRecipeResponse.OutputItem.slot_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11539,
  serialized_end=11604,
)

_CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_INPUTERROR = _descriptor.Descriptor(
  name='InputError',
  full_name='CMsgClientToGCCreateStaticRecipeResponse.InputError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slot_id', full_name='CMsgClientToGCCreateStaticRecipeResponse.InputError.slot_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error', full_name='CMsgClientToGCCreateStaticRecipeResponse.InputError.error', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11606,
  serialized_end=11722,
)

_CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_ADDITIONALOUTPUT = _descriptor.Descriptor(
  name='AdditionalOutput',
  full_name='CMsgClientToGCCreateStaticRecipeResponse.AdditionalOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slot_id', full_name='CMsgClientToGCCreateStaticRecipeResponse.AdditionalOutput.slot_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='CMsgClientToGCCreateStaticRecipeResponse.AdditionalOutput.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11724,
  serialized_end=11774,
)

_CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCCreateStaticRecipeResponse',
  full_name='CMsgClientToGCCreateStaticRecipeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='CMsgClientToGCCreateStaticRecipeResponse.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='output_items', full_name='CMsgClientToGCCreateStaticRecipeResponse.output_items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='input_errors', full_name='CMsgClientToGCCreateStaticRecipeResponse.input_errors', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='additional_outputs', full_name='CMsgClientToGCCreateStaticRecipeResponse.additional_outputs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_OUTPUTITEM, _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_INPUTERROR, _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_ADDITIONALOUTPUT, ],
  enum_types=[
    _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_ERESPONSE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11165,
  serialized_end=11929,
)


_CMSGPROCESSTRANSACTIONORDER_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='CMsgProcessTransactionOrder.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def_index', full_name='CMsgProcessTransactionOrder.Item.item_def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_price', full_name='CMsgProcessTransactionOrder.Item.item_price', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='CMsgProcessTransactionOrder.Item.quantity', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='category_desc', full_name='CMsgProcessTransactionOrder.Item.category_desc', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='store_purchase_type', full_name='CMsgProcessTransactionOrder.Item.store_purchase_type', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source_reference_id', full_name='CMsgProcessTransactionOrder.Item.source_reference_id', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_stack_index', full_name='CMsgProcessTransactionOrder.Item.parent_stack_index', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='default_price', full_name='CMsgProcessTransactionOrder.Item.default_price', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_user_facing', full_name='CMsgProcessTransactionOrder.Item.is_user_facing', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12183,
  serialized_end=12407,
)

_CMSGPROCESSTRANSACTIONORDER = _descriptor.Descriptor(
  name='CMsgProcessTransactionOrder',
  full_name='CMsgProcessTransactionOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txn_id', full_name='CMsgProcessTransactionOrder.txn_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steam_txn_id', full_name='CMsgProcessTransactionOrder.steam_txn_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='partner_txn_id', full_name='CMsgProcessTransactionOrder.partner_txn_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgProcessTransactionOrder.steam_id', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='CMsgProcessTransactionOrder.time_stamp', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='watermark', full_name='CMsgProcessTransactionOrder.watermark', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='purchase_report_status', full_name='CMsgProcessTransactionOrder.purchase_report_status', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currency', full_name='CMsgProcessTransactionOrder.currency', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='items', full_name='CMsgProcessTransactionOrder.items', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGPROCESSTRANSACTIONORDER_ITEM, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11932,
  serialized_end=12407,
)


_CMSGGCTOGCSTOREPROCESSCDKEYTRANSACTION = _descriptor.Descriptor(
  name='CMsgGCToGCStoreProcessCDKeyTransaction',
  full_name='CMsgGCToGCStoreProcessCDKeyTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='order', full_name='CMsgGCToGCStoreProcessCDKeyTransaction.order', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason_code', full_name='CMsgGCToGCStoreProcessCDKeyTransaction.reason_code', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12409,
  serialized_end=12515,
)


_CMSGGCTOGCSTOREPROCESSCDKEYTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToGCStoreProcessCDKeyTransactionResponse',
  full_name='CMsgGCToGCStoreProcessCDKeyTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CMsgGCToGCStoreProcessCDKeyTransactionResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12517,
  serialized_end=12582,
)


_CMSGGCTOGCSTOREPROCESSSETTLEMENT = _descriptor.Descriptor(
  name='CMsgGCToGCStoreProcessSettlement',
  full_name='CMsgGCToGCStoreProcessSettlement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='order', full_name='CMsgGCToGCStoreProcessSettlement.order', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='partner', full_name='CMsgGCToGCStoreProcessSettlement.partner', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12584,
  serialized_end=12680,
)


_CMSGGCTOGCSTOREPROCESSSETTLEMENTRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToGCStoreProcessSettlementResponse',
  full_name='CMsgGCToGCStoreProcessSettlementResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CMsgGCToGCStoreProcessSettlementResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12682,
  serialized_end=12741,
)


_CMSGGCTOGCBROADCASTCONSOLECOMMAND = _descriptor.Descriptor(
  name='CMsgGCToGCBroadcastConsoleCommand',
  full_name='CMsgGCToGCBroadcastConsoleCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='con_command', full_name='CMsgGCToGCBroadcastConsoleCommand.con_command', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='report_output', full_name='CMsgGCToGCBroadcastConsoleCommand.report_output', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sending_gc', full_name='CMsgGCToGCBroadcastConsoleCommand.sending_gc', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='output_initiator', full_name='CMsgGCToGCBroadcastConsoleCommand.output_initiator', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12743,
  serialized_end=12868,
)


_CMSGGCTOGCCONSOLEOUTPUT_OUTPUTLINE = _descriptor.Descriptor(
  name='OutputLine',
  full_name='CMsgGCToGCConsoleOutput.OutputLine',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='CMsgGCToGCConsoleOutput.OutputLine.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spew_level', full_name='CMsgGCToGCConsoleOutput.OutputLine.spew_level', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12988,
  serialized_end=13034,
)

_CMSGGCTOGCCONSOLEOUTPUT = _descriptor.Descriptor(
  name='CMsgGCToGCConsoleOutput',
  full_name='CMsgGCToGCConsoleOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='initiator', full_name='CMsgGCToGCConsoleOutput.initiator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sending_gc', full_name='CMsgGCToGCConsoleOutput.sending_gc', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='msgs', full_name='CMsgGCToGCConsoleOutput.msgs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOGCCONSOLEOUTPUT_OUTPUTLINE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12871,
  serialized_end=13034,
)


_CMSGITEMAGES_MAXITEMIDTIMESTAMP = _descriptor.Descriptor(
  name='MaxItemIDTimestamp',
  full_name='CMsgItemAges.MaxItemIDTimestamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgItemAges.MaxItemIDTimestamp.timestamp', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_item_id', full_name='CMsgItemAges.MaxItemIDTimestamp.max_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13119,
  serialized_end=13179,
)

_CMSGITEMAGES = _descriptor.Descriptor(
  name='CMsgItemAges',
  full_name='CMsgItemAges',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_item_id_timestamps', full_name='CMsgItemAges.max_item_id_timestamps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGITEMAGES_MAXITEMIDTIMESTAMP, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13037,
  serialized_end=13179,
)


_CMSGGCTOGCINTERNALTESTMSG = _descriptor.Descriptor(
  name='CMsgGCToGCInternalTestMsg',
  full_name='CMsgGCToGCInternalTestMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sending_gc', full_name='CMsgGCToGCInternalTestMsg.sending_gc', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sender_id', full_name='CMsgGCToGCInternalTestMsg.sender_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='context', full_name='CMsgGCToGCInternalTestMsg.context', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='CMsgGCToGCInternalTestMsg.message_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_body', full_name='CMsgGCToGCInternalTestMsg.message_body', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='job_id_source', full_name='CMsgGCToGCInternalTestMsg.job_id_source', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='job_id_target', full_name='CMsgGCToGCInternalTestMsg.job_id_target', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13182,
  serialized_end=13353,
)


_CMSGGCTOGCCLIENTSERVERVERSIONSUPDATED = _descriptor.Descriptor(
  name='CMsgGCToGCClientServerVersionsUpdated',
  full_name='CMsgGCToGCClientServerVersionsUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_min_allowed_version', full_name='CMsgGCToGCClientServerVersionsUpdated.client_min_allowed_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_active_version', full_name='CMsgGCToGCClientServerVersionsUpdated.client_active_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_active_version', full_name='CMsgGCToGCClientServerVersionsUpdated.server_active_version', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_deployed_version', full_name='CMsgGCToGCClientServerVersionsUpdated.server_deployed_version', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13356,
  serialized_end=13526,
)

_CMSGECONPLAYERSTRANGECOUNTADJUSTMENT_CSTRANGECOUNTADJUSTMENT.containing_type = _CMSGECONPLAYERSTRANGECOUNTADJUSTMENT
_CMSGECONPLAYERSTRANGECOUNTADJUSTMENT.fields_by_name['strange_count_adjustments'].message_type = _CMSGECONPLAYERSTRANGECOUNTADJUSTMENT_CSTRANGECOUNTADJUSTMENT
_CMSGGCREQUESTSTORESALESDATARESPONSE_PRICE.containing_type = _CMSGGCREQUESTSTORESALESDATARESPONSE
_CMSGGCREQUESTSTORESALESDATARESPONSE.fields_by_name['sale_price'].message_type = _CMSGGCREQUESTSTORESALESDATARESPONSE_PRICE
_CMSGLOOKUPMULTIPLEACCOUNTNAMESRESPONSE_ACCOUNT.containing_type = _CMSGLOOKUPMULTIPLEACCOUNTNAMESRESPONSE
_CMSGLOOKUPMULTIPLEACCOUNTNAMESRESPONSE.fields_by_name['accounts'].message_type = _CMSGLOOKUPMULTIPLEACCOUNTNAMESRESPONSE_ACCOUNT
_CMSGREQUESTCRATEITEMSRESPONSE_ERESULT.containing_type = _CMSGREQUESTCRATEITEMSRESPONSE
_CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM_DYNAMICATTRIBUTE.containing_type = _CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM
_CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM_ADDITIONALAUDITENTRY.containing_type = _CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM
_CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM.fields_by_name['dynamic_attributes'].message_type = _CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM_DYNAMICATTRIBUTE
_CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM.fields_by_name['additional_audit_entries'].message_type = _CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM_ADDITIONALAUDITENTRY
_CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM.containing_type = _CMSGGCTOGCGRANTACCOUNTROLLEDITEMS
_CMSGGCTOGCGRANTACCOUNTROLLEDITEMS.fields_by_name['items'].message_type = _CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM
_CMSGSERVERUSEITEM.fields_by_name['use_item_msg'].message_type = _CMSGUSEITEM
_CMSGGCPARTNERBALANCERESPONSE.fields_by_name['result'].enum_type = econ__shared__enums__pb2._EGCPARTNERREQUESTRESPONSE
_CMSGGCPARTNERRECHARGEREDIRECTURLREQUEST.fields_by_name['line_items'].message_type = _CGCSTORERECHARGEREDIRECT_LINEITEM
_CMSGGCPARTNERRECHARGEREDIRECTURLRESPONSE.fields_by_name['result'].enum_type = econ__shared__enums__pb2._EGCPARTNERREQUESTRESPONSE
_CMSGREDEEMCODERESPONSE_ERESULTCODE.containing_type = _CMSGREDEEMCODERESPONSE
_CMSGCLIENTTOGCWRAPANDDELIVERGIFTRESPONSE.fields_by_name['response'].enum_type = econ__shared__enums__pb2._EGCMSGRESPONSE
_CMSGCLIENTTOGCWRAPANDDELIVERGIFTRESPONSE.fields_by_name['trade_restriction'].enum_type = _EGCMSGINITIATETRADERESPONSE
_CMSGCLIENTTOGCGETGIFTPERMISSIONSRESPONSE_FRIENDPERMISSION.fields_by_name['permission'].enum_type = _EGCMSGINITIATETRADERESPONSE
_CMSGCLIENTTOGCGETGIFTPERMISSIONSRESPONSE_FRIENDPERMISSION.containing_type = _CMSGCLIENTTOGCGETGIFTPERMISSIONSRESPONSE
_CMSGCLIENTTOGCGETGIFTPERMISSIONSRESPONSE.fields_by_name['sender_permission'].enum_type = _EGCMSGINITIATETRADERESPONSE
_CMSGCLIENTTOGCGETGIFTPERMISSIONSRESPONSE.fields_by_name['friend_permissions'].message_type = _CMSGCLIENTTOGCGETGIFTPERMISSIONSRESPONSE_FRIENDPERMISSION
_CMSGCLIENTTOGCUNPACKBUNDLERESPONSE.fields_by_name['response'].enum_type = _CMSGCLIENTTOGCUNPACKBUNDLERESPONSE_EUNPACKBUNDLE
_CMSGCLIENTTOGCUNPACKBUNDLERESPONSE_EUNPACKBUNDLE.containing_type = _CMSGCLIENTTOGCUNPACKBUNDLERESPONSE
_CMSGCLIENTTOGCEQUIPITEMS.fields_by_name['equips'].message_type = _CMSGADJUSTITEMEQUIPPEDSTATE
_CMSGCLIENTTOGCSETITEMSTYLERESPONSE.fields_by_name['response'].enum_type = _CMSGCLIENTTOGCSETITEMSTYLERESPONSE_ESETSTYLE
_CMSGCLIENTTOGCSETITEMSTYLERESPONSE_ESETSTYLE.containing_type = _CMSGCLIENTTOGCSETITEMSTYLERESPONSE
_CMSGCLIENTTOGCUNLOCKITEMSTYLERESPONSE.fields_by_name['response'].enum_type = _CMSGCLIENTTOGCUNLOCKITEMSTYLERESPONSE_EUNLOCKSTYLE
_CMSGCLIENTTOGCUNLOCKITEMSTYLERESPONSE_EUNLOCKSTYLE.containing_type = _CMSGCLIENTTOGCUNLOCKITEMSTYLERESPONSE
_CMSGCLIENTTOGCUNLOCKCRATERESPONSE_ITEM.containing_type = _CMSGCLIENTTOGCUNLOCKCRATERESPONSE
_CMSGCLIENTTOGCUNLOCKCRATERESPONSE.fields_by_name['result'].enum_type = econ__shared__enums__pb2._EGCMSGRESPONSE
_CMSGCLIENTTOGCUNLOCKCRATERESPONSE.fields_by_name['granted_items'].message_type = _CMSGCLIENTTOGCUNLOCKCRATERESPONSE_ITEM
_CMSGCLIENTTOGCREMOVEITEMATTRIBUTERESPONSE.fields_by_name['response'].enum_type = _CMSGCLIENTTOGCREMOVEITEMATTRIBUTERESPONSE_EREMOVEITEMATTRIBUTE
_CMSGCLIENTTOGCREMOVEITEMATTRIBUTERESPONSE_EREMOVEITEMATTRIBUTE.containing_type = _CMSGCLIENTTOGCREMOVEITEMATTRIBUTERESPONSE
_CMSGCLIENTTOGCNAMEITEMRESPONSE.fields_by_name['response'].enum_type = _CMSGCLIENTTOGCNAMEITEMRESPONSE_ENAMEITEM
_CMSGCLIENTTOGCNAMEITEMRESPONSE_ENAMEITEM.containing_type = _CMSGCLIENTTOGCNAMEITEMRESPONSE
_CPROTOITEMSOCKET_EMPTY.fields_by_name['socket'].message_type = _CPROTOITEMSOCKET
_CPROTOITEMSOCKET_EFFECT.fields_by_name['socket'].message_type = _CPROTOITEMSOCKET
_CPROTOITEMSOCKET_COLOR.fields_by_name['socket'].message_type = _CPROTOITEMSOCKET
_CPROTOITEMSOCKET_STRANGE.fields_by_name['socket'].message_type = _CPROTOITEMSOCKET
_CPROTOITEMSOCKET_SPECTATOR.fields_by_name['socket'].message_type = _CPROTOITEMSOCKET
_CPROTOITEMSOCKET_ASSETMODIFIER.fields_by_name['socket'].message_type = _CPROTOITEMSOCKET
_CPROTOITEMSOCKET_ASSETMODIFIER_DESERIALIZE_FROM_STRING_ONLY.fields_by_name['socket'].message_type = _CPROTOITEMSOCKET
_CPROTOITEMSOCKET_AUTOGRAPH.fields_by_name['socket'].message_type = _CPROTOITEMSOCKET
_CPROTOITEMSOCKET_STATICVISUALS.fields_by_name['socket'].message_type = _CPROTOITEMSOCKET
_CWORKSHOP_GETITEMDAILYREVENUE_RESPONSE_COUNTRYDAILYREVENUE.containing_type = _CWORKSHOP_GETITEMDAILYREVENUE_RESPONSE
_CWORKSHOP_GETITEMDAILYREVENUE_RESPONSE.fields_by_name['country_revenue'].message_type = _CWORKSHOP_GETITEMDAILYREVENUE_RESPONSE_COUNTRYDAILYREVENUE
_CMSGCLIENTTOGCCREATESTATICRECIPE_ITEM.containing_type = _CMSGCLIENTTOGCCREATESTATICRECIPE
_CMSGCLIENTTOGCCREATESTATICRECIPE.fields_by_name['items'].message_type = _CMSGCLIENTTOGCCREATESTATICRECIPE_ITEM
_CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_OUTPUTITEM.containing_type = _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE
_CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_INPUTERROR.fields_by_name['error'].enum_type = _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_ERESPONSE
_CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_INPUTERROR.containing_type = _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE
_CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_ADDITIONALOUTPUT.containing_type = _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE
_CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE.fields_by_name['response'].enum_type = _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_ERESPONSE
_CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE.fields_by_name['output_items'].message_type = _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_OUTPUTITEM
_CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE.fields_by_name['input_errors'].message_type = _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_INPUTERROR
_CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE.fields_by_name['additional_outputs'].message_type = _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_ADDITIONALOUTPUT
_CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_ERESPONSE.containing_type = _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE
_CMSGPROCESSTRANSACTIONORDER_ITEM.containing_type = _CMSGPROCESSTRANSACTIONORDER
_CMSGPROCESSTRANSACTIONORDER.fields_by_name['items'].message_type = _CMSGPROCESSTRANSACTIONORDER_ITEM
_CMSGGCTOGCSTOREPROCESSCDKEYTRANSACTION.fields_by_name['order'].message_type = _CMSGPROCESSTRANSACTIONORDER
_CMSGGCTOGCSTOREPROCESSSETTLEMENT.fields_by_name['order'].message_type = _CMSGPROCESSTRANSACTIONORDER
_CMSGGCTOGCCONSOLEOUTPUT_OUTPUTLINE.containing_type = _CMSGGCTOGCCONSOLEOUTPUT
_CMSGGCTOGCCONSOLEOUTPUT.fields_by_name['msgs'].message_type = _CMSGGCTOGCCONSOLEOUTPUT_OUTPUTLINE
_CMSGITEMAGES_MAXITEMIDTIMESTAMP.containing_type = _CMSGITEMAGES
_CMSGITEMAGES.fields_by_name['max_item_id_timestamps'].message_type = _CMSGITEMAGES_MAXITEMIDTIMESTAMP
DESCRIPTOR.message_types_by_name['CMsgApplyAutograph'] = _CMSGAPPLYAUTOGRAPH
DESCRIPTOR.message_types_by_name['CMsgAdjustItemEquippedState'] = _CMSGADJUSTITEMEQUIPPEDSTATE
DESCRIPTOR.message_types_by_name['CMsgEconPlayerStrangeCountAdjustment'] = _CMSGECONPLAYERSTRANGECOUNTADJUSTMENT
DESCRIPTOR.message_types_by_name['CMsgRequestItemPurgatory_FinalizePurchase'] = _CMSGREQUESTITEMPURGATORY_FINALIZEPURCHASE
DESCRIPTOR.message_types_by_name['CMsgRequestItemPurgatory_FinalizePurchaseResponse'] = _CMSGREQUESTITEMPURGATORY_FINALIZEPURCHASERESPONSE
DESCRIPTOR.message_types_by_name['CMsgRequestItemPurgatory_RefundPurchase'] = _CMSGREQUESTITEMPURGATORY_REFUNDPURCHASE
DESCRIPTOR.message_types_by_name['CMsgRequestItemPurgatory_RefundPurchaseResponse'] = _CMSGREQUESTITEMPURGATORY_REFUNDPURCHASERESPONSE
DESCRIPTOR.message_types_by_name['CMsgCraftingResponse'] = _CMSGCRAFTINGRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCRequestStoreSalesData'] = _CMSGGCREQUESTSTORESALESDATA
DESCRIPTOR.message_types_by_name['CMsgGCRequestStoreSalesDataResponse'] = _CMSGGCREQUESTSTORESALESDATARESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCRequestStoreSalesDataUpToDateResponse'] = _CMSGGCREQUESTSTORESALESDATAUPTODATERESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCPingRequest'] = _CMSGGCTOGCPINGREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToGCPingResponse'] = _CMSGGCTOGCPINGRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCGetUserSessionServer'] = _CMSGGCTOGCGETUSERSESSIONSERVER
DESCRIPTOR.message_types_by_name['CMsgGCToGCGetUserSessionServerResponse'] = _CMSGGCTOGCGETUSERSESSIONSERVERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCGetUserServerMembers'] = _CMSGGCTOGCGETUSERSERVERMEMBERS
DESCRIPTOR.message_types_by_name['CMsgGCToGCGetUserServerMembersResponse'] = _CMSGGCTOGCGETUSERSERVERMEMBERSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgLookupMultipleAccountNames'] = _CMSGLOOKUPMULTIPLEACCOUNTNAMES
DESCRIPTOR.message_types_by_name['CMsgLookupMultipleAccountNamesResponse'] = _CMSGLOOKUPMULTIPLEACCOUNTNAMESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCGetUserPCBangNo'] = _CMSGGCTOGCGETUSERPCBANGNO
DESCRIPTOR.message_types_by_name['CMsgGCToGCGetUserPCBangNoResponse'] = _CMSGGCTOGCGETUSERPCBANGNORESPONSE
DESCRIPTOR.message_types_by_name['CMsgRequestCrateItems'] = _CMSGREQUESTCRATEITEMS
DESCRIPTOR.message_types_by_name['CMsgRequestCrateItemsResponse'] = _CMSGREQUESTCRATEITEMSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCCanUseDropRateBonus'] = _CMSGGCTOGCCANUSEDROPRATEBONUS
DESCRIPTOR.message_types_by_name['CMsgSQLAddDropRateBonus'] = _CMSGSQLADDDROPRATEBONUS
DESCRIPTOR.message_types_by_name['CMsgSQLUpgradeBattleBooster'] = _CMSGSQLUPGRADEBATTLEBOOSTER
DESCRIPTOR.message_types_by_name['CMsgGCToGCRefreshSOCache'] = _CMSGGCTOGCREFRESHSOCACHE
DESCRIPTOR.message_types_by_name['CMsgGCToGCCheckAccountTradeStatus'] = _CMSGGCTOGCCHECKACCOUNTTRADESTATUS
DESCRIPTOR.message_types_by_name['CMsgGCToGCCheckAccountTradeStatusResponse'] = _CMSGGCTOGCCHECKACCOUNTTRADESTATUSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCGrantAccountRolledItems'] = _CMSGGCTOGCGRANTACCOUNTROLLEDITEMS
DESCRIPTOR.message_types_by_name['CMsgGCToGCGrantSelfMadeItemToAccount'] = _CMSGGCTOGCGRANTSELFMADEITEMTOACCOUNT
DESCRIPTOR.message_types_by_name['CMsgUseItem'] = _CMSGUSEITEM
DESCRIPTOR.message_types_by_name['CMsgServerUseItem'] = _CMSGSERVERUSEITEM
DESCRIPTOR.message_types_by_name['CMsgUseMultipleItems'] = _CMSGUSEMULTIPLEITEMS
DESCRIPTOR.message_types_by_name['CMsgGCPartnerBalanceRequest'] = _CMSGGCPARTNERBALANCEREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCPartnerBalanceResponse'] = _CMSGGCPARTNERBALANCERESPONSE
DESCRIPTOR.message_types_by_name['CGCStoreRechargeRedirect_LineItem'] = _CGCSTORERECHARGEREDIRECT_LINEITEM
DESCRIPTOR.message_types_by_name['CMsgGCPartnerRechargeRedirectURLRequest'] = _CMSGGCPARTNERRECHARGEREDIRECTURLREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCPartnerRechargeRedirectURLResponse'] = _CMSGGCPARTNERRECHARGEREDIRECTURLRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCEconSQLWorkItemEmbeddedRollbackData'] = _CMSGGCECONSQLWORKITEMEMBEDDEDROLLBACKDATA
DESCRIPTOR.message_types_by_name['CMsgCraftStatue'] = _CMSGCRAFTSTATUE
DESCRIPTOR.message_types_by_name['CMsgRedeemCode'] = _CMSGREDEEMCODE
DESCRIPTOR.message_types_by_name['CMsgRedeemCodeResponse'] = _CMSGREDEEMCODERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDevNewItemRequest'] = _CMSGDEVNEWITEMREQUEST
DESCRIPTOR.message_types_by_name['CMsgDevNewItemRequestResponse'] = _CMSGDEVNEWITEMREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCAddGiftItem'] = _CMSGGCADDGIFTITEM
DESCRIPTOR.message_types_by_name['CMsgClientToGCWrapAndDeliverGift'] = _CMSGCLIENTTOGCWRAPANDDELIVERGIFT
DESCRIPTOR.message_types_by_name['CMsgClientToGCWrapAndDeliverGiftResponse'] = _CMSGCLIENTTOGCWRAPANDDELIVERGIFTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCUnwrapGift'] = _CMSGCLIENTTOGCUNWRAPGIFT
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetGiftPermissions'] = _CMSGCLIENTTOGCGETGIFTPERMISSIONS
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetGiftPermissionsResponse'] = _CMSGCLIENTTOGCGETGIFTPERMISSIONSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCUnpackBundle'] = _CMSGCLIENTTOGCUNPACKBUNDLE
DESCRIPTOR.message_types_by_name['CMsgClientToGCUnpackBundleResponse'] = _CMSGCLIENTTOGCUNPACKBUNDLERESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientStoreTransactionCompleted'] = _CMSGGCTOCLIENTSTORETRANSACTIONCOMPLETED
DESCRIPTOR.message_types_by_name['CMsgClientToGCEquipItems'] = _CMSGCLIENTTOGCEQUIPITEMS
DESCRIPTOR.message_types_by_name['CMsgClientToGCEquipItemsResponse'] = _CMSGCLIENTTOGCEQUIPITEMSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCSetItemStyle'] = _CMSGCLIENTTOGCSETITEMSTYLE
DESCRIPTOR.message_types_by_name['CMsgClientToGCSetItemStyleResponse'] = _CMSGCLIENTTOGCSETITEMSTYLERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCUnlockItemStyle'] = _CMSGCLIENTTOGCUNLOCKITEMSTYLE
DESCRIPTOR.message_types_by_name['CMsgClientToGCUnlockItemStyleResponse'] = _CMSGCLIENTTOGCUNLOCKITEMSTYLERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCSetItemInventoryCategory'] = _CMSGCLIENTTOGCSETITEMINVENTORYCATEGORY
DESCRIPTOR.message_types_by_name['CMsgClientToGCUnlockCrate'] = _CMSGCLIENTTOGCUNLOCKCRATE
DESCRIPTOR.message_types_by_name['CMsgClientToGCUnlockCrateResponse'] = _CMSGCLIENTTOGCUNLOCKCRATERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRemoveItemAttribute'] = _CMSGCLIENTTOGCREMOVEITEMATTRIBUTE
DESCRIPTOR.message_types_by_name['CMsgClientToGCRemoveItemAttributeResponse'] = _CMSGCLIENTTOGCREMOVEITEMATTRIBUTERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCNameItem'] = _CMSGCLIENTTOGCNAMEITEM
DESCRIPTOR.message_types_by_name['CMsgClientToGCNameItemResponse'] = _CMSGCLIENTTOGCNAMEITEMRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCSetItemPosition'] = _CMSGGCSETITEMPOSITION
DESCRIPTOR.message_types_by_name['CAttribute_ItemDynamicRecipeComponent'] = _CATTRIBUTE_ITEMDYNAMICRECIPECOMPONENT
DESCRIPTOR.message_types_by_name['CProtoItemSocket'] = _CPROTOITEMSOCKET
DESCRIPTOR.message_types_by_name['CProtoItemSocket_Empty'] = _CPROTOITEMSOCKET_EMPTY
DESCRIPTOR.message_types_by_name['CProtoItemSocket_Effect'] = _CPROTOITEMSOCKET_EFFECT
DESCRIPTOR.message_types_by_name['CProtoItemSocket_Color'] = _CPROTOITEMSOCKET_COLOR
DESCRIPTOR.message_types_by_name['CProtoItemSocket_Strange'] = _CPROTOITEMSOCKET_STRANGE
DESCRIPTOR.message_types_by_name['CProtoItemSocket_Spectator'] = _CPROTOITEMSOCKET_SPECTATOR
DESCRIPTOR.message_types_by_name['CProtoItemSocket_AssetModifier'] = _CPROTOITEMSOCKET_ASSETMODIFIER
DESCRIPTOR.message_types_by_name['CProtoItemSocket_AssetModifier_DESERIALIZE_FROM_STRING_ONLY'] = _CPROTOITEMSOCKET_ASSETMODIFIER_DESERIALIZE_FROM_STRING_ONLY
DESCRIPTOR.message_types_by_name['CProtoItemSocket_Autograph'] = _CPROTOITEMSOCKET_AUTOGRAPH
DESCRIPTOR.message_types_by_name['CProtoItemSocket_StaticVisuals'] = _CPROTOITEMSOCKET_STATICVISUALS
DESCRIPTOR.message_types_by_name['CAttribute_String'] = _CATTRIBUTE_STRING
DESCRIPTOR.message_types_by_name['CWorkshop_GetItemDailyRevenue_Request'] = _CWORKSHOP_GETITEMDAILYREVENUE_REQUEST
DESCRIPTOR.message_types_by_name['CWorkshop_GetItemDailyRevenue_Response'] = _CWORKSHOP_GETITEMDAILYREVENUE_RESPONSE
DESCRIPTOR.message_types_by_name['CMsgSQLGCToGCGrantBackpackSlots'] = _CMSGSQLGCTOGCGRANTBACKPACKSLOTS
DESCRIPTOR.message_types_by_name['CMsgClientToGCLookupAccountName'] = _CMSGCLIENTTOGCLOOKUPACCOUNTNAME
DESCRIPTOR.message_types_by_name['CMsgClientToGCLookupAccountNameResponse'] = _CMSGCLIENTTOGCLOOKUPACCOUNTNAMERESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCDevRevokeUserItems'] = _CMSGGCTOGCDEVREVOKEUSERITEMS
DESCRIPTOR.message_types_by_name['CMsgClientToGCCreateStaticRecipe'] = _CMSGCLIENTTOGCCREATESTATICRECIPE
DESCRIPTOR.message_types_by_name['CMsgClientToGCCreateStaticRecipeResponse'] = _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE
DESCRIPTOR.message_types_by_name['CMsgProcessTransactionOrder'] = _CMSGPROCESSTRANSACTIONORDER
DESCRIPTOR.message_types_by_name['CMsgGCToGCStoreProcessCDKeyTransaction'] = _CMSGGCTOGCSTOREPROCESSCDKEYTRANSACTION
DESCRIPTOR.message_types_by_name['CMsgGCToGCStoreProcessCDKeyTransactionResponse'] = _CMSGGCTOGCSTOREPROCESSCDKEYTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCStoreProcessSettlement'] = _CMSGGCTOGCSTOREPROCESSSETTLEMENT
DESCRIPTOR.message_types_by_name['CMsgGCToGCStoreProcessSettlementResponse'] = _CMSGGCTOGCSTOREPROCESSSETTLEMENTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCBroadcastConsoleCommand'] = _CMSGGCTOGCBROADCASTCONSOLECOMMAND
DESCRIPTOR.message_types_by_name['CMsgGCToGCConsoleOutput'] = _CMSGGCTOGCCONSOLEOUTPUT
DESCRIPTOR.message_types_by_name['CMsgItemAges'] = _CMSGITEMAGES
DESCRIPTOR.message_types_by_name['CMsgGCToGCInternalTestMsg'] = _CMSGGCTOGCINTERNALTESTMSG
DESCRIPTOR.message_types_by_name['CMsgGCToGCClientServerVersionsUpdated'] = _CMSGGCTOGCCLIENTSERVERVERSIONSUPDATED
DESCRIPTOR.enum_types_by_name['EGCItemMsg'] = _EGCITEMMSG
DESCRIPTOR.enum_types_by_name['EItemPurgatoryResponse_Finalize'] = _EITEMPURGATORYRESPONSE_FINALIZE
DESCRIPTOR.enum_types_by_name['EItemPurgatoryResponse_Refund'] = _EITEMPURGATORYRESPONSE_REFUND
DESCRIPTOR.enum_types_by_name['EGCMsgInitiateTradeResponse'] = _EGCMSGINITIATETRADERESPONSE

CMsgApplyAutograph = _reflection.GeneratedProtocolMessageType('CMsgApplyAutograph', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAPPLYAUTOGRAPH,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgApplyAutograph)
  ))
_sym_db.RegisterMessage(CMsgApplyAutograph)

CMsgAdjustItemEquippedState = _reflection.GeneratedProtocolMessageType('CMsgAdjustItemEquippedState', (_message.Message,), dict(
  DESCRIPTOR = _CMSGADJUSTITEMEQUIPPEDSTATE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgAdjustItemEquippedState)
  ))
_sym_db.RegisterMessage(CMsgAdjustItemEquippedState)

CMsgEconPlayerStrangeCountAdjustment = _reflection.GeneratedProtocolMessageType('CMsgEconPlayerStrangeCountAdjustment', (_message.Message,), dict(

  CStrangeCountAdjustment = _reflection.GeneratedProtocolMessageType('CStrangeCountAdjustment', (_message.Message,), dict(
    DESCRIPTOR = _CMSGECONPLAYERSTRANGECOUNTADJUSTMENT_CSTRANGECOUNTADJUSTMENT,
    __module__ = 'econ_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgEconPlayerStrangeCountAdjustment.CStrangeCountAdjustment)
    ))
  ,
  DESCRIPTOR = _CMSGECONPLAYERSTRANGECOUNTADJUSTMENT,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgEconPlayerStrangeCountAdjustment)
  ))
_sym_db.RegisterMessage(CMsgEconPlayerStrangeCountAdjustment)
_sym_db.RegisterMessage(CMsgEconPlayerStrangeCountAdjustment.CStrangeCountAdjustment)

CMsgRequestItemPurgatory_FinalizePurchase = _reflection.GeneratedProtocolMessageType('CMsgRequestItemPurgatory_FinalizePurchase', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTITEMPURGATORY_FINALIZEPURCHASE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRequestItemPurgatory_FinalizePurchase)
  ))
_sym_db.RegisterMessage(CMsgRequestItemPurgatory_FinalizePurchase)

CMsgRequestItemPurgatory_FinalizePurchaseResponse = _reflection.GeneratedProtocolMessageType('CMsgRequestItemPurgatory_FinalizePurchaseResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTITEMPURGATORY_FINALIZEPURCHASERESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRequestItemPurgatory_FinalizePurchaseResponse)
  ))
_sym_db.RegisterMessage(CMsgRequestItemPurgatory_FinalizePurchaseResponse)

CMsgRequestItemPurgatory_RefundPurchase = _reflection.GeneratedProtocolMessageType('CMsgRequestItemPurgatory_RefundPurchase', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTITEMPURGATORY_REFUNDPURCHASE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRequestItemPurgatory_RefundPurchase)
  ))
_sym_db.RegisterMessage(CMsgRequestItemPurgatory_RefundPurchase)

CMsgRequestItemPurgatory_RefundPurchaseResponse = _reflection.GeneratedProtocolMessageType('CMsgRequestItemPurgatory_RefundPurchaseResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTITEMPURGATORY_REFUNDPURCHASERESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRequestItemPurgatory_RefundPurchaseResponse)
  ))
_sym_db.RegisterMessage(CMsgRequestItemPurgatory_RefundPurchaseResponse)

CMsgCraftingResponse = _reflection.GeneratedProtocolMessageType('CMsgCraftingResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCRAFTINGRESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCraftingResponse)
  ))
_sym_db.RegisterMessage(CMsgCraftingResponse)

CMsgGCRequestStoreSalesData = _reflection.GeneratedProtocolMessageType('CMsgGCRequestStoreSalesData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCREQUESTSTORESALESDATA,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCRequestStoreSalesData)
  ))
_sym_db.RegisterMessage(CMsgGCRequestStoreSalesData)

CMsgGCRequestStoreSalesDataResponse = _reflection.GeneratedProtocolMessageType('CMsgGCRequestStoreSalesDataResponse', (_message.Message,), dict(

  Price = _reflection.GeneratedProtocolMessageType('Price', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCREQUESTSTORESALESDATARESPONSE_PRICE,
    __module__ = 'econ_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCRequestStoreSalesDataResponse.Price)
    ))
  ,
  DESCRIPTOR = _CMSGGCREQUESTSTORESALESDATARESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCRequestStoreSalesDataResponse)
  ))
_sym_db.RegisterMessage(CMsgGCRequestStoreSalesDataResponse)
_sym_db.RegisterMessage(CMsgGCRequestStoreSalesDataResponse.Price)

CMsgGCRequestStoreSalesDataUpToDateResponse = _reflection.GeneratedProtocolMessageType('CMsgGCRequestStoreSalesDataUpToDateResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCREQUESTSTORESALESDATAUPTODATERESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCRequestStoreSalesDataUpToDateResponse)
  ))
_sym_db.RegisterMessage(CMsgGCRequestStoreSalesDataUpToDateResponse)

CMsgGCToGCPingRequest = _reflection.GeneratedProtocolMessageType('CMsgGCToGCPingRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCPINGREQUEST,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCPingRequest)
  ))
_sym_db.RegisterMessage(CMsgGCToGCPingRequest)

CMsgGCToGCPingResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToGCPingResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCPINGRESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCPingResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToGCPingResponse)

CMsgGCToGCGetUserSessionServer = _reflection.GeneratedProtocolMessageType('CMsgGCToGCGetUserSessionServer', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCGETUSERSESSIONSERVER,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCGetUserSessionServer)
  ))
_sym_db.RegisterMessage(CMsgGCToGCGetUserSessionServer)

CMsgGCToGCGetUserSessionServerResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToGCGetUserSessionServerResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCGETUSERSESSIONSERVERRESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCGetUserSessionServerResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToGCGetUserSessionServerResponse)

CMsgGCToGCGetUserServerMembers = _reflection.GeneratedProtocolMessageType('CMsgGCToGCGetUserServerMembers', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCGETUSERSERVERMEMBERS,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCGetUserServerMembers)
  ))
_sym_db.RegisterMessage(CMsgGCToGCGetUserServerMembers)

CMsgGCToGCGetUserServerMembersResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToGCGetUserServerMembersResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCGETUSERSERVERMEMBERSRESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCGetUserServerMembersResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToGCGetUserServerMembersResponse)

CMsgLookupMultipleAccountNames = _reflection.GeneratedProtocolMessageType('CMsgLookupMultipleAccountNames', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLOOKUPMULTIPLEACCOUNTNAMES,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgLookupMultipleAccountNames)
  ))
_sym_db.RegisterMessage(CMsgLookupMultipleAccountNames)

CMsgLookupMultipleAccountNamesResponse = _reflection.GeneratedProtocolMessageType('CMsgLookupMultipleAccountNamesResponse', (_message.Message,), dict(

  Account = _reflection.GeneratedProtocolMessageType('Account', (_message.Message,), dict(
    DESCRIPTOR = _CMSGLOOKUPMULTIPLEACCOUNTNAMESRESPONSE_ACCOUNT,
    __module__ = 'econ_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgLookupMultipleAccountNamesResponse.Account)
    ))
  ,
  DESCRIPTOR = _CMSGLOOKUPMULTIPLEACCOUNTNAMESRESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgLookupMultipleAccountNamesResponse)
  ))
_sym_db.RegisterMessage(CMsgLookupMultipleAccountNamesResponse)
_sym_db.RegisterMessage(CMsgLookupMultipleAccountNamesResponse.Account)

CMsgGCToGCGetUserPCBangNo = _reflection.GeneratedProtocolMessageType('CMsgGCToGCGetUserPCBangNo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCGETUSERPCBANGNO,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCGetUserPCBangNo)
  ))
_sym_db.RegisterMessage(CMsgGCToGCGetUserPCBangNo)

CMsgGCToGCGetUserPCBangNoResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToGCGetUserPCBangNoResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCGETUSERPCBANGNORESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCGetUserPCBangNoResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToGCGetUserPCBangNoResponse)

CMsgRequestCrateItems = _reflection.GeneratedProtocolMessageType('CMsgRequestCrateItems', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTCRATEITEMS,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRequestCrateItems)
  ))
_sym_db.RegisterMessage(CMsgRequestCrateItems)

CMsgRequestCrateItemsResponse = _reflection.GeneratedProtocolMessageType('CMsgRequestCrateItemsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTCRATEITEMSRESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRequestCrateItemsResponse)
  ))
_sym_db.RegisterMessage(CMsgRequestCrateItemsResponse)

CMsgGCToGCCanUseDropRateBonus = _reflection.GeneratedProtocolMessageType('CMsgGCToGCCanUseDropRateBonus', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCCANUSEDROPRATEBONUS,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCCanUseDropRateBonus)
  ))
_sym_db.RegisterMessage(CMsgGCToGCCanUseDropRateBonus)

CMsgSQLAddDropRateBonus = _reflection.GeneratedProtocolMessageType('CMsgSQLAddDropRateBonus', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSQLADDDROPRATEBONUS,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSQLAddDropRateBonus)
  ))
_sym_db.RegisterMessage(CMsgSQLAddDropRateBonus)

CMsgSQLUpgradeBattleBooster = _reflection.GeneratedProtocolMessageType('CMsgSQLUpgradeBattleBooster', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSQLUPGRADEBATTLEBOOSTER,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSQLUpgradeBattleBooster)
  ))
_sym_db.RegisterMessage(CMsgSQLUpgradeBattleBooster)

CMsgGCToGCRefreshSOCache = _reflection.GeneratedProtocolMessageType('CMsgGCToGCRefreshSOCache', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCREFRESHSOCACHE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCRefreshSOCache)
  ))
_sym_db.RegisterMessage(CMsgGCToGCRefreshSOCache)

CMsgGCToGCCheckAccountTradeStatus = _reflection.GeneratedProtocolMessageType('CMsgGCToGCCheckAccountTradeStatus', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCCHECKACCOUNTTRADESTATUS,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCCheckAccountTradeStatus)
  ))
_sym_db.RegisterMessage(CMsgGCToGCCheckAccountTradeStatus)

CMsgGCToGCCheckAccountTradeStatusResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToGCCheckAccountTradeStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCCHECKACCOUNTTRADESTATUSRESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCCheckAccountTradeStatusResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToGCCheckAccountTradeStatusResponse)

CMsgGCToGCGrantAccountRolledItems = _reflection.GeneratedProtocolMessageType('CMsgGCToGCGrantAccountRolledItems', (_message.Message,), dict(

  Item = _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), dict(

    DynamicAttribute = _reflection.GeneratedProtocolMessageType('DynamicAttribute', (_message.Message,), dict(
      DESCRIPTOR = _CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM_DYNAMICATTRIBUTE,
      __module__ = 'econ_gcmessages_pb2'
      # @@protoc_insertion_point(class_scope:CMsgGCToGCGrantAccountRolledItems.Item.DynamicAttribute)
      ))
    ,

    AdditionalAuditEntry = _reflection.GeneratedProtocolMessageType('AdditionalAuditEntry', (_message.Message,), dict(
      DESCRIPTOR = _CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM_ADDITIONALAUDITENTRY,
      __module__ = 'econ_gcmessages_pb2'
      # @@protoc_insertion_point(class_scope:CMsgGCToGCGrantAccountRolledItems.Item.AdditionalAuditEntry)
      ))
    ,
    DESCRIPTOR = _CMSGGCTOGCGRANTACCOUNTROLLEDITEMS_ITEM,
    __module__ = 'econ_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToGCGrantAccountRolledItems.Item)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOGCGRANTACCOUNTROLLEDITEMS,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCGrantAccountRolledItems)
  ))
_sym_db.RegisterMessage(CMsgGCToGCGrantAccountRolledItems)
_sym_db.RegisterMessage(CMsgGCToGCGrantAccountRolledItems.Item)
_sym_db.RegisterMessage(CMsgGCToGCGrantAccountRolledItems.Item.DynamicAttribute)
_sym_db.RegisterMessage(CMsgGCToGCGrantAccountRolledItems.Item.AdditionalAuditEntry)

CMsgGCToGCGrantSelfMadeItemToAccount = _reflection.GeneratedProtocolMessageType('CMsgGCToGCGrantSelfMadeItemToAccount', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCGRANTSELFMADEITEMTOACCOUNT,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCGrantSelfMadeItemToAccount)
  ))
_sym_db.RegisterMessage(CMsgGCToGCGrantSelfMadeItemToAccount)

CMsgUseItem = _reflection.GeneratedProtocolMessageType('CMsgUseItem', (_message.Message,), dict(
  DESCRIPTOR = _CMSGUSEITEM,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgUseItem)
  ))
_sym_db.RegisterMessage(CMsgUseItem)

CMsgServerUseItem = _reflection.GeneratedProtocolMessageType('CMsgServerUseItem', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSERVERUSEITEM,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgServerUseItem)
  ))
_sym_db.RegisterMessage(CMsgServerUseItem)

CMsgUseMultipleItems = _reflection.GeneratedProtocolMessageType('CMsgUseMultipleItems', (_message.Message,), dict(
  DESCRIPTOR = _CMSGUSEMULTIPLEITEMS,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgUseMultipleItems)
  ))
_sym_db.RegisterMessage(CMsgUseMultipleItems)

CMsgGCPartnerBalanceRequest = _reflection.GeneratedProtocolMessageType('CMsgGCPartnerBalanceRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCPARTNERBALANCEREQUEST,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCPartnerBalanceRequest)
  ))
_sym_db.RegisterMessage(CMsgGCPartnerBalanceRequest)

CMsgGCPartnerBalanceResponse = _reflection.GeneratedProtocolMessageType('CMsgGCPartnerBalanceResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCPARTNERBALANCERESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCPartnerBalanceResponse)
  ))
_sym_db.RegisterMessage(CMsgGCPartnerBalanceResponse)

CGCStoreRechargeRedirect_LineItem = _reflection.GeneratedProtocolMessageType('CGCStoreRechargeRedirect_LineItem', (_message.Message,), dict(
  DESCRIPTOR = _CGCSTORERECHARGEREDIRECT_LINEITEM,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CGCStoreRechargeRedirect_LineItem)
  ))
_sym_db.RegisterMessage(CGCStoreRechargeRedirect_LineItem)

CMsgGCPartnerRechargeRedirectURLRequest = _reflection.GeneratedProtocolMessageType('CMsgGCPartnerRechargeRedirectURLRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCPARTNERRECHARGEREDIRECTURLREQUEST,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCPartnerRechargeRedirectURLRequest)
  ))
_sym_db.RegisterMessage(CMsgGCPartnerRechargeRedirectURLRequest)

CMsgGCPartnerRechargeRedirectURLResponse = _reflection.GeneratedProtocolMessageType('CMsgGCPartnerRechargeRedirectURLResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCPARTNERRECHARGEREDIRECTURLRESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCPartnerRechargeRedirectURLResponse)
  ))
_sym_db.RegisterMessage(CMsgGCPartnerRechargeRedirectURLResponse)

CMsgGCEconSQLWorkItemEmbeddedRollbackData = _reflection.GeneratedProtocolMessageType('CMsgGCEconSQLWorkItemEmbeddedRollbackData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCECONSQLWORKITEMEMBEDDEDROLLBACKDATA,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCEconSQLWorkItemEmbeddedRollbackData)
  ))
_sym_db.RegisterMessage(CMsgGCEconSQLWorkItemEmbeddedRollbackData)

CMsgCraftStatue = _reflection.GeneratedProtocolMessageType('CMsgCraftStatue', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCRAFTSTATUE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCraftStatue)
  ))
_sym_db.RegisterMessage(CMsgCraftStatue)

CMsgRedeemCode = _reflection.GeneratedProtocolMessageType('CMsgRedeemCode', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREDEEMCODE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRedeemCode)
  ))
_sym_db.RegisterMessage(CMsgRedeemCode)

CMsgRedeemCodeResponse = _reflection.GeneratedProtocolMessageType('CMsgRedeemCodeResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREDEEMCODERESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRedeemCodeResponse)
  ))
_sym_db.RegisterMessage(CMsgRedeemCodeResponse)

CMsgDevNewItemRequest = _reflection.GeneratedProtocolMessageType('CMsgDevNewItemRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDEVNEWITEMREQUEST,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDevNewItemRequest)
  ))
_sym_db.RegisterMessage(CMsgDevNewItemRequest)

CMsgDevNewItemRequestResponse = _reflection.GeneratedProtocolMessageType('CMsgDevNewItemRequestResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDEVNEWITEMREQUESTRESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDevNewItemRequestResponse)
  ))
_sym_db.RegisterMessage(CMsgDevNewItemRequestResponse)

CMsgGCAddGiftItem = _reflection.GeneratedProtocolMessageType('CMsgGCAddGiftItem', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCADDGIFTITEM,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCAddGiftItem)
  ))
_sym_db.RegisterMessage(CMsgGCAddGiftItem)

CMsgClientToGCWrapAndDeliverGift = _reflection.GeneratedProtocolMessageType('CMsgClientToGCWrapAndDeliverGift', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCWRAPANDDELIVERGIFT,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCWrapAndDeliverGift)
  ))
_sym_db.RegisterMessage(CMsgClientToGCWrapAndDeliverGift)

CMsgClientToGCWrapAndDeliverGiftResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCWrapAndDeliverGiftResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCWRAPANDDELIVERGIFTRESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCWrapAndDeliverGiftResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCWrapAndDeliverGiftResponse)

CMsgClientToGCUnwrapGift = _reflection.GeneratedProtocolMessageType('CMsgClientToGCUnwrapGift', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCUNWRAPGIFT,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCUnwrapGift)
  ))
_sym_db.RegisterMessage(CMsgClientToGCUnwrapGift)

CMsgClientToGCGetGiftPermissions = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetGiftPermissions', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETGIFTPERMISSIONS,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetGiftPermissions)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetGiftPermissions)

CMsgClientToGCGetGiftPermissionsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetGiftPermissionsResponse', (_message.Message,), dict(

  FriendPermission = _reflection.GeneratedProtocolMessageType('FriendPermission', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCGETGIFTPERMISSIONSRESPONSE_FRIENDPERMISSION,
    __module__ = 'econ_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCGetGiftPermissionsResponse.FriendPermission)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCGETGIFTPERMISSIONSRESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetGiftPermissionsResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetGiftPermissionsResponse)
_sym_db.RegisterMessage(CMsgClientToGCGetGiftPermissionsResponse.FriendPermission)

CMsgClientToGCUnpackBundle = _reflection.GeneratedProtocolMessageType('CMsgClientToGCUnpackBundle', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCUNPACKBUNDLE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCUnpackBundle)
  ))
_sym_db.RegisterMessage(CMsgClientToGCUnpackBundle)

CMsgClientToGCUnpackBundleResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCUnpackBundleResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCUNPACKBUNDLERESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCUnpackBundleResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCUnpackBundleResponse)

CMsgGCToClientStoreTransactionCompleted = _reflection.GeneratedProtocolMessageType('CMsgGCToClientStoreTransactionCompleted', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTSTORETRANSACTIONCOMPLETED,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToClientStoreTransactionCompleted)
  ))
_sym_db.RegisterMessage(CMsgGCToClientStoreTransactionCompleted)

CMsgClientToGCEquipItems = _reflection.GeneratedProtocolMessageType('CMsgClientToGCEquipItems', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCEQUIPITEMS,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCEquipItems)
  ))
_sym_db.RegisterMessage(CMsgClientToGCEquipItems)

CMsgClientToGCEquipItemsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCEquipItemsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCEQUIPITEMSRESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCEquipItemsResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCEquipItemsResponse)

CMsgClientToGCSetItemStyle = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSetItemStyle', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSETITEMSTYLE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCSetItemStyle)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSetItemStyle)

CMsgClientToGCSetItemStyleResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSetItemStyleResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSETITEMSTYLERESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCSetItemStyleResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSetItemStyleResponse)

CMsgClientToGCUnlockItemStyle = _reflection.GeneratedProtocolMessageType('CMsgClientToGCUnlockItemStyle', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCUNLOCKITEMSTYLE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCUnlockItemStyle)
  ))
_sym_db.RegisterMessage(CMsgClientToGCUnlockItemStyle)

CMsgClientToGCUnlockItemStyleResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCUnlockItemStyleResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCUNLOCKITEMSTYLERESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCUnlockItemStyleResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCUnlockItemStyleResponse)

CMsgClientToGCSetItemInventoryCategory = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSetItemInventoryCategory', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSETITEMINVENTORYCATEGORY,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCSetItemInventoryCategory)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSetItemInventoryCategory)

CMsgClientToGCUnlockCrate = _reflection.GeneratedProtocolMessageType('CMsgClientToGCUnlockCrate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCUNLOCKCRATE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCUnlockCrate)
  ))
_sym_db.RegisterMessage(CMsgClientToGCUnlockCrate)

CMsgClientToGCUnlockCrateResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCUnlockCrateResponse', (_message.Message,), dict(

  Item = _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCUNLOCKCRATERESPONSE_ITEM,
    __module__ = 'econ_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCUnlockCrateResponse.Item)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCUNLOCKCRATERESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCUnlockCrateResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCUnlockCrateResponse)
_sym_db.RegisterMessage(CMsgClientToGCUnlockCrateResponse.Item)

CMsgClientToGCRemoveItemAttribute = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRemoveItemAttribute', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREMOVEITEMATTRIBUTE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRemoveItemAttribute)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRemoveItemAttribute)

CMsgClientToGCRemoveItemAttributeResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCRemoveItemAttributeResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCREMOVEITEMATTRIBUTERESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCRemoveItemAttributeResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCRemoveItemAttributeResponse)

CMsgClientToGCNameItem = _reflection.GeneratedProtocolMessageType('CMsgClientToGCNameItem', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCNAMEITEM,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCNameItem)
  ))
_sym_db.RegisterMessage(CMsgClientToGCNameItem)

CMsgClientToGCNameItemResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCNameItemResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCNAMEITEMRESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCNameItemResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCNameItemResponse)

CMsgGCSetItemPosition = _reflection.GeneratedProtocolMessageType('CMsgGCSetItemPosition', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSETITEMPOSITION,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCSetItemPosition)
  ))
_sym_db.RegisterMessage(CMsgGCSetItemPosition)

CAttribute_ItemDynamicRecipeComponent = _reflection.GeneratedProtocolMessageType('CAttribute_ItemDynamicRecipeComponent', (_message.Message,), dict(
  DESCRIPTOR = _CATTRIBUTE_ITEMDYNAMICRECIPECOMPONENT,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CAttribute_ItemDynamicRecipeComponent)
  ))
_sym_db.RegisterMessage(CAttribute_ItemDynamicRecipeComponent)

CProtoItemSocket = _reflection.GeneratedProtocolMessageType('CProtoItemSocket', (_message.Message,), dict(
  DESCRIPTOR = _CPROTOITEMSOCKET,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CProtoItemSocket)
  ))
_sym_db.RegisterMessage(CProtoItemSocket)

CProtoItemSocket_Empty = _reflection.GeneratedProtocolMessageType('CProtoItemSocket_Empty', (_message.Message,), dict(
  DESCRIPTOR = _CPROTOITEMSOCKET_EMPTY,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CProtoItemSocket_Empty)
  ))
_sym_db.RegisterMessage(CProtoItemSocket_Empty)

CProtoItemSocket_Effect = _reflection.GeneratedProtocolMessageType('CProtoItemSocket_Effect', (_message.Message,), dict(
  DESCRIPTOR = _CPROTOITEMSOCKET_EFFECT,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CProtoItemSocket_Effect)
  ))
_sym_db.RegisterMessage(CProtoItemSocket_Effect)

CProtoItemSocket_Color = _reflection.GeneratedProtocolMessageType('CProtoItemSocket_Color', (_message.Message,), dict(
  DESCRIPTOR = _CPROTOITEMSOCKET_COLOR,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CProtoItemSocket_Color)
  ))
_sym_db.RegisterMessage(CProtoItemSocket_Color)

CProtoItemSocket_Strange = _reflection.GeneratedProtocolMessageType('CProtoItemSocket_Strange', (_message.Message,), dict(
  DESCRIPTOR = _CPROTOITEMSOCKET_STRANGE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CProtoItemSocket_Strange)
  ))
_sym_db.RegisterMessage(CProtoItemSocket_Strange)

CProtoItemSocket_Spectator = _reflection.GeneratedProtocolMessageType('CProtoItemSocket_Spectator', (_message.Message,), dict(
  DESCRIPTOR = _CPROTOITEMSOCKET_SPECTATOR,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CProtoItemSocket_Spectator)
  ))
_sym_db.RegisterMessage(CProtoItemSocket_Spectator)

CProtoItemSocket_AssetModifier = _reflection.GeneratedProtocolMessageType('CProtoItemSocket_AssetModifier', (_message.Message,), dict(
  DESCRIPTOR = _CPROTOITEMSOCKET_ASSETMODIFIER,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CProtoItemSocket_AssetModifier)
  ))
_sym_db.RegisterMessage(CProtoItemSocket_AssetModifier)

CProtoItemSocket_AssetModifier_DESERIALIZE_FROM_STRING_ONLY = _reflection.GeneratedProtocolMessageType('CProtoItemSocket_AssetModifier_DESERIALIZE_FROM_STRING_ONLY', (_message.Message,), dict(
  DESCRIPTOR = _CPROTOITEMSOCKET_ASSETMODIFIER_DESERIALIZE_FROM_STRING_ONLY,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CProtoItemSocket_AssetModifier_DESERIALIZE_FROM_STRING_ONLY)
  ))
_sym_db.RegisterMessage(CProtoItemSocket_AssetModifier_DESERIALIZE_FROM_STRING_ONLY)

CProtoItemSocket_Autograph = _reflection.GeneratedProtocolMessageType('CProtoItemSocket_Autograph', (_message.Message,), dict(
  DESCRIPTOR = _CPROTOITEMSOCKET_AUTOGRAPH,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CProtoItemSocket_Autograph)
  ))
_sym_db.RegisterMessage(CProtoItemSocket_Autograph)

CProtoItemSocket_StaticVisuals = _reflection.GeneratedProtocolMessageType('CProtoItemSocket_StaticVisuals', (_message.Message,), dict(
  DESCRIPTOR = _CPROTOITEMSOCKET_STATICVISUALS,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CProtoItemSocket_StaticVisuals)
  ))
_sym_db.RegisterMessage(CProtoItemSocket_StaticVisuals)

CAttribute_String = _reflection.GeneratedProtocolMessageType('CAttribute_String', (_message.Message,), dict(
  DESCRIPTOR = _CATTRIBUTE_STRING,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CAttribute_String)
  ))
_sym_db.RegisterMessage(CAttribute_String)

CWorkshop_GetItemDailyRevenue_Request = _reflection.GeneratedProtocolMessageType('CWorkshop_GetItemDailyRevenue_Request', (_message.Message,), dict(
  DESCRIPTOR = _CWORKSHOP_GETITEMDAILYREVENUE_REQUEST,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CWorkshop_GetItemDailyRevenue_Request)
  ))
_sym_db.RegisterMessage(CWorkshop_GetItemDailyRevenue_Request)

CWorkshop_GetItemDailyRevenue_Response = _reflection.GeneratedProtocolMessageType('CWorkshop_GetItemDailyRevenue_Response', (_message.Message,), dict(

  CountryDailyRevenue = _reflection.GeneratedProtocolMessageType('CountryDailyRevenue', (_message.Message,), dict(
    DESCRIPTOR = _CWORKSHOP_GETITEMDAILYREVENUE_RESPONSE_COUNTRYDAILYREVENUE,
    __module__ = 'econ_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CWorkshop_GetItemDailyRevenue_Response.CountryDailyRevenue)
    ))
  ,
  DESCRIPTOR = _CWORKSHOP_GETITEMDAILYREVENUE_RESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CWorkshop_GetItemDailyRevenue_Response)
  ))
_sym_db.RegisterMessage(CWorkshop_GetItemDailyRevenue_Response)
_sym_db.RegisterMessage(CWorkshop_GetItemDailyRevenue_Response.CountryDailyRevenue)

CMsgSQLGCToGCGrantBackpackSlots = _reflection.GeneratedProtocolMessageType('CMsgSQLGCToGCGrantBackpackSlots', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSQLGCTOGCGRANTBACKPACKSLOTS,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSQLGCToGCGrantBackpackSlots)
  ))
_sym_db.RegisterMessage(CMsgSQLGCToGCGrantBackpackSlots)

CMsgClientToGCLookupAccountName = _reflection.GeneratedProtocolMessageType('CMsgClientToGCLookupAccountName', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCLOOKUPACCOUNTNAME,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCLookupAccountName)
  ))
_sym_db.RegisterMessage(CMsgClientToGCLookupAccountName)

CMsgClientToGCLookupAccountNameResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCLookupAccountNameResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCLOOKUPACCOUNTNAMERESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCLookupAccountNameResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCLookupAccountNameResponse)

CMsgGCToGCDevRevokeUserItems = _reflection.GeneratedProtocolMessageType('CMsgGCToGCDevRevokeUserItems', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCDEVREVOKEUSERITEMS,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCDevRevokeUserItems)
  ))
_sym_db.RegisterMessage(CMsgGCToGCDevRevokeUserItems)

CMsgClientToGCCreateStaticRecipe = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCreateStaticRecipe', (_message.Message,), dict(

  Item = _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCCREATESTATICRECIPE_ITEM,
    __module__ = 'econ_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCCreateStaticRecipe.Item)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCCREATESTATICRECIPE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCCreateStaticRecipe)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCreateStaticRecipe)
_sym_db.RegisterMessage(CMsgClientToGCCreateStaticRecipe.Item)

CMsgClientToGCCreateStaticRecipeResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCCreateStaticRecipeResponse', (_message.Message,), dict(

  OutputItem = _reflection.GeneratedProtocolMessageType('OutputItem', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_OUTPUTITEM,
    __module__ = 'econ_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCCreateStaticRecipeResponse.OutputItem)
    ))
  ,

  InputError = _reflection.GeneratedProtocolMessageType('InputError', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_INPUTERROR,
    __module__ = 'econ_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCCreateStaticRecipeResponse.InputError)
    ))
  ,

  AdditionalOutput = _reflection.GeneratedProtocolMessageType('AdditionalOutput', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE_ADDITIONALOUTPUT,
    __module__ = 'econ_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientToGCCreateStaticRecipeResponse.AdditionalOutput)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTTOGCCREATESTATICRECIPERESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCCreateStaticRecipeResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCCreateStaticRecipeResponse)
_sym_db.RegisterMessage(CMsgClientToGCCreateStaticRecipeResponse.OutputItem)
_sym_db.RegisterMessage(CMsgClientToGCCreateStaticRecipeResponse.InputError)
_sym_db.RegisterMessage(CMsgClientToGCCreateStaticRecipeResponse.AdditionalOutput)

CMsgProcessTransactionOrder = _reflection.GeneratedProtocolMessageType('CMsgProcessTransactionOrder', (_message.Message,), dict(

  Item = _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), dict(
    DESCRIPTOR = _CMSGPROCESSTRANSACTIONORDER_ITEM,
    __module__ = 'econ_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgProcessTransactionOrder.Item)
    ))
  ,
  DESCRIPTOR = _CMSGPROCESSTRANSACTIONORDER,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgProcessTransactionOrder)
  ))
_sym_db.RegisterMessage(CMsgProcessTransactionOrder)
_sym_db.RegisterMessage(CMsgProcessTransactionOrder.Item)

CMsgGCToGCStoreProcessCDKeyTransaction = _reflection.GeneratedProtocolMessageType('CMsgGCToGCStoreProcessCDKeyTransaction', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCSTOREPROCESSCDKEYTRANSACTION,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCStoreProcessCDKeyTransaction)
  ))
_sym_db.RegisterMessage(CMsgGCToGCStoreProcessCDKeyTransaction)

CMsgGCToGCStoreProcessCDKeyTransactionResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToGCStoreProcessCDKeyTransactionResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCSTOREPROCESSCDKEYTRANSACTIONRESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCStoreProcessCDKeyTransactionResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToGCStoreProcessCDKeyTransactionResponse)

CMsgGCToGCStoreProcessSettlement = _reflection.GeneratedProtocolMessageType('CMsgGCToGCStoreProcessSettlement', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCSTOREPROCESSSETTLEMENT,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCStoreProcessSettlement)
  ))
_sym_db.RegisterMessage(CMsgGCToGCStoreProcessSettlement)

CMsgGCToGCStoreProcessSettlementResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToGCStoreProcessSettlementResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCSTOREPROCESSSETTLEMENTRESPONSE,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCStoreProcessSettlementResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToGCStoreProcessSettlementResponse)

CMsgGCToGCBroadcastConsoleCommand = _reflection.GeneratedProtocolMessageType('CMsgGCToGCBroadcastConsoleCommand', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCBROADCASTCONSOLECOMMAND,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCBroadcastConsoleCommand)
  ))
_sym_db.RegisterMessage(CMsgGCToGCBroadcastConsoleCommand)

CMsgGCToGCConsoleOutput = _reflection.GeneratedProtocolMessageType('CMsgGCToGCConsoleOutput', (_message.Message,), dict(

  OutputLine = _reflection.GeneratedProtocolMessageType('OutputLine', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOGCCONSOLEOUTPUT_OUTPUTLINE,
    __module__ = 'econ_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCToGCConsoleOutput.OutputLine)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOGCCONSOLEOUTPUT,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCConsoleOutput)
  ))
_sym_db.RegisterMessage(CMsgGCToGCConsoleOutput)
_sym_db.RegisterMessage(CMsgGCToGCConsoleOutput.OutputLine)

CMsgItemAges = _reflection.GeneratedProtocolMessageType('CMsgItemAges', (_message.Message,), dict(

  MaxItemIDTimestamp = _reflection.GeneratedProtocolMessageType('MaxItemIDTimestamp', (_message.Message,), dict(
    DESCRIPTOR = _CMSGITEMAGES_MAXITEMIDTIMESTAMP,
    __module__ = 'econ_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgItemAges.MaxItemIDTimestamp)
    ))
  ,
  DESCRIPTOR = _CMSGITEMAGES,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgItemAges)
  ))
_sym_db.RegisterMessage(CMsgItemAges)
_sym_db.RegisterMessage(CMsgItemAges.MaxItemIDTimestamp)

CMsgGCToGCInternalTestMsg = _reflection.GeneratedProtocolMessageType('CMsgGCToGCInternalTestMsg', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCINTERNALTESTMSG,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCInternalTestMsg)
  ))
_sym_db.RegisterMessage(CMsgGCToGCInternalTestMsg)

CMsgGCToGCClientServerVersionsUpdated = _reflection.GeneratedProtocolMessageType('CMsgGCToGCClientServerVersionsUpdated', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCCLIENTSERVERVERSIONSUPDATED,
  __module__ = 'econ_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCClientServerVersionsUpdated)
  ))
_sym_db.RegisterMessage(CMsgGCToGCClientServerVersionsUpdated)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
_CMSGLOOKUPMULTIPLEACCOUNTNAMES.fields_by_name['accountids'].has_options = True
_CMSGLOOKUPMULTIPLEACCOUNTNAMES.fields_by_name['accountids']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)
