# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_gcmessages_client_fantasy.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import dota2.protobufs.dota_shared_enums_pb2 as dota__shared__enums__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_gcmessages_client_fantasy.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n$dota_gcmessages_client_fantasy.proto\x1a\x17\x64ota_shared_enums.proto\"\xad\x03\n\x10\x43MsgGCPlayerInfo\x12\x32\n\x0cplayer_infos\x18\x01 \x03(\x0b\x32\x1c.CMsgGCPlayerInfo.PlayerInfo\x12\x39\n\x0cleaderboards\x18\x02 \x03(\x0b\x32#.CMsgGCPlayerInfo.RegionLeaderboard\x1a\xed\x01\n\nPlayerInfo\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x03 \x01(\t\x12\x14\n\x0c\x66\x61ntasy_role\x18\x04 \x01(\r\x12\x0f\n\x07team_id\x18\x05 \x01(\r\x12\x11\n\tteam_name\x18\x06 \x01(\t\x12\x10\n\x08team_tag\x18\x07 \x01(\t\x12\x0f\n\x07sponsor\x18\x08 \x01(\t\x12\x11\n\tis_locked\x18\t \x01(\x08\x12\x0e\n\x06is_pro\x18\n \x01(\x08\x12\x14\n\x0clocked_until\x18\x0b \x01(\r\x12\x11\n\ttimestamp\x18\x0c \x01(\r\x1a:\n\x11RegionLeaderboard\x12\x10\n\x08\x64ivision\x18\x01 \x01(\r\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x02 \x03(\r\"\xae\x01\n\"CMsgDOTACreateFantasyLeagueRequest\x12\x13\n\x0bleague_name\x18\x01 \x01(\t\x12\x13\n\x0bleague_logo\x18\x02 \x01(\x04\x12J\n\x0eselection_mode\x18\x03 \x01(\x0e\x32\x17.Fantasy_Selection_Mode:\x19\x46\x41NTASY_SELECTION_INVALID\x12\x12\n\nteam_count\x18\x04 \x01(\r\"\xf3\x01\n#CMsgDOTACreateFantasyLeagueResponse\x12\x45\n\x06result\x18\x01 \x01(\x0e\x32,.CMsgDOTACreateFantasyLeagueResponse.EResult:\x07SUCCESS\"\x84\x01\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x1a\n\x16\x45RROR_TOO_MANY_LEAGUES\x10\x02\x12\x1c\n\x18\x45RROR_INVALID_TEAM_COUNT\x10\x03\x12\x1b\n\x17\x45RROR_CREATION_DISABLED\x10\x04\"\x9f\x02\n\x18\x43MsgFantasyLeagueScoring\x12\r\n\x05level\x18\x01 \x01(\x02\x12\r\n\x05kills\x18\x02 \x01(\x02\x12\x0e\n\x06\x64\x65\x61ths\x18\x03 \x01(\x02\x12\x0f\n\x07\x61ssists\x18\x04 \x01(\x02\x12\x11\n\tlast_hits\x18\x05 \x01(\x02\x12\x0e\n\x06\x64\x65nies\x18\x06 \x01(\x02\x12\x0b\n\x03gpm\x18\x07 \x01(\x02\x12\x0c\n\x04xppm\x18\x08 \x01(\x02\x12\r\n\x05stuns\x18\t \x01(\x02\x12\x0f\n\x07healing\x18\n \x01(\x02\x12\x13\n\x0btower_kills\x18\x0b \x01(\x02\x12\x14\n\x0croshan_kills\x18\x0c \x01(\x02\x12\x1a\n\x12multiplier_premium\x18\r \x01(\x02\x12\x1f\n\x17multiplier_professional\x18\x0e \x01(\x02\"\xce\x05\n\x19\x43MsgDOTAFantasyLeagueInfo\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x1f\n\x17\x63ommissioner_account_id\x18\x02 \x01(\r\x12\x1b\n\x13\x66\x61ntasy_league_name\x18\x03 \x01(\t\x12J\n\x0eselection_mode\x18\x04 \x01(\x0e\x32\x17.Fantasy_Selection_Mode:\x19\x46\x41NTASY_SELECTION_INVALID\x12\x12\n\nteam_count\x18\x05 \x01(\r\x12\x0c\n\x04logo\x18\x06 \x01(\x04\x12*\n\x07scoring\x18\x07 \x01(\x0b\x32\x19.CMsgFantasyLeagueScoring\x12\x12\n\ndraft_time\x18\x0c \x01(\r\x12\x17\n\x0f\x64raft_pick_time\x18\r \x01(\r\x12\x14\n\x0cseason_start\x18\x0f \x01(\r\x12\x15\n\rseason_length\x18\x10 \x01(\r\x12\x12\n\nveto_votes\x18\x11 \x01(\r\x12\x14\n\x0c\x61\x63quisitions\x18\x12 \x01(\r\x12\x0e\n\x06slot_1\x18\x13 \x01(\r\x12\x0e\n\x06slot_2\x18\x14 \x01(\r\x12\x0e\n\x06slot_3\x18\x15 \x01(\r\x12\x0e\n\x06slot_4\x18\x16 \x01(\r\x12\x0e\n\x06slot_5\x18\x17 \x01(\r\x12\x13\n\x0b\x62\x65nch_slots\x18\x18 \x01(\r\x12\x38\n\nowner_info\x18\x19 \x03(\x0b\x32$.CMsgDOTAFantasyLeagueInfo.OwnerInfo\x12\x0f\n\x07players\x18\x1a \x03(\r\x12\x11\n\ttime_zone\x18\x1b \x01(\r\x12\x0e\n\x06season\x18\x1c \x01(\r\x12\x10\n\x08password\x18\x1d \x01(\t\x1aU\n\tOwnerInfo\x12\x18\n\x10owner_account_id\x18\x01 \x01(\r\x12\x13\n\x0bleft_league\x18\x02 \x01(\x08\x12\x19\n\x11player_account_id\x18\x03 \x03(\r\"p\n$CMsgDOTAFantasyLeagueEditInfoRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12-\n\tedit_info\x18\x02 \x01(\x0b\x32\x1a.CMsgDOTAFantasyLeagueInfo\"\xb8\x01\n%CMsgDOTAFantasyLeagueEditInfoResponse\x12G\n\x06result\x18\x01 \x01(\x0e\x32..CMsgDOTAFantasyLeagueEditInfoResponse.EResult:\x07SUCCESS\"F\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x02\"O\n CMsgDOTAFantasyLeagueFindRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x10\n\x08password\x18\x02 \x01(\t\"\xc7\x02\n!CMsgDOTAFantasyLeagueFindResponse\x12\x43\n\x06result\x18\x01 \x01(\x0e\x32*.CMsgDOTAFantasyLeagueFindResponse.EResult:\x07SUCCESS\x12\x1b\n\x13\x66\x61ntasy_league_name\x18\x02 \x01(\t\x12\x19\n\x11\x63ommissioner_name\x18\x03 \x01(\t\"\xa4\x01\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x1a\n\x16\x45RROR_LEAGUE_NOT_FOUND\x10\x01\x12\x16\n\x12\x45RROR_BAD_PASSWORD\x10\x02\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x03\x12\x0e\n\nERROR_FULL\x10\x04\x12\x18\n\x14\x45RROR_ALREADY_MEMBER\x10\x05\x12\x17\n\x13\x45RROR_LEAGUE_LOCKED\x10\x06\"=\n CMsgDOTAFantasyLeagueInfoRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\"\xb0\x01\n!CMsgDOTAFantasyLeagueInfoResponse\x12\x43\n\x06result\x18\x01 \x01(\x0e\x32*.CMsgDOTAFantasyLeagueInfoResponse.EResult:\x07SUCCESS\"F\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_BAD_LEAGUE_ID\x10\x02\"A\n$CMsgDOTAFantasyLeagueMatchupsRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\"\x9a\x04\n%CMsgDOTAFantasyLeagueMatchupsResponse\x12G\n\x06result\x18\x01 \x01(\x0e\x32..CMsgDOTAFantasyLeagueMatchupsResponse.EResult:\x07SUCCESS\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x02 \x01(\r\x12N\n\x0fweekly_matchups\x18\x03 \x03(\x0b\x32\x35.CMsgDOTAFantasyLeagueMatchupsResponse.WeeklyMatchups\x1a\x63\n\x07Matchup\x12\x1a\n\x12owner_account_id_1\x18\x01 \x01(\r\x12\x1a\n\x12owner_account_id_2\x18\x02 \x01(\r\x12\x0f\n\x07score_1\x18\x03 \x01(\x02\x12\x0f\n\x07score_2\x18\x04 \x01(\x02\x1aw\n\x0eWeeklyMatchups\x12?\n\x07matchup\x18\x01 \x03(\x0b\x32..CMsgDOTAFantasyLeagueMatchupsResponse.Matchup\x12\x12\n\nstart_time\x18\x02 \x01(\r\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\r\"_\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_BAD_LEAGUE_ID\x10\x02\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x03\"u\n\x1e\x43MsgDOTAEditFantasyTeamRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x12\n\nteam_index\x18\x02 \x01(\r\x12\x11\n\tteam_name\x18\x03 \x01(\t\x12\x11\n\tteam_logo\x18\x04 \x01(\x04\"\xe8\x01\n\x1f\x43MsgDOTAEditFantasyTeamResponse\x12\x41\n\x06result\x18\x01 \x01(\x0e\x32(.CMsgDOTAEditFantasyTeamResponse.EResult:\x07SUCCESS\"\x81\x01\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x1b\n\x17\x45RROR_INVALID_TEAM_INFO\x10\x02\x12\x1c\n\x18\x45RROR_NAME_ALREADY_TAKEN\x10\x03\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x04\"L\n/CMsgDOTAFantasyTeamInfoRequestByFantasyLeagueID\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\"J\n.CMsgDOTAFantasyTeamInfoRequestByOwnerAccountID\x12\x18\n\x10owner_account_id\x18\x01 \x01(\r\"L\n\x1f\x43MsgDOTAFantasyTeamInfoResponse\x12)\n\x07results\x18\x01 \x03(\x0b\x32\x18.CMsgDOTAFantasyTeamInfo\"\xc6\x01\n\x17\x43MsgDOTAFantasyTeamInfo\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x18\n\x10owner_account_id\x18\x02 \x01(\r\x12\x1a\n\x12\x66\x61ntasy_team_index\x18\x03 \x01(\r\x12\x11\n\tteam_name\x18\x04 \x01(\t\x12\x11\n\tteam_logo\x18\x05 \x01(\x04\x12\x0c\n\x04wins\x18\x06 \x01(\r\x12\x0e\n\x06losses\x18\x07 \x01(\r\x12\x16\n\x0e\x63urrent_roster\x18\x08 \x03(\r\"\xd6\x01\n\x1f\x43MsgDOTAFantasyTeamScoreRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x18\n\x10owner_account_id\x18\x02 \x01(\r\x12\x1a\n\x12\x66\x61ntasy_team_index\x18\x03 \x01(\r\x12\x17\n\x0f\x66ilter_match_id\x18\x04 \x01(\x04\x12\x19\n\x11\x66ilter_start_time\x18\x05 \x01(\r\x12\x17\n\x0f\x66ilter_end_time\x18\x06 \x01(\r\x12\x15\n\rinclude_bench\x18\x07 \x01(\x08\"\xf0\x02\n CMsgDOTAFantasyTeamScoreResponse\x12\x42\n\x06result\x18\x01 \x01(\x0e\x32).CMsgDOTAFantasyTeamScoreResponse.EResult:\x07SUCCESS\x12\x1a\n\x12\x66\x61ntasy_team_score\x18\x02 \x01(\x02\x12O\n\x14\x66\x61ntasy_player_score\x18\x03 \x03(\x0b\x32\x31.CMsgDOTAFantasyTeamScoreResponse.CMsgPlayerScore\x1a\x34\n\x0f\x43MsgPlayerScore\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\r\n\x05score\x18\x02 \x01(\x02\"e\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x02\x12\x1d\n\x19\x45RROR_OWNER_NOT_IN_LEAGUE\x10\x03\"\xcf\x01\n#CMsgDOTAFantasyTeamStandingsRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x12\x19\n\x11\x66ilter_start_time\x18\x03 \x01(\r\x12\x17\n\x0f\x66ilter_end_time\x18\x04 \x01(\r\x12\x17\n\x0f\x66ilter_match_id\x18\x05 \x01(\x04\x12\x19\n\x11\x66ilter_last_match\x18\x06 \x01(\x08\x12\x16\n\x0e\x66ilter_in_hall\x18\x07 \x01(\x08\"\x81\x04\n$CMsgDOTAFantasyTeamStandingsResponse\x12\x46\n\x06result\x18\x01 \x01(\x0e\x32-.CMsgDOTAFantasyTeamStandingsResponse.EResult:\x07SUCCESS\x12H\n\x0bteam_scores\x18\x03 \x03(\x0b\x32\x33.CMsgDOTAFantasyTeamStandingsResponse.CMsgTeamScore\x1a\xfe\x01\n\rCMsgTeamScore\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x18\n\x10owner_account_id\x18\x02 \x01(\r\x12\x1a\n\x12\x66\x61ntasy_team_index\x18\x03 \x01(\r\x12\x19\n\x11\x66\x61ntasy_team_logo\x18\x04 \x01(\x04\x12\x12\n\nowner_name\x18\x05 \x01(\t\x12\x19\n\x11\x66\x61ntasy_team_name\x18\x06 \x01(\t\x12\r\n\x05score\x18\x07 \x01(\x02\x12\x15\n\rscore_against\x18\x08 \x01(\x02\x12\x0c\n\x04wins\x18\t \x01(\r\x12\x0e\n\x06losses\x18\n \x01(\r\x12\x0e\n\x06streak\x18\x0b \x01(\x05\"F\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x02\"\xc1\x01\n!CMsgDOTAFantasyPlayerScoreRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x19\n\x11player_account_id\x18\x02 \x01(\r\x12\x19\n\x11\x66ilter_start_time\x18\x03 \x01(\r\x12\x17\n\x0f\x66ilter_end_time\x18\x04 \x01(\r\x12\x17\n\x0f\x66ilter_match_id\x18\x05 \x01(\x04\x12\x19\n\x11\x66ilter_last_match\x18\x06 \x01(\x08\"\x8c\x02\n\"CMsgDOTAFantasyPlayerScoreResponse\x12\x44\n\x06result\x18\x01 \x01(\x0e\x32+.CMsgDOTAFantasyPlayerScoreResponse.EResult:\x07SUCCESS\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x02 \x01(\r\x12\x19\n\x11player_account_id\x18\x03 \x01(\r\x12\x13\n\x0bplayer_name\x18\x04 \x01(\t\x12\r\n\x05score\x18\x05 \x01(\x02\"F\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x02\"\xc7\x01\n%CMsgDOTAFantasyPlayerStandingsRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x12\x0c\n\x04role\x18\x03 \x01(\r\x12\x19\n\x11\x66ilter_start_time\x18\x04 \x01(\r\x12\x17\n\x0f\x66ilter_end_time\x18\x05 \x01(\r\x12\x17\n\x0f\x66ilter_match_id\x18\x06 \x01(\x04\x12\x19\n\x11\x66ilter_last_match\x18\x07 \x01(\x08\"\x85\x03\n&CMsgDOTAFantasyPlayerStandingsResponse\x12H\n\x06result\x18\x01 \x01(\x0e\x32/.CMsgDOTAFantasyPlayerStandingsResponse.EResult:\x07SUCCESS\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x02 \x01(\r\x12\x0c\n\x04role\x18\x03 \x01(\r\x12N\n\rplayer_scores\x18\x04 \x03(\x0b\x32\x37.CMsgDOTAFantasyPlayerStandingsResponse.CMsgPlayerScore\x1aP\n\x0f\x43MsgPlayerScore\x12\x19\n\x11player_account_id\x18\x01 \x01(\r\x12\x13\n\x0bplayer_name\x18\x02 \x01(\t\x12\r\n\x05score\x18\x03 \x01(\x02\"F\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x02\"\"\n CMsgDOTAFantasyPlayerInfoRequest\"C\n!CMsgDOTAFantasyPlayerInfoResponse\x12\x1e\n\x03msg\x18\x01 \x01(\x0b\x32\x11.CMsgGCPlayerInfo\"\x9f\x01\n\"CMsgDOTAFantasyLeagueCreateRequest\x12\x11\n\tseason_id\x18\x01 \x01(\r\x12\x1b\n\x13\x66\x61ntasy_league_name\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x11\n\tteam_name\x18\x04 \x01(\t\x12\x0c\n\x04logo\x18\x05 \x01(\x04\x12\x16\n\x0eticket_item_id\x18\x06 \x01(\x04\"\xd0\x02\n#CMsgDOTAFantasyLeagueCreateResponse\x12\x45\n\x06result\x18\x01 \x01(\x0e\x32,.CMsgDOTAFantasyLeagueCreateResponse.EResult:\x07SUCCESS\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x02 \x01(\r\"\xc6\x01\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x01\x12\x17\n\x13\x45RROR_BAD_SEASON_ID\x10\x02\x12\x19\n\x15\x45RROR_BAD_LEAGUE_NAME\x10\x03\x12\x17\n\x13\x45RROR_BAD_TEAM_NAME\x10\x04\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x05\x12\x1c\n\x18\x45RROR_FAILED_LOGO_UPLOAD\x10\x06\x12\x13\n\x0f\x45RROR_NO_TICKET\x10\x07\"\x88\x01\n CMsgDOTAFantasyTeamCreateRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x11\n\tteam_name\x18\x03 \x01(\t\x12\x0c\n\x04logo\x18\x04 \x01(\x04\x12\x16\n\x0eticket_item_id\x18\x05 \x01(\x04\"\x90\x03\n!CMsgDOTAFantasyTeamCreateResponse\x12\x43\n\x06result\x18\x01 \x01(\x0e\x32*.CMsgDOTAFantasyTeamCreateResponse.EResult:\x07SUCCESS\x12\x1a\n\x12\x66\x61ntasy_team_index\x18\x02 \x01(\r\"\x89\x02\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x01\x12\x1c\n\x18\x45RROR_FAILED_LOGO_UPLOAD\x10\x02\x12\x1f\n\x1b\x45RROR_BAD_FANTASY_LEAGUE_ID\x10\x03\x12\x12\n\x0e\x45RROR_BAD_NAME\x10\x04\x12\x0e\n\nERROR_FULL\x10\x05\x12\x18\n\x14\x45RROR_ALREADY_MEMBER\x10\x06\x12\x16\n\x12\x45RROR_BAD_PASSWORD\x10\x07\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x08\x12\x13\n\x0f\x45RROR_NO_TICKET\x10\t\x12\x17\n\x13\x45RROR_LEAGUE_LOCKED\x10\n\"\xd9\x01\n\'CMsgDOTAFantasyLeagueEditInvitesRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x10\n\x08password\x18\x02 \x01(\t\x12L\n\rinvite_change\x18\x03 \x03(\x0b\x32\x35.CMsgDOTAFantasyLeagueEditInvitesRequest.InviteChange\x1a\x33\n\x0cInviteChange\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x0f\n\x07invited\x18\x02 \x01(\x08\"\xa5\x01\n(CMsgDOTAFantasyLeagueEditInvitesResponse\x12J\n\x06result\x18\x01 \x01(\x0e\x32\x31.CMsgDOTAFantasyLeagueEditInvitesResponse.EResult:\x07SUCCESS\"-\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\"D\n\'CMsgDOTAFantasyLeagueDraftStatusRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\"\xc6\x01\n CMsgDOTAFantasyLeagueDraftStatus\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x13\n\x0b\x64raft_order\x18\x02 \x03(\r\x12\x14\n\x0c\x63urrent_pick\x18\x03 \x01(\r\x12\x16\n\x0etime_remaining\x18\x04 \x01(\r\x12\x16\n\x0epending_resume\x18\x05 \x01(\x08\x12\x11\n\tcompleted\x18\x06 \x01(\x08\x12\x19\n\x11\x61vailable_players\x18\x07 \x03(\r\"s\n\'CMsgDOTAFantasyLeagueDraftPlayerRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x12\n\nteam_index\x18\x02 \x01(\r\x12\x19\n\x11player_account_id\x18\x03 \x01(\r\"\x82\x03\n(CMsgDOTAFantasyLeagueDraftPlayerResponse\x12J\n\x06result\x18\x01 \x01(\x0e\x32\x31.CMsgDOTAFantasyLeagueDraftPlayerResponse.EResult:\x07SUCCESS\"\x89\x02\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12 \n\x1c\x45RROR_INVALID_FANTASY_LEAGUE\x10\x02\x12%\n!ERROR_FANTASY_LEAGUE_NOT_DRAFTING\x10\x03\x12\x1d\n\x19\x45RROR_OWNER_NOT_IN_LEAGUE\x10\x04\x12\x19\n\x15\x45RROR_NOT_OWNERS_TURN\x10\x05\x12\x18\n\x14\x45RROR_PLAYER_INVALID\x10\x06\x12\x1c\n\x18\x45RROR_PLAYER_UNAVAILABLE\x10\x07\x12\x1f\n\x1b\x45RROR_PLAYER_NO_VALID_SLOTS\x10\x08\"\x88\x01\n$CMsgDOTAFantasyTeamRosterSwapRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x12\n\nteam_index\x18\x02 \x01(\r\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x0e\n\x06slot_1\x18\x04 \x01(\r\x12\x0e\n\x06slot_2\x18\x05 \x01(\r\"\xee\x01\n%CMsgDOTAFantasyTeamRosterSwapResponse\x12G\n\x06result\x18\x01 \x01(\x0e\x32..CMsgDOTAFantasyTeamRosterSwapResponse.EResult:\x07SUCCESS\"|\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x1d\n\x19\x45RROR_OWNER_NOT_IN_LEAGUE\x10\x02\x12\x17\n\x13\x45RROR_SLOTS_INVALID\x10\x03\x12\x15\n\x11\x45RROR_SLOT_LOCKED\x10\x04\"\x89\x01\n\'CMsgDOTAFantasyTeamRosterAddDropRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x12\n\nteam_index\x18\x02 \x01(\r\x12\x16\n\x0e\x61\x64\x64_account_id\x18\x05 \x01(\r\x12\x17\n\x0f\x64rop_account_id\x18\x06 \x01(\r\"\xa4\x02\n(CMsgDOTAFantasyTeamRosterAddDropResponse\x12J\n\x06result\x18\x01 \x01(\x0e\x32\x31.CMsgDOTAFantasyTeamRosterAddDropResponse.EResult:\x07SUCCESS\"\xab\x01\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x1d\n\x19\x45RROR_OWNER_NOT_IN_LEAGUE\x10\x02\x12\x1e\n\x1a\x45RROR_PLAYER_NOT_AVAILABLE\x10\x03\x12\x1c\n\x18\x45RROR_PLAYER_NOT_ON_TEAM\x10\x04\x12\x1f\n\x1b\x45RROR_TRADE_ALREADY_PENDING\x10\x05\"=\n CMsgDOTAFantasyTeamTradesRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\"\x89\x03\n!CMsgDOTAFantasyTeamTradesResponse\x12\x43\n\x06result\x18\x01 \x01(\x0e\x32*.CMsgDOTAFantasyTeamTradesResponse.EResult:\x07SUCCESS\x12\x38\n\x06trades\x18\x02 \x03(\x0b\x32(.CMsgDOTAFantasyTeamTradesResponse.Trade\x1a\x9c\x01\n\x05Trade\x12\x11\n\ttimestamp\x18\x01 \x01(\r\x12\x1a\n\x12owner_account_id_1\x18\x02 \x01(\r\x12\x1a\n\x12owner_account_id_2\x18\x03 \x01(\r\x12\x1b\n\x13player_account_id_1\x18\x04 \x01(\r\x12\x1b\n\x13player_account_id_2\x18\x05 \x01(\r\x12\x0e\n\x06status\x18\x06 \x01(\r\"F\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x02\"\x8a\x01\n%CMsgDOTAFantasyTeamTradeCancelRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x14\n\x0cteam_index_1\x18\x03 \x01(\r\x12\x1a\n\x12owner_account_id_2\x18\x04 \x01(\r\x12\x14\n\x0cteam_index_2\x18\x05 \x01(\r\"\xce\x01\n&CMsgDOTAFantasyTeamTradeCancelResponse\x12H\n\x06result\x18\x01 \x01(\x0e\x32/.CMsgDOTAFantasyTeamTradeCancelResponse.EResult:\x07SUCCESS\"Z\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x02\x12\x12\n\x0e\x45RROR_NO_TRADE\x10\x03\"~\n CMsgDOTAFantasyTeamRosterRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x12\n\nteam_index\x18\x02 \x01(\r\x12\x18\n\x10owner_account_id\x18\x03 \x01(\r\x12\x11\n\ttimestamp\x18\x04 \x01(\r\"\x82\x02\n!CMsgDOTAFantasyTeamRosterResponse\x12\x43\n\x06result\x18\x01 \x01(\x0e\x32*.CMsgDOTAFantasyTeamRosterResponse.EResult:\x07SUCCESS\x12\x1a\n\x12player_account_ids\x18\x02 \x03(\r\x12\x15\n\rplayer_locked\x18\x03 \x03(\x08\"e\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x02\x12\x1d\n\x19\x45RROR_OWNER_NOT_IN_LEAGUE\x10\x03\"G\n*CMsgDOTAFantasyPlayerHisoricalStatsRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\"\x81\x06\n+CMsgDOTAFantasyPlayerHisoricalStatsResponse\x12M\n\x06result\x18\x01 \x01(\x0e\x32\x34.CMsgDOTAFantasyPlayerHisoricalStatsResponse.EResult:\x07SUCCESS\x12G\n\x05stats\x18\x02 \x03(\x0b\x32\x38.CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerStats\x1a\x81\x02\n\x16PlayerScoreAccumulator\x12\x0f\n\x07matches\x18\x01 \x01(\r\x12\x0e\n\x06levels\x18\x02 \x01(\x02\x12\r\n\x05kills\x18\x03 \x01(\x02\x12\x0e\n\x06\x64\x65\x61ths\x18\x04 \x01(\x02\x12\x0f\n\x07\x61ssists\x18\x05 \x01(\x02\x12\x11\n\tlast_hits\x18\x06 \x01(\x02\x12\x0e\n\x06\x64\x65nies\x18\x07 \x01(\x02\x12\x0b\n\x03gpm\x18\x08 \x01(\x02\x12\x0c\n\x04xppm\x18\t \x01(\x02\x12\r\n\x05stuns\x18\n \x01(\x02\x12\x0f\n\x07healing\x18\x0b \x01(\x02\x12\x13\n\x0btower_kills\x18\x0c \x01(\x02\x12\x14\n\x0croshan_kills\x18\r \x01(\x02\x12\r\n\x05score\x18\x0e \x01(\x02\x1a\xed\x01\n\x0bPlayerStats\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\r\n\x05weeks\x18\x02 \x01(\r\x12Z\n\rstats_premium\x18\x04 \x01(\x0b\x32\x43.CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator\x12_\n\x12stats_professional\x18\x05 \x01(\x0b\x32\x43.CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator\"F\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x02\"G\n\x19\x43MsgDOTAFantasyMessageAdd\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\"g\n\x1e\x43MsgDOTAFantasyMessagesRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x15\n\rstart_message\x18\x02 \x01(\r\x12\x13\n\x0b\x65nd_message\x18\x03 \x01(\r\"\xdd\x02\n\x1f\x43MsgDOTAFantasyMessagesResponse\x12\x41\n\x06result\x18\x01 \x01(\x0e\x32(.CMsgDOTAFantasyMessagesResponse.EResult:\x07SUCCESS\x12:\n\x08messages\x18\x02 \x03(\x0b\x32(.CMsgDOTAFantasyMessagesResponse.Message\x12\x1a\n\x12num_total_messages\x18\x03 \x01(\r\x1aW\n\x07Message\x12\x12\n\nmessage_id\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x19\n\x11\x61uthor_account_id\x18\x03 \x01(\r\x12\x0c\n\x04time\x18\x04 \x01(\r\"F\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x02\"e\n\x1a\x43MsgDOTAFantasyRemoveOwner\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x18\n\x10owner_account_id\x18\x02 \x01(\r\x12\x12\n\nteam_index\x18\x03 \x01(\r\"\xe3\x01\n\"CMsgDOTAFantasyRemoveOwnerResponse\x12\x44\n\x06result\x18\x01 \x01(\x0e\x32+.CMsgDOTAFantasyRemoveOwnerResponse.EResult:\x07SUCCESS\"w\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x02\x12\x17\n\x13\x45RROR_LEAGUE_LOCKED\x10\x03\x12\x16\n\x12\x45RROR_NOT_A_MEMBER\x10\x04\"C\n&CMsgDOTAFantasyScheduledMatchesRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\"\xcd\x02\n\'CMsgDOTAFantasyScheduledMatchesResponse\x12I\n\x06result\x18\x01 \x01(\x0e\x32\x30.CMsgDOTAFantasyScheduledMatchesResponse.EResult:\x07SUCCESS\x12Y\n\x14scheduled_match_days\x18\x02 \x03(\x0b\x32;.CMsgDOTAFantasyScheduledMatchesResponse.ScheduledMatchDays\x1aM\n\x12ScheduledMatchDays\x12\x11\n\ttimestamp\x18\x01 \x01(\r\x12\x10\n\x08team_ids\x18\x02 \x03(\r\x12\x12\n\nleague_ids\x18\x03 \x03(\r\"-\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\"Z\n!CMsgDOTAFantasyLeaveLeagueRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x1a\n\x12\x66\x61ntasy_team_index\x18\x02 \x01(\r\"\xe3\x01\n\"CMsgDOTAFantasyLeaveLeagueResponse\x12\x44\n\x06result\x18\x01 \x01(\x0e\x32+.CMsgDOTAFantasyLeaveLeagueResponse.EResult:\x07SUCCESS\"w\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x14\n\x10\x45RROR_NOT_MEMBER\x10\x02\x12\x1a\n\x16\x45RROR_LEAGUE_NOT_FOUND\x10\x03\x12\x16\n\x12\x45RROR_DRAFT_ACTIVE\x10\x04\"\x86\x01\n(CMsgDOTAFantasyPlayerScoreDetailsRequest\x12\x19\n\x11\x66\x61ntasy_league_id\x18\x01 \x01(\r\x12\x19\n\x11player_account_id\x18\x02 \x01(\r\x12\x12\n\nstart_time\x18\x03 \x01(\r\x12\x10\n\x08\x65nd_time\x18\x04 \x01(\r\"\x86\x04\n)CMsgDOTAFantasyPlayerScoreDetailsResponse\x12K\n\x06result\x18\x01 \x01(\x0e\x32\x32.CMsgDOTAFantasyPlayerScoreDetailsResponse.EResult:\x07SUCCESS\x12H\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32:.CMsgDOTAFantasyPlayerScoreDetailsResponse.PlayerMatchData\x1a\xfc\x01\n\x0fPlayerMatchData\x12\x10\n\x08match_id\x18\x01 \x01(\x04\x12\x11\n\tseries_id\x18\x02 \x01(\r\x12\x12\n\nseries_num\x18\x03 \x01(\r\x12\x13\n\x0bseries_type\x18\x04 \x01(\r\x12\x13\n\x0bleague_tier\x18\x05 \x01(\r\x12\x11\n\tleague_id\x18\x06 \x01(\r\x12\x18\n\x10opposing_team_id\x18\x07 \x01(\r\x12\x1a\n\x12opposing_team_logo\x18\x08 \x01(\x04\x12\x1a\n\x12opposing_team_name\x18\t \x01(\t\x12\x10\n\x08owned_by\x18\x0b \x01(\r\x12\x0f\n\x07\x62\x65nched\x18\x0c \x01(\x08\"C\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x14\n\x10\x45RROR_NOT_MEMBER\x10\x02\"Z\n\x1d\x43MsgDOTAPassportVoteTeamGuess\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12\x11\n\twinner_id\x18\x02 \x01(\r\x12\x13\n\x0brunnerup_id\x18\x03 \x01(\r\"\x91\x01\n$CMsgDOTAPassportVoteGenericSelection\x12V\n\x0fselection_index\x18\x01 \x01(\x0e\x32\".DOTA_2013PassportSelectionIndices:\x19PP13_SEL_ALLSTAR_PLAYER_0\x12\x11\n\tselection\x18\x02 \x01(\r\"F\n\x1d\x43MsgDOTAPassportStampedPlayer\x12\x10\n\x08steam_id\x18\x01 \x01(\x04\x12\x13\n\x0bstamp_level\x18\x02 \x01(\r\";\n#CMsgDOTAPassportPlayerCardChallenge\x12\x14\n\x0c\x63hallenge_id\x18\x01 \x01(\r\"\x8c\x02\n\x14\x43MsgDOTAPassportVote\x12\x32\n\nteam_votes\x18\x01 \x03(\x0b\x32\x1e.CMsgDOTAPassportVoteTeamGuess\x12\x41\n\x12generic_selections\x18\x02 \x03(\x0b\x32%.CMsgDOTAPassportVoteGenericSelection\x12\x37\n\x0fstamped_players\x18\x03 \x03(\x0b\x32\x1e.CMsgDOTAPassportStampedPlayer\x12\x44\n\x16player_card_challenges\x18\x04 \x03(\x0b\x32$.CMsgDOTAPassportPlayerCardChallenge\"P\n(CMsgClientToGCGetPlayerCardRosterRequest\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\"\xb2\x02\n)CMsgClientToGCGetPlayerCardRosterResponse\x12J\n\x06result\x18\x01 \x01(\x0e\x32\x31.CMsgClientToGCGetPlayerCardRosterResponse.Result:\x07SUCCESS\x12\x1b\n\x13player_card_item_id\x18\x02 \x03(\x04\x12\r\n\x05score\x18\x03 \x01(\x02\x12\x11\n\tfinalized\x18\x04 \x01(\x08\x12\x12\n\npercentile\x18\x05 \x01(\x02\"f\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x1b\n\x17\x45RROR_INVALID_LEAGUE_ID\x10\x02\x12\x1b\n\x17\x45RROR_INVALID_TIMESTAMP\x10\x03\"{\n(CMsgClientToGCSetPlayerCardRosterRequest\x12\x11\n\tleague_id\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x0c\n\x04slot\x18\x03 \x01(\r\x12\x1b\n\x13player_card_item_id\x18\x04 \x01(\x04\"\xee\x02\n)CMsgClientToGCSetPlayerCardRosterResponse\x12J\n\x06result\x18\x01 \x01(\x0e\x32\x31.CMsgClientToGCSetPlayerCardRosterResponse.Result:\x07SUCCESS\"\xf4\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x1b\n\x17\x45RROR_INVALID_LEAGUE_ID\x10\x02\x12\x1b\n\x17\x45RROR_INVALID_TIMESTAMP\x10\x03\x12\x1f\n\x1b\x45RROR_PLAYER_CARD_NOT_OWNED\x10\x04\x12\x16\n\x12\x45RROR_INVALID_SLOT\x10\x05\x12\x1a\n\x16\x45RROR_FAILED_CARD_INFO\x10\x06\x12\x1b\n\x17\x45RROR_ACCOUNT_DUPLICATE\x10\x07\x12\x1a\n\x16\x45RROR_LOCKED_TIMESTAMP\x10\x08*\xa3\x15\n!DOTA_2013PassportSelectionIndices\x12\x1d\n\x19PP13_SEL_ALLSTAR_PLAYER_0\x10\x00\x12\x1d\n\x19PP13_SEL_ALLSTAR_PLAYER_1\x10\x01\x12\x1d\n\x19PP13_SEL_ALLSTAR_PLAYER_2\x10\x02\x12\x1d\n\x19PP13_SEL_ALLSTAR_PLAYER_3\x10\x03\x12\x1d\n\x19PP13_SEL_ALLSTAR_PLAYER_4\x10\x04\x12\x1d\n\x19PP13_SEL_ALLSTAR_PLAYER_5\x10\x05\x12\x1d\n\x19PP13_SEL_ALLSTAR_PLAYER_6\x10\x06\x12\x1d\n\x19PP13_SEL_ALLSTAR_PLAYER_7\x10\x07\x12\x1d\n\x19PP13_SEL_ALLSTAR_PLAYER_8\x10\x08\x12\x1d\n\x19PP13_SEL_ALLSTAR_PLAYER_9\x10\t\x12\x1c\n\x18PP13_SEL_QUALPRED_WEST_0\x10\n\x12\x1c\n\x18PP13_SEL_QUALPRED_WEST_1\x10\x0b\x12\x1c\n\x18PP13_SEL_QUALPRED_WEST_2\x10\x0c\x12\x1c\n\x18PP13_SEL_QUALPRED_WEST_3\x10\r\x12\x1c\n\x18PP13_SEL_QUALPRED_WEST_4\x10\x0e\x12\x1c\n\x18PP13_SEL_QUALPRED_WEST_5\x10\x0f\x12\x1c\n\x18PP13_SEL_QUALPRED_WEST_6\x10\x10\x12\x1c\n\x18PP13_SEL_QUALPRED_WEST_7\x10\x11\x12\x1c\n\x18PP13_SEL_QUALPRED_WEST_8\x10\x12\x12\x1c\n\x18PP13_SEL_QUALPRED_WEST_9\x10\x13\x12\x1d\n\x19PP13_SEL_QUALPRED_WEST_10\x10\x14\x12\x1d\n\x19PP13_SEL_QUALPRED_WEST_11\x10\x15\x12\x1d\n\x19PP13_SEL_QUALPRED_WEST_12\x10\x16\x12\x1d\n\x19PP13_SEL_QUALPRED_WEST_13\x10\x17\x12\x1d\n\x19PP13_SEL_QUALPRED_WEST_14\x10\x18\x12\x1c\n\x18PP13_SEL_QUALPRED_EAST_0\x10\x19\x12\x1c\n\x18PP13_SEL_QUALPRED_EAST_1\x10\x1a\x12\x1c\n\x18PP13_SEL_QUALPRED_EAST_2\x10\x1b\x12\x1c\n\x18PP13_SEL_QUALPRED_EAST_3\x10\x1c\x12\x1c\n\x18PP13_SEL_QUALPRED_EAST_4\x10\x1d\x12\x1c\n\x18PP13_SEL_QUALPRED_EAST_5\x10\x1e\x12\x1c\n\x18PP13_SEL_QUALPRED_EAST_6\x10\x1f\x12\x1c\n\x18PP13_SEL_QUALPRED_EAST_7\x10 \x12\x1c\n\x18PP13_SEL_QUALPRED_EAST_8\x10!\x12\x1c\n\x18PP13_SEL_QUALPRED_EAST_9\x10\"\x12\x1d\n\x19PP13_SEL_QUALPRED_EAST_10\x10#\x12\x1d\n\x19PP13_SEL_QUALPRED_EAST_11\x10$\x12\x1d\n\x19PP13_SEL_QUALPRED_EAST_12\x10%\x12\x1d\n\x19PP13_SEL_QUALPRED_EAST_13\x10&\x12\x1d\n\x19PP13_SEL_QUALPRED_EAST_14\x10\'\x12\x19\n\x15PP13_SEL_TEAMCUP_TEAM\x10(\x12\x1b\n\x17PP13_SEL_TEAMCUP_PLAYER\x10)\x12\x1e\n\x1aPP13_SEL_TEAMCUP_TEAM_LOCK\x10*\x12 \n\x1cPP13_SEL_TEAMCUP_PLAYER_LOCK\x10+\x12\x18\n\x14PP13_SEL_EVENTPRED_0\x10,\x12\x18\n\x14PP13_SEL_EVENTPRED_1\x10-\x12\x18\n\x14PP13_SEL_EVENTPRED_2\x10.\x12\x18\n\x14PP13_SEL_EVENTPRED_3\x10/\x12\x18\n\x14PP13_SEL_EVENTPRED_4\x10\x30\x12\x18\n\x14PP13_SEL_EVENTPRED_5\x10\x31\x12\x18\n\x14PP13_SEL_EVENTPRED_6\x10\x32\x12\x18\n\x14PP13_SEL_EVENTPRED_7\x10\x33\x12\x18\n\x14PP13_SEL_EVENTPRED_8\x10\x34\x12\x18\n\x14PP13_SEL_EVENTPRED_9\x10\x35\x12\x19\n\x15PP13_SEL_EVENTPRED_10\x10\x36\x12\x19\n\x15PP13_SEL_EVENTPRED_11\x10\x37\x12\x19\n\x15PP13_SEL_EVENTPRED_12\x10\x38\x12\x19\n\x15PP13_SEL_EVENTPRED_13\x10\x39\x12\x19\n\x15PP13_SEL_EVENTPRED_14\x10:\x12\x19\n\x15PP13_SEL_EVENTPRED_15\x10;\x12\x19\n\x15PP13_SEL_EVENTPRED_16\x10<\x12\x19\n\x15PP13_SEL_EVENTPRED_17\x10=\x12\x19\n\x15PP13_SEL_EVENTPRED_18\x10>\x12\x19\n\x15PP13_SEL_EVENTPRED_19\x10?\x12\x19\n\x15PP13_SEL_EVENTPRED_20\x10@\x12\x19\n\x15PP13_SEL_EVENTPRED_21\x10\x41\x12\x19\n\x15PP13_SEL_EVENTPRED_22\x10\x42\x12\x19\n\x15PP13_SEL_EVENTPRED_23\x10\x43\x12\x19\n\x15PP13_SEL_EVENTPRED_24\x10\x44\x12\x19\n\x15PP13_SEL_EVENTPRED_25\x10\x45\x12\x19\n\x15PP13_SEL_EVENTPRED_26\x10\x46\x12\x19\n\x15PP13_SEL_EVENTPRED_27\x10G\x12\x19\n\x15PP13_SEL_EVENTPRED_28\x10H\x12\x19\n\x15PP13_SEL_EVENTPRED_29\x10I\x12\x19\n\x15PP13_SEL_EVENTPRED_30\x10J\x12\x19\n\x15PP13_SEL_EVENTPRED_31\x10K\x12\x19\n\x15PP13_SEL_EVENTPRED_32\x10L\x12\x19\n\x15PP13_SEL_EVENTPRED_33\x10M\x12\x19\n\x15PP13_SEL_EVENTPRED_34\x10N\x12\x19\n\x15PP13_SEL_EVENTPRED_35\x10O\x12\x19\n\x15PP13_SEL_EVENTPRED_36\x10P\x12\x19\n\x15PP13_SEL_EVENTPRED_37\x10Q\x12\x19\n\x15PP13_SEL_EVENTPRED_38\x10R\x12\x19\n\x15PP13_SEL_EVENTPRED_39\x10S\x12\x19\n\x15PP13_SEL_EVENTPRED_40\x10T\x12\x19\n\x15PP13_SEL_EVENTPRED_41\x10U\x12\x19\n\x15PP13_SEL_EVENTPRED_42\x10V\x12\x19\n\x15PP13_SEL_EVENTPRED_43\x10W\x12\x13\n\x0fPP13_SEL_SOLO_0\x10X\x12\x13\n\x0fPP13_SEL_SOLO_1\x10Y\x12\x13\n\x0fPP13_SEL_SOLO_2\x10Z\x12\x13\n\x0fPP13_SEL_SOLO_3\x10[\x12\x13\n\x0fPP13_SEL_SOLO_4\x10\\\x12\x13\n\x0fPP13_SEL_SOLO_5\x10]\x12\x13\n\x0fPP13_SEL_SOLO_6\x10^\x12\x13\n\x0fPP13_SEL_SOLO_7\x10_B\x05H\x01\x90\x01\x00')
  ,
  dependencies=[dota__shared__enums__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_DOTA_2013PASSPORTSELECTIONINDICES = _descriptor.EnumDescriptor(
  name='DOTA_2013PassportSelectionIndices',
  full_name='DOTA_2013PassportSelectionIndices',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_ALLSTAR_PLAYER_0', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_ALLSTAR_PLAYER_1', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_ALLSTAR_PLAYER_2', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_ALLSTAR_PLAYER_3', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_ALLSTAR_PLAYER_4', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_ALLSTAR_PLAYER_5', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_ALLSTAR_PLAYER_6', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_ALLSTAR_PLAYER_7', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_ALLSTAR_PLAYER_8', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_ALLSTAR_PLAYER_9', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_WEST_0', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_WEST_1', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_WEST_2', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_WEST_3', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_WEST_4', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_WEST_5', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_WEST_6', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_WEST_7', index=17, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_WEST_8', index=18, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_WEST_9', index=19, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_WEST_10', index=20, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_WEST_11', index=21, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_WEST_12', index=22, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_WEST_13', index=23, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_WEST_14', index=24, number=24,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_EAST_0', index=25, number=25,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_EAST_1', index=26, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_EAST_2', index=27, number=27,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_EAST_3', index=28, number=28,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_EAST_4', index=29, number=29,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_EAST_5', index=30, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_EAST_6', index=31, number=31,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_EAST_7', index=32, number=32,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_EAST_8', index=33, number=33,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_EAST_9', index=34, number=34,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_EAST_10', index=35, number=35,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_EAST_11', index=36, number=36,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_EAST_12', index=37, number=37,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_EAST_13', index=38, number=38,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_QUALPRED_EAST_14', index=39, number=39,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_TEAMCUP_TEAM', index=40, number=40,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_TEAMCUP_PLAYER', index=41, number=41,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_TEAMCUP_TEAM_LOCK', index=42, number=42,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_TEAMCUP_PLAYER_LOCK', index=43, number=43,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_0', index=44, number=44,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_1', index=45, number=45,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_2', index=46, number=46,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_3', index=47, number=47,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_4', index=48, number=48,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_5', index=49, number=49,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_6', index=50, number=50,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_7', index=51, number=51,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_8', index=52, number=52,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_9', index=53, number=53,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_10', index=54, number=54,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_11', index=55, number=55,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_12', index=56, number=56,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_13', index=57, number=57,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_14', index=58, number=58,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_15', index=59, number=59,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_16', index=60, number=60,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_17', index=61, number=61,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_18', index=62, number=62,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_19', index=63, number=63,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_20', index=64, number=64,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_21', index=65, number=65,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_22', index=66, number=66,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_23', index=67, number=67,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_24', index=68, number=68,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_25', index=69, number=69,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_26', index=70, number=70,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_27', index=71, number=71,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_28', index=72, number=72,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_29', index=73, number=73,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_30', index=74, number=74,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_31', index=75, number=75,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_32', index=76, number=76,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_33', index=77, number=77,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_34', index=78, number=78,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_35', index=79, number=79,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_36', index=80, number=80,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_37', index=81, number=81,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_38', index=82, number=82,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_39', index=83, number=83,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_40', index=84, number=84,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_41', index=85, number=85,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_42', index=86, number=86,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_EVENTPRED_43', index=87, number=87,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_SOLO_0', index=88, number=88,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_SOLO_1', index=89, number=89,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_SOLO_2', index=90, number=90,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_SOLO_3', index=91, number=91,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_SOLO_4', index=92, number=92,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_SOLO_5', index=93, number=93,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_SOLO_6', index=94, number=94,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PP13_SEL_SOLO_7', index=95, number=95,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=15604,
  serialized_end=18327,
)
_sym_db.RegisterEnumDescriptor(_DOTA_2013PASSPORTSELECTIONINDICES)

DOTA_2013PassportSelectionIndices = enum_type_wrapper.EnumTypeWrapper(_DOTA_2013PASSPORTSELECTIONINDICES)
PP13_SEL_ALLSTAR_PLAYER_0 = 0
PP13_SEL_ALLSTAR_PLAYER_1 = 1
PP13_SEL_ALLSTAR_PLAYER_2 = 2
PP13_SEL_ALLSTAR_PLAYER_3 = 3
PP13_SEL_ALLSTAR_PLAYER_4 = 4
PP13_SEL_ALLSTAR_PLAYER_5 = 5
PP13_SEL_ALLSTAR_PLAYER_6 = 6
PP13_SEL_ALLSTAR_PLAYER_7 = 7
PP13_SEL_ALLSTAR_PLAYER_8 = 8
PP13_SEL_ALLSTAR_PLAYER_9 = 9
PP13_SEL_QUALPRED_WEST_0 = 10
PP13_SEL_QUALPRED_WEST_1 = 11
PP13_SEL_QUALPRED_WEST_2 = 12
PP13_SEL_QUALPRED_WEST_3 = 13
PP13_SEL_QUALPRED_WEST_4 = 14
PP13_SEL_QUALPRED_WEST_5 = 15
PP13_SEL_QUALPRED_WEST_6 = 16
PP13_SEL_QUALPRED_WEST_7 = 17
PP13_SEL_QUALPRED_WEST_8 = 18
PP13_SEL_QUALPRED_WEST_9 = 19
PP13_SEL_QUALPRED_WEST_10 = 20
PP13_SEL_QUALPRED_WEST_11 = 21
PP13_SEL_QUALPRED_WEST_12 = 22
PP13_SEL_QUALPRED_WEST_13 = 23
PP13_SEL_QUALPRED_WEST_14 = 24
PP13_SEL_QUALPRED_EAST_0 = 25
PP13_SEL_QUALPRED_EAST_1 = 26
PP13_SEL_QUALPRED_EAST_2 = 27
PP13_SEL_QUALPRED_EAST_3 = 28
PP13_SEL_QUALPRED_EAST_4 = 29
PP13_SEL_QUALPRED_EAST_5 = 30
PP13_SEL_QUALPRED_EAST_6 = 31
PP13_SEL_QUALPRED_EAST_7 = 32
PP13_SEL_QUALPRED_EAST_8 = 33
PP13_SEL_QUALPRED_EAST_9 = 34
PP13_SEL_QUALPRED_EAST_10 = 35
PP13_SEL_QUALPRED_EAST_11 = 36
PP13_SEL_QUALPRED_EAST_12 = 37
PP13_SEL_QUALPRED_EAST_13 = 38
PP13_SEL_QUALPRED_EAST_14 = 39
PP13_SEL_TEAMCUP_TEAM = 40
PP13_SEL_TEAMCUP_PLAYER = 41
PP13_SEL_TEAMCUP_TEAM_LOCK = 42
PP13_SEL_TEAMCUP_PLAYER_LOCK = 43
PP13_SEL_EVENTPRED_0 = 44
PP13_SEL_EVENTPRED_1 = 45
PP13_SEL_EVENTPRED_2 = 46
PP13_SEL_EVENTPRED_3 = 47
PP13_SEL_EVENTPRED_4 = 48
PP13_SEL_EVENTPRED_5 = 49
PP13_SEL_EVENTPRED_6 = 50
PP13_SEL_EVENTPRED_7 = 51
PP13_SEL_EVENTPRED_8 = 52
PP13_SEL_EVENTPRED_9 = 53
PP13_SEL_EVENTPRED_10 = 54
PP13_SEL_EVENTPRED_11 = 55
PP13_SEL_EVENTPRED_12 = 56
PP13_SEL_EVENTPRED_13 = 57
PP13_SEL_EVENTPRED_14 = 58
PP13_SEL_EVENTPRED_15 = 59
PP13_SEL_EVENTPRED_16 = 60
PP13_SEL_EVENTPRED_17 = 61
PP13_SEL_EVENTPRED_18 = 62
PP13_SEL_EVENTPRED_19 = 63
PP13_SEL_EVENTPRED_20 = 64
PP13_SEL_EVENTPRED_21 = 65
PP13_SEL_EVENTPRED_22 = 66
PP13_SEL_EVENTPRED_23 = 67
PP13_SEL_EVENTPRED_24 = 68
PP13_SEL_EVENTPRED_25 = 69
PP13_SEL_EVENTPRED_26 = 70
PP13_SEL_EVENTPRED_27 = 71
PP13_SEL_EVENTPRED_28 = 72
PP13_SEL_EVENTPRED_29 = 73
PP13_SEL_EVENTPRED_30 = 74
PP13_SEL_EVENTPRED_31 = 75
PP13_SEL_EVENTPRED_32 = 76
PP13_SEL_EVENTPRED_33 = 77
PP13_SEL_EVENTPRED_34 = 78
PP13_SEL_EVENTPRED_35 = 79
PP13_SEL_EVENTPRED_36 = 80
PP13_SEL_EVENTPRED_37 = 81
PP13_SEL_EVENTPRED_38 = 82
PP13_SEL_EVENTPRED_39 = 83
PP13_SEL_EVENTPRED_40 = 84
PP13_SEL_EVENTPRED_41 = 85
PP13_SEL_EVENTPRED_42 = 86
PP13_SEL_EVENTPRED_43 = 87
PP13_SEL_SOLO_0 = 88
PP13_SEL_SOLO_1 = 89
PP13_SEL_SOLO_2 = 90
PP13_SEL_SOLO_3 = 91
PP13_SEL_SOLO_4 = 92
PP13_SEL_SOLO_5 = 93
PP13_SEL_SOLO_6 = 94
PP13_SEL_SOLO_7 = 95


_CMSGDOTACREATEFANTASYLEAGUERESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTACreateFantasyLeagueResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_TOO_MANY_LEAGUES', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INVALID_TEAM_COUNT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_CREATION_DISABLED', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=786,
  serialized_end=918,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTACREATEFANTASYLEAGUERESPONSE_ERESULT)

_CMSGDOTAFANTASYLEAGUEEDITINFORESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyLeagueEditInfoResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2160,
  serialized_end=2230,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYLEAGUEEDITINFORESPONSE_ERESULT)

_CMSGDOTAFANTASYLEAGUEFINDRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyLeagueFindResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_LEAGUE_NOT_FOUND', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_BAD_PASSWORD', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FULL', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ALREADY_MEMBER', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_LEAGUE_LOCKED', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2477,
  serialized_end=2641,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYLEAGUEFINDRESPONSE_ERESULT)

_CMSGDOTAFANTASYLEAGUEINFORESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyLeagueInfoResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_BAD_LEAGUE_ID', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2813,
  serialized_end=2883,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYLEAGUEINFORESPONSE_ERESULT)

_CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyLeagueMatchupsResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_BAD_LEAGUE_ID', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3396,
  serialized_end=3491,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE_ERESULT)

_CMSGDOTAEDITFANTASYTEAMRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAEditFantasyTeamResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INVALID_TEAM_INFO', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NAME_ALREADY_TAKEN', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3716,
  serialized_end=3845,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAEDITFANTASYTEAMRESPONSE_ERESULT)

_CMSGDOTAFANTASYTEAMSCORERESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyTeamScoreResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_OWNER_NOT_IN_LEAGUE', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4765,
  serialized_end=4866,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYTEAMSCORERESPONSE_ERESULT)

_CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyTeamStandingsResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2160,
  serialized_end=2230,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE_ERESULT)

_CMSGDOTAFANTASYPLAYERSCORERESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyPlayerScoreResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2160,
  serialized_end=2230,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYPLAYERSCORERESPONSE_ERESULT)

_CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyPlayerStandingsResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2160,
  serialized_end=2230,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE_ERESULT)

_CMSGDOTAFANTASYLEAGUECREATERESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyLeagueCreateResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_BAD_SEASON_ID', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_BAD_LEAGUE_NAME', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_BAD_TEAM_NAME', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FAILED_LOGO_UPLOAD', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_TICKET', index=7, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7061,
  serialized_end=7259,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYLEAGUECREATERESPONSE_ERESULT)

_CMSGDOTAFANTASYTEAMCREATERESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyTeamCreateResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FAILED_LOGO_UPLOAD', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_BAD_FANTASY_LEAGUE_ID', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_BAD_NAME', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FULL', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ALREADY_MEMBER', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_BAD_PASSWORD', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_TICKET', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_LEAGUE_LOCKED', index=10, number=10,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7536,
  serialized_end=7801,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYTEAMCREATERESPONSE_ERESULT)

_CMSGDOTAFANTASYLEAGUEEDITINVITESRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyLeagueEditInvitesResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=786,
  serialized_end=831,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYLEAGUEEDITINVITESRESPONSE_ERESULT)

_CMSGDOTAFANTASYLEAGUEDRAFTPLAYERRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyLeagueDraftPlayerResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INVALID_FANTASY_LEAGUE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FANTASY_LEAGUE_NOT_DRAFTING', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_OWNER_NOT_IN_LEAGUE', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NOT_OWNERS_TURN', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_PLAYER_INVALID', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_PLAYER_UNAVAILABLE', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_PLAYER_NO_VALID_SLOTS', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8701,
  serialized_end=8966,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYLEAGUEDRAFTPLAYERRESPONSE_ERESULT)

_CMSGDOTAFANTASYTEAMROSTERSWAPRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyTeamRosterSwapResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_OWNER_NOT_IN_LEAGUE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_SLOTS_INVALID', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_SLOT_LOCKED', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=9222,
  serialized_end=9346,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYTEAMROSTERSWAPRESPONSE_ERESULT)

_CMSGDOTAFANTASYTEAMROSTERADDDROPRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyTeamRosterAddDropResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_OWNER_NOT_IN_LEAGUE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_PLAYER_NOT_AVAILABLE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_PLAYER_NOT_ON_TEAM', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_TRADE_ALREADY_PENDING', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=9610,
  serialized_end=9781,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYTEAMROSTERADDDROPRESPONSE_ERESULT)

_CMSGDOTAFANTASYTEAMTRADESRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyTeamTradesResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2160,
  serialized_end=2230,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYTEAMTRADESRESPONSE_ERESULT)

_CMSGDOTAFANTASYTEAMTRADECANCELRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyTeamTradeCancelResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_TRADE', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=10500,
  serialized_end=10590,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYTEAMTRADECANCELRESPONSE_ERESULT)

_CMSGDOTAFANTASYTEAMROSTERRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyTeamRosterResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_OWNER_NOT_IN_LEAGUE', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4765,
  serialized_end=4866,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYTEAMROSTERRESPONSE_ERESULT)

_CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2160,
  serialized_end=2230,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_ERESULT)

_CMSGDOTAFANTASYMESSAGESRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyMessagesResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2160,
  serialized_end=2230,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYMESSAGESRESPONSE_ERESULT)

_CMSGDOTAFANTASYREMOVEOWNERRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyRemoveOwnerResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_LEAGUE_LOCKED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NOT_A_MEMBER', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=12568,
  serialized_end=12687,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYREMOVEOWNERRESPONSE_ERESULT)

_CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyScheduledMatchesResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=786,
  serialized_end=831,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE_ERESULT)

_CMSGDOTAFANTASYLEAVELEAGUERESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyLeaveLeagueResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NOT_MEMBER', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_LEAGUE_NOT_FOUND', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_DRAFT_ACTIVE', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=13295,
  serialized_end=13414,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYLEAVELEAGUERESPONSE_ERESULT)

_CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAFantasyPlayerScoreDetailsResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NOT_MEMBER', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=13295,
  serialized_end=13362,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE_ERESULT)

_CMSGCLIENTTOGCGETPLAYERCARDROSTERRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='CMsgClientToGCGetPlayerCardRosterResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INVALID_LEAGUE_ID', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INVALID_TIMESTAMP', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=15005,
  serialized_end=15107,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCGETPLAYERCARDROSTERRESPONSE_RESULT)

_CMSGCLIENTTOGCSETPLAYERCARDROSTERRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='CMsgClientToGCSetPlayerCardRosterResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INVALID_LEAGUE_ID', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INVALID_TIMESTAMP', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_PLAYER_CARD_NOT_OWNED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_INVALID_SLOT', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_FAILED_CARD_INFO', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ACCOUNT_DUPLICATE', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_LOCKED_TIMESTAMP', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=15357,
  serialized_end=15601,
)
_sym_db.RegisterEnumDescriptor(_CMSGCLIENTTOGCSETPLAYERCARDROSTERRESPONSE_RESULT)


_CMSGGCPLAYERINFO_PLAYERINFO = _descriptor.Descriptor(
  name='PlayerInfo',
  full_name='CMsgGCPlayerInfo.PlayerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgGCPlayerInfo.PlayerInfo.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgGCPlayerInfo.PlayerInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CMsgGCPlayerInfo.PlayerInfo.country_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_role', full_name='CMsgGCPlayerInfo.PlayerInfo.fantasy_role', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgGCPlayerInfo.PlayerInfo.team_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgGCPlayerInfo.PlayerInfo.team_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_tag', full_name='CMsgGCPlayerInfo.PlayerInfo.team_tag', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sponsor', full_name='CMsgGCPlayerInfo.PlayerInfo.sponsor', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_locked', full_name='CMsgGCPlayerInfo.PlayerInfo.is_locked', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_pro', full_name='CMsgGCPlayerInfo.PlayerInfo.is_pro', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='locked_until', full_name='CMsgGCPlayerInfo.PlayerInfo.locked_until', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgGCPlayerInfo.PlayerInfo.timestamp', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=198,
  serialized_end=435,
)

_CMSGGCPLAYERINFO_REGIONLEADERBOARD = _descriptor.Descriptor(
  name='RegionLeaderboard',
  full_name='CMsgGCPlayerInfo.RegionLeaderboard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='division', full_name='CMsgGCPlayerInfo.RegionLeaderboard.division', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='CMsgGCPlayerInfo.RegionLeaderboard.account_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=437,
  serialized_end=495,
)

_CMSGGCPLAYERINFO = _descriptor.Descriptor(
  name='CMsgGCPlayerInfo',
  full_name='CMsgGCPlayerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_infos', full_name='CMsgGCPlayerInfo.player_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leaderboards', full_name='CMsgGCPlayerInfo.leaderboards', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCPLAYERINFO_PLAYERINFO, _CMSGGCPLAYERINFO_REGIONLEADERBOARD, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=495,
)


_CMSGDOTACREATEFANTASYLEAGUEREQUEST = _descriptor.Descriptor(
  name='CMsgDOTACreateFantasyLeagueRequest',
  full_name='CMsgDOTACreateFantasyLeagueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_name', full_name='CMsgDOTACreateFantasyLeagueRequest.league_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_logo', full_name='CMsgDOTACreateFantasyLeagueRequest.league_logo', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='selection_mode', full_name='CMsgDOTACreateFantasyLeagueRequest.selection_mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_count', full_name='CMsgDOTACreateFantasyLeagueRequest.team_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=498,
  serialized_end=672,
)


_CMSGDOTACREATEFANTASYLEAGUERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTACreateFantasyLeagueResponse',
  full_name='CMsgDOTACreateFantasyLeagueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTACreateFantasyLeagueResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTACREATEFANTASYLEAGUERESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=675,
  serialized_end=918,
)


_CMSGFANTASYLEAGUESCORING = _descriptor.Descriptor(
  name='CMsgFantasyLeagueScoring',
  full_name='CMsgFantasyLeagueScoring',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='CMsgFantasyLeagueScoring.level', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kills', full_name='CMsgFantasyLeagueScoring.kills', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deaths', full_name='CMsgFantasyLeagueScoring.deaths', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assists', full_name='CMsgFantasyLeagueScoring.assists', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_hits', full_name='CMsgFantasyLeagueScoring.last_hits', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='denies', full_name='CMsgFantasyLeagueScoring.denies', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gpm', full_name='CMsgFantasyLeagueScoring.gpm', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xppm', full_name='CMsgFantasyLeagueScoring.xppm', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stuns', full_name='CMsgFantasyLeagueScoring.stuns', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='healing', full_name='CMsgFantasyLeagueScoring.healing', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tower_kills', full_name='CMsgFantasyLeagueScoring.tower_kills', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='roshan_kills', full_name='CMsgFantasyLeagueScoring.roshan_kills', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='multiplier_premium', full_name='CMsgFantasyLeagueScoring.multiplier_premium', index=12,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='multiplier_professional', full_name='CMsgFantasyLeagueScoring.multiplier_professional', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=921,
  serialized_end=1208,
)


_CMSGDOTAFANTASYLEAGUEINFO_OWNERINFO = _descriptor.Descriptor(
  name='OwnerInfo',
  full_name='CMsgDOTAFantasyLeagueInfo.OwnerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_account_id', full_name='CMsgDOTAFantasyLeagueInfo.OwnerInfo.owner_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='left_league', full_name='CMsgDOTAFantasyLeagueInfo.OwnerInfo.left_league', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_account_id', full_name='CMsgDOTAFantasyLeagueInfo.OwnerInfo.player_account_id', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1844,
  serialized_end=1929,
)

_CMSGDOTAFANTASYLEAGUEINFO = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueInfo',
  full_name='CMsgDOTAFantasyLeagueInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyLeagueInfo.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='commissioner_account_id', full_name='CMsgDOTAFantasyLeagueInfo.commissioner_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_league_name', full_name='CMsgDOTAFantasyLeagueInfo.fantasy_league_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='selection_mode', full_name='CMsgDOTAFantasyLeagueInfo.selection_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_count', full_name='CMsgDOTAFantasyLeagueInfo.team_count', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logo', full_name='CMsgDOTAFantasyLeagueInfo.logo', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scoring', full_name='CMsgDOTAFantasyLeagueInfo.scoring', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='draft_time', full_name='CMsgDOTAFantasyLeagueInfo.draft_time', index=7,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='draft_pick_time', full_name='CMsgDOTAFantasyLeagueInfo.draft_pick_time', index=8,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='season_start', full_name='CMsgDOTAFantasyLeagueInfo.season_start', index=9,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='season_length', full_name='CMsgDOTAFantasyLeagueInfo.season_length', index=10,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='veto_votes', full_name='CMsgDOTAFantasyLeagueInfo.veto_votes', index=11,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='acquisitions', full_name='CMsgDOTAFantasyLeagueInfo.acquisitions', index=12,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot_1', full_name='CMsgDOTAFantasyLeagueInfo.slot_1', index=13,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot_2', full_name='CMsgDOTAFantasyLeagueInfo.slot_2', index=14,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot_3', full_name='CMsgDOTAFantasyLeagueInfo.slot_3', index=15,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot_4', full_name='CMsgDOTAFantasyLeagueInfo.slot_4', index=16,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot_5', full_name='CMsgDOTAFantasyLeagueInfo.slot_5', index=17,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bench_slots', full_name='CMsgDOTAFantasyLeagueInfo.bench_slots', index=18,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_info', full_name='CMsgDOTAFantasyLeagueInfo.owner_info', index=19,
      number=25, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players', full_name='CMsgDOTAFantasyLeagueInfo.players', index=20,
      number=26, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='CMsgDOTAFantasyLeagueInfo.time_zone', index=21,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='season', full_name='CMsgDOTAFantasyLeagueInfo.season', index=22,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='password', full_name='CMsgDOTAFantasyLeagueInfo.password', index=23,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAFANTASYLEAGUEINFO_OWNERINFO, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1211,
  serialized_end=1929,
)


_CMSGDOTAFANTASYLEAGUEEDITINFOREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueEditInfoRequest',
  full_name='CMsgDOTAFantasyLeagueEditInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyLeagueEditInfoRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='edit_info', full_name='CMsgDOTAFantasyLeagueEditInfoRequest.edit_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1931,
  serialized_end=2043,
)


_CMSGDOTAFANTASYLEAGUEEDITINFORESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueEditInfoResponse',
  full_name='CMsgDOTAFantasyLeagueEditInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyLeagueEditInfoResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAFANTASYLEAGUEEDITINFORESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2046,
  serialized_end=2230,
)


_CMSGDOTAFANTASYLEAGUEFINDREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueFindRequest',
  full_name='CMsgDOTAFantasyLeagueFindRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyLeagueFindRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='password', full_name='CMsgDOTAFantasyLeagueFindRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2232,
  serialized_end=2311,
)


_CMSGDOTAFANTASYLEAGUEFINDRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueFindResponse',
  full_name='CMsgDOTAFantasyLeagueFindResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyLeagueFindResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_league_name', full_name='CMsgDOTAFantasyLeagueFindResponse.fantasy_league_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='commissioner_name', full_name='CMsgDOTAFantasyLeagueFindResponse.commissioner_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAFANTASYLEAGUEFINDRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2314,
  serialized_end=2641,
)


_CMSGDOTAFANTASYLEAGUEINFOREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueInfoRequest',
  full_name='CMsgDOTAFantasyLeagueInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyLeagueInfoRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2643,
  serialized_end=2704,
)


_CMSGDOTAFANTASYLEAGUEINFORESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueInfoResponse',
  full_name='CMsgDOTAFantasyLeagueInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyLeagueInfoResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAFANTASYLEAGUEINFORESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2707,
  serialized_end=2883,
)


_CMSGDOTAFANTASYLEAGUEMATCHUPSREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueMatchupsRequest',
  full_name='CMsgDOTAFantasyLeagueMatchupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyLeagueMatchupsRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2885,
  serialized_end=2950,
)


_CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE_MATCHUP = _descriptor.Descriptor(
  name='Matchup',
  full_name='CMsgDOTAFantasyLeagueMatchupsResponse.Matchup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_account_id_1', full_name='CMsgDOTAFantasyLeagueMatchupsResponse.Matchup.owner_account_id_1', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_account_id_2', full_name='CMsgDOTAFantasyLeagueMatchupsResponse.Matchup.owner_account_id_2', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score_1', full_name='CMsgDOTAFantasyLeagueMatchupsResponse.Matchup.score_1', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score_2', full_name='CMsgDOTAFantasyLeagueMatchupsResponse.Matchup.score_2', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3174,
  serialized_end=3273,
)

_CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE_WEEKLYMATCHUPS = _descriptor.Descriptor(
  name='WeeklyMatchups',
  full_name='CMsgDOTAFantasyLeagueMatchupsResponse.WeeklyMatchups',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matchup', full_name='CMsgDOTAFantasyLeagueMatchupsResponse.WeeklyMatchups.matchup', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='CMsgDOTAFantasyLeagueMatchupsResponse.WeeklyMatchups.start_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='CMsgDOTAFantasyLeagueMatchupsResponse.WeeklyMatchups.end_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3275,
  serialized_end=3394,
)

_CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueMatchupsResponse',
  full_name='CMsgDOTAFantasyLeagueMatchupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyLeagueMatchupsResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyLeagueMatchupsResponse.fantasy_league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weekly_matchups', full_name='CMsgDOTAFantasyLeagueMatchupsResponse.weekly_matchups', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE_MATCHUP, _CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE_WEEKLYMATCHUPS, ],
  enum_types=[
    _CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2953,
  serialized_end=3491,
)


_CMSGDOTAEDITFANTASYTEAMREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAEditFantasyTeamRequest',
  full_name='CMsgDOTAEditFantasyTeamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAEditFantasyTeamRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_index', full_name='CMsgDOTAEditFantasyTeamRequest.team_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgDOTAEditFantasyTeamRequest.team_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_logo', full_name='CMsgDOTAEditFantasyTeamRequest.team_logo', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3493,
  serialized_end=3610,
)


_CMSGDOTAEDITFANTASYTEAMRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAEditFantasyTeamResponse',
  full_name='CMsgDOTAEditFantasyTeamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAEditFantasyTeamResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAEDITFANTASYTEAMRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3613,
  serialized_end=3845,
)


_CMSGDOTAFANTASYTEAMINFOREQUESTBYFANTASYLEAGUEID = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamInfoRequestByFantasyLeagueID',
  full_name='CMsgDOTAFantasyTeamInfoRequestByFantasyLeagueID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyTeamInfoRequestByFantasyLeagueID.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3847,
  serialized_end=3923,
)


_CMSGDOTAFANTASYTEAMINFOREQUESTBYOWNERACCOUNTID = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamInfoRequestByOwnerAccountID',
  full_name='CMsgDOTAFantasyTeamInfoRequestByOwnerAccountID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_account_id', full_name='CMsgDOTAFantasyTeamInfoRequestByOwnerAccountID.owner_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3925,
  serialized_end=3999,
)


_CMSGDOTAFANTASYTEAMINFORESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamInfoResponse',
  full_name='CMsgDOTAFantasyTeamInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CMsgDOTAFantasyTeamInfoResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4001,
  serialized_end=4077,
)


_CMSGDOTAFANTASYTEAMINFO = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamInfo',
  full_name='CMsgDOTAFantasyTeamInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyTeamInfo.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_account_id', full_name='CMsgDOTAFantasyTeamInfo.owner_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_team_index', full_name='CMsgDOTAFantasyTeamInfo.fantasy_team_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgDOTAFantasyTeamInfo.team_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_logo', full_name='CMsgDOTAFantasyTeamInfo.team_logo', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wins', full_name='CMsgDOTAFantasyTeamInfo.wins', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='losses', full_name='CMsgDOTAFantasyTeamInfo.losses', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='current_roster', full_name='CMsgDOTAFantasyTeamInfo.current_roster', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4080,
  serialized_end=4278,
)


_CMSGDOTAFANTASYTEAMSCOREREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamScoreRequest',
  full_name='CMsgDOTAFantasyTeamScoreRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyTeamScoreRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_account_id', full_name='CMsgDOTAFantasyTeamScoreRequest.owner_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_team_index', full_name='CMsgDOTAFantasyTeamScoreRequest.fantasy_team_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_match_id', full_name='CMsgDOTAFantasyTeamScoreRequest.filter_match_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_start_time', full_name='CMsgDOTAFantasyTeamScoreRequest.filter_start_time', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_end_time', full_name='CMsgDOTAFantasyTeamScoreRequest.filter_end_time', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='include_bench', full_name='CMsgDOTAFantasyTeamScoreRequest.include_bench', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4281,
  serialized_end=4495,
)


_CMSGDOTAFANTASYTEAMSCORERESPONSE_CMSGPLAYERSCORE = _descriptor.Descriptor(
  name='CMsgPlayerScore',
  full_name='CMsgDOTAFantasyTeamScoreResponse.CMsgPlayerScore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAFantasyTeamScoreResponse.CMsgPlayerScore.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgDOTAFantasyTeamScoreResponse.CMsgPlayerScore.score', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4711,
  serialized_end=4763,
)

_CMSGDOTAFANTASYTEAMSCORERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamScoreResponse',
  full_name='CMsgDOTAFantasyTeamScoreResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyTeamScoreResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_team_score', full_name='CMsgDOTAFantasyTeamScoreResponse.fantasy_team_score', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_player_score', full_name='CMsgDOTAFantasyTeamScoreResponse.fantasy_player_score', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAFANTASYTEAMSCORERESPONSE_CMSGPLAYERSCORE, ],
  enum_types=[
    _CMSGDOTAFANTASYTEAMSCORERESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4498,
  serialized_end=4866,
)


_CMSGDOTAFANTASYTEAMSTANDINGSREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamStandingsRequest',
  full_name='CMsgDOTAFantasyTeamStandingsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyTeamStandingsRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='count', full_name='CMsgDOTAFantasyTeamStandingsRequest.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_start_time', full_name='CMsgDOTAFantasyTeamStandingsRequest.filter_start_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_end_time', full_name='CMsgDOTAFantasyTeamStandingsRequest.filter_end_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_match_id', full_name='CMsgDOTAFantasyTeamStandingsRequest.filter_match_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_last_match', full_name='CMsgDOTAFantasyTeamStandingsRequest.filter_last_match', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_in_hall', full_name='CMsgDOTAFantasyTeamStandingsRequest.filter_in_hall', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4869,
  serialized_end=5076,
)


_CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE_CMSGTEAMSCORE = _descriptor.Descriptor(
  name='CMsgTeamScore',
  full_name='CMsgDOTAFantasyTeamStandingsResponse.CMsgTeamScore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyTeamStandingsResponse.CMsgTeamScore.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_account_id', full_name='CMsgDOTAFantasyTeamStandingsResponse.CMsgTeamScore.owner_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_team_index', full_name='CMsgDOTAFantasyTeamStandingsResponse.CMsgTeamScore.fantasy_team_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_team_logo', full_name='CMsgDOTAFantasyTeamStandingsResponse.CMsgTeamScore.fantasy_team_logo', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_name', full_name='CMsgDOTAFantasyTeamStandingsResponse.CMsgTeamScore.owner_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_team_name', full_name='CMsgDOTAFantasyTeamStandingsResponse.CMsgTeamScore.fantasy_team_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgDOTAFantasyTeamStandingsResponse.CMsgTeamScore.score', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score_against', full_name='CMsgDOTAFantasyTeamStandingsResponse.CMsgTeamScore.score_against', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wins', full_name='CMsgDOTAFantasyTeamStandingsResponse.CMsgTeamScore.wins', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='losses', full_name='CMsgDOTAFantasyTeamStandingsResponse.CMsgTeamScore.losses', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='streak', full_name='CMsgDOTAFantasyTeamStandingsResponse.CMsgTeamScore.streak', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5266,
  serialized_end=5520,
)

_CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamStandingsResponse',
  full_name='CMsgDOTAFantasyTeamStandingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyTeamStandingsResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_scores', full_name='CMsgDOTAFantasyTeamStandingsResponse.team_scores', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE_CMSGTEAMSCORE, ],
  enum_types=[
    _CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5079,
  serialized_end=5592,
)


_CMSGDOTAFANTASYPLAYERSCOREREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyPlayerScoreRequest',
  full_name='CMsgDOTAFantasyPlayerScoreRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyPlayerScoreRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_account_id', full_name='CMsgDOTAFantasyPlayerScoreRequest.player_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_start_time', full_name='CMsgDOTAFantasyPlayerScoreRequest.filter_start_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_end_time', full_name='CMsgDOTAFantasyPlayerScoreRequest.filter_end_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_match_id', full_name='CMsgDOTAFantasyPlayerScoreRequest.filter_match_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_last_match', full_name='CMsgDOTAFantasyPlayerScoreRequest.filter_last_match', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5595,
  serialized_end=5788,
)


_CMSGDOTAFANTASYPLAYERSCORERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyPlayerScoreResponse',
  full_name='CMsgDOTAFantasyPlayerScoreResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyPlayerScoreResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyPlayerScoreResponse.fantasy_league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_account_id', full_name='CMsgDOTAFantasyPlayerScoreResponse.player_account_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_name', full_name='CMsgDOTAFantasyPlayerScoreResponse.player_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgDOTAFantasyPlayerScoreResponse.score', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAFANTASYPLAYERSCORERESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5791,
  serialized_end=6059,
)


_CMSGDOTAFANTASYPLAYERSTANDINGSREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyPlayerStandingsRequest',
  full_name='CMsgDOTAFantasyPlayerStandingsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyPlayerStandingsRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='count', full_name='CMsgDOTAFantasyPlayerStandingsRequest.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='CMsgDOTAFantasyPlayerStandingsRequest.role', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_start_time', full_name='CMsgDOTAFantasyPlayerStandingsRequest.filter_start_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_end_time', full_name='CMsgDOTAFantasyPlayerStandingsRequest.filter_end_time', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_match_id', full_name='CMsgDOTAFantasyPlayerStandingsRequest.filter_match_id', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_last_match', full_name='CMsgDOTAFantasyPlayerStandingsRequest.filter_last_match', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6062,
  serialized_end=6261,
)


_CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE_CMSGPLAYERSCORE = _descriptor.Descriptor(
  name='CMsgPlayerScore',
  full_name='CMsgDOTAFantasyPlayerStandingsResponse.CMsgPlayerScore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_account_id', full_name='CMsgDOTAFantasyPlayerStandingsResponse.CMsgPlayerScore.player_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_name', full_name='CMsgDOTAFantasyPlayerStandingsResponse.CMsgPlayerScore.player_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgDOTAFantasyPlayerStandingsResponse.CMsgPlayerScore.score', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6501,
  serialized_end=6581,
)

_CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyPlayerStandingsResponse',
  full_name='CMsgDOTAFantasyPlayerStandingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyPlayerStandingsResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyPlayerStandingsResponse.fantasy_league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='CMsgDOTAFantasyPlayerStandingsResponse.role', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_scores', full_name='CMsgDOTAFantasyPlayerStandingsResponse.player_scores', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE_CMSGPLAYERSCORE, ],
  enum_types=[
    _CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6264,
  serialized_end=6653,
)


_CMSGDOTAFANTASYPLAYERINFOREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyPlayerInfoRequest',
  full_name='CMsgDOTAFantasyPlayerInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6655,
  serialized_end=6689,
)


_CMSGDOTAFANTASYPLAYERINFORESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyPlayerInfoResponse',
  full_name='CMsgDOTAFantasyPlayerInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg', full_name='CMsgDOTAFantasyPlayerInfoResponse.msg', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6691,
  serialized_end=6758,
)


_CMSGDOTAFANTASYLEAGUECREATEREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueCreateRequest',
  full_name='CMsgDOTAFantasyLeagueCreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='season_id', full_name='CMsgDOTAFantasyLeagueCreateRequest.season_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_league_name', full_name='CMsgDOTAFantasyLeagueCreateRequest.fantasy_league_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='password', full_name='CMsgDOTAFantasyLeagueCreateRequest.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgDOTAFantasyLeagueCreateRequest.team_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logo', full_name='CMsgDOTAFantasyLeagueCreateRequest.logo', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ticket_item_id', full_name='CMsgDOTAFantasyLeagueCreateRequest.ticket_item_id', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6761,
  serialized_end=6920,
)


_CMSGDOTAFANTASYLEAGUECREATERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueCreateResponse',
  full_name='CMsgDOTAFantasyLeagueCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyLeagueCreateResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyLeagueCreateResponse.fantasy_league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAFANTASYLEAGUECREATERESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6923,
  serialized_end=7259,
)


_CMSGDOTAFANTASYTEAMCREATEREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamCreateRequest',
  full_name='CMsgDOTAFantasyTeamCreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyTeamCreateRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='password', full_name='CMsgDOTAFantasyTeamCreateRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_name', full_name='CMsgDOTAFantasyTeamCreateRequest.team_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logo', full_name='CMsgDOTAFantasyTeamCreateRequest.logo', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ticket_item_id', full_name='CMsgDOTAFantasyTeamCreateRequest.ticket_item_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7262,
  serialized_end=7398,
)


_CMSGDOTAFANTASYTEAMCREATERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamCreateResponse',
  full_name='CMsgDOTAFantasyTeamCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyTeamCreateResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_team_index', full_name='CMsgDOTAFantasyTeamCreateResponse.fantasy_team_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAFANTASYTEAMCREATERESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7401,
  serialized_end=7801,
)


_CMSGDOTAFANTASYLEAGUEEDITINVITESREQUEST_INVITECHANGE = _descriptor.Descriptor(
  name='InviteChange',
  full_name='CMsgDOTAFantasyLeagueEditInvitesRequest.InviteChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAFantasyLeagueEditInvitesRequest.InviteChange.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invited', full_name='CMsgDOTAFantasyLeagueEditInvitesRequest.InviteChange.invited', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7970,
  serialized_end=8021,
)

_CMSGDOTAFANTASYLEAGUEEDITINVITESREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueEditInvitesRequest',
  full_name='CMsgDOTAFantasyLeagueEditInvitesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyLeagueEditInvitesRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='password', full_name='CMsgDOTAFantasyLeagueEditInvitesRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invite_change', full_name='CMsgDOTAFantasyLeagueEditInvitesRequest.invite_change', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAFANTASYLEAGUEEDITINVITESREQUEST_INVITECHANGE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7804,
  serialized_end=8021,
)


_CMSGDOTAFANTASYLEAGUEEDITINVITESRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueEditInvitesResponse',
  full_name='CMsgDOTAFantasyLeagueEditInvitesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyLeagueEditInvitesResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAFANTASYLEAGUEEDITINVITESRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8024,
  serialized_end=8189,
)


_CMSGDOTAFANTASYLEAGUEDRAFTSTATUSREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueDraftStatusRequest',
  full_name='CMsgDOTAFantasyLeagueDraftStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyLeagueDraftStatusRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8191,
  serialized_end=8259,
)


_CMSGDOTAFANTASYLEAGUEDRAFTSTATUS = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueDraftStatus',
  full_name='CMsgDOTAFantasyLeagueDraftStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyLeagueDraftStatus.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='draft_order', full_name='CMsgDOTAFantasyLeagueDraftStatus.draft_order', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='current_pick', full_name='CMsgDOTAFantasyLeagueDraftStatus.current_pick', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_remaining', full_name='CMsgDOTAFantasyLeagueDraftStatus.time_remaining', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pending_resume', full_name='CMsgDOTAFantasyLeagueDraftStatus.pending_resume', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='completed', full_name='CMsgDOTAFantasyLeagueDraftStatus.completed', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='available_players', full_name='CMsgDOTAFantasyLeagueDraftStatus.available_players', index=6,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8262,
  serialized_end=8460,
)


_CMSGDOTAFANTASYLEAGUEDRAFTPLAYERREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueDraftPlayerRequest',
  full_name='CMsgDOTAFantasyLeagueDraftPlayerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyLeagueDraftPlayerRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_index', full_name='CMsgDOTAFantasyLeagueDraftPlayerRequest.team_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_account_id', full_name='CMsgDOTAFantasyLeagueDraftPlayerRequest.player_account_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8462,
  serialized_end=8577,
)


_CMSGDOTAFANTASYLEAGUEDRAFTPLAYERRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeagueDraftPlayerResponse',
  full_name='CMsgDOTAFantasyLeagueDraftPlayerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyLeagueDraftPlayerResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAFANTASYLEAGUEDRAFTPLAYERRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8580,
  serialized_end=8966,
)


_CMSGDOTAFANTASYTEAMROSTERSWAPREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamRosterSwapRequest',
  full_name='CMsgDOTAFantasyTeamRosterSwapRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyTeamRosterSwapRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_index', full_name='CMsgDOTAFantasyTeamRosterSwapRequest.team_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgDOTAFantasyTeamRosterSwapRequest.timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot_1', full_name='CMsgDOTAFantasyTeamRosterSwapRequest.slot_1', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot_2', full_name='CMsgDOTAFantasyTeamRosterSwapRequest.slot_2', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8969,
  serialized_end=9105,
)


_CMSGDOTAFANTASYTEAMROSTERSWAPRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamRosterSwapResponse',
  full_name='CMsgDOTAFantasyTeamRosterSwapResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyTeamRosterSwapResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAFANTASYTEAMROSTERSWAPRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9108,
  serialized_end=9346,
)


_CMSGDOTAFANTASYTEAMROSTERADDDROPREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamRosterAddDropRequest',
  full_name='CMsgDOTAFantasyTeamRosterAddDropRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyTeamRosterAddDropRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_index', full_name='CMsgDOTAFantasyTeamRosterAddDropRequest.team_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='add_account_id', full_name='CMsgDOTAFantasyTeamRosterAddDropRequest.add_account_id', index=2,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='drop_account_id', full_name='CMsgDOTAFantasyTeamRosterAddDropRequest.drop_account_id', index=3,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9349,
  serialized_end=9486,
)


_CMSGDOTAFANTASYTEAMROSTERADDDROPRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamRosterAddDropResponse',
  full_name='CMsgDOTAFantasyTeamRosterAddDropResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyTeamRosterAddDropResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAFANTASYTEAMROSTERADDDROPRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9489,
  serialized_end=9781,
)


_CMSGDOTAFANTASYTEAMTRADESREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamTradesRequest',
  full_name='CMsgDOTAFantasyTeamTradesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyTeamTradesRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9783,
  serialized_end=9844,
)


_CMSGDOTAFANTASYTEAMTRADESRESPONSE_TRADE = _descriptor.Descriptor(
  name='Trade',
  full_name='CMsgDOTAFantasyTeamTradesResponse.Trade',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgDOTAFantasyTeamTradesResponse.Trade.timestamp', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_account_id_1', full_name='CMsgDOTAFantasyTeamTradesResponse.Trade.owner_account_id_1', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_account_id_2', full_name='CMsgDOTAFantasyTeamTradesResponse.Trade.owner_account_id_2', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_account_id_1', full_name='CMsgDOTAFantasyTeamTradesResponse.Trade.player_account_id_1', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_account_id_2', full_name='CMsgDOTAFantasyTeamTradesResponse.Trade.player_account_id_2', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='CMsgDOTAFantasyTeamTradesResponse.Trade.status', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10012,
  serialized_end=10168,
)

_CMSGDOTAFANTASYTEAMTRADESRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamTradesResponse',
  full_name='CMsgDOTAFantasyTeamTradesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyTeamTradesResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trades', full_name='CMsgDOTAFantasyTeamTradesResponse.trades', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAFANTASYTEAMTRADESRESPONSE_TRADE, ],
  enum_types=[
    _CMSGDOTAFANTASYTEAMTRADESRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9847,
  serialized_end=10240,
)


_CMSGDOTAFANTASYTEAMTRADECANCELREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamTradeCancelRequest',
  full_name='CMsgDOTAFantasyTeamTradeCancelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyTeamTradeCancelRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_index_1', full_name='CMsgDOTAFantasyTeamTradeCancelRequest.team_index_1', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_account_id_2', full_name='CMsgDOTAFantasyTeamTradeCancelRequest.owner_account_id_2', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_index_2', full_name='CMsgDOTAFantasyTeamTradeCancelRequest.team_index_2', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10243,
  serialized_end=10381,
)


_CMSGDOTAFANTASYTEAMTRADECANCELRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamTradeCancelResponse',
  full_name='CMsgDOTAFantasyTeamTradeCancelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyTeamTradeCancelResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAFANTASYTEAMTRADECANCELRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10384,
  serialized_end=10590,
)


_CMSGDOTAFANTASYTEAMROSTERREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamRosterRequest',
  full_name='CMsgDOTAFantasyTeamRosterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyTeamRosterRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_index', full_name='CMsgDOTAFantasyTeamRosterRequest.team_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_account_id', full_name='CMsgDOTAFantasyTeamRosterRequest.owner_account_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgDOTAFantasyTeamRosterRequest.timestamp', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10592,
  serialized_end=10718,
)


_CMSGDOTAFANTASYTEAMROSTERRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyTeamRosterResponse',
  full_name='CMsgDOTAFantasyTeamRosterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyTeamRosterResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_account_ids', full_name='CMsgDOTAFantasyTeamRosterResponse.player_account_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_locked', full_name='CMsgDOTAFantasyTeamRosterResponse.player_locked', index=2,
      number=3, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAFANTASYTEAMROSTERRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10721,
  serialized_end=10979,
)


_CMSGDOTAFANTASYPLAYERHISORICALSTATSREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyPlayerHisoricalStatsRequest',
  full_name='CMsgDOTAFantasyPlayerHisoricalStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyPlayerHisoricalStatsRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10981,
  serialized_end=11052,
)


_CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_PLAYERSCOREACCUMULATOR = _descriptor.Descriptor(
  name='PlayerScoreAccumulator',
  full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator.matches', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='levels', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator.levels', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kills', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator.kills', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deaths', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator.deaths', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assists', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator.assists', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_hits', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator.last_hits', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='denies', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator.denies', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gpm', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator.gpm', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xppm', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator.xppm', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stuns', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator.stuns', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='healing', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator.healing', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tower_kills', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator.tower_kills', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='roshan_kills', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator.roshan_kills', index=12,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator.score', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11255,
  serialized_end=11512,
)

_CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_PLAYERSTATS = _descriptor.Descriptor(
  name='PlayerStats',
  full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerStats.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weeks', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerStats.weeks', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stats_premium', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerStats.stats_premium', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stats_professional', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerStats.stats_professional', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11515,
  serialized_end=11752,
)

_CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyPlayerHisoricalStatsResponse',
  full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stats', full_name='CMsgDOTAFantasyPlayerHisoricalStatsResponse.stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_PLAYERSCOREACCUMULATOR, _CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_PLAYERSTATS, ],
  enum_types=[
    _CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11055,
  serialized_end=11824,
)


_CMSGDOTAFANTASYMESSAGEADD = _descriptor.Descriptor(
  name='CMsgDOTAFantasyMessageAdd',
  full_name='CMsgDOTAFantasyMessageAdd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyMessageAdd.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='CMsgDOTAFantasyMessageAdd.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11826,
  serialized_end=11897,
)


_CMSGDOTAFANTASYMESSAGESREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyMessagesRequest',
  full_name='CMsgDOTAFantasyMessagesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyMessagesRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_message', full_name='CMsgDOTAFantasyMessagesRequest.start_message', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_message', full_name='CMsgDOTAFantasyMessagesRequest.end_message', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11899,
  serialized_end=12002,
)


_CMSGDOTAFANTASYMESSAGESRESPONSE_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='CMsgDOTAFantasyMessagesResponse.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='CMsgDOTAFantasyMessagesResponse.Message.message_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='CMsgDOTAFantasyMessagesResponse.Message.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='author_account_id', full_name='CMsgDOTAFantasyMessagesResponse.Message.author_account_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='CMsgDOTAFantasyMessagesResponse.Message.time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12195,
  serialized_end=12282,
)

_CMSGDOTAFANTASYMESSAGESRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyMessagesResponse',
  full_name='CMsgDOTAFantasyMessagesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyMessagesResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='messages', full_name='CMsgDOTAFantasyMessagesResponse.messages', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_total_messages', full_name='CMsgDOTAFantasyMessagesResponse.num_total_messages', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAFANTASYMESSAGESRESPONSE_MESSAGE, ],
  enum_types=[
    _CMSGDOTAFANTASYMESSAGESRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12005,
  serialized_end=12354,
)


_CMSGDOTAFANTASYREMOVEOWNER = _descriptor.Descriptor(
  name='CMsgDOTAFantasyRemoveOwner',
  full_name='CMsgDOTAFantasyRemoveOwner',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyRemoveOwner.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_account_id', full_name='CMsgDOTAFantasyRemoveOwner.owner_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_index', full_name='CMsgDOTAFantasyRemoveOwner.team_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12356,
  serialized_end=12457,
)


_CMSGDOTAFANTASYREMOVEOWNERRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyRemoveOwnerResponse',
  full_name='CMsgDOTAFantasyRemoveOwnerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyRemoveOwnerResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAFANTASYREMOVEOWNERRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12460,
  serialized_end=12687,
)


_CMSGDOTAFANTASYSCHEDULEDMATCHESREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyScheduledMatchesRequest',
  full_name='CMsgDOTAFantasyScheduledMatchesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyScheduledMatchesRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12689,
  serialized_end=12756,
)


_CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE_SCHEDULEDMATCHDAYS = _descriptor.Descriptor(
  name='ScheduledMatchDays',
  full_name='CMsgDOTAFantasyScheduledMatchesResponse.ScheduledMatchDays',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgDOTAFantasyScheduledMatchesResponse.ScheduledMatchDays.timestamp', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_ids', full_name='CMsgDOTAFantasyScheduledMatchesResponse.ScheduledMatchDays.team_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_ids', full_name='CMsgDOTAFantasyScheduledMatchesResponse.ScheduledMatchDays.league_ids', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12968,
  serialized_end=13045,
)

_CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyScheduledMatchesResponse',
  full_name='CMsgDOTAFantasyScheduledMatchesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyScheduledMatchesResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scheduled_match_days', full_name='CMsgDOTAFantasyScheduledMatchesResponse.scheduled_match_days', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE_SCHEDULEDMATCHDAYS, ],
  enum_types=[
    _CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12759,
  serialized_end=13092,
)


_CMSGDOTAFANTASYLEAVELEAGUEREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeaveLeagueRequest',
  full_name='CMsgDOTAFantasyLeaveLeagueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyLeaveLeagueRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fantasy_team_index', full_name='CMsgDOTAFantasyLeaveLeagueRequest.fantasy_team_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13094,
  serialized_end=13184,
)


_CMSGDOTAFANTASYLEAVELEAGUERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyLeaveLeagueResponse',
  full_name='CMsgDOTAFantasyLeaveLeagueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyLeaveLeagueResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAFANTASYLEAVELEAGUERESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13187,
  serialized_end=13414,
)


_CMSGDOTAFANTASYPLAYERSCOREDETAILSREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAFantasyPlayerScoreDetailsRequest',
  full_name='CMsgDOTAFantasyPlayerScoreDetailsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fantasy_league_id', full_name='CMsgDOTAFantasyPlayerScoreDetailsRequest.fantasy_league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_account_id', full_name='CMsgDOTAFantasyPlayerScoreDetailsRequest.player_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='CMsgDOTAFantasyPlayerScoreDetailsRequest.start_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='CMsgDOTAFantasyPlayerScoreDetailsRequest.end_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13417,
  serialized_end=13551,
)


_CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE_PLAYERMATCHDATA = _descriptor.Descriptor(
  name='PlayerMatchData',
  full_name='CMsgDOTAFantasyPlayerScoreDetailsResponse.PlayerMatchData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='CMsgDOTAFantasyPlayerScoreDetailsResponse.PlayerMatchData.match_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_id', full_name='CMsgDOTAFantasyPlayerScoreDetailsResponse.PlayerMatchData.series_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_num', full_name='CMsgDOTAFantasyPlayerScoreDetailsResponse.PlayerMatchData.series_num', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='series_type', full_name='CMsgDOTAFantasyPlayerScoreDetailsResponse.PlayerMatchData.series_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_tier', full_name='CMsgDOTAFantasyPlayerScoreDetailsResponse.PlayerMatchData.league_tier', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgDOTAFantasyPlayerScoreDetailsResponse.PlayerMatchData.league_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='opposing_team_id', full_name='CMsgDOTAFantasyPlayerScoreDetailsResponse.PlayerMatchData.opposing_team_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='opposing_team_logo', full_name='CMsgDOTAFantasyPlayerScoreDetailsResponse.PlayerMatchData.opposing_team_logo', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='opposing_team_name', full_name='CMsgDOTAFantasyPlayerScoreDetailsResponse.PlayerMatchData.opposing_team_name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owned_by', full_name='CMsgDOTAFantasyPlayerScoreDetailsResponse.PlayerMatchData.owned_by', index=9,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='benched', full_name='CMsgDOTAFantasyPlayerScoreDetailsResponse.PlayerMatchData.benched', index=10,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13751,
  serialized_end=14003,
)

_CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAFantasyPlayerScoreDetailsResponse',
  full_name='CMsgDOTAFantasyPlayerScoreDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAFantasyPlayerScoreDetailsResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='CMsgDOTAFantasyPlayerScoreDetailsResponse.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE_PLAYERMATCHDATA, ],
  enum_types=[
    _CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13554,
  serialized_end=14072,
)


_CMSGDOTAPASSPORTVOTETEAMGUESS = _descriptor.Descriptor(
  name='CMsgDOTAPassportVoteTeamGuess',
  full_name='CMsgDOTAPassportVoteTeamGuess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgDOTAPassportVoteTeamGuess.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='winner_id', full_name='CMsgDOTAPassportVoteTeamGuess.winner_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='runnerup_id', full_name='CMsgDOTAPassportVoteTeamGuess.runnerup_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14074,
  serialized_end=14164,
)


_CMSGDOTAPASSPORTVOTEGENERICSELECTION = _descriptor.Descriptor(
  name='CMsgDOTAPassportVoteGenericSelection',
  full_name='CMsgDOTAPassportVoteGenericSelection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selection_index', full_name='CMsgDOTAPassportVoteGenericSelection.selection_index', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='selection', full_name='CMsgDOTAPassportVoteGenericSelection.selection', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14167,
  serialized_end=14312,
)


_CMSGDOTAPASSPORTSTAMPEDPLAYER = _descriptor.Descriptor(
  name='CMsgDOTAPassportStampedPlayer',
  full_name='CMsgDOTAPassportStampedPlayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgDOTAPassportStampedPlayer.steam_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stamp_level', full_name='CMsgDOTAPassportStampedPlayer.stamp_level', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14314,
  serialized_end=14384,
)


_CMSGDOTAPASSPORTPLAYERCARDCHALLENGE = _descriptor.Descriptor(
  name='CMsgDOTAPassportPlayerCardChallenge',
  full_name='CMsgDOTAPassportPlayerCardChallenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='challenge_id', full_name='CMsgDOTAPassportPlayerCardChallenge.challenge_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14386,
  serialized_end=14445,
)


_CMSGDOTAPASSPORTVOTE = _descriptor.Descriptor(
  name='CMsgDOTAPassportVote',
  full_name='CMsgDOTAPassportVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team_votes', full_name='CMsgDOTAPassportVote.team_votes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='generic_selections', full_name='CMsgDOTAPassportVote.generic_selections', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stamped_players', full_name='CMsgDOTAPassportVote.stamped_players', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_card_challenges', full_name='CMsgDOTAPassportVote.player_card_challenges', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14448,
  serialized_end=14716,
)


_CMSGCLIENTTOGCGETPLAYERCARDROSTERREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCGetPlayerCardRosterRequest',
  full_name='CMsgClientToGCGetPlayerCardRosterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgClientToGCGetPlayerCardRosterRequest.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgClientToGCGetPlayerCardRosterRequest.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14718,
  serialized_end=14798,
)


_CMSGCLIENTTOGCGETPLAYERCARDROSTERRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCGetPlayerCardRosterResponse',
  full_name='CMsgClientToGCGetPlayerCardRosterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientToGCGetPlayerCardRosterResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_card_item_id', full_name='CMsgClientToGCGetPlayerCardRosterResponse.player_card_item_id', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgClientToGCGetPlayerCardRosterResponse.score', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='finalized', full_name='CMsgClientToGCGetPlayerCardRosterResponse.finalized', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentile', full_name='CMsgClientToGCGetPlayerCardRosterResponse.percentile', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCGETPLAYERCARDROSTERRESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14801,
  serialized_end=15107,
)


_CMSGCLIENTTOGCSETPLAYERCARDROSTERREQUEST = _descriptor.Descriptor(
  name='CMsgClientToGCSetPlayerCardRosterRequest',
  full_name='CMsgClientToGCSetPlayerCardRosterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CMsgClientToGCSetPlayerCardRosterRequest.league_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgClientToGCSetPlayerCardRosterRequest.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot', full_name='CMsgClientToGCSetPlayerCardRosterRequest.slot', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_card_item_id', full_name='CMsgClientToGCSetPlayerCardRosterRequest.player_card_item_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15109,
  serialized_end=15232,
)


_CMSGCLIENTTOGCSETPLAYERCARDROSTERRESPONSE = _descriptor.Descriptor(
  name='CMsgClientToGCSetPlayerCardRosterResponse',
  full_name='CMsgClientToGCSetPlayerCardRosterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientToGCSetPlayerCardRosterResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGCLIENTTOGCSETPLAYERCARDROSTERRESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15235,
  serialized_end=15601,
)

_CMSGGCPLAYERINFO_PLAYERINFO.containing_type = _CMSGGCPLAYERINFO
_CMSGGCPLAYERINFO_REGIONLEADERBOARD.containing_type = _CMSGGCPLAYERINFO
_CMSGGCPLAYERINFO.fields_by_name['player_infos'].message_type = _CMSGGCPLAYERINFO_PLAYERINFO
_CMSGGCPLAYERINFO.fields_by_name['leaderboards'].message_type = _CMSGGCPLAYERINFO_REGIONLEADERBOARD
_CMSGDOTACREATEFANTASYLEAGUEREQUEST.fields_by_name['selection_mode'].enum_type = dota__shared__enums__pb2._FANTASY_SELECTION_MODE
_CMSGDOTACREATEFANTASYLEAGUERESPONSE.fields_by_name['result'].enum_type = _CMSGDOTACREATEFANTASYLEAGUERESPONSE_ERESULT
_CMSGDOTACREATEFANTASYLEAGUERESPONSE_ERESULT.containing_type = _CMSGDOTACREATEFANTASYLEAGUERESPONSE
_CMSGDOTAFANTASYLEAGUEINFO_OWNERINFO.containing_type = _CMSGDOTAFANTASYLEAGUEINFO
_CMSGDOTAFANTASYLEAGUEINFO.fields_by_name['selection_mode'].enum_type = dota__shared__enums__pb2._FANTASY_SELECTION_MODE
_CMSGDOTAFANTASYLEAGUEINFO.fields_by_name['scoring'].message_type = _CMSGFANTASYLEAGUESCORING
_CMSGDOTAFANTASYLEAGUEINFO.fields_by_name['owner_info'].message_type = _CMSGDOTAFANTASYLEAGUEINFO_OWNERINFO
_CMSGDOTAFANTASYLEAGUEEDITINFOREQUEST.fields_by_name['edit_info'].message_type = _CMSGDOTAFANTASYLEAGUEINFO
_CMSGDOTAFANTASYLEAGUEEDITINFORESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYLEAGUEEDITINFORESPONSE_ERESULT
_CMSGDOTAFANTASYLEAGUEEDITINFORESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYLEAGUEEDITINFORESPONSE
_CMSGDOTAFANTASYLEAGUEFINDRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYLEAGUEFINDRESPONSE_ERESULT
_CMSGDOTAFANTASYLEAGUEFINDRESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYLEAGUEFINDRESPONSE
_CMSGDOTAFANTASYLEAGUEINFORESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYLEAGUEINFORESPONSE_ERESULT
_CMSGDOTAFANTASYLEAGUEINFORESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYLEAGUEINFORESPONSE
_CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE_MATCHUP.containing_type = _CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE
_CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE_WEEKLYMATCHUPS.fields_by_name['matchup'].message_type = _CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE_MATCHUP
_CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE_WEEKLYMATCHUPS.containing_type = _CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE
_CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE_ERESULT
_CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE.fields_by_name['weekly_matchups'].message_type = _CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE_WEEKLYMATCHUPS
_CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE
_CMSGDOTAEDITFANTASYTEAMRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAEDITFANTASYTEAMRESPONSE_ERESULT
_CMSGDOTAEDITFANTASYTEAMRESPONSE_ERESULT.containing_type = _CMSGDOTAEDITFANTASYTEAMRESPONSE
_CMSGDOTAFANTASYTEAMINFORESPONSE.fields_by_name['results'].message_type = _CMSGDOTAFANTASYTEAMINFO
_CMSGDOTAFANTASYTEAMSCORERESPONSE_CMSGPLAYERSCORE.containing_type = _CMSGDOTAFANTASYTEAMSCORERESPONSE
_CMSGDOTAFANTASYTEAMSCORERESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYTEAMSCORERESPONSE_ERESULT
_CMSGDOTAFANTASYTEAMSCORERESPONSE.fields_by_name['fantasy_player_score'].message_type = _CMSGDOTAFANTASYTEAMSCORERESPONSE_CMSGPLAYERSCORE
_CMSGDOTAFANTASYTEAMSCORERESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYTEAMSCORERESPONSE
_CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE_CMSGTEAMSCORE.containing_type = _CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE
_CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE_ERESULT
_CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE.fields_by_name['team_scores'].message_type = _CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE_CMSGTEAMSCORE
_CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE
_CMSGDOTAFANTASYPLAYERSCORERESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYPLAYERSCORERESPONSE_ERESULT
_CMSGDOTAFANTASYPLAYERSCORERESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYPLAYERSCORERESPONSE
_CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE_CMSGPLAYERSCORE.containing_type = _CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE
_CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE_ERESULT
_CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE.fields_by_name['player_scores'].message_type = _CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE_CMSGPLAYERSCORE
_CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE
_CMSGDOTAFANTASYPLAYERINFORESPONSE.fields_by_name['msg'].message_type = _CMSGGCPLAYERINFO
_CMSGDOTAFANTASYLEAGUECREATERESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYLEAGUECREATERESPONSE_ERESULT
_CMSGDOTAFANTASYLEAGUECREATERESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYLEAGUECREATERESPONSE
_CMSGDOTAFANTASYTEAMCREATERESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYTEAMCREATERESPONSE_ERESULT
_CMSGDOTAFANTASYTEAMCREATERESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYTEAMCREATERESPONSE
_CMSGDOTAFANTASYLEAGUEEDITINVITESREQUEST_INVITECHANGE.containing_type = _CMSGDOTAFANTASYLEAGUEEDITINVITESREQUEST
_CMSGDOTAFANTASYLEAGUEEDITINVITESREQUEST.fields_by_name['invite_change'].message_type = _CMSGDOTAFANTASYLEAGUEEDITINVITESREQUEST_INVITECHANGE
_CMSGDOTAFANTASYLEAGUEEDITINVITESRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYLEAGUEEDITINVITESRESPONSE_ERESULT
_CMSGDOTAFANTASYLEAGUEEDITINVITESRESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYLEAGUEEDITINVITESRESPONSE
_CMSGDOTAFANTASYLEAGUEDRAFTPLAYERRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYLEAGUEDRAFTPLAYERRESPONSE_ERESULT
_CMSGDOTAFANTASYLEAGUEDRAFTPLAYERRESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYLEAGUEDRAFTPLAYERRESPONSE
_CMSGDOTAFANTASYTEAMROSTERSWAPRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYTEAMROSTERSWAPRESPONSE_ERESULT
_CMSGDOTAFANTASYTEAMROSTERSWAPRESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYTEAMROSTERSWAPRESPONSE
_CMSGDOTAFANTASYTEAMROSTERADDDROPRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYTEAMROSTERADDDROPRESPONSE_ERESULT
_CMSGDOTAFANTASYTEAMROSTERADDDROPRESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYTEAMROSTERADDDROPRESPONSE
_CMSGDOTAFANTASYTEAMTRADESRESPONSE_TRADE.containing_type = _CMSGDOTAFANTASYTEAMTRADESRESPONSE
_CMSGDOTAFANTASYTEAMTRADESRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYTEAMTRADESRESPONSE_ERESULT
_CMSGDOTAFANTASYTEAMTRADESRESPONSE.fields_by_name['trades'].message_type = _CMSGDOTAFANTASYTEAMTRADESRESPONSE_TRADE
_CMSGDOTAFANTASYTEAMTRADESRESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYTEAMTRADESRESPONSE
_CMSGDOTAFANTASYTEAMTRADECANCELRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYTEAMTRADECANCELRESPONSE_ERESULT
_CMSGDOTAFANTASYTEAMTRADECANCELRESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYTEAMTRADECANCELRESPONSE
_CMSGDOTAFANTASYTEAMROSTERRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYTEAMROSTERRESPONSE_ERESULT
_CMSGDOTAFANTASYTEAMROSTERRESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYTEAMROSTERRESPONSE
_CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_PLAYERSCOREACCUMULATOR.containing_type = _CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE
_CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_PLAYERSTATS.fields_by_name['stats_premium'].message_type = _CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_PLAYERSCOREACCUMULATOR
_CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_PLAYERSTATS.fields_by_name['stats_professional'].message_type = _CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_PLAYERSCOREACCUMULATOR
_CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_PLAYERSTATS.containing_type = _CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE
_CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_ERESULT
_CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE.fields_by_name['stats'].message_type = _CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_PLAYERSTATS
_CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE
_CMSGDOTAFANTASYMESSAGESRESPONSE_MESSAGE.containing_type = _CMSGDOTAFANTASYMESSAGESRESPONSE
_CMSGDOTAFANTASYMESSAGESRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYMESSAGESRESPONSE_ERESULT
_CMSGDOTAFANTASYMESSAGESRESPONSE.fields_by_name['messages'].message_type = _CMSGDOTAFANTASYMESSAGESRESPONSE_MESSAGE
_CMSGDOTAFANTASYMESSAGESRESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYMESSAGESRESPONSE
_CMSGDOTAFANTASYREMOVEOWNERRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYREMOVEOWNERRESPONSE_ERESULT
_CMSGDOTAFANTASYREMOVEOWNERRESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYREMOVEOWNERRESPONSE
_CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE_SCHEDULEDMATCHDAYS.containing_type = _CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE
_CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE_ERESULT
_CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE.fields_by_name['scheduled_match_days'].message_type = _CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE_SCHEDULEDMATCHDAYS
_CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE
_CMSGDOTAFANTASYLEAVELEAGUERESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYLEAVELEAGUERESPONSE_ERESULT
_CMSGDOTAFANTASYLEAVELEAGUERESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYLEAVELEAGUERESPONSE
_CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE_PLAYERMATCHDATA.containing_type = _CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE
_CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE_ERESULT
_CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE.fields_by_name['data'].message_type = _CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE_PLAYERMATCHDATA
_CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE_ERESULT.containing_type = _CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE
_CMSGDOTAPASSPORTVOTEGENERICSELECTION.fields_by_name['selection_index'].enum_type = _DOTA_2013PASSPORTSELECTIONINDICES
_CMSGDOTAPASSPORTVOTE.fields_by_name['team_votes'].message_type = _CMSGDOTAPASSPORTVOTETEAMGUESS
_CMSGDOTAPASSPORTVOTE.fields_by_name['generic_selections'].message_type = _CMSGDOTAPASSPORTVOTEGENERICSELECTION
_CMSGDOTAPASSPORTVOTE.fields_by_name['stamped_players'].message_type = _CMSGDOTAPASSPORTSTAMPEDPLAYER
_CMSGDOTAPASSPORTVOTE.fields_by_name['player_card_challenges'].message_type = _CMSGDOTAPASSPORTPLAYERCARDCHALLENGE
_CMSGCLIENTTOGCGETPLAYERCARDROSTERRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCGETPLAYERCARDROSTERRESPONSE_RESULT
_CMSGCLIENTTOGCGETPLAYERCARDROSTERRESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCGETPLAYERCARDROSTERRESPONSE
_CMSGCLIENTTOGCSETPLAYERCARDROSTERRESPONSE.fields_by_name['result'].enum_type = _CMSGCLIENTTOGCSETPLAYERCARDROSTERRESPONSE_RESULT
_CMSGCLIENTTOGCSETPLAYERCARDROSTERRESPONSE_RESULT.containing_type = _CMSGCLIENTTOGCSETPLAYERCARDROSTERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCPlayerInfo'] = _CMSGGCPLAYERINFO
DESCRIPTOR.message_types_by_name['CMsgDOTACreateFantasyLeagueRequest'] = _CMSGDOTACREATEFANTASYLEAGUEREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTACreateFantasyLeagueResponse'] = _CMSGDOTACREATEFANTASYLEAGUERESPONSE
DESCRIPTOR.message_types_by_name['CMsgFantasyLeagueScoring'] = _CMSGFANTASYLEAGUESCORING
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueInfo'] = _CMSGDOTAFANTASYLEAGUEINFO
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueEditInfoRequest'] = _CMSGDOTAFANTASYLEAGUEEDITINFOREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueEditInfoResponse'] = _CMSGDOTAFANTASYLEAGUEEDITINFORESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueFindRequest'] = _CMSGDOTAFANTASYLEAGUEFINDREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueFindResponse'] = _CMSGDOTAFANTASYLEAGUEFINDRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueInfoRequest'] = _CMSGDOTAFANTASYLEAGUEINFOREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueInfoResponse'] = _CMSGDOTAFANTASYLEAGUEINFORESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueMatchupsRequest'] = _CMSGDOTAFANTASYLEAGUEMATCHUPSREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueMatchupsResponse'] = _CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAEditFantasyTeamRequest'] = _CMSGDOTAEDITFANTASYTEAMREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAEditFantasyTeamResponse'] = _CMSGDOTAEDITFANTASYTEAMRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamInfoRequestByFantasyLeagueID'] = _CMSGDOTAFANTASYTEAMINFOREQUESTBYFANTASYLEAGUEID
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamInfoRequestByOwnerAccountID'] = _CMSGDOTAFANTASYTEAMINFOREQUESTBYOWNERACCOUNTID
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamInfoResponse'] = _CMSGDOTAFANTASYTEAMINFORESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamInfo'] = _CMSGDOTAFANTASYTEAMINFO
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamScoreRequest'] = _CMSGDOTAFANTASYTEAMSCOREREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamScoreResponse'] = _CMSGDOTAFANTASYTEAMSCORERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamStandingsRequest'] = _CMSGDOTAFANTASYTEAMSTANDINGSREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamStandingsResponse'] = _CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyPlayerScoreRequest'] = _CMSGDOTAFANTASYPLAYERSCOREREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyPlayerScoreResponse'] = _CMSGDOTAFANTASYPLAYERSCORERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyPlayerStandingsRequest'] = _CMSGDOTAFANTASYPLAYERSTANDINGSREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyPlayerStandingsResponse'] = _CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyPlayerInfoRequest'] = _CMSGDOTAFANTASYPLAYERINFOREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyPlayerInfoResponse'] = _CMSGDOTAFANTASYPLAYERINFORESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueCreateRequest'] = _CMSGDOTAFANTASYLEAGUECREATEREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueCreateResponse'] = _CMSGDOTAFANTASYLEAGUECREATERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamCreateRequest'] = _CMSGDOTAFANTASYTEAMCREATEREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamCreateResponse'] = _CMSGDOTAFANTASYTEAMCREATERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueEditInvitesRequest'] = _CMSGDOTAFANTASYLEAGUEEDITINVITESREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueEditInvitesResponse'] = _CMSGDOTAFANTASYLEAGUEEDITINVITESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueDraftStatusRequest'] = _CMSGDOTAFANTASYLEAGUEDRAFTSTATUSREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueDraftStatus'] = _CMSGDOTAFANTASYLEAGUEDRAFTSTATUS
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueDraftPlayerRequest'] = _CMSGDOTAFANTASYLEAGUEDRAFTPLAYERREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeagueDraftPlayerResponse'] = _CMSGDOTAFANTASYLEAGUEDRAFTPLAYERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamRosterSwapRequest'] = _CMSGDOTAFANTASYTEAMROSTERSWAPREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamRosterSwapResponse'] = _CMSGDOTAFANTASYTEAMROSTERSWAPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamRosterAddDropRequest'] = _CMSGDOTAFANTASYTEAMROSTERADDDROPREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamRosterAddDropResponse'] = _CMSGDOTAFANTASYTEAMROSTERADDDROPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamTradesRequest'] = _CMSGDOTAFANTASYTEAMTRADESREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamTradesResponse'] = _CMSGDOTAFANTASYTEAMTRADESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamTradeCancelRequest'] = _CMSGDOTAFANTASYTEAMTRADECANCELREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamTradeCancelResponse'] = _CMSGDOTAFANTASYTEAMTRADECANCELRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamRosterRequest'] = _CMSGDOTAFANTASYTEAMROSTERREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyTeamRosterResponse'] = _CMSGDOTAFANTASYTEAMROSTERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyPlayerHisoricalStatsRequest'] = _CMSGDOTAFANTASYPLAYERHISORICALSTATSREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyPlayerHisoricalStatsResponse'] = _CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyMessageAdd'] = _CMSGDOTAFANTASYMESSAGEADD
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyMessagesRequest'] = _CMSGDOTAFANTASYMESSAGESREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyMessagesResponse'] = _CMSGDOTAFANTASYMESSAGESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyRemoveOwner'] = _CMSGDOTAFANTASYREMOVEOWNER
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyRemoveOwnerResponse'] = _CMSGDOTAFANTASYREMOVEOWNERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyScheduledMatchesRequest'] = _CMSGDOTAFANTASYSCHEDULEDMATCHESREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyScheduledMatchesResponse'] = _CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeaveLeagueRequest'] = _CMSGDOTAFANTASYLEAVELEAGUEREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyLeaveLeagueResponse'] = _CMSGDOTAFANTASYLEAVELEAGUERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyPlayerScoreDetailsRequest'] = _CMSGDOTAFANTASYPLAYERSCOREDETAILSREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAFantasyPlayerScoreDetailsResponse'] = _CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAPassportVoteTeamGuess'] = _CMSGDOTAPASSPORTVOTETEAMGUESS
DESCRIPTOR.message_types_by_name['CMsgDOTAPassportVoteGenericSelection'] = _CMSGDOTAPASSPORTVOTEGENERICSELECTION
DESCRIPTOR.message_types_by_name['CMsgDOTAPassportStampedPlayer'] = _CMSGDOTAPASSPORTSTAMPEDPLAYER
DESCRIPTOR.message_types_by_name['CMsgDOTAPassportPlayerCardChallenge'] = _CMSGDOTAPASSPORTPLAYERCARDCHALLENGE
DESCRIPTOR.message_types_by_name['CMsgDOTAPassportVote'] = _CMSGDOTAPASSPORTVOTE
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetPlayerCardRosterRequest'] = _CMSGCLIENTTOGCGETPLAYERCARDROSTERREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCGetPlayerCardRosterResponse'] = _CMSGCLIENTTOGCGETPLAYERCARDROSTERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientToGCSetPlayerCardRosterRequest'] = _CMSGCLIENTTOGCSETPLAYERCARDROSTERREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientToGCSetPlayerCardRosterResponse'] = _CMSGCLIENTTOGCSETPLAYERCARDROSTERRESPONSE
DESCRIPTOR.enum_types_by_name['DOTA_2013PassportSelectionIndices'] = _DOTA_2013PASSPORTSELECTIONINDICES

CMsgGCPlayerInfo = _reflection.GeneratedProtocolMessageType('CMsgGCPlayerInfo', (_message.Message,), dict(

  PlayerInfo = _reflection.GeneratedProtocolMessageType('PlayerInfo', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCPLAYERINFO_PLAYERINFO,
    __module__ = 'dota_gcmessages_client_fantasy_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCPlayerInfo.PlayerInfo)
    ))
  ,

  RegionLeaderboard = _reflection.GeneratedProtocolMessageType('RegionLeaderboard', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCPLAYERINFO_REGIONLEADERBOARD,
    __module__ = 'dota_gcmessages_client_fantasy_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGCPlayerInfo.RegionLeaderboard)
    ))
  ,
  DESCRIPTOR = _CMSGGCPLAYERINFO,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCPlayerInfo)
  ))
_sym_db.RegisterMessage(CMsgGCPlayerInfo)
_sym_db.RegisterMessage(CMsgGCPlayerInfo.PlayerInfo)
_sym_db.RegisterMessage(CMsgGCPlayerInfo.RegionLeaderboard)

CMsgDOTACreateFantasyLeagueRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTACreateFantasyLeagueRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACREATEFANTASYLEAGUEREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTACreateFantasyLeagueRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTACreateFantasyLeagueRequest)

CMsgDOTACreateFantasyLeagueResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTACreateFantasyLeagueResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACREATEFANTASYLEAGUERESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTACreateFantasyLeagueResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTACreateFantasyLeagueResponse)

CMsgFantasyLeagueScoring = _reflection.GeneratedProtocolMessageType('CMsgFantasyLeagueScoring', (_message.Message,), dict(
  DESCRIPTOR = _CMSGFANTASYLEAGUESCORING,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgFantasyLeagueScoring)
  ))
_sym_db.RegisterMessage(CMsgFantasyLeagueScoring)

CMsgDOTAFantasyLeagueInfo = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueInfo', (_message.Message,), dict(

  OwnerInfo = _reflection.GeneratedProtocolMessageType('OwnerInfo', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEINFO_OWNERINFO,
    __module__ = 'dota_gcmessages_client_fantasy_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueInfo.OwnerInfo)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEINFO,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueInfo)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueInfo)
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueInfo.OwnerInfo)

CMsgDOTAFantasyLeagueEditInfoRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueEditInfoRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEEDITINFOREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueEditInfoRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueEditInfoRequest)

CMsgDOTAFantasyLeagueEditInfoResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueEditInfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEEDITINFORESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueEditInfoResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueEditInfoResponse)

CMsgDOTAFantasyLeagueFindRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueFindRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEFINDREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueFindRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueFindRequest)

CMsgDOTAFantasyLeagueFindResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueFindResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEFINDRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueFindResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueFindResponse)

CMsgDOTAFantasyLeagueInfoRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueInfoRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEINFOREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueInfoRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueInfoRequest)

CMsgDOTAFantasyLeagueInfoResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueInfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEINFORESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueInfoResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueInfoResponse)

CMsgDOTAFantasyLeagueMatchupsRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueMatchupsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEMATCHUPSREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueMatchupsRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueMatchupsRequest)

CMsgDOTAFantasyLeagueMatchupsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueMatchupsResponse', (_message.Message,), dict(

  Matchup = _reflection.GeneratedProtocolMessageType('Matchup', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE_MATCHUP,
    __module__ = 'dota_gcmessages_client_fantasy_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueMatchupsResponse.Matchup)
    ))
  ,

  WeeklyMatchups = _reflection.GeneratedProtocolMessageType('WeeklyMatchups', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE_WEEKLYMATCHUPS,
    __module__ = 'dota_gcmessages_client_fantasy_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueMatchupsResponse.WeeklyMatchups)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEMATCHUPSRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueMatchupsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueMatchupsResponse)
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueMatchupsResponse.Matchup)
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueMatchupsResponse.WeeklyMatchups)

CMsgDOTAEditFantasyTeamRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAEditFantasyTeamRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAEDITFANTASYTEAMREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAEditFantasyTeamRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAEditFantasyTeamRequest)

CMsgDOTAEditFantasyTeamResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAEditFantasyTeamResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAEDITFANTASYTEAMRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAEditFantasyTeamResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAEditFantasyTeamResponse)

CMsgDOTAFantasyTeamInfoRequestByFantasyLeagueID = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamInfoRequestByFantasyLeagueID', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMINFOREQUESTBYFANTASYLEAGUEID,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamInfoRequestByFantasyLeagueID)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamInfoRequestByFantasyLeagueID)

CMsgDOTAFantasyTeamInfoRequestByOwnerAccountID = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamInfoRequestByOwnerAccountID', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMINFOREQUESTBYOWNERACCOUNTID,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamInfoRequestByOwnerAccountID)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamInfoRequestByOwnerAccountID)

CMsgDOTAFantasyTeamInfoResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamInfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMINFORESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamInfoResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamInfoResponse)

CMsgDOTAFantasyTeamInfo = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMINFO,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamInfo)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamInfo)

CMsgDOTAFantasyTeamScoreRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamScoreRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMSCOREREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamScoreRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamScoreRequest)

CMsgDOTAFantasyTeamScoreResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamScoreResponse', (_message.Message,), dict(

  CMsgPlayerScore = _reflection.GeneratedProtocolMessageType('CMsgPlayerScore', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAFANTASYTEAMSCORERESPONSE_CMSGPLAYERSCORE,
    __module__ = 'dota_gcmessages_client_fantasy_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamScoreResponse.CMsgPlayerScore)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMSCORERESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamScoreResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamScoreResponse)
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamScoreResponse.CMsgPlayerScore)

CMsgDOTAFantasyTeamStandingsRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamStandingsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMSTANDINGSREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamStandingsRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamStandingsRequest)

CMsgDOTAFantasyTeamStandingsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamStandingsResponse', (_message.Message,), dict(

  CMsgTeamScore = _reflection.GeneratedProtocolMessageType('CMsgTeamScore', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE_CMSGTEAMSCORE,
    __module__ = 'dota_gcmessages_client_fantasy_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamStandingsResponse.CMsgTeamScore)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMSTANDINGSRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamStandingsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamStandingsResponse)
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamStandingsResponse.CMsgTeamScore)

CMsgDOTAFantasyPlayerScoreRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyPlayerScoreRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYPLAYERSCOREREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyPlayerScoreRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyPlayerScoreRequest)

CMsgDOTAFantasyPlayerScoreResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyPlayerScoreResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYPLAYERSCORERESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyPlayerScoreResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyPlayerScoreResponse)

CMsgDOTAFantasyPlayerStandingsRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyPlayerStandingsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYPLAYERSTANDINGSREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyPlayerStandingsRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyPlayerStandingsRequest)

CMsgDOTAFantasyPlayerStandingsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyPlayerStandingsResponse', (_message.Message,), dict(

  CMsgPlayerScore = _reflection.GeneratedProtocolMessageType('CMsgPlayerScore', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE_CMSGPLAYERSCORE,
    __module__ = 'dota_gcmessages_client_fantasy_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyPlayerStandingsResponse.CMsgPlayerScore)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAFANTASYPLAYERSTANDINGSRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyPlayerStandingsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyPlayerStandingsResponse)
_sym_db.RegisterMessage(CMsgDOTAFantasyPlayerStandingsResponse.CMsgPlayerScore)

CMsgDOTAFantasyPlayerInfoRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyPlayerInfoRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYPLAYERINFOREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyPlayerInfoRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyPlayerInfoRequest)

CMsgDOTAFantasyPlayerInfoResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyPlayerInfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYPLAYERINFORESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyPlayerInfoResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyPlayerInfoResponse)

CMsgDOTAFantasyLeagueCreateRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueCreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUECREATEREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueCreateRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueCreateRequest)

CMsgDOTAFantasyLeagueCreateResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueCreateResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUECREATERESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueCreateResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueCreateResponse)

CMsgDOTAFantasyTeamCreateRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamCreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMCREATEREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamCreateRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamCreateRequest)

CMsgDOTAFantasyTeamCreateResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamCreateResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMCREATERESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamCreateResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamCreateResponse)

CMsgDOTAFantasyLeagueEditInvitesRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueEditInvitesRequest', (_message.Message,), dict(

  InviteChange = _reflection.GeneratedProtocolMessageType('InviteChange', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEEDITINVITESREQUEST_INVITECHANGE,
    __module__ = 'dota_gcmessages_client_fantasy_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueEditInvitesRequest.InviteChange)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEEDITINVITESREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueEditInvitesRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueEditInvitesRequest)
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueEditInvitesRequest.InviteChange)

CMsgDOTAFantasyLeagueEditInvitesResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueEditInvitesResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEEDITINVITESRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueEditInvitesResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueEditInvitesResponse)

CMsgDOTAFantasyLeagueDraftStatusRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueDraftStatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEDRAFTSTATUSREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueDraftStatusRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueDraftStatusRequest)

CMsgDOTAFantasyLeagueDraftStatus = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueDraftStatus', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEDRAFTSTATUS,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueDraftStatus)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueDraftStatus)

CMsgDOTAFantasyLeagueDraftPlayerRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueDraftPlayerRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEDRAFTPLAYERREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueDraftPlayerRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueDraftPlayerRequest)

CMsgDOTAFantasyLeagueDraftPlayerResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeagueDraftPlayerResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYLEAGUEDRAFTPLAYERRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeagueDraftPlayerResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeagueDraftPlayerResponse)

CMsgDOTAFantasyTeamRosterSwapRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamRosterSwapRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMROSTERSWAPREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamRosterSwapRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamRosterSwapRequest)

CMsgDOTAFantasyTeamRosterSwapResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamRosterSwapResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMROSTERSWAPRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamRosterSwapResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamRosterSwapResponse)

CMsgDOTAFantasyTeamRosterAddDropRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamRosterAddDropRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMROSTERADDDROPREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamRosterAddDropRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamRosterAddDropRequest)

CMsgDOTAFantasyTeamRosterAddDropResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamRosterAddDropResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMROSTERADDDROPRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamRosterAddDropResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamRosterAddDropResponse)

CMsgDOTAFantasyTeamTradesRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamTradesRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMTRADESREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamTradesRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamTradesRequest)

CMsgDOTAFantasyTeamTradesResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamTradesResponse', (_message.Message,), dict(

  Trade = _reflection.GeneratedProtocolMessageType('Trade', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAFANTASYTEAMTRADESRESPONSE_TRADE,
    __module__ = 'dota_gcmessages_client_fantasy_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamTradesResponse.Trade)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMTRADESRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamTradesResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamTradesResponse)
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamTradesResponse.Trade)

CMsgDOTAFantasyTeamTradeCancelRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamTradeCancelRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMTRADECANCELREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamTradeCancelRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamTradeCancelRequest)

CMsgDOTAFantasyTeamTradeCancelResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamTradeCancelResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMTRADECANCELRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamTradeCancelResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamTradeCancelResponse)

CMsgDOTAFantasyTeamRosterRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamRosterRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMROSTERREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamRosterRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamRosterRequest)

CMsgDOTAFantasyTeamRosterResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyTeamRosterResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYTEAMROSTERRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyTeamRosterResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyTeamRosterResponse)

CMsgDOTAFantasyPlayerHisoricalStatsRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyPlayerHisoricalStatsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYPLAYERHISORICALSTATSREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyPlayerHisoricalStatsRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyPlayerHisoricalStatsRequest)

CMsgDOTAFantasyPlayerHisoricalStatsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyPlayerHisoricalStatsResponse', (_message.Message,), dict(

  PlayerScoreAccumulator = _reflection.GeneratedProtocolMessageType('PlayerScoreAccumulator', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_PLAYERSCOREACCUMULATOR,
    __module__ = 'dota_gcmessages_client_fantasy_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator)
    ))
  ,

  PlayerStats = _reflection.GeneratedProtocolMessageType('PlayerStats', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE_PLAYERSTATS,
    __module__ = 'dota_gcmessages_client_fantasy_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerStats)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAFANTASYPLAYERHISORICALSTATSRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyPlayerHisoricalStatsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyPlayerHisoricalStatsResponse)
_sym_db.RegisterMessage(CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerScoreAccumulator)
_sym_db.RegisterMessage(CMsgDOTAFantasyPlayerHisoricalStatsResponse.PlayerStats)

CMsgDOTAFantasyMessageAdd = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyMessageAdd', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYMESSAGEADD,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyMessageAdd)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyMessageAdd)

CMsgDOTAFantasyMessagesRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyMessagesRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYMESSAGESREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyMessagesRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyMessagesRequest)

CMsgDOTAFantasyMessagesResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyMessagesResponse', (_message.Message,), dict(

  Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAFANTASYMESSAGESRESPONSE_MESSAGE,
    __module__ = 'dota_gcmessages_client_fantasy_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyMessagesResponse.Message)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAFANTASYMESSAGESRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyMessagesResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyMessagesResponse)
_sym_db.RegisterMessage(CMsgDOTAFantasyMessagesResponse.Message)

CMsgDOTAFantasyRemoveOwner = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyRemoveOwner', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYREMOVEOWNER,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyRemoveOwner)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyRemoveOwner)

CMsgDOTAFantasyRemoveOwnerResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyRemoveOwnerResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYREMOVEOWNERRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyRemoveOwnerResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyRemoveOwnerResponse)

CMsgDOTAFantasyScheduledMatchesRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyScheduledMatchesRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYSCHEDULEDMATCHESREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyScheduledMatchesRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyScheduledMatchesRequest)

CMsgDOTAFantasyScheduledMatchesResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyScheduledMatchesResponse', (_message.Message,), dict(

  ScheduledMatchDays = _reflection.GeneratedProtocolMessageType('ScheduledMatchDays', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE_SCHEDULEDMATCHDAYS,
    __module__ = 'dota_gcmessages_client_fantasy_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyScheduledMatchesResponse.ScheduledMatchDays)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAFANTASYSCHEDULEDMATCHESRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyScheduledMatchesResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyScheduledMatchesResponse)
_sym_db.RegisterMessage(CMsgDOTAFantasyScheduledMatchesResponse.ScheduledMatchDays)

CMsgDOTAFantasyLeaveLeagueRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeaveLeagueRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYLEAVELEAGUEREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeaveLeagueRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeaveLeagueRequest)

CMsgDOTAFantasyLeaveLeagueResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyLeaveLeagueResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYLEAVELEAGUERESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyLeaveLeagueResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyLeaveLeagueResponse)

CMsgDOTAFantasyPlayerScoreDetailsRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyPlayerScoreDetailsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAFANTASYPLAYERSCOREDETAILSREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyPlayerScoreDetailsRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyPlayerScoreDetailsRequest)

CMsgDOTAFantasyPlayerScoreDetailsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAFantasyPlayerScoreDetailsResponse', (_message.Message,), dict(

  PlayerMatchData = _reflection.GeneratedProtocolMessageType('PlayerMatchData', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE_PLAYERMATCHDATA,
    __module__ = 'dota_gcmessages_client_fantasy_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyPlayerScoreDetailsResponse.PlayerMatchData)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAFANTASYPLAYERSCOREDETAILSRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAFantasyPlayerScoreDetailsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAFantasyPlayerScoreDetailsResponse)
_sym_db.RegisterMessage(CMsgDOTAFantasyPlayerScoreDetailsResponse.PlayerMatchData)

CMsgDOTAPassportVoteTeamGuess = _reflection.GeneratedProtocolMessageType('CMsgDOTAPassportVoteTeamGuess', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPASSPORTVOTETEAMGUESS,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAPassportVoteTeamGuess)
  ))
_sym_db.RegisterMessage(CMsgDOTAPassportVoteTeamGuess)

CMsgDOTAPassportVoteGenericSelection = _reflection.GeneratedProtocolMessageType('CMsgDOTAPassportVoteGenericSelection', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPASSPORTVOTEGENERICSELECTION,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAPassportVoteGenericSelection)
  ))
_sym_db.RegisterMessage(CMsgDOTAPassportVoteGenericSelection)

CMsgDOTAPassportStampedPlayer = _reflection.GeneratedProtocolMessageType('CMsgDOTAPassportStampedPlayer', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPASSPORTSTAMPEDPLAYER,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAPassportStampedPlayer)
  ))
_sym_db.RegisterMessage(CMsgDOTAPassportStampedPlayer)

CMsgDOTAPassportPlayerCardChallenge = _reflection.GeneratedProtocolMessageType('CMsgDOTAPassportPlayerCardChallenge', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPASSPORTPLAYERCARDCHALLENGE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAPassportPlayerCardChallenge)
  ))
_sym_db.RegisterMessage(CMsgDOTAPassportPlayerCardChallenge)

CMsgDOTAPassportVote = _reflection.GeneratedProtocolMessageType('CMsgDOTAPassportVote', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPASSPORTVOTE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAPassportVote)
  ))
_sym_db.RegisterMessage(CMsgDOTAPassportVote)

CMsgClientToGCGetPlayerCardRosterRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetPlayerCardRosterRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETPLAYERCARDROSTERREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetPlayerCardRosterRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetPlayerCardRosterRequest)

CMsgClientToGCGetPlayerCardRosterResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCGetPlayerCardRosterResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCGETPLAYERCARDROSTERRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCGetPlayerCardRosterResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCGetPlayerCardRosterResponse)

CMsgClientToGCSetPlayerCardRosterRequest = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSetPlayerCardRosterRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSETPLAYERCARDROSTERREQUEST,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCSetPlayerCardRosterRequest)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSetPlayerCardRosterRequest)

CMsgClientToGCSetPlayerCardRosterResponse = _reflection.GeneratedProtocolMessageType('CMsgClientToGCSetPlayerCardRosterResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTOGCSETPLAYERCARDROSTERRESPONSE,
  __module__ = 'dota_gcmessages_client_fantasy_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientToGCSetPlayerCardRosterResponse)
  ))
_sym_db.RegisterMessage(CMsgClientToGCSetPlayerCardRosterResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
# @@protoc_insertion_point(module_scope)
